#' AWS App Runner
#'
#' @description
#' App Runner
#' 
#' App Runner is an application service that provides a fast, simple, and
#' cost-effective way to go directly from an existing container image or
#' source code to a running service in the Amazon Web Services Cloud in
#' seconds. You don't need to learn new technologies, decide which compute
#' service to use, or understand how to provision and configure Amazon Web
#' Services resources.
#' 
#' App Runner connects directly to your container registry or source code
#' repository. It provides an automatic delivery pipeline with fully
#' managed operations, high performance, scalability, and security.
#' 
#' For more information about App Runner, see the [App Runner Developer
#' Guide](https://docs.aws.amazon.com/apprunner/latest/dg/). For release
#' information, see the [App Runner Release
#' Notes](https://docs.aws.amazon.com/apprunner/latest/relnotes/).
#' 
#' To install the Software Development Kits (SDKs), Integrated Development
#' Environment (IDE) Toolkits, and command line tools that you can use to
#' access the API, see [Tools for Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#' 
#' **Endpoints**
#' 
#' For a list of Region-specific endpoints that App Runner supports, see
#' [App Runner endpoints and
#' quotas](https://docs.aws.amazon.com/general/latest/gr/apprunner.html) in
#' the *Amazon Web Services General Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- apprunner(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- apprunner()
#' svc$associate_custom_domain(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:apprunner_associate_custom_domain]{associate_custom_domain} \tab Associate your own domain name with the App Runner subdomain URL of your App Runner service\cr
#'  \link[paws.compute:apprunner_create_auto_scaling_configuration]{create_auto_scaling_configuration} \tab Create an App Runner automatic scaling configuration resource\cr
#'  \link[paws.compute:apprunner_create_connection]{create_connection} \tab Create an App Runner connection resource\cr
#'  \link[paws.compute:apprunner_create_observability_configuration]{create_observability_configuration} \tab Create an App Runner observability configuration resource\cr
#'  \link[paws.compute:apprunner_create_service]{create_service} \tab Create an App Runner service\cr
#'  \link[paws.compute:apprunner_create_vpc_connector]{create_vpc_connector} \tab Create an App Runner VPC connector resource\cr
#'  \link[paws.compute:apprunner_create_vpc_ingress_connection]{create_vpc_ingress_connection} \tab Create an App Runner VPC Ingress Connection resource\cr
#'  \link[paws.compute:apprunner_delete_auto_scaling_configuration]{delete_auto_scaling_configuration} \tab Delete an App Runner automatic scaling configuration resource\cr
#'  \link[paws.compute:apprunner_delete_connection]{delete_connection} \tab Delete an App Runner connection\cr
#'  \link[paws.compute:apprunner_delete_observability_configuration]{delete_observability_configuration} \tab Delete an App Runner observability configuration resource\cr
#'  \link[paws.compute:apprunner_delete_service]{delete_service} \tab Delete an App Runner service\cr
#'  \link[paws.compute:apprunner_delete_vpc_connector]{delete_vpc_connector} \tab Delete an App Runner VPC connector resource\cr
#'  \link[paws.compute:apprunner_delete_vpc_ingress_connection]{delete_vpc_ingress_connection} \tab Delete an App Runner VPC Ingress Connection resource that's associated with an App Runner service\cr
#'  \link[paws.compute:apprunner_describe_auto_scaling_configuration]{describe_auto_scaling_configuration} \tab Return a full description of an App Runner automatic scaling configuration resource\cr
#'  \link[paws.compute:apprunner_describe_custom_domains]{describe_custom_domains} \tab Return a description of custom domain names that are associated with an App Runner service\cr
#'  \link[paws.compute:apprunner_describe_observability_configuration]{describe_observability_configuration} \tab Return a full description of an App Runner observability configuration resource\cr
#'  \link[paws.compute:apprunner_describe_service]{describe_service} \tab Return a full description of an App Runner service\cr
#'  \link[paws.compute:apprunner_describe_vpc_connector]{describe_vpc_connector} \tab Return a description of an App Runner VPC connector resource\cr
#'  \link[paws.compute:apprunner_describe_vpc_ingress_connection]{describe_vpc_ingress_connection} \tab Return a full description of an App Runner VPC Ingress Connection resource\cr
#'  \link[paws.compute:apprunner_disassociate_custom_domain]{disassociate_custom_domain} \tab Disassociate a custom domain name from an App Runner service\cr
#'  \link[paws.compute:apprunner_list_auto_scaling_configurations]{list_auto_scaling_configurations} \tab Returns a list of active App Runner automatic scaling configurations in your Amazon Web Services account\cr
#'  \link[paws.compute:apprunner_list_connections]{list_connections} \tab Returns a list of App Runner connections that are associated with your Amazon Web Services account\cr
#'  \link[paws.compute:apprunner_list_observability_configurations]{list_observability_configurations} \tab Returns a list of active App Runner observability configurations in your Amazon Web Services account\cr
#'  \link[paws.compute:apprunner_list_operations]{list_operations} \tab Return a list of operations that occurred on an App Runner service\cr
#'  \link[paws.compute:apprunner_list_services]{list_services} \tab Returns a list of running App Runner services in your Amazon Web Services account\cr
#'  \link[paws.compute:apprunner_list_services_for_auto_scaling_configuration]{list_services_for_auto_scaling_configuration} \tab Returns a list of the associated App Runner services using an auto scaling configuration\cr
#'  \link[paws.compute:apprunner_list_tags_for_resource]{list_tags_for_resource} \tab List tags that are associated with for an App Runner resource\cr
#'  \link[paws.compute:apprunner_list_vpc_connectors]{list_vpc_connectors} \tab Returns a list of App Runner VPC connectors in your Amazon Web Services account\cr
#'  \link[paws.compute:apprunner_list_vpc_ingress_connections]{list_vpc_ingress_connections} \tab Return a list of App Runner VPC Ingress Connections in your Amazon Web Services account\cr
#'  \link[paws.compute:apprunner_pause_service]{pause_service} \tab Pause an active App Runner service\cr
#'  \link[paws.compute:apprunner_resume_service]{resume_service} \tab Resume an active App Runner service\cr
#'  \link[paws.compute:apprunner_start_deployment]{start_deployment} \tab Initiate a manual deployment of the latest commit in a source code repository or the latest image in a source image repository to an App Runner service\cr
#'  \link[paws.compute:apprunner_tag_resource]{tag_resource} \tab Add tags to, or update the tag values of, an App Runner resource\cr
#'  \link[paws.compute:apprunner_untag_resource]{untag_resource} \tab Remove tags from an App Runner resource\cr
#'  \link[paws.compute:apprunner_update_default_auto_scaling_configuration]{update_default_auto_scaling_configuration} \tab Update an auto scaling configuration to be the default\cr
#'  \link[paws.compute:apprunner_update_service]{update_service} \tab Update an App Runner service\cr
#'  \link[paws.compute:apprunner_update_vpc_ingress_connection]{update_vpc_ingress_connection} \tab Update an existing App Runner VPC Ingress Connection resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname apprunner
#' @export
apprunner <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::apprunner(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Batch
#'
#' @description
#' Batch
#' 
#' Using Batch, you can run batch computing workloads on the Amazon Web
#' Services Cloud. Batch computing is a common means for developers,
#' scientists, and engineers to access large amounts of compute resources.
#' Batch uses the advantages of the batch computing to remove the
#' undifferentiated heavy lifting of configuring and managing required
#' infrastructure. At the same time, it also adopts a familiar batch
#' computing software approach. You can use Batch to efficiently provision
#' resources, and work toward eliminating capacity constraints, reducing
#' your overall compute costs, and delivering results more quickly.
#' 
#' As a fully managed service, Batch can run batch computing workloads of
#' any scale. Batch automatically provisions compute resources and
#' optimizes workload distribution based on the quantity and scale of your
#' specific workloads. With Batch, there's no need to install or manage
#' batch computing software. This means that you can focus on analyzing
#' results and solving your specific problems instead.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- batch(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- batch()
#' # This example cancels a job with the specified job ID.
#' svc$cancel_job(
#'   jobId = "1d828f65-7a4d-42e8-996d-3b900ed59dc4",
#'   reason = "Cancelling job."
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:batch_cancel_job]{cancel_job} \tab Cancels a job in an Batch job queue\cr
#'  \link[paws.compute:batch_create_compute_environment]{create_compute_environment} \tab Creates an Batch compute environment\cr
#'  \link[paws.compute:batch_create_job_queue]{create_job_queue} \tab Creates an Batch job queue\cr
#'  \link[paws.compute:batch_create_scheduling_policy]{create_scheduling_policy} \tab Creates an Batch scheduling policy\cr
#'  \link[paws.compute:batch_delete_compute_environment]{delete_compute_environment} \tab Deletes an Batch compute environment\cr
#'  \link[paws.compute:batch_delete_job_queue]{delete_job_queue} \tab Deletes the specified job queue\cr
#'  \link[paws.compute:batch_delete_scheduling_policy]{delete_scheduling_policy} \tab Deletes the specified scheduling policy\cr
#'  \link[paws.compute:batch_deregister_job_definition]{deregister_job_definition} \tab Deregisters an Batch job definition\cr
#'  \link[paws.compute:batch_describe_compute_environments]{describe_compute_environments} \tab Describes one or more of your compute environments\cr
#'  \link[paws.compute:batch_describe_job_definitions]{describe_job_definitions} \tab Describes a list of job definitions\cr
#'  \link[paws.compute:batch_describe_job_queues]{describe_job_queues} \tab Describes one or more of your job queues\cr
#'  \link[paws.compute:batch_describe_jobs]{describe_jobs} \tab Describes a list of Batch jobs\cr
#'  \link[paws.compute:batch_describe_scheduling_policies]{describe_scheduling_policies} \tab Describes one or more of your scheduling policies\cr
#'  \link[paws.compute:batch_get_job_queue_snapshot]{get_job_queue_snapshot} \tab Provides a list of the first 100 RUNNABLE jobs associated to a single job queue\cr
#'  \link[paws.compute:batch_list_jobs]{list_jobs} \tab Returns a list of Batch jobs\cr
#'  \link[paws.compute:batch_list_scheduling_policies]{list_scheduling_policies} \tab Returns a list of Batch scheduling policies\cr
#'  \link[paws.compute:batch_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for an Batch resource\cr
#'  \link[paws.compute:batch_register_job_definition]{register_job_definition} \tab Registers an Batch job definition\cr
#'  \link[paws.compute:batch_submit_job]{submit_job} \tab Submits an Batch job from a job definition\cr
#'  \link[paws.compute:batch_tag_resource]{tag_resource} \tab Associates the specified tags to a resource with the specified resourceArn\cr
#'  \link[paws.compute:batch_terminate_job]{terminate_job} \tab Terminates a job in a job queue\cr
#'  \link[paws.compute:batch_untag_resource]{untag_resource} \tab Deletes specified tags from an Batch resource\cr
#'  \link[paws.compute:batch_update_compute_environment]{update_compute_environment} \tab Updates an Batch compute environment\cr
#'  \link[paws.compute:batch_update_job_queue]{update_job_queue} \tab Updates a job queue\cr
#'  \link[paws.compute:batch_update_scheduling_policy]{update_scheduling_policy} \tab Updates a scheduling policy
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname batch
#' @export
batch <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::batch(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Braket
#'
#' @description
#' The Amazon Braket API Reference provides information about the
#' operations and structures supported in Amazon Braket.
#' 
#' Additional Resources:
#' 
#' -   [Amazon Braket Developer
#'     Guide](https://docs.aws.amazon.com/braket/latest/developerguide/what-is-braket.html)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- braket(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- braket()
#' svc$cancel_job(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:braket_cancel_job]{cancel_job} \tab Cancels an Amazon Braket job\cr
#'  \link[paws.compute:braket_cancel_quantum_task]{cancel_quantum_task} \tab Cancels the specified task\cr
#'  \link[paws.compute:braket_create_job]{create_job} \tab Creates an Amazon Braket job\cr
#'  \link[paws.compute:braket_create_quantum_task]{create_quantum_task} \tab Creates a quantum task\cr
#'  \link[paws.compute:braket_get_device]{get_device} \tab Retrieves the devices available in Amazon Braket\cr
#'  \link[paws.compute:braket_get_job]{get_job} \tab Retrieves the specified Amazon Braket job\cr
#'  \link[paws.compute:braket_get_quantum_task]{get_quantum_task} \tab Retrieves the specified quantum task\cr
#'  \link[paws.compute:braket_list_tags_for_resource]{list_tags_for_resource} \tab Shows the tags associated with this resource\cr
#'  \link[paws.compute:braket_search_devices]{search_devices} \tab Searches for devices using the specified filters\cr
#'  \link[paws.compute:braket_search_jobs]{search_jobs} \tab Searches for Amazon Braket jobs that match the specified filter values\cr
#'  \link[paws.compute:braket_search_quantum_tasks]{search_quantum_tasks} \tab Searches for tasks that match the specified filter values\cr
#'  \link[paws.compute:braket_tag_resource]{tag_resource} \tab Add a tag to the specified resource\cr
#'  \link[paws.compute:braket_untag_resource]{untag_resource} \tab Remove tags from a resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname braket
#' @export
braket <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::braket(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Compute Optimizer
#'
#' @description
#' Compute Optimizer is a service that analyzes the configuration and
#' utilization metrics of your Amazon Web Services compute resources, such
#' as Amazon EC2 instances, Amazon EC2 Auto Scaling groups, Lambda
#' functions, Amazon EBS volumes, and Amazon ECS services on Fargate. It
#' reports whether your resources are optimal, and generates optimization
#' recommendations to reduce the cost and improve the performance of your
#' workloads. Compute Optimizer also provides recent utilization metric
#' data, in addition to projected utilization metric data for the
#' recommendations, which you can use to evaluate which recommendation
#' provides the best price-performance trade-off. The analysis of your
#' usage patterns can help you decide when to move or resize your running
#' resources, and still meet your performance and capacity requirements.
#' For more information about Compute Optimizer, including the required
#' permissions to use the service, see the [Compute Optimizer User
#' Guide](https://docs.aws.amazon.com/compute-optimizer/latest/ug/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- computeoptimizer(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- computeoptimizer()
#' svc$delete_recommendation_preferences(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:computeoptimizer_delete_recommendation_preferences]{delete_recommendation_preferences} \tab Deletes a recommendation preference, such as enhanced infrastructure metrics\cr
#'  \link[paws.compute:computeoptimizer_describe_recommendation_export_jobs]{describe_recommendation_export_jobs} \tab Describes recommendation export jobs created in the last seven days\cr
#'  \link[paws.compute:computeoptimizer_export_auto_scaling_group_recommendations]{export_auto_scaling_group_recommendations} \tab Exports optimization recommendations for Auto Scaling groups\cr
#'  \link[paws.compute:computeoptimizer_export_ebs_volume_recommendations]{export_ebs_volume_recommendations} \tab Exports optimization recommendations for Amazon EBS volumes\cr
#'  \link[paws.compute:computeoptimizer_export_ec2_instance_recommendations]{export_ec2_instance_recommendations} \tab Exports optimization recommendations for Amazon EC2 instances\cr
#'  \link[paws.compute:computeoptimizer_export_ecs_service_recommendations]{export_ecs_service_recommendations} \tab Exports optimization recommendations for Amazon ECS services on Fargate\cr
#'  \link[paws.compute:computeoptimizer_export_idle_recommendations]{export_idle_recommendations} \tab Export optimization recommendations for your idle resources\cr
#'  \link[paws.compute:computeoptimizer_export_lambda_function_recommendations]{export_lambda_function_recommendations} \tab Exports optimization recommendations for Lambda functions\cr
#'  \link[paws.compute:computeoptimizer_export_license_recommendations]{export_license_recommendations} \tab Export optimization recommendations for your licenses\cr
#'  \link[paws.compute:computeoptimizer_export_rds_database_recommendations]{export_rds_database_recommendations} \tab Export optimization recommendations for your Amazon Relational Database Service (Amazon RDS)\cr
#'  \link[paws.compute:computeoptimizer_get_auto_scaling_group_recommendations]{get_auto_scaling_group_recommendations} \tab Returns Auto Scaling group recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_ebs_volume_recommendations]{get_ebs_volume_recommendations} \tab Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_ec2_instance_recommendations]{get_ec2_instance_recommendations} \tab Returns Amazon EC2 instance recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_ec2_recommendation_projected_metrics]{get_ec2_recommendation_projected_metrics} \tab Returns the projected utilization metrics of Amazon EC2 instance recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_ecs_service_recommendation_projected_metrics]{get_ecs_service_recommendation_projected_metrics} \tab Returns the projected metrics of Amazon ECS service recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_ecs_service_recommendations]{get_ecs_service_recommendations} \tab Returns Amazon ECS service recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_effective_recommendation_preferences]{get_effective_recommendation_preferences} \tab Returns the recommendation preferences that are in effect for a given resource, such as enhanced infrastructure metrics\cr
#'  \link[paws.compute:computeoptimizer_get_enrollment_status]{get_enrollment_status} \tab Returns the enrollment (opt in) status of an account to the Compute Optimizer service\cr
#'  \link[paws.compute:computeoptimizer_get_enrollment_statuses_for_organization]{get_enrollment_statuses_for_organization} \tab Returns the Compute Optimizer enrollment (opt-in) status of organization member accounts, if your account is an organization management account\cr
#'  \link[paws.compute:computeoptimizer_get_idle_recommendations]{get_idle_recommendations} \tab Returns idle resource recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_lambda_function_recommendations]{get_lambda_function_recommendations} \tab Returns Lambda function recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_license_recommendations]{get_license_recommendations} \tab Returns license recommendations for Amazon EC2 instances that run on a specific license\cr
#'  \link[paws.compute:computeoptimizer_get_rds_database_recommendation_projected_metrics]{get_rds_database_recommendation_projected_metrics} \tab Returns the projected metrics of Amazon RDS recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_rds_database_recommendations]{get_rds_database_recommendations} \tab Returns Amazon RDS recommendations\cr
#'  \link[paws.compute:computeoptimizer_get_recommendation_preferences]{get_recommendation_preferences} \tab Returns existing recommendation preferences, such as enhanced infrastructure metrics\cr
#'  \link[paws.compute:computeoptimizer_get_recommendation_summaries]{get_recommendation_summaries} \tab Returns the optimization findings for an account\cr
#'  \link[paws.compute:computeoptimizer_put_recommendation_preferences]{put_recommendation_preferences} \tab Creates a new recommendation preference or updates an existing recommendation preference, such as enhanced infrastructure metrics\cr
#'  \link[paws.compute:computeoptimizer_update_enrollment_status]{update_enrollment_status} \tab Updates the enrollment (opt in and opt out) status of an account to the Compute Optimizer service
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname computeoptimizer
#' @export
computeoptimizer <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::computeoptimizer(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Elastic Compute Cloud
#'
#' @description
#' You can access the features of Amazon Elastic Compute Cloud (Amazon EC2)
#' programmatically. For more information, see the [Amazon EC2 Developer
#' Guide](https://docs.aws.amazon.com/ec2/latest/devguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ec2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ec2()
#' # This example allocates an Elastic IP address to use with an instance in
#' # a VPC.
#' svc$allocate_address(
#'   Domain = "vpc"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:ec2_accept_address_transfer]{accept_address_transfer} \tab Accepts an Elastic IP address transfer\cr
#'  \link[paws.compute:ec2_accept_capacity_reservation_billing_ownership]{accept_capacity_reservation_billing_ownership} \tab Accepts a request to assign billing of the available capacity of a shared Capacity Reservation to your account\cr
#'  \link[paws.compute:ec2_accept_reserved_instances_exchange_quote]{accept_reserved_instances_exchange_quote} \tab Accepts the Convertible Reserved Instance exchange quote described in the GetReservedInstancesExchangeQuote call\cr
#'  \link[paws.compute:ec2_accept_transit_gateway_multicast_domain_associations]{accept_transit_gateway_multicast_domain_associations} \tab Accepts a request to associate subnets with a transit gateway multicast domain\cr
#'  \link[paws.compute:ec2_accept_transit_gateway_peering_attachment]{accept_transit_gateway_peering_attachment} \tab Accepts a transit gateway peering attachment request\cr
#'  \link[paws.compute:ec2_accept_transit_gateway_vpc_attachment]{accept_transit_gateway_vpc_attachment} \tab Accepts a request to attach a VPC to a transit gateway\cr
#'  \link[paws.compute:ec2_accept_vpc_endpoint_connections]{accept_vpc_endpoint_connections} \tab Accepts connection requests to your VPC endpoint service\cr
#'  \link[paws.compute:ec2_accept_vpc_peering_connection]{accept_vpc_peering_connection} \tab Accept a VPC peering connection request\cr
#'  \link[paws.compute:ec2_advertise_byoip_cidr]{advertise_byoip_cidr} \tab Advertises an IPv4 or IPv6 address range that is provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP)\cr
#'  \link[paws.compute:ec2_allocate_address]{allocate_address} \tab Allocates an Elastic IP address to your Amazon Web Services account\cr
#'  \link[paws.compute:ec2_allocate_hosts]{allocate_hosts} \tab Allocates a Dedicated Host to your account\cr
#'  \link[paws.compute:ec2_allocate_ipam_pool_cidr]{allocate_ipam_pool_cidr} \tab Allocate a CIDR from an IPAM pool\cr
#'  \link[paws.compute:ec2_apply_security_groups_to_client_vpn_target_network]{apply_security_groups_to_client_vpn_target_network} \tab Applies a security group to the association between the target network and the Client VPN endpoint\cr
#'  \link[paws.compute:ec2_assign_ipv_6_addresses]{assign_ipv_6_addresses} \tab Assigns the specified IPv6 addresses to the specified network interface\cr
#'  \link[paws.compute:ec2_assign_private_ip_addresses]{assign_private_ip_addresses} \tab Assigns the specified secondary private IP addresses to the specified network interface\cr
#'  \link[paws.compute:ec2_assign_private_nat_gateway_address]{assign_private_nat_gateway_address} \tab Assigns private IPv4 addresses to a private NAT gateway\cr
#'  \link[paws.compute:ec2_associate_address]{associate_address} \tab Associates an Elastic IP address, or carrier IP address (for instances that are in subnets in Wavelength Zones) with an instance or a network interface\cr
#'  \link[paws.compute:ec2_associate_capacity_reservation_billing_owner]{associate_capacity_reservation_billing_owner} \tab Initiates a request to assign billing of the unused capacity of a shared Capacity Reservation to a consumer account that is consolidated under the same Amazon Web Services organizations payer account\cr
#'  \link[paws.compute:ec2_associate_client_vpn_target_network]{associate_client_vpn_target_network} \tab Associates a target network with a Client VPN endpoint\cr
#'  \link[paws.compute:ec2_associate_dhcp_options]{associate_dhcp_options} \tab Associates a set of DHCP options (that you've previously created) with the specified VPC, or associates no DHCP options with the VPC\cr
#'  \link[paws.compute:ec2_associate_enclave_certificate_iam_role]{associate_enclave_certificate_iam_role} \tab Associates an Identity and Access Management (IAM) role with an Certificate Manager (ACM) certificate\cr
#'  \link[paws.compute:ec2_associate_iam_instance_profile]{associate_iam_instance_profile} \tab Associates an IAM instance profile with a running or stopped instance\cr
#'  \link[paws.compute:ec2_associate_instance_event_window]{associate_instance_event_window} \tab Associates one or more targets with an event window\cr
#'  \link[paws.compute:ec2_associate_ipam_byoasn]{associate_ipam_byoasn} \tab Associates your Autonomous System Number (ASN) with a BYOIP CIDR that you own in the same Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_associate_ipam_resource_discovery]{associate_ipam_resource_discovery} \tab Associates an IPAM resource discovery with an Amazon VPC IPAM\cr
#'  \link[paws.compute:ec2_associate_nat_gateway_address]{associate_nat_gateway_address} \tab Associates Elastic IP addresses (EIPs) and private IPv4 addresses with a public NAT gateway\cr
#'  \link[paws.compute:ec2_associate_route_table]{associate_route_table} \tab Associates a subnet in your VPC or an internet gateway or virtual private gateway attached to your VPC with a route table in your VPC\cr
#'  \link[paws.compute:ec2_associate_security_group_vpc]{associate_security_group_vpc} \tab Associates a security group with another VPC in the same Region\cr
#'  \link[paws.compute:ec2_associate_subnet_cidr_block]{associate_subnet_cidr_block} \tab Associates a CIDR block with your subnet\cr
#'  \link[paws.compute:ec2_associate_transit_gateway_multicast_domain]{associate_transit_gateway_multicast_domain} \tab Associates the specified subnets and transit gateway attachments with the specified transit gateway multicast domain\cr
#'  \link[paws.compute:ec2_associate_transit_gateway_policy_table]{associate_transit_gateway_policy_table} \tab Associates the specified transit gateway attachment with a transit gateway policy table\cr
#'  \link[paws.compute:ec2_associate_transit_gateway_route_table]{associate_transit_gateway_route_table} \tab Associates the specified attachment with the specified transit gateway route table\cr
#'  \link[paws.compute:ec2_associate_trunk_interface]{associate_trunk_interface} \tab Associates a branch network interface with a trunk network interface\cr
#'  \link[paws.compute:ec2_associate_vpc_cidr_block]{associate_vpc_cidr_block} \tab Associates a CIDR block with your VPC\cr
#'  \link[paws.compute:ec2_attach_classic_link_vpc]{attach_classic_link_vpc} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_attach_internet_gateway]{attach_internet_gateway} \tab Attaches an internet gateway or a virtual private gateway to a VPC, enabling connectivity between the internet and the VPC\cr
#'  \link[paws.compute:ec2_attach_network_interface]{attach_network_interface} \tab Attaches a network interface to an instance\cr
#'  \link[paws.compute:ec2_attach_verified_access_trust_provider]{attach_verified_access_trust_provider} \tab Attaches the specified Amazon Web Services Verified Access trust provider to the specified Amazon Web Services Verified Access instance\cr
#'  \link[paws.compute:ec2_attach_volume]{attach_volume} \tab Attaches an EBS volume to a running or stopped instance and exposes it to the instance with the specified device name\cr
#'  \link[paws.compute:ec2_attach_vpn_gateway]{attach_vpn_gateway} \tab Attaches an available virtual private gateway to a VPC\cr
#'  \link[paws.compute:ec2_authorize_client_vpn_ingress]{authorize_client_vpn_ingress} \tab Adds an ingress authorization rule to a Client VPN endpoint\cr
#'  \link[paws.compute:ec2_authorize_security_group_egress]{authorize_security_group_egress} \tab Adds the specified outbound (egress) rules to a security group\cr
#'  \link[paws.compute:ec2_authorize_security_group_ingress]{authorize_security_group_ingress} \tab Adds the specified inbound (ingress) rules to a security group\cr
#'  \link[paws.compute:ec2_bundle_instance]{bundle_instance} \tab Bundles an Amazon instance store-backed Windows instance\cr
#'  \link[paws.compute:ec2_cancel_bundle_task]{cancel_bundle_task} \tab Cancels a bundling operation for an instance store-backed Windows instance\cr
#'  \link[paws.compute:ec2_cancel_capacity_reservation]{cancel_capacity_reservation} \tab Cancels the specified Capacity Reservation, releases the reserved capacity, and changes the Capacity Reservation's state to cancelled\cr
#'  \link[paws.compute:ec2_cancel_capacity_reservation_fleets]{cancel_capacity_reservation_fleets} \tab Cancels one or more Capacity Reservation Fleets\cr
#'  \link[paws.compute:ec2_cancel_conversion_task]{cancel_conversion_task} \tab Cancels an active conversion task\cr
#'  \link[paws.compute:ec2_cancel_declarative_policies_report]{cancel_declarative_policies_report} \tab Cancels the generation of an account status report\cr
#'  \link[paws.compute:ec2_cancel_export_task]{cancel_export_task} \tab Cancels an active export task\cr
#'  \link[paws.compute:ec2_cancel_image_launch_permission]{cancel_image_launch_permission} \tab Removes your Amazon Web Services account from the launch permissions for the specified AMI\cr
#'  \link[paws.compute:ec2_cancel_import_task]{cancel_import_task} \tab Cancels an in-process import virtual machine or import snapshot task\cr
#'  \link[paws.compute:ec2_cancel_reserved_instances_listing]{cancel_reserved_instances_listing} \tab Cancels the specified Reserved Instance listing in the Reserved Instance Marketplace\cr
#'  \link[paws.compute:ec2_cancel_spot_fleet_requests]{cancel_spot_fleet_requests} \tab Cancels the specified Spot Fleet requests\cr
#'  \link[paws.compute:ec2_cancel_spot_instance_requests]{cancel_spot_instance_requests} \tab Cancels one or more Spot Instance requests\cr
#'  \link[paws.compute:ec2_confirm_product_instance]{confirm_product_instance} \tab Determines whether a product code is associated with an instance\cr
#'  \link[paws.compute:ec2_copy_fpga_image]{copy_fpga_image} \tab Copies the specified Amazon FPGA Image (AFI) to the current Region\cr
#'  \link[paws.compute:ec2_copy_image]{copy_image} \tab Initiates an AMI copy operation\cr
#'  \link[paws.compute:ec2_copy_snapshot]{copy_snapshot} \tab Copies a point-in-time snapshot of an EBS volume and stores it in Amazon S3\cr
#'  \link[paws.compute:ec2_create_capacity_reservation]{create_capacity_reservation} \tab Creates a new Capacity Reservation with the specified attributes\cr
#'  \link[paws.compute:ec2_create_capacity_reservation_by_splitting]{create_capacity_reservation_by_splitting} \tab Create a new Capacity Reservation by splitting the capacity of the source Capacity Reservation\cr
#'  \link[paws.compute:ec2_create_capacity_reservation_fleet]{create_capacity_reservation_fleet} \tab Creates a Capacity Reservation Fleet\cr
#'  \link[paws.compute:ec2_create_carrier_gateway]{create_carrier_gateway} \tab Creates a carrier gateway\cr
#'  \link[paws.compute:ec2_create_client_vpn_endpoint]{create_client_vpn_endpoint} \tab Creates a Client VPN endpoint\cr
#'  \link[paws.compute:ec2_create_client_vpn_route]{create_client_vpn_route} \tab Adds a route to a network to a Client VPN endpoint\cr
#'  \link[paws.compute:ec2_create_coip_cidr]{create_coip_cidr} \tab Creates a range of customer-owned IP addresses\cr
#'  \link[paws.compute:ec2_create_coip_pool]{create_coip_pool} \tab Creates a pool of customer-owned IP (CoIP) addresses\cr
#'  \link[paws.compute:ec2_create_customer_gateway]{create_customer_gateway} \tab Provides information to Amazon Web Services about your customer gateway device\cr
#'  \link[paws.compute:ec2_create_default_subnet]{create_default_subnet} \tab Creates a default subnet with a size /20 IPv4 CIDR block in the specified Availability Zone in your default VPC\cr
#'  \link[paws.compute:ec2_create_default_vpc]{create_default_vpc} \tab Creates a default VPC with a size /16 IPv4 CIDR block and a default subnet in each Availability Zone\cr
#'  \link[paws.compute:ec2_create_dhcp_options]{create_dhcp_options} \tab Creates a custom set of DHCP options\cr
#'  \link[paws.compute:ec2_create_egress_only_internet_gateway]{create_egress_only_internet_gateway} \tab &#91;IPv6 only&#93; Creates an egress-only internet gateway for your VPC\cr
#'  \link[paws.compute:ec2_create_fleet]{create_fleet} \tab Creates an EC2 Fleet that contains the configuration information for On-Demand Instances and Spot Instances\cr
#'  \link[paws.compute:ec2_create_flow_logs]{create_flow_logs} \tab Creates one or more flow logs to capture information about IP traffic for a specific network interface, subnet, or VPC\cr
#'  \link[paws.compute:ec2_create_fpga_image]{create_fpga_image} \tab Creates an Amazon FPGA Image (AFI) from the specified design checkpoint (DCP)\cr
#'  \link[paws.compute:ec2_create_image]{create_image} \tab Creates an Amazon EBS-backed AMI from an Amazon EBS-backed instance that is either running or stopped\cr
#'  \link[paws.compute:ec2_create_instance_connect_endpoint]{create_instance_connect_endpoint} \tab Creates an EC2 Instance Connect Endpoint\cr
#'  \link[paws.compute:ec2_create_instance_event_window]{create_instance_event_window} \tab Creates an event window in which scheduled events for the associated Amazon EC2 instances can run\cr
#'  \link[paws.compute:ec2_create_instance_export_task]{create_instance_export_task} \tab Exports a running or stopped instance to an Amazon S3 bucket\cr
#'  \link[paws.compute:ec2_create_internet_gateway]{create_internet_gateway} \tab Creates an internet gateway for use with a VPC\cr
#'  \link[paws.compute:ec2_create_ipam]{create_ipam} \tab Create an IPAM\cr
#'  \link[paws.compute:ec2_create_ipam_external_resource_verification_token]{create_ipam_external_resource_verification_token} \tab Create a verification token\cr
#'  \link[paws.compute:ec2_create_ipam_pool]{create_ipam_pool} \tab Create an IP address pool for Amazon VPC IP Address Manager (IPAM)\cr
#'  \link[paws.compute:ec2_create_ipam_resource_discovery]{create_ipam_resource_discovery} \tab Creates an IPAM resource discovery\cr
#'  \link[paws.compute:ec2_create_ipam_scope]{create_ipam_scope} \tab Create an IPAM scope\cr
#'  \link[paws.compute:ec2_create_key_pair]{create_key_pair} \tab Creates an ED25519 or 2048-bit RSA key pair with the specified name and in the specified format\cr
#'  \link[paws.compute:ec2_create_launch_template]{create_launch_template} \tab Creates a launch template\cr
#'  \link[paws.compute:ec2_create_launch_template_version]{create_launch_template_version} \tab Creates a new version of a launch template\cr
#'  \link[paws.compute:ec2_create_local_gateway_route]{create_local_gateway_route} \tab Creates a static route for the specified local gateway route table\cr
#'  \link[paws.compute:ec2_create_local_gateway_route_table]{create_local_gateway_route_table} \tab Creates a local gateway route table\cr
#'  \link[paws.compute:ec2_create_local_gateway_route_table_virtual_interface_group_association]{create_local_gateway_route_table_virtual_interface_group_association} \tab Creates a local gateway route table virtual interface group association\cr
#'  \link[paws.compute:ec2_create_local_gateway_route_table_vpc_association]{create_local_gateway_route_table_vpc_association} \tab Associates the specified VPC with the specified local gateway route table\cr
#'  \link[paws.compute:ec2_create_managed_prefix_list]{create_managed_prefix_list} \tab Creates a managed prefix list\cr
#'  \link[paws.compute:ec2_create_nat_gateway]{create_nat_gateway} \tab Creates a NAT gateway in the specified subnet\cr
#'  \link[paws.compute:ec2_create_network_acl]{create_network_acl} \tab Creates a network ACL in a VPC\cr
#'  \link[paws.compute:ec2_create_network_acl_entry]{create_network_acl_entry} \tab Creates an entry (a rule) in a network ACL with the specified rule number\cr
#'  \link[paws.compute:ec2_create_network_insights_access_scope]{create_network_insights_access_scope} \tab Creates a Network Access Scope\cr
#'  \link[paws.compute:ec2_create_network_insights_path]{create_network_insights_path} \tab Creates a path to analyze for reachability\cr
#'  \link[paws.compute:ec2_create_network_interface]{create_network_interface} \tab Creates a network interface in the specified subnet\cr
#'  \link[paws.compute:ec2_create_network_interface_permission]{create_network_interface_permission} \tab Grants an Amazon Web Services-authorized account permission to attach the specified network interface to an instance in their account\cr
#'  \link[paws.compute:ec2_create_placement_group]{create_placement_group} \tab Creates a placement group in which to launch instances\cr
#'  \link[paws.compute:ec2_create_public_ipv_4_pool]{create_public_ipv_4_pool} \tab Creates a public IPv4 address pool\cr
#'  \link[paws.compute:ec2_create_replace_root_volume_task]{create_replace_root_volume_task} \tab Replaces the EBS-backed root volume for a running instance with a new volume that is restored to the original root volume's launch state, that is restored to a specific snapshot taken from the original root volume, or that is restored from an AMI that has the same key characteristics as that of the instance\cr
#'  \link[paws.compute:ec2_create_reserved_instances_listing]{create_reserved_instances_listing} \tab Creates a listing for Amazon EC2 Standard Reserved Instances to be sold in the Reserved Instance Marketplace\cr
#'  \link[paws.compute:ec2_create_restore_image_task]{create_restore_image_task} \tab Starts a task that restores an AMI from an Amazon S3 object that was previously created by using CreateStoreImageTask\cr
#'  \link[paws.compute:ec2_create_route]{create_route} \tab Creates a route in a route table within a VPC\cr
#'  \link[paws.compute:ec2_create_route_table]{create_route_table} \tab Creates a route table for the specified VPC\cr
#'  \link[paws.compute:ec2_create_security_group]{create_security_group} \tab Creates a security group\cr
#'  \link[paws.compute:ec2_create_snapshot]{create_snapshot} \tab Creates a snapshot of an EBS volume and stores it in Amazon S3\cr
#'  \link[paws.compute:ec2_create_snapshots]{create_snapshots} \tab Creates crash-consistent snapshots of multiple EBS volumes attached to an Amazon EC2 instance\cr
#'  \link[paws.compute:ec2_create_spot_datafeed_subscription]{create_spot_datafeed_subscription} \tab Creates a data feed for Spot Instances, enabling you to view Spot Instance usage logs\cr
#'  \link[paws.compute:ec2_create_store_image_task]{create_store_image_task} \tab Stores an AMI as a single object in an Amazon S3 bucket\cr
#'  \link[paws.compute:ec2_create_subnet]{create_subnet} \tab Creates a subnet in the specified VPC\cr
#'  \link[paws.compute:ec2_create_subnet_cidr_reservation]{create_subnet_cidr_reservation} \tab Creates a subnet CIDR reservation\cr
#'  \link[paws.compute:ec2_create_tags]{create_tags} \tab Adds or overwrites only the specified tags for the specified Amazon EC2 resource or resources\cr
#'  \link[paws.compute:ec2_create_traffic_mirror_filter]{create_traffic_mirror_filter} \tab Creates a Traffic Mirror filter\cr
#'  \link[paws.compute:ec2_create_traffic_mirror_filter_rule]{create_traffic_mirror_filter_rule} \tab Creates a Traffic Mirror filter rule\cr
#'  \link[paws.compute:ec2_create_traffic_mirror_session]{create_traffic_mirror_session} \tab Creates a Traffic Mirror session\cr
#'  \link[paws.compute:ec2_create_traffic_mirror_target]{create_traffic_mirror_target} \tab Creates a target for your Traffic Mirror session\cr
#'  \link[paws.compute:ec2_create_transit_gateway]{create_transit_gateway} \tab Creates a transit gateway\cr
#'  \link[paws.compute:ec2_create_transit_gateway_connect]{create_transit_gateway_connect} \tab Creates a Connect attachment from a specified transit gateway attachment\cr
#'  \link[paws.compute:ec2_create_transit_gateway_connect_peer]{create_transit_gateway_connect_peer} \tab Creates a Connect peer for a specified transit gateway Connect attachment between a transit gateway and an appliance\cr
#'  \link[paws.compute:ec2_create_transit_gateway_multicast_domain]{create_transit_gateway_multicast_domain} \tab Creates a multicast domain using the specified transit gateway\cr
#'  \link[paws.compute:ec2_create_transit_gateway_peering_attachment]{create_transit_gateway_peering_attachment} \tab Requests a transit gateway peering attachment between the specified transit gateway (requester) and a peer transit gateway (accepter)\cr
#'  \link[paws.compute:ec2_create_transit_gateway_policy_table]{create_transit_gateway_policy_table} \tab Creates a transit gateway policy table\cr
#'  \link[paws.compute:ec2_create_transit_gateway_prefix_list_reference]{create_transit_gateway_prefix_list_reference} \tab Creates a reference (route) to a prefix list in a specified transit gateway route table\cr
#'  \link[paws.compute:ec2_create_transit_gateway_route]{create_transit_gateway_route} \tab Creates a static route for the specified transit gateway route table\cr
#'  \link[paws.compute:ec2_create_transit_gateway_route_table]{create_transit_gateway_route_table} \tab Creates a route table for the specified transit gateway\cr
#'  \link[paws.compute:ec2_create_transit_gateway_route_table_announcement]{create_transit_gateway_route_table_announcement} \tab Advertises a new transit gateway route table\cr
#'  \link[paws.compute:ec2_create_transit_gateway_vpc_attachment]{create_transit_gateway_vpc_attachment} \tab Attaches the specified VPC to the specified transit gateway\cr
#'  \link[paws.compute:ec2_create_verified_access_endpoint]{create_verified_access_endpoint} \tab An Amazon Web Services Verified Access endpoint is where you define your application along with an optional endpoint-level access policy\cr
#'  \link[paws.compute:ec2_create_verified_access_group]{create_verified_access_group} \tab An Amazon Web Services Verified Access group is a collection of Amazon Web Services Verified Access endpoints who's associated applications have similar security requirements\cr
#'  \link[paws.compute:ec2_create_verified_access_instance]{create_verified_access_instance} \tab An Amazon Web Services Verified Access instance is a regional entity that evaluates application requests and grants access only when your security requirements are met\cr
#'  \link[paws.compute:ec2_create_verified_access_trust_provider]{create_verified_access_trust_provider} \tab A trust provider is a third-party entity that creates, maintains, and manages identity information for users and devices\cr
#'  \link[paws.compute:ec2_create_volume]{create_volume} \tab Creates an EBS volume that can be attached to an instance in the same Availability Zone\cr
#'  \link[paws.compute:ec2_create_vpc]{create_vpc} \tab Creates a VPC with the specified CIDR blocks\cr
#'  \link[paws.compute:ec2_create_vpc_block_public_access_exclusion]{create_vpc_block_public_access_exclusion} \tab Create a VPC Block Public Access (BPA) exclusion\cr
#'  \link[paws.compute:ec2_create_vpc_endpoint]{create_vpc_endpoint} \tab Creates a VPC endpoint\cr
#'  \link[paws.compute:ec2_create_vpc_endpoint_connection_notification]{create_vpc_endpoint_connection_notification} \tab Creates a connection notification for a specified VPC endpoint or VPC endpoint service\cr
#'  \link[paws.compute:ec2_create_vpc_endpoint_service_configuration]{create_vpc_endpoint_service_configuration} \tab Creates a VPC endpoint service to which service consumers (Amazon Web Services accounts, users, and IAM roles) can connect\cr
#'  \link[paws.compute:ec2_create_vpc_peering_connection]{create_vpc_peering_connection} \tab Requests a VPC peering connection between two VPCs: a requester VPC that you own and an accepter VPC with which to create the connection\cr
#'  \link[paws.compute:ec2_create_vpn_connection]{create_vpn_connection} \tab Creates a VPN connection between an existing virtual private gateway or transit gateway and a customer gateway\cr
#'  \link[paws.compute:ec2_create_vpn_connection_route]{create_vpn_connection_route} \tab Creates a static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway\cr
#'  \link[paws.compute:ec2_create_vpn_gateway]{create_vpn_gateway} \tab Creates a virtual private gateway\cr
#'  \link[paws.compute:ec2_delete_carrier_gateway]{delete_carrier_gateway} \tab Deletes a carrier gateway\cr
#'  \link[paws.compute:ec2_delete_client_vpn_endpoint]{delete_client_vpn_endpoint} \tab Deletes the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_delete_client_vpn_route]{delete_client_vpn_route} \tab Deletes a route from a Client VPN endpoint\cr
#'  \link[paws.compute:ec2_delete_coip_cidr]{delete_coip_cidr} \tab Deletes a range of customer-owned IP addresses\cr
#'  \link[paws.compute:ec2_delete_coip_pool]{delete_coip_pool} \tab Deletes a pool of customer-owned IP (CoIP) addresses\cr
#'  \link[paws.compute:ec2_delete_customer_gateway]{delete_customer_gateway} \tab Deletes the specified customer gateway\cr
#'  \link[paws.compute:ec2_delete_dhcp_options]{delete_dhcp_options} \tab Deletes the specified set of DHCP options\cr
#'  \link[paws.compute:ec2_delete_egress_only_internet_gateway]{delete_egress_only_internet_gateway} \tab Deletes an egress-only internet gateway\cr
#'  \link[paws.compute:ec2_delete_fleets]{delete_fleets} \tab Deletes the specified EC2 Fleets\cr
#'  \link[paws.compute:ec2_delete_flow_logs]{delete_flow_logs} \tab Deletes one or more flow logs\cr
#'  \link[paws.compute:ec2_delete_fpga_image]{delete_fpga_image} \tab Deletes the specified Amazon FPGA Image (AFI)\cr
#'  \link[paws.compute:ec2_delete_instance_connect_endpoint]{delete_instance_connect_endpoint} \tab Deletes the specified EC2 Instance Connect Endpoint\cr
#'  \link[paws.compute:ec2_delete_instance_event_window]{delete_instance_event_window} \tab Deletes the specified event window\cr
#'  \link[paws.compute:ec2_delete_internet_gateway]{delete_internet_gateway} \tab Deletes the specified internet gateway\cr
#'  \link[paws.compute:ec2_delete_ipam]{delete_ipam} \tab Delete an IPAM\cr
#'  \link[paws.compute:ec2_delete_ipam_external_resource_verification_token]{delete_ipam_external_resource_verification_token} \tab Delete a verification token\cr
#'  \link[paws.compute:ec2_delete_ipam_pool]{delete_ipam_pool} \tab Delete an IPAM pool\cr
#'  \link[paws.compute:ec2_delete_ipam_resource_discovery]{delete_ipam_resource_discovery} \tab Deletes an IPAM resource discovery\cr
#'  \link[paws.compute:ec2_delete_ipam_scope]{delete_ipam_scope} \tab Delete the scope for an IPAM\cr
#'  \link[paws.compute:ec2_delete_key_pair]{delete_key_pair} \tab Deletes the specified key pair, by removing the public key from Amazon EC2\cr
#'  \link[paws.compute:ec2_delete_launch_template]{delete_launch_template} \tab Deletes a launch template\cr
#'  \link[paws.compute:ec2_delete_launch_template_versions]{delete_launch_template_versions} \tab Deletes one or more versions of a launch template\cr
#'  \link[paws.compute:ec2_delete_local_gateway_route]{delete_local_gateway_route} \tab Deletes the specified route from the specified local gateway route table\cr
#'  \link[paws.compute:ec2_delete_local_gateway_route_table]{delete_local_gateway_route_table} \tab Deletes a local gateway route table\cr
#'  \link[paws.compute:ec2_delete_local_gateway_route_table_virtual_interface_group_association]{delete_local_gateway_route_table_virtual_interface_group_association} \tab Deletes a local gateway route table virtual interface group association\cr
#'  \link[paws.compute:ec2_delete_local_gateway_route_table_vpc_association]{delete_local_gateway_route_table_vpc_association} \tab Deletes the specified association between a VPC and local gateway route table\cr
#'  \link[paws.compute:ec2_delete_managed_prefix_list]{delete_managed_prefix_list} \tab Deletes the specified managed prefix list\cr
#'  \link[paws.compute:ec2_delete_nat_gateway]{delete_nat_gateway} \tab Deletes the specified NAT gateway\cr
#'  \link[paws.compute:ec2_delete_network_acl]{delete_network_acl} \tab Deletes the specified network ACL\cr
#'  \link[paws.compute:ec2_delete_network_acl_entry]{delete_network_acl_entry} \tab Deletes the specified ingress or egress entry (rule) from the specified network ACL\cr
#'  \link[paws.compute:ec2_delete_network_insights_access_scope]{delete_network_insights_access_scope} \tab Deletes the specified Network Access Scope\cr
#'  \link[paws.compute:ec2_delete_network_insights_access_scope_analysis]{delete_network_insights_access_scope_analysis} \tab Deletes the specified Network Access Scope analysis\cr
#'  \link[paws.compute:ec2_delete_network_insights_analysis]{delete_network_insights_analysis} \tab Deletes the specified network insights analysis\cr
#'  \link[paws.compute:ec2_delete_network_insights_path]{delete_network_insights_path} \tab Deletes the specified path\cr
#'  \link[paws.compute:ec2_delete_network_interface]{delete_network_interface} \tab Deletes the specified network interface\cr
#'  \link[paws.compute:ec2_delete_network_interface_permission]{delete_network_interface_permission} \tab Deletes a permission for a network interface\cr
#'  \link[paws.compute:ec2_delete_placement_group]{delete_placement_group} \tab Deletes the specified placement group\cr
#'  \link[paws.compute:ec2_delete_public_ipv_4_pool]{delete_public_ipv_4_pool} \tab Delete a public IPv4 pool\cr
#'  \link[paws.compute:ec2_delete_queued_reserved_instances]{delete_queued_reserved_instances} \tab Deletes the queued purchases for the specified Reserved Instances\cr
#'  \link[paws.compute:ec2_delete_route]{delete_route} \tab Deletes the specified route from the specified route table\cr
#'  \link[paws.compute:ec2_delete_route_table]{delete_route_table} \tab Deletes the specified route table\cr
#'  \link[paws.compute:ec2_delete_security_group]{delete_security_group} \tab Deletes a security group\cr
#'  \link[paws.compute:ec2_delete_snapshot]{delete_snapshot} \tab Deletes the specified snapshot\cr
#'  \link[paws.compute:ec2_delete_spot_datafeed_subscription]{delete_spot_datafeed_subscription} \tab Deletes the data feed for Spot Instances\cr
#'  \link[paws.compute:ec2_delete_subnet]{delete_subnet} \tab Deletes the specified subnet\cr
#'  \link[paws.compute:ec2_delete_subnet_cidr_reservation]{delete_subnet_cidr_reservation} \tab Deletes a subnet CIDR reservation\cr
#'  \link[paws.compute:ec2_delete_tags]{delete_tags} \tab Deletes the specified set of tags from the specified set of resources\cr
#'  \link[paws.compute:ec2_delete_traffic_mirror_filter]{delete_traffic_mirror_filter} \tab Deletes the specified Traffic Mirror filter\cr
#'  \link[paws.compute:ec2_delete_traffic_mirror_filter_rule]{delete_traffic_mirror_filter_rule} \tab Deletes the specified Traffic Mirror rule\cr
#'  \link[paws.compute:ec2_delete_traffic_mirror_session]{delete_traffic_mirror_session} \tab Deletes the specified Traffic Mirror session\cr
#'  \link[paws.compute:ec2_delete_traffic_mirror_target]{delete_traffic_mirror_target} \tab Deletes the specified Traffic Mirror target\cr
#'  \link[paws.compute:ec2_delete_transit_gateway]{delete_transit_gateway} \tab Deletes the specified transit gateway\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_connect]{delete_transit_gateway_connect} \tab Deletes the specified Connect attachment\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_connect_peer]{delete_transit_gateway_connect_peer} \tab Deletes the specified Connect peer\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_multicast_domain]{delete_transit_gateway_multicast_domain} \tab Deletes the specified transit gateway multicast domain\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_peering_attachment]{delete_transit_gateway_peering_attachment} \tab Deletes a transit gateway peering attachment\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_policy_table]{delete_transit_gateway_policy_table} \tab Deletes the specified transit gateway policy table\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_prefix_list_reference]{delete_transit_gateway_prefix_list_reference} \tab Deletes a reference (route) to a prefix list in a specified transit gateway route table\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_route]{delete_transit_gateway_route} \tab Deletes the specified route from the specified transit gateway route table\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_route_table]{delete_transit_gateway_route_table} \tab Deletes the specified transit gateway route table\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_route_table_announcement]{delete_transit_gateway_route_table_announcement} \tab Advertises to the transit gateway that a transit gateway route table is deleted\cr
#'  \link[paws.compute:ec2_delete_transit_gateway_vpc_attachment]{delete_transit_gateway_vpc_attachment} \tab Deletes the specified VPC attachment\cr
#'  \link[paws.compute:ec2_delete_verified_access_endpoint]{delete_verified_access_endpoint} \tab Delete an Amazon Web Services Verified Access endpoint\cr
#'  \link[paws.compute:ec2_delete_verified_access_group]{delete_verified_access_group} \tab Delete an Amazon Web Services Verified Access group\cr
#'  \link[paws.compute:ec2_delete_verified_access_instance]{delete_verified_access_instance} \tab Delete an Amazon Web Services Verified Access instance\cr
#'  \link[paws.compute:ec2_delete_verified_access_trust_provider]{delete_verified_access_trust_provider} \tab Delete an Amazon Web Services Verified Access trust provider\cr
#'  \link[paws.compute:ec2_delete_volume]{delete_volume} \tab Deletes the specified EBS volume\cr
#'  \link[paws.compute:ec2_delete_vpc]{delete_vpc} \tab Deletes the specified VPC\cr
#'  \link[paws.compute:ec2_delete_vpc_block_public_access_exclusion]{delete_vpc_block_public_access_exclusion} \tab Delete a VPC Block Public Access (BPA) exclusion\cr
#'  \link[paws.compute:ec2_delete_vpc_endpoint_connection_notifications]{delete_vpc_endpoint_connection_notifications} \tab Deletes the specified VPC endpoint connection notifications\cr
#'  \link[paws.compute:ec2_delete_vpc_endpoints]{delete_vpc_endpoints} \tab Deletes the specified VPC endpoints\cr
#'  \link[paws.compute:ec2_delete_vpc_endpoint_service_configurations]{delete_vpc_endpoint_service_configurations} \tab Deletes the specified VPC endpoint service configurations\cr
#'  \link[paws.compute:ec2_delete_vpc_peering_connection]{delete_vpc_peering_connection} \tab Deletes a VPC peering connection\cr
#'  \link[paws.compute:ec2_delete_vpn_connection]{delete_vpn_connection} \tab Deletes the specified VPN connection\cr
#'  \link[paws.compute:ec2_delete_vpn_connection_route]{delete_vpn_connection_route} \tab Deletes the specified static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway\cr
#'  \link[paws.compute:ec2_delete_vpn_gateway]{delete_vpn_gateway} \tab Deletes the specified virtual private gateway\cr
#'  \link[paws.compute:ec2_deprovision_byoip_cidr]{deprovision_byoip_cidr} \tab Releases the specified address range that you provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and deletes the corresponding address pool\cr
#'  \link[paws.compute:ec2_deprovision_ipam_byoasn]{deprovision_ipam_byoasn} \tab Deprovisions your Autonomous System Number (ASN) from your Amazon Web Services account\cr
#'  \link[paws.compute:ec2_deprovision_ipam_pool_cidr]{deprovision_ipam_pool_cidr} \tab Deprovision a CIDR provisioned from an IPAM pool\cr
#'  \link[paws.compute:ec2_deprovision_public_ipv_4_pool_cidr]{deprovision_public_ipv_4_pool_cidr} \tab Deprovision a CIDR from a public IPv4 pool\cr
#'  \link[paws.compute:ec2_deregister_image]{deregister_image} \tab Deregisters the specified AMI\cr
#'  \link[paws.compute:ec2_deregister_instance_event_notification_attributes]{deregister_instance_event_notification_attributes} \tab Deregisters tag keys to prevent tags that have the specified tag keys from being included in scheduled event notifications for resources in the Region\cr
#'  \link[paws.compute:ec2_deregister_transit_gateway_multicast_group_members]{deregister_transit_gateway_multicast_group_members} \tab Deregisters the specified members (network interfaces) from the transit gateway multicast group\cr
#'  \link[paws.compute:ec2_deregister_transit_gateway_multicast_group_sources]{deregister_transit_gateway_multicast_group_sources} \tab Deregisters the specified sources (network interfaces) from the transit gateway multicast group\cr
#'  \link[paws.compute:ec2_describe_account_attributes]{describe_account_attributes} \tab Describes attributes of your Amazon Web Services account\cr
#'  \link[paws.compute:ec2_describe_addresses]{describe_addresses} \tab Describes the specified Elastic IP addresses or all of your Elastic IP addresses\cr
#'  \link[paws.compute:ec2_describe_addresses_attribute]{describe_addresses_attribute} \tab Describes the attributes of the specified Elastic IP addresses\cr
#'  \link[paws.compute:ec2_describe_address_transfers]{describe_address_transfers} \tab Describes an Elastic IP address transfer\cr
#'  \link[paws.compute:ec2_describe_aggregate_id_format]{describe_aggregate_id_format} \tab Describes the longer ID format settings for all resource types in a specific Region\cr
#'  \link[paws.compute:ec2_describe_availability_zones]{describe_availability_zones} \tab Describes the Availability Zones, Local Zones, and Wavelength Zones that are available to you\cr
#'  \link[paws.compute:ec2_describe_aws_network_performance_metric_subscriptions]{describe_aws_network_performance_metric_subscriptions} \tab Describes the current Infrastructure Performance metric subscriptions\cr
#'  \link[paws.compute:ec2_describe_bundle_tasks]{describe_bundle_tasks} \tab Describes the specified bundle tasks or all of your bundle tasks\cr
#'  \link[paws.compute:ec2_describe_byoip_cidrs]{describe_byoip_cidrs} \tab Describes the IP address ranges that were specified in calls to ProvisionByoipCidr\cr
#'  \link[paws.compute:ec2_describe_capacity_block_extension_history]{describe_capacity_block_extension_history} \tab Describes the events for the specified Capacity Block extension during the specified time\cr
#'  \link[paws.compute:ec2_describe_capacity_block_extension_offerings]{describe_capacity_block_extension_offerings} \tab Describes Capacity Block extension offerings available for purchase in the Amazon Web Services Region that you're currently using\cr
#'  \link[paws.compute:ec2_describe_capacity_block_offerings]{describe_capacity_block_offerings} \tab Describes Capacity Block offerings available for purchase in the Amazon Web Services Region that you're currently using\cr
#'  \link[paws.compute:ec2_describe_capacity_reservation_billing_requests]{describe_capacity_reservation_billing_requests} \tab Describes a request to assign the billing of the unused capacity of a Capacity Reservation\cr
#'  \link[paws.compute:ec2_describe_capacity_reservation_fleets]{describe_capacity_reservation_fleets} \tab Describes one or more Capacity Reservation Fleets\cr
#'  \link[paws.compute:ec2_describe_capacity_reservations]{describe_capacity_reservations} \tab Describes one or more of your Capacity Reservations\cr
#'  \link[paws.compute:ec2_describe_carrier_gateways]{describe_carrier_gateways} \tab Describes one or more of your carrier gateways\cr
#'  \link[paws.compute:ec2_describe_classic_link_instances]{describe_classic_link_instances} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_describe_client_vpn_authorization_rules]{describe_client_vpn_authorization_rules} \tab Describes the authorization rules for a specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_describe_client_vpn_connections]{describe_client_vpn_connections} \tab Describes active client connections and connections that have been terminated within the last 60 minutes for the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_describe_client_vpn_endpoints]{describe_client_vpn_endpoints} \tab Describes one or more Client VPN endpoints in the account\cr
#'  \link[paws.compute:ec2_describe_client_vpn_routes]{describe_client_vpn_routes} \tab Describes the routes for the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_describe_client_vpn_target_networks]{describe_client_vpn_target_networks} \tab Describes the target networks associated with the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_describe_coip_pools]{describe_coip_pools} \tab Describes the specified customer-owned address pools or all of your customer-owned address pools\cr
#'  \link[paws.compute:ec2_describe_conversion_tasks]{describe_conversion_tasks} \tab Describes the specified conversion tasks or all your conversion tasks\cr
#'  \link[paws.compute:ec2_describe_customer_gateways]{describe_customer_gateways} \tab Describes one or more of your VPN customer gateways\cr
#'  \link[paws.compute:ec2_describe_declarative_policies_reports]{describe_declarative_policies_reports} \tab Describes the metadata of an account status report, including the status of the report\cr
#'  \link[paws.compute:ec2_describe_dhcp_options]{describe_dhcp_options} \tab Describes your DHCP option sets\cr
#'  \link[paws.compute:ec2_describe_egress_only_internet_gateways]{describe_egress_only_internet_gateways} \tab Describes your egress-only internet gateways\cr
#'  \link[paws.compute:ec2_describe_elastic_gpus]{describe_elastic_gpus} \tab Amazon Elastic Graphics reached end of life on January 8, 2024\cr
#'  \link[paws.compute:ec2_describe_export_image_tasks]{describe_export_image_tasks} \tab Describes the specified export image tasks or all of your export image tasks\cr
#'  \link[paws.compute:ec2_describe_export_tasks]{describe_export_tasks} \tab Describes the specified export instance tasks or all of your export instance tasks\cr
#'  \link[paws.compute:ec2_describe_fast_launch_images]{describe_fast_launch_images} \tab Describe details for Windows AMIs that are configured for Windows fast launch\cr
#'  \link[paws.compute:ec2_describe_fast_snapshot_restores]{describe_fast_snapshot_restores} \tab Describes the state of fast snapshot restores for your snapshots\cr
#'  \link[paws.compute:ec2_describe_fleet_history]{describe_fleet_history} \tab Describes the events for the specified EC2 Fleet during the specified time\cr
#'  \link[paws.compute:ec2_describe_fleet_instances]{describe_fleet_instances} \tab Describes the running instances for the specified EC2 Fleet\cr
#'  \link[paws.compute:ec2_describe_fleets]{describe_fleets} \tab Describes the specified EC2 Fleet or all of your EC2 Fleets\cr
#'  \link[paws.compute:ec2_describe_flow_logs]{describe_flow_logs} \tab Describes one or more flow logs\cr
#'  \link[paws.compute:ec2_describe_fpga_image_attribute]{describe_fpga_image_attribute} \tab Describes the specified attribute of the specified Amazon FPGA Image (AFI)\cr
#'  \link[paws.compute:ec2_describe_fpga_images]{describe_fpga_images} \tab Describes the Amazon FPGA Images (AFIs) available to you\cr
#'  \link[paws.compute:ec2_describe_host_reservation_offerings]{describe_host_reservation_offerings} \tab Describes the Dedicated Host reservations that are available to purchase\cr
#'  \link[paws.compute:ec2_describe_host_reservations]{describe_host_reservations} \tab Describes reservations that are associated with Dedicated Hosts in your account\cr
#'  \link[paws.compute:ec2_describe_hosts]{describe_hosts} \tab Describes the specified Dedicated Hosts or all your Dedicated Hosts\cr
#'  \link[paws.compute:ec2_describe_iam_instance_profile_associations]{describe_iam_instance_profile_associations} \tab Describes your IAM instance profile associations\cr
#'  \link[paws.compute:ec2_describe_identity_id_format]{describe_identity_id_format} \tab Describes the ID format settings for resources for the specified IAM user, IAM role, or root user\cr
#'  \link[paws.compute:ec2_describe_id_format]{describe_id_format} \tab Describes the ID format settings for your resources on a per-Region basis, for example, to view which resource types are enabled for longer IDs\cr
#'  \link[paws.compute:ec2_describe_image_attribute]{describe_image_attribute} \tab Describes the specified attribute of the specified AMI\cr
#'  \link[paws.compute:ec2_describe_images]{describe_images} \tab Describes the specified images (AMIs, AKIs, and ARIs) available to you or all of the images available to you\cr
#'  \link[paws.compute:ec2_describe_import_image_tasks]{describe_import_image_tasks} \tab Displays details about an import virtual machine or import snapshot tasks that are already created\cr
#'  \link[paws.compute:ec2_describe_import_snapshot_tasks]{describe_import_snapshot_tasks} \tab Describes your import snapshot tasks\cr
#'  \link[paws.compute:ec2_describe_instance_attribute]{describe_instance_attribute} \tab Describes the specified attribute of the specified instance\cr
#'  \link[paws.compute:ec2_describe_instance_connect_endpoints]{describe_instance_connect_endpoints} \tab Describes the specified EC2 Instance Connect Endpoints or all EC2 Instance Connect Endpoints\cr
#'  \link[paws.compute:ec2_describe_instance_credit_specifications]{describe_instance_credit_specifications} \tab Describes the credit option for CPU usage of the specified burstable performance instances\cr
#'  \link[paws.compute:ec2_describe_instance_event_notification_attributes]{describe_instance_event_notification_attributes} \tab Describes the tag keys that are registered to appear in scheduled event notifications for resources in the current Region\cr
#'  \link[paws.compute:ec2_describe_instance_event_windows]{describe_instance_event_windows} \tab Describes the specified event windows or all event windows\cr
#'  \link[paws.compute:ec2_describe_instance_image_metadata]{describe_instance_image_metadata} \tab Describes the AMI that was used to launch an instance, even if the AMI is deprecated, deregistered, made private (no longer public or shared with your account), or not allowed\cr
#'  \link[paws.compute:ec2_describe_instances]{describe_instances} \tab Describes the specified instances or all instances\cr
#'  \link[paws.compute:ec2_describe_instance_status]{describe_instance_status} \tab Describes the status of the specified instances or all of your instances\cr
#'  \link[paws.compute:ec2_describe_instance_topology]{describe_instance_topology} \tab Describes a tree-based hierarchy that represents the physical host placement of your EC2 instances within an Availability Zone or Local Zone\cr
#'  \link[paws.compute:ec2_describe_instance_type_offerings]{describe_instance_type_offerings} \tab Lists the instance types that are offered for the specified location\cr
#'  \link[paws.compute:ec2_describe_instance_types]{describe_instance_types} \tab Describes the specified instance types\cr
#'  \link[paws.compute:ec2_describe_internet_gateways]{describe_internet_gateways} \tab Describes your internet gateways\cr
#'  \link[paws.compute:ec2_describe_ipam_byoasn]{describe_ipam_byoasn} \tab Describes your Autonomous System Numbers (ASNs), their provisioning statuses, and the BYOIP CIDRs with which they are associated\cr
#'  \link[paws.compute:ec2_describe_ipam_external_resource_verification_tokens]{describe_ipam_external_resource_verification_tokens} \tab Describe verification tokens\cr
#'  \link[paws.compute:ec2_describe_ipam_pools]{describe_ipam_pools} \tab Get information about your IPAM pools\cr
#'  \link[paws.compute:ec2_describe_ipam_resource_discoveries]{describe_ipam_resource_discoveries} \tab Describes IPAM resource discoveries\cr
#'  \link[paws.compute:ec2_describe_ipam_resource_discovery_associations]{describe_ipam_resource_discovery_associations} \tab Describes resource discovery association with an Amazon VPC IPAM\cr
#'  \link[paws.compute:ec2_describe_ipams]{describe_ipams} \tab Get information about your IPAM pools\cr
#'  \link[paws.compute:ec2_describe_ipam_scopes]{describe_ipam_scopes} \tab Get information about your IPAM scopes\cr
#'  \link[paws.compute:ec2_describe_ipv_6_pools]{describe_ipv_6_pools} \tab Describes your IPv6 address pools\cr
#'  \link[paws.compute:ec2_describe_key_pairs]{describe_key_pairs} \tab Describes the specified key pairs or all of your key pairs\cr
#'  \link[paws.compute:ec2_describe_launch_templates]{describe_launch_templates} \tab Describes one or more launch templates\cr
#'  \link[paws.compute:ec2_describe_launch_template_versions]{describe_launch_template_versions} \tab Describes one or more versions of a specified launch template\cr
#'  \link[paws.compute:ec2_describe_local_gateway_route_tables]{describe_local_gateway_route_tables} \tab Describes one or more local gateway route tables\cr
#'  \link[paws.compute:ec2_describe_local_gateway_route_table_virtual_interface_group_associations]{describe_local_gateway_route_table_virtual_interface_group_associations} \tab Describes the associations between virtual interface groups and local gateway route tables\cr
#'  \link[paws.compute:ec2_describe_local_gateway_route_table_vpc_associations]{describe_local_gateway_route_table_vpc_associations} \tab Describes the specified associations between VPCs and local gateway route tables\cr
#'  \link[paws.compute:ec2_describe_local_gateways]{describe_local_gateways} \tab Describes one or more local gateways\cr
#'  \link[paws.compute:ec2_describe_local_gateway_virtual_interface_groups]{describe_local_gateway_virtual_interface_groups} \tab Describes the specified local gateway virtual interface groups\cr
#'  \link[paws.compute:ec2_describe_local_gateway_virtual_interfaces]{describe_local_gateway_virtual_interfaces} \tab Describes the specified local gateway virtual interfaces\cr
#'  \link[paws.compute:ec2_describe_locked_snapshots]{describe_locked_snapshots} \tab Describes the lock status for a snapshot\cr
#'  \link[paws.compute:ec2_describe_mac_hosts]{describe_mac_hosts} \tab Describes the specified EC2 Mac Dedicated Host or all of your EC2 Mac Dedicated Hosts\cr
#'  \link[paws.compute:ec2_describe_managed_prefix_lists]{describe_managed_prefix_lists} \tab Describes your managed prefix lists and any Amazon Web Services-managed prefix lists\cr
#'  \link[paws.compute:ec2_describe_moving_addresses]{describe_moving_addresses} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_describe_nat_gateways]{describe_nat_gateways} \tab Describes your NAT gateways\cr
#'  \link[paws.compute:ec2_describe_network_acls]{describe_network_acls} \tab Describes your network ACLs\cr
#'  \link[paws.compute:ec2_describe_network_insights_access_scope_analyses]{describe_network_insights_access_scope_analyses} \tab Describes the specified Network Access Scope analyses\cr
#'  \link[paws.compute:ec2_describe_network_insights_access_scopes]{describe_network_insights_access_scopes} \tab Describes the specified Network Access Scopes\cr
#'  \link[paws.compute:ec2_describe_network_insights_analyses]{describe_network_insights_analyses} \tab Describes one or more of your network insights analyses\cr
#'  \link[paws.compute:ec2_describe_network_insights_paths]{describe_network_insights_paths} \tab Describes one or more of your paths\cr
#'  \link[paws.compute:ec2_describe_network_interface_attribute]{describe_network_interface_attribute} \tab Describes a network interface attribute\cr
#'  \link[paws.compute:ec2_describe_network_interface_permissions]{describe_network_interface_permissions} \tab Describes the permissions for your network interfaces\cr
#'  \link[paws.compute:ec2_describe_network_interfaces]{describe_network_interfaces} \tab Describes the specified network interfaces or all your network interfaces\cr
#'  \link[paws.compute:ec2_describe_placement_groups]{describe_placement_groups} \tab Describes the specified placement groups or all of your placement groups\cr
#'  \link[paws.compute:ec2_describe_prefix_lists]{describe_prefix_lists} \tab Describes available Amazon Web Services services in a prefix list format, which includes the prefix list name and prefix list ID of the service and the IP address range for the service\cr
#'  \link[paws.compute:ec2_describe_principal_id_format]{describe_principal_id_format} \tab Describes the ID format settings for the root user and all IAM roles and IAM users that have explicitly specified a longer ID (17-character ID) preference\cr
#'  \link[paws.compute:ec2_describe_public_ipv_4_pools]{describe_public_ipv_4_pools} \tab Describes the specified IPv4 address pools\cr
#'  \link[paws.compute:ec2_describe_regions]{describe_regions} \tab Describes the Regions that are enabled for your account, or all Regions\cr
#'  \link[paws.compute:ec2_describe_replace_root_volume_tasks]{describe_replace_root_volume_tasks} \tab Describes a root volume replacement task\cr
#'  \link[paws.compute:ec2_describe_reserved_instances]{describe_reserved_instances} \tab Describes one or more of the Reserved Instances that you purchased\cr
#'  \link[paws.compute:ec2_describe_reserved_instances_listings]{describe_reserved_instances_listings} \tab Describes your account's Reserved Instance listings in the Reserved Instance Marketplace\cr
#'  \link[paws.compute:ec2_describe_reserved_instances_modifications]{describe_reserved_instances_modifications} \tab Describes the modifications made to your Reserved Instances\cr
#'  \link[paws.compute:ec2_describe_reserved_instances_offerings]{describe_reserved_instances_offerings} \tab Describes Reserved Instance offerings that are available for purchase\cr
#'  \link[paws.compute:ec2_describe_route_tables]{describe_route_tables} \tab Describes your route tables\cr
#'  \link[paws.compute:ec2_describe_scheduled_instance_availability]{describe_scheduled_instance_availability} \tab Finds available schedules that meet the specified criteria\cr
#'  \link[paws.compute:ec2_describe_scheduled_instances]{describe_scheduled_instances} \tab Describes the specified Scheduled Instances or all your Scheduled Instances\cr
#'  \link[paws.compute:ec2_describe_security_group_references]{describe_security_group_references} \tab Describes the VPCs on the other side of a VPC peering or Transit Gateway connection that are referencing the security groups you've specified in this request\cr
#'  \link[paws.compute:ec2_describe_security_group_rules]{describe_security_group_rules} \tab Describes one or more of your security group rules\cr
#'  \link[paws.compute:ec2_describe_security_groups]{describe_security_groups} \tab Describes the specified security groups or all of your security groups\cr
#'  \link[paws.compute:ec2_describe_security_group_vpc_associations]{describe_security_group_vpc_associations} \tab Describes security group VPC associations made with AssociateSecurityGroupVpc\cr
#'  \link[paws.compute:ec2_describe_snapshot_attribute]{describe_snapshot_attribute} \tab Describes the specified attribute of the specified snapshot\cr
#'  \link[paws.compute:ec2_describe_snapshots]{describe_snapshots} \tab Describes the specified EBS snapshots available to you or all of the EBS snapshots available to you\cr
#'  \link[paws.compute:ec2_describe_snapshot_tier_status]{describe_snapshot_tier_status} \tab Describes the storage tier status of one or more Amazon EBS snapshots\cr
#'  \link[paws.compute:ec2_describe_spot_datafeed_subscription]{describe_spot_datafeed_subscription} \tab Describes the data feed for Spot Instances\cr
#'  \link[paws.compute:ec2_describe_spot_fleet_instances]{describe_spot_fleet_instances} \tab Describes the running instances for the specified Spot Fleet\cr
#'  \link[paws.compute:ec2_describe_spot_fleet_request_history]{describe_spot_fleet_request_history} \tab Describes the events for the specified Spot Fleet request during the specified time\cr
#'  \link[paws.compute:ec2_describe_spot_fleet_requests]{describe_spot_fleet_requests} \tab Describes your Spot Fleet requests\cr
#'  \link[paws.compute:ec2_describe_spot_instance_requests]{describe_spot_instance_requests} \tab Describes the specified Spot Instance requests\cr
#'  \link[paws.compute:ec2_describe_spot_price_history]{describe_spot_price_history} \tab Describes the Spot price history\cr
#'  \link[paws.compute:ec2_describe_stale_security_groups]{describe_stale_security_groups} \tab Describes the stale security group rules for security groups referenced across a VPC peering connection, transit gateway connection, or with a security group VPC association\cr
#'  \link[paws.compute:ec2_describe_store_image_tasks]{describe_store_image_tasks} \tab Describes the progress of the AMI store tasks\cr
#'  \link[paws.compute:ec2_describe_subnets]{describe_subnets} \tab Describes your subnets\cr
#'  \link[paws.compute:ec2_describe_tags]{describe_tags} \tab Describes the specified tags for your EC2 resources\cr
#'  \link[paws.compute:ec2_describe_traffic_mirror_filter_rules]{describe_traffic_mirror_filter_rules} \tab Describe traffic mirror filters that determine the traffic that is mirrored\cr
#'  \link[paws.compute:ec2_describe_traffic_mirror_filters]{describe_traffic_mirror_filters} \tab Describes one or more Traffic Mirror filters\cr
#'  \link[paws.compute:ec2_describe_traffic_mirror_sessions]{describe_traffic_mirror_sessions} \tab Describes one or more Traffic Mirror sessions\cr
#'  \link[paws.compute:ec2_describe_traffic_mirror_targets]{describe_traffic_mirror_targets} \tab Information about one or more Traffic Mirror targets\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_attachments]{describe_transit_gateway_attachments} \tab Describes one or more attachments between resources and transit gateways\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_connect_peers]{describe_transit_gateway_connect_peers} \tab Describes one or more Connect peers\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_connects]{describe_transit_gateway_connects} \tab Describes one or more Connect attachments\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_multicast_domains]{describe_transit_gateway_multicast_domains} \tab Describes one or more transit gateway multicast domains\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_peering_attachments]{describe_transit_gateway_peering_attachments} \tab Describes your transit gateway peering attachments\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_policy_tables]{describe_transit_gateway_policy_tables} \tab Describes one or more transit gateway route policy tables\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_route_table_announcements]{describe_transit_gateway_route_table_announcements} \tab Describes one or more transit gateway route table advertisements\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_route_tables]{describe_transit_gateway_route_tables} \tab Describes one or more transit gateway route tables\cr
#'  \link[paws.compute:ec2_describe_transit_gateways]{describe_transit_gateways} \tab Describes one or more transit gateways\cr
#'  \link[paws.compute:ec2_describe_transit_gateway_vpc_attachments]{describe_transit_gateway_vpc_attachments} \tab Describes one or more VPC attachments\cr
#'  \link[paws.compute:ec2_describe_trunk_interface_associations]{describe_trunk_interface_associations} \tab Describes one or more network interface trunk associations\cr
#'  \link[paws.compute:ec2_describe_verified_access_endpoints]{describe_verified_access_endpoints} \tab Describes the specified Amazon Web Services Verified Access endpoints\cr
#'  \link[paws.compute:ec2_describe_verified_access_groups]{describe_verified_access_groups} \tab Describes the specified Verified Access groups\cr
#'  \link[paws.compute:ec2_describe_verified_access_instance_logging_configurations]{describe_verified_access_instance_logging_configurations} \tab Describes the specified Amazon Web Services Verified Access instances\cr
#'  \link[paws.compute:ec2_describe_verified_access_instances]{describe_verified_access_instances} \tab Describes the specified Amazon Web Services Verified Access instances\cr
#'  \link[paws.compute:ec2_describe_verified_access_trust_providers]{describe_verified_access_trust_providers} \tab Describes the specified Amazon Web Services Verified Access trust providers\cr
#'  \link[paws.compute:ec2_describe_volume_attribute]{describe_volume_attribute} \tab Describes the specified attribute of the specified volume\cr
#'  \link[paws.compute:ec2_describe_volumes]{describe_volumes} \tab Describes the specified EBS volumes or all of your EBS volumes\cr
#'  \link[paws.compute:ec2_describe_volumes_modifications]{describe_volumes_modifications} \tab Describes the most recent volume modification request for the specified EBS volumes\cr
#'  \link[paws.compute:ec2_describe_volume_status]{describe_volume_status} \tab Describes the status of the specified volumes\cr
#'  \link[paws.compute:ec2_describe_vpc_attribute]{describe_vpc_attribute} \tab Describes the specified attribute of the specified VPC\cr
#'  \link[paws.compute:ec2_describe_vpc_block_public_access_exclusions]{describe_vpc_block_public_access_exclusions} \tab Describe VPC Block Public Access (BPA) exclusions\cr
#'  \link[paws.compute:ec2_describe_vpc_block_public_access_options]{describe_vpc_block_public_access_options} \tab Describe VPC Block Public Access (BPA) options\cr
#'  \link[paws.compute:ec2_describe_vpc_classic_link]{describe_vpc_classic_link} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_describe_vpc_classic_link_dns_support]{describe_vpc_classic_link_dns_support} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_describe_vpc_endpoint_associations]{describe_vpc_endpoint_associations} \tab Describes the VPC resources, VPC endpoint services, Amazon Lattice services, or service networks associated with the VPC endpoint\cr
#'  \link[paws.compute:ec2_describe_vpc_endpoint_connection_notifications]{describe_vpc_endpoint_connection_notifications} \tab Describes the connection notifications for VPC endpoints and VPC endpoint services\cr
#'  \link[paws.compute:ec2_describe_vpc_endpoint_connections]{describe_vpc_endpoint_connections} \tab Describes the VPC endpoint connections to your VPC endpoint services, including any endpoints that are pending your acceptance\cr
#'  \link[paws.compute:ec2_describe_vpc_endpoints]{describe_vpc_endpoints} \tab Describes your VPC endpoints\cr
#'  \link[paws.compute:ec2_describe_vpc_endpoint_service_configurations]{describe_vpc_endpoint_service_configurations} \tab Describes the VPC endpoint service configurations in your account (your services)\cr
#'  \link[paws.compute:ec2_describe_vpc_endpoint_service_permissions]{describe_vpc_endpoint_service_permissions} \tab Describes the principals (service consumers) that are permitted to discover your VPC endpoint service\cr
#'  \link[paws.compute:ec2_describe_vpc_endpoint_services]{describe_vpc_endpoint_services} \tab Describes available services to which you can create a VPC endpoint\cr
#'  \link[paws.compute:ec2_describe_vpc_peering_connections]{describe_vpc_peering_connections} \tab Describes your VPC peering connections\cr
#'  \link[paws.compute:ec2_describe_vpcs]{describe_vpcs} \tab Describes your VPCs\cr
#'  \link[paws.compute:ec2_describe_vpn_connections]{describe_vpn_connections} \tab Describes one or more of your VPN connections\cr
#'  \link[paws.compute:ec2_describe_vpn_gateways]{describe_vpn_gateways} \tab Describes one or more of your virtual private gateways\cr
#'  \link[paws.compute:ec2_detach_classic_link_vpc]{detach_classic_link_vpc} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_detach_internet_gateway]{detach_internet_gateway} \tab Detaches an internet gateway from a VPC, disabling connectivity between the internet and the VPC\cr
#'  \link[paws.compute:ec2_detach_network_interface]{detach_network_interface} \tab Detaches a network interface from an instance\cr
#'  \link[paws.compute:ec2_detach_verified_access_trust_provider]{detach_verified_access_trust_provider} \tab Detaches the specified Amazon Web Services Verified Access trust provider from the specified Amazon Web Services Verified Access instance\cr
#'  \link[paws.compute:ec2_detach_volume]{detach_volume} \tab Detaches an EBS volume from an instance\cr
#'  \link[paws.compute:ec2_detach_vpn_gateway]{detach_vpn_gateway} \tab Detaches a virtual private gateway from a VPC\cr
#'  \link[paws.compute:ec2_disable_address_transfer]{disable_address_transfer} \tab Disables Elastic IP address transfer\cr
#'  \link[paws.compute:ec2_disable_allowed_images_settings]{disable_allowed_images_settings} \tab Disables Allowed AMIs for your account in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_disable_aws_network_performance_metric_subscription]{disable_aws_network_performance_metric_subscription} \tab Disables Infrastructure Performance metric subscriptions\cr
#'  \link[paws.compute:ec2_disable_ebs_encryption_by_default]{disable_ebs_encryption_by_default} \tab Disables EBS encryption by default for your account in the current Region\cr
#'  \link[paws.compute:ec2_disable_fast_launch]{disable_fast_launch} \tab Discontinue Windows fast launch for a Windows AMI, and clean up existing pre-provisioned snapshots\cr
#'  \link[paws.compute:ec2_disable_fast_snapshot_restores]{disable_fast_snapshot_restores} \tab Disables fast snapshot restores for the specified snapshots in the specified Availability Zones\cr
#'  \link[paws.compute:ec2_disable_image]{disable_image} \tab Sets the AMI state to disabled and removes all launch permissions from the AMI\cr
#'  \link[paws.compute:ec2_disable_image_block_public_access]{disable_image_block_public_access} \tab Disables block public access for AMIs at the account level in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_disable_image_deprecation]{disable_image_deprecation} \tab Cancels the deprecation of the specified AMI\cr
#'  \link[paws.compute:ec2_disable_image_deregistration_protection]{disable_image_deregistration_protection} \tab Disables deregistration protection for an AMI\cr
#'  \link[paws.compute:ec2_disable_ipam_organization_admin_account]{disable_ipam_organization_admin_account} \tab Disable the IPAM account\cr
#'  \link[paws.compute:ec2_disable_serial_console_access]{disable_serial_console_access} \tab Disables access to the EC2 serial console of all instances for your account\cr
#'  \link[paws.compute:ec2_disable_snapshot_block_public_access]{disable_snapshot_block_public_access} \tab Disables the block public access for snapshots setting at the account level for the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_disable_transit_gateway_route_table_propagation]{disable_transit_gateway_route_table_propagation} \tab Disables the specified resource attachment from propagating routes to the specified propagation route table\cr
#'  \link[paws.compute:ec2_disable_vgw_route_propagation]{disable_vgw_route_propagation} \tab Disables a virtual private gateway (VGW) from propagating routes to a specified route table of a VPC\cr
#'  \link[paws.compute:ec2_disable_vpc_classic_link]{disable_vpc_classic_link} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_disable_vpc_classic_link_dns_support]{disable_vpc_classic_link_dns_support} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_disassociate_address]{disassociate_address} \tab Disassociates an Elastic IP address from the instance or network interface it's associated with\cr
#'  \link[paws.compute:ec2_disassociate_capacity_reservation_billing_owner]{disassociate_capacity_reservation_billing_owner} \tab Cancels a pending request to assign billing of the unused capacity of a Capacity Reservation to a consumer account, or revokes a request that has already been accepted\cr
#'  \link[paws.compute:ec2_disassociate_client_vpn_target_network]{disassociate_client_vpn_target_network} \tab Disassociates a target network from the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_disassociate_enclave_certificate_iam_role]{disassociate_enclave_certificate_iam_role} \tab Disassociates an IAM role from an Certificate Manager (ACM) certificate\cr
#'  \link[paws.compute:ec2_disassociate_iam_instance_profile]{disassociate_iam_instance_profile} \tab Disassociates an IAM instance profile from a running or stopped instance\cr
#'  \link[paws.compute:ec2_disassociate_instance_event_window]{disassociate_instance_event_window} \tab Disassociates one or more targets from an event window\cr
#'  \link[paws.compute:ec2_disassociate_ipam_byoasn]{disassociate_ipam_byoasn} \tab Remove the association between your Autonomous System Number (ASN) and your BYOIP CIDR\cr
#'  \link[paws.compute:ec2_disassociate_ipam_resource_discovery]{disassociate_ipam_resource_discovery} \tab Disassociates a resource discovery from an Amazon VPC IPAM\cr
#'  \link[paws.compute:ec2_disassociate_nat_gateway_address]{disassociate_nat_gateway_address} \tab Disassociates secondary Elastic IP addresses (EIPs) from a public NAT gateway\cr
#'  \link[paws.compute:ec2_disassociate_route_table]{disassociate_route_table} \tab Disassociates a subnet or gateway from a route table\cr
#'  \link[paws.compute:ec2_disassociate_security_group_vpc]{disassociate_security_group_vpc} \tab Disassociates a security group from a VPC\cr
#'  \link[paws.compute:ec2_disassociate_subnet_cidr_block]{disassociate_subnet_cidr_block} \tab Disassociates a CIDR block from a subnet\cr
#'  \link[paws.compute:ec2_disassociate_transit_gateway_multicast_domain]{disassociate_transit_gateway_multicast_domain} \tab Disassociates the specified subnets from the transit gateway multicast domain\cr
#'  \link[paws.compute:ec2_disassociate_transit_gateway_policy_table]{disassociate_transit_gateway_policy_table} \tab Removes the association between an an attachment and a policy table\cr
#'  \link[paws.compute:ec2_disassociate_transit_gateway_route_table]{disassociate_transit_gateway_route_table} \tab Disassociates a resource attachment from a transit gateway route table\cr
#'  \link[paws.compute:ec2_disassociate_trunk_interface]{disassociate_trunk_interface} \tab Removes an association between a branch network interface with a trunk network interface\cr
#'  \link[paws.compute:ec2_disassociate_vpc_cidr_block]{disassociate_vpc_cidr_block} \tab Disassociates a CIDR block from a VPC\cr
#'  \link[paws.compute:ec2_enable_address_transfer]{enable_address_transfer} \tab Enables Elastic IP address transfer\cr
#'  \link[paws.compute:ec2_enable_allowed_images_settings]{enable_allowed_images_settings} \tab Enables Allowed AMIs for your account in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_enable_aws_network_performance_metric_subscription]{enable_aws_network_performance_metric_subscription} \tab Enables Infrastructure Performance subscriptions\cr
#'  \link[paws.compute:ec2_enable_ebs_encryption_by_default]{enable_ebs_encryption_by_default} \tab Enables EBS encryption by default for your account in the current Region\cr
#'  \link[paws.compute:ec2_enable_fast_launch]{enable_fast_launch} \tab When you enable Windows fast launch for a Windows AMI, images are pre-provisioned, using snapshots to launch instances up to 65% faster\cr
#'  \link[paws.compute:ec2_enable_fast_snapshot_restores]{enable_fast_snapshot_restores} \tab Enables fast snapshot restores for the specified snapshots in the specified Availability Zones\cr
#'  \link[paws.compute:ec2_enable_image]{enable_image} \tab Re-enables a disabled AMI\cr
#'  \link[paws.compute:ec2_enable_image_block_public_access]{enable_image_block_public_access} \tab Enables block public access for AMIs at the account level in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_enable_image_deprecation]{enable_image_deprecation} \tab Enables deprecation of the specified AMI at the specified date and time\cr
#'  \link[paws.compute:ec2_enable_image_deregistration_protection]{enable_image_deregistration_protection} \tab Enables deregistration protection for an AMI\cr
#'  \link[paws.compute:ec2_enable_ipam_organization_admin_account]{enable_ipam_organization_admin_account} \tab Enable an Organizations member account as the IPAM admin account\cr
#'  \link[paws.compute:ec2_enable_reachability_analyzer_organization_sharing]{enable_reachability_analyzer_organization_sharing} \tab Establishes a trust relationship between Reachability Analyzer and Organizations\cr
#'  \link[paws.compute:ec2_enable_serial_console_access]{enable_serial_console_access} \tab Enables access to the EC2 serial console of all instances for your account\cr
#'  \link[paws.compute:ec2_enable_snapshot_block_public_access]{enable_snapshot_block_public_access} \tab Enables or modifies the block public access for snapshots setting at the account level for the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_enable_transit_gateway_route_table_propagation]{enable_transit_gateway_route_table_propagation} \tab Enables the specified attachment to propagate routes to the specified propagation route table\cr
#'  \link[paws.compute:ec2_enable_vgw_route_propagation]{enable_vgw_route_propagation} \tab Enables a virtual private gateway (VGW) to propagate routes to the specified route table of a VPC\cr
#'  \link[paws.compute:ec2_enable_volume_io]{enable_volume_io} \tab Enables I/O operations for a volume that had I/O operations disabled because the data on the volume was potentially inconsistent\cr
#'  \link[paws.compute:ec2_enable_vpc_classic_link]{enable_vpc_classic_link} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_enable_vpc_classic_link_dns_support]{enable_vpc_classic_link_dns_support} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_export_client_vpn_client_certificate_revocation_list]{export_client_vpn_client_certificate_revocation_list} \tab Downloads the client certificate revocation list for the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_export_client_vpn_client_configuration]{export_client_vpn_client_configuration} \tab Downloads the contents of the Client VPN endpoint configuration file for the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_export_image]{export_image} \tab Exports an Amazon Machine Image (AMI) to a VM file\cr
#'  \link[paws.compute:ec2_export_transit_gateway_routes]{export_transit_gateway_routes} \tab Exports routes from the specified transit gateway route table to the specified S3 bucket\cr
#'  \link[paws.compute:ec2_export_verified_access_instance_client_configuration]{export_verified_access_instance_client_configuration} \tab Exports the client configuration for a Verified Access instance\cr
#'  \link[paws.compute:ec2_get_allowed_images_settings]{get_allowed_images_settings} \tab Gets the current state of the Allowed AMIs setting and the list of Allowed AMIs criteria at the account level in the specified Region\cr
#'  \link[paws.compute:ec2_get_associated_enclave_certificate_iam_roles]{get_associated_enclave_certificate_iam_roles} \tab Returns the IAM roles that are associated with the specified ACM (ACM) certificate\cr
#'  \link[paws.compute:ec2_get_associated_ipv_6_pool_cidrs]{get_associated_ipv_6_pool_cidrs} \tab Gets information about the IPv6 CIDR block associations for a specified IPv6 address pool\cr
#'  \link[paws.compute:ec2_get_aws_network_performance_data]{get_aws_network_performance_data} \tab Gets network performance data\cr
#'  \link[paws.compute:ec2_get_capacity_reservation_usage]{get_capacity_reservation_usage} \tab Gets usage information about a Capacity Reservation\cr
#'  \link[paws.compute:ec2_get_coip_pool_usage]{get_coip_pool_usage} \tab Describes the allocations from the specified customer-owned address pool\cr
#'  \link[paws.compute:ec2_get_console_output]{get_console_output} \tab Gets the console output for the specified instance\cr
#'  \link[paws.compute:ec2_get_console_screenshot]{get_console_screenshot} \tab Retrieve a JPG-format screenshot of a running instance to help with troubleshooting\cr
#'  \link[paws.compute:ec2_get_declarative_policies_report_summary]{get_declarative_policies_report_summary} \tab Retrieves a summary of the account status report\cr
#'  \link[paws.compute:ec2_get_default_credit_specification]{get_default_credit_specification} \tab Describes the default credit option for CPU usage of a burstable performance instance family\cr
#'  \link[paws.compute:ec2_get_ebs_default_kms_key_id]{get_ebs_default_kms_key_id} \tab Describes the default KMS key for EBS encryption by default for your account in this Region\cr
#'  \link[paws.compute:ec2_get_ebs_encryption_by_default]{get_ebs_encryption_by_default} \tab Describes whether EBS encryption by default is enabled for your account in the current Region\cr
#'  \link[paws.compute:ec2_get_flow_logs_integration_template]{get_flow_logs_integration_template} \tab Generates a CloudFormation template that streamlines and automates the integration of VPC flow logs with Amazon Athena\cr
#'  \link[paws.compute:ec2_get_groups_for_capacity_reservation]{get_groups_for_capacity_reservation} \tab Lists the resource groups to which a Capacity Reservation has been added\cr
#'  \link[paws.compute:ec2_get_host_reservation_purchase_preview]{get_host_reservation_purchase_preview} \tab Preview a reservation purchase with configurations that match those of your Dedicated Host\cr
#'  \link[paws.compute:ec2_get_image_block_public_access_state]{get_image_block_public_access_state} \tab Gets the current state of block public access for AMIs at the account level in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_get_instance_metadata_defaults]{get_instance_metadata_defaults} \tab Gets the default instance metadata service (IMDS) settings that are set at the account level in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_get_instance_tpm_ek_pub]{get_instance_tpm_ek_pub} \tab Gets the public endorsement key associated with the Nitro Trusted Platform Module (NitroTPM) for the specified instance\cr
#'  \link[paws.compute:ec2_get_instance_types_from_instance_requirements]{get_instance_types_from_instance_requirements} \tab Returns a list of instance types with the specified instance attributes\cr
#'  \link[paws.compute:ec2_get_instance_uefi_data]{get_instance_uefi_data} \tab A binary representation of the UEFI variable store\cr
#'  \link[paws.compute:ec2_get_ipam_address_history]{get_ipam_address_history} \tab Retrieve historical information about a CIDR within an IPAM scope\cr
#'  \link[paws.compute:ec2_get_ipam_discovered_accounts]{get_ipam_discovered_accounts} \tab Gets IPAM discovered accounts\cr
#'  \link[paws.compute:ec2_get_ipam_discovered_public_addresses]{get_ipam_discovered_public_addresses} \tab Gets the public IP addresses that have been discovered by IPAM\cr
#'  \link[paws.compute:ec2_get_ipam_discovered_resource_cidrs]{get_ipam_discovered_resource_cidrs} \tab Returns the resource CIDRs that are monitored as part of a resource discovery\cr
#'  \link[paws.compute:ec2_get_ipam_pool_allocations]{get_ipam_pool_allocations} \tab Get a list of all the CIDR allocations in an IPAM pool\cr
#'  \link[paws.compute:ec2_get_ipam_pool_cidrs]{get_ipam_pool_cidrs} \tab Get the CIDRs provisioned to an IPAM pool\cr
#'  \link[paws.compute:ec2_get_ipam_resource_cidrs]{get_ipam_resource_cidrs} \tab Returns resource CIDRs managed by IPAM in a given scope\cr
#'  \link[paws.compute:ec2_get_launch_template_data]{get_launch_template_data} \tab Retrieves the configuration data of the specified instance\cr
#'  \link[paws.compute:ec2_get_managed_prefix_list_associations]{get_managed_prefix_list_associations} \tab Gets information about the resources that are associated with the specified managed prefix list\cr
#'  \link[paws.compute:ec2_get_managed_prefix_list_entries]{get_managed_prefix_list_entries} \tab Gets information about the entries for a specified managed prefix list\cr
#'  \link[paws.compute:ec2_get_network_insights_access_scope_analysis_findings]{get_network_insights_access_scope_analysis_findings} \tab Gets the findings for the specified Network Access Scope analysis\cr
#'  \link[paws.compute:ec2_get_network_insights_access_scope_content]{get_network_insights_access_scope_content} \tab Gets the content for the specified Network Access Scope\cr
#'  \link[paws.compute:ec2_get_password_data]{get_password_data} \tab Retrieves the encrypted administrator password for a running Windows instance\cr
#'  \link[paws.compute:ec2_get_reserved_instances_exchange_quote]{get_reserved_instances_exchange_quote} \tab Returns a quote and exchange information for exchanging one or more specified Convertible Reserved Instances for a new Convertible Reserved Instance\cr
#'  \link[paws.compute:ec2_get_security_groups_for_vpc]{get_security_groups_for_vpc} \tab Gets security groups that can be associated by the Amazon Web Services account making the request with network interfaces in the specified VPC\cr
#'  \link[paws.compute:ec2_get_serial_console_access_status]{get_serial_console_access_status} \tab Retrieves the access status of your account to the EC2 serial console of all instances\cr
#'  \link[paws.compute:ec2_get_snapshot_block_public_access_state]{get_snapshot_block_public_access_state} \tab Gets the current state of block public access for snapshots setting for the account and Region\cr
#'  \link[paws.compute:ec2_get_spot_placement_scores]{get_spot_placement_scores} \tab Calculates the Spot placement score for a Region or Availability Zone based on the specified target capacity and compute requirements\cr
#'  \link[paws.compute:ec2_get_subnet_cidr_reservations]{get_subnet_cidr_reservations} \tab Gets information about the subnet CIDR reservations\cr
#'  \link[paws.compute:ec2_get_transit_gateway_attachment_propagations]{get_transit_gateway_attachment_propagations} \tab Lists the route tables to which the specified resource attachment propagates routes\cr
#'  \link[paws.compute:ec2_get_transit_gateway_multicast_domain_associations]{get_transit_gateway_multicast_domain_associations} \tab Gets information about the associations for the transit gateway multicast domain\cr
#'  \link[paws.compute:ec2_get_transit_gateway_policy_table_associations]{get_transit_gateway_policy_table_associations} \tab Gets a list of the transit gateway policy table associations\cr
#'  \link[paws.compute:ec2_get_transit_gateway_policy_table_entries]{get_transit_gateway_policy_table_entries} \tab Returns a list of transit gateway policy table entries\cr
#'  \link[paws.compute:ec2_get_transit_gateway_prefix_list_references]{get_transit_gateway_prefix_list_references} \tab Gets information about the prefix list references in a specified transit gateway route table\cr
#'  \link[paws.compute:ec2_get_transit_gateway_route_table_associations]{get_transit_gateway_route_table_associations} \tab Gets information about the associations for the specified transit gateway route table\cr
#'  \link[paws.compute:ec2_get_transit_gateway_route_table_propagations]{get_transit_gateway_route_table_propagations} \tab Gets information about the route table propagations for the specified transit gateway route table\cr
#'  \link[paws.compute:ec2_get_verified_access_endpoint_policy]{get_verified_access_endpoint_policy} \tab Get the Verified Access policy associated with the endpoint\cr
#'  \link[paws.compute:ec2_get_verified_access_endpoint_targets]{get_verified_access_endpoint_targets} \tab Gets the targets for the specified network CIDR endpoint for Verified Access\cr
#'  \link[paws.compute:ec2_get_verified_access_group_policy]{get_verified_access_group_policy} \tab Shows the contents of the Verified Access policy associated with the group\cr
#'  \link[paws.compute:ec2_get_vpn_connection_device_sample_configuration]{get_vpn_connection_device_sample_configuration} \tab Download an Amazon Web Services-provided sample configuration file to be used with the customer gateway device specified for your Site-to-Site VPN connection\cr
#'  \link[paws.compute:ec2_get_vpn_connection_device_types]{get_vpn_connection_device_types} \tab Obtain a list of customer gateway devices for which sample configuration files can be provided\cr
#'  \link[paws.compute:ec2_get_vpn_tunnel_replacement_status]{get_vpn_tunnel_replacement_status} \tab Get details of available tunnel endpoint maintenance\cr
#'  \link[paws.compute:ec2_import_client_vpn_client_certificate_revocation_list]{import_client_vpn_client_certificate_revocation_list} \tab Uploads a client certificate revocation list to the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_import_image]{import_image} \tab To import your virtual machines (VMs) with a console-based experience, you can use the Import virtual machine images to Amazon Web Services template in the Migration Hub Orchestrator console\cr
#'  \link[paws.compute:ec2_import_instance]{import_instance} \tab We recommend that you use the ImportImage API instead\cr
#'  \link[paws.compute:ec2_import_key_pair]{import_key_pair} \tab Imports the public key from an RSA or ED25519 key pair that you created using a third-party tool\cr
#'  \link[paws.compute:ec2_import_snapshot]{import_snapshot} \tab Imports a disk into an EBS snapshot\cr
#'  \link[paws.compute:ec2_import_volume]{import_volume} \tab This API action supports only single-volume VMs\cr
#'  \link[paws.compute:ec2_list_images_in_recycle_bin]{list_images_in_recycle_bin} \tab Lists one or more AMIs that are currently in the Recycle Bin\cr
#'  \link[paws.compute:ec2_list_snapshots_in_recycle_bin]{list_snapshots_in_recycle_bin} \tab Lists one or more snapshots that are currently in the Recycle Bin\cr
#'  \link[paws.compute:ec2_lock_snapshot]{lock_snapshot} \tab Locks an Amazon EBS snapshot in either governance or compliance mode to protect it against accidental or malicious deletions for a specific duration\cr
#'  \link[paws.compute:ec2_modify_address_attribute]{modify_address_attribute} \tab Modifies an attribute of the specified Elastic IP address\cr
#'  \link[paws.compute:ec2_modify_availability_zone_group]{modify_availability_zone_group} \tab Changes the opt-in status of the specified zone group for your account\cr
#'  \link[paws.compute:ec2_modify_capacity_reservation]{modify_capacity_reservation} \tab Modifies a Capacity Reservation's capacity, instance eligibility, and the conditions under which it is to be released\cr
#'  \link[paws.compute:ec2_modify_capacity_reservation_fleet]{modify_capacity_reservation_fleet} \tab Modifies a Capacity Reservation Fleet\cr
#'  \link[paws.compute:ec2_modify_client_vpn_endpoint]{modify_client_vpn_endpoint} \tab Modifies the specified Client VPN endpoint\cr
#'  \link[paws.compute:ec2_modify_default_credit_specification]{modify_default_credit_specification} \tab Modifies the default credit option for CPU usage of burstable performance instances\cr
#'  \link[paws.compute:ec2_modify_ebs_default_kms_key_id]{modify_ebs_default_kms_key_id} \tab Changes the default KMS key for EBS encryption by default for your account in this Region\cr
#'  \link[paws.compute:ec2_modify_fleet]{modify_fleet} \tab Modifies the specified EC2 Fleet\cr
#'  \link[paws.compute:ec2_modify_fpga_image_attribute]{modify_fpga_image_attribute} \tab Modifies the specified attribute of the specified Amazon FPGA Image (AFI)\cr
#'  \link[paws.compute:ec2_modify_hosts]{modify_hosts} \tab Modify the auto-placement setting of a Dedicated Host\cr
#'  \link[paws.compute:ec2_modify_identity_id_format]{modify_identity_id_format} \tab Modifies the ID format of a resource for a specified IAM user, IAM role, or the root user for an account; or all IAM users, IAM roles, and the root user for an account\cr
#'  \link[paws.compute:ec2_modify_id_format]{modify_id_format} \tab Modifies the ID format for the specified resource on a per-Region basis\cr
#'  \link[paws.compute:ec2_modify_image_attribute]{modify_image_attribute} \tab Modifies the specified attribute of the specified AMI\cr
#'  \link[paws.compute:ec2_modify_instance_attribute]{modify_instance_attribute} \tab Modifies the specified attribute of the specified instance\cr
#'  \link[paws.compute:ec2_modify_instance_capacity_reservation_attributes]{modify_instance_capacity_reservation_attributes} \tab Modifies the Capacity Reservation settings for a stopped instance\cr
#'  \link[paws.compute:ec2_modify_instance_cpu_options]{modify_instance_cpu_options} \tab By default, all vCPUs for the instance type are active when you launch an instance\cr
#'  \link[paws.compute:ec2_modify_instance_credit_specification]{modify_instance_credit_specification} \tab Modifies the credit option for CPU usage on a running or stopped burstable performance instance\cr
#'  \link[paws.compute:ec2_modify_instance_event_start_time]{modify_instance_event_start_time} \tab Modifies the start time for a scheduled Amazon EC2 instance event\cr
#'  \link[paws.compute:ec2_modify_instance_event_window]{modify_instance_event_window} \tab Modifies the specified event window\cr
#'  \link[paws.compute:ec2_modify_instance_maintenance_options]{modify_instance_maintenance_options} \tab Modifies the recovery behavior of your instance to disable simplified automatic recovery or set the recovery behavior to default\cr
#'  \link[paws.compute:ec2_modify_instance_metadata_defaults]{modify_instance_metadata_defaults} \tab Modifies the default instance metadata service (IMDS) settings at the account level in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:ec2_modify_instance_metadata_options]{modify_instance_metadata_options} \tab Modify the instance metadata parameters on a running or stopped instance\cr
#'  \link[paws.compute:ec2_modify_instance_network_performance_options]{modify_instance_network_performance_options} \tab Change the configuration of the network performance options for an existing instance\cr
#'  \link[paws.compute:ec2_modify_instance_placement]{modify_instance_placement} \tab Modifies the placement attributes for a specified instance\cr
#'  \link[paws.compute:ec2_modify_ipam]{modify_ipam} \tab Modify the configurations of an IPAM\cr
#'  \link[paws.compute:ec2_modify_ipam_pool]{modify_ipam_pool} \tab Modify the configurations of an IPAM pool\cr
#'  \link[paws.compute:ec2_modify_ipam_resource_cidr]{modify_ipam_resource_cidr} \tab Modify a resource CIDR\cr
#'  \link[paws.compute:ec2_modify_ipam_resource_discovery]{modify_ipam_resource_discovery} \tab Modifies a resource discovery\cr
#'  \link[paws.compute:ec2_modify_ipam_scope]{modify_ipam_scope} \tab Modify an IPAM scope\cr
#'  \link[paws.compute:ec2_modify_launch_template]{modify_launch_template} \tab Modifies a launch template\cr
#'  \link[paws.compute:ec2_modify_local_gateway_route]{modify_local_gateway_route} \tab Modifies the specified local gateway route\cr
#'  \link[paws.compute:ec2_modify_managed_prefix_list]{modify_managed_prefix_list} \tab Modifies the specified managed prefix list\cr
#'  \link[paws.compute:ec2_modify_network_interface_attribute]{modify_network_interface_attribute} \tab Modifies the specified network interface attribute\cr
#'  \link[paws.compute:ec2_modify_private_dns_name_options]{modify_private_dns_name_options} \tab Modifies the options for instance hostnames for the specified instance\cr
#'  \link[paws.compute:ec2_modify_reserved_instances]{modify_reserved_instances} \tab Modifies the configuration of your Reserved Instances, such as the Availability Zone, instance count, or instance type\cr
#'  \link[paws.compute:ec2_modify_security_group_rules]{modify_security_group_rules} \tab Modifies the rules of a security group\cr
#'  \link[paws.compute:ec2_modify_snapshot_attribute]{modify_snapshot_attribute} \tab Adds or removes permission settings for the specified snapshot\cr
#'  \link[paws.compute:ec2_modify_snapshot_tier]{modify_snapshot_tier} \tab Archives an Amazon EBS snapshot\cr
#'  \link[paws.compute:ec2_modify_spot_fleet_request]{modify_spot_fleet_request} \tab Modifies the specified Spot Fleet request\cr
#'  \link[paws.compute:ec2_modify_subnet_attribute]{modify_subnet_attribute} \tab Modifies a subnet attribute\cr
#'  \link[paws.compute:ec2_modify_traffic_mirror_filter_network_services]{modify_traffic_mirror_filter_network_services} \tab Allows or restricts mirroring network services\cr
#'  \link[paws.compute:ec2_modify_traffic_mirror_filter_rule]{modify_traffic_mirror_filter_rule} \tab Modifies the specified Traffic Mirror rule\cr
#'  \link[paws.compute:ec2_modify_traffic_mirror_session]{modify_traffic_mirror_session} \tab Modifies a Traffic Mirror session\cr
#'  \link[paws.compute:ec2_modify_transit_gateway]{modify_transit_gateway} \tab Modifies the specified transit gateway\cr
#'  \link[paws.compute:ec2_modify_transit_gateway_prefix_list_reference]{modify_transit_gateway_prefix_list_reference} \tab Modifies a reference (route) to a prefix list in a specified transit gateway route table\cr
#'  \link[paws.compute:ec2_modify_transit_gateway_vpc_attachment]{modify_transit_gateway_vpc_attachment} \tab Modifies the specified VPC attachment\cr
#'  \link[paws.compute:ec2_modify_verified_access_endpoint]{modify_verified_access_endpoint} \tab Modifies the configuration of the specified Amazon Web Services Verified Access endpoint\cr
#'  \link[paws.compute:ec2_modify_verified_access_endpoint_policy]{modify_verified_access_endpoint_policy} \tab Modifies the specified Amazon Web Services Verified Access endpoint policy\cr
#'  \link[paws.compute:ec2_modify_verified_access_group]{modify_verified_access_group} \tab Modifies the specified Amazon Web Services Verified Access group configuration\cr
#'  \link[paws.compute:ec2_modify_verified_access_group_policy]{modify_verified_access_group_policy} \tab Modifies the specified Amazon Web Services Verified Access group policy\cr
#'  \link[paws.compute:ec2_modify_verified_access_instance]{modify_verified_access_instance} \tab Modifies the configuration of the specified Amazon Web Services Verified Access instance\cr
#'  \link[paws.compute:ec2_modify_verified_access_instance_logging_configuration]{modify_verified_access_instance_logging_configuration} \tab Modifies the logging configuration for the specified Amazon Web Services Verified Access instance\cr
#'  \link[paws.compute:ec2_modify_verified_access_trust_provider]{modify_verified_access_trust_provider} \tab Modifies the configuration of the specified Amazon Web Services Verified Access trust provider\cr
#'  \link[paws.compute:ec2_modify_volume]{modify_volume} \tab You can modify several parameters of an existing EBS volume, including volume size, volume type, and IOPS capacity\cr
#'  \link[paws.compute:ec2_modify_volume_attribute]{modify_volume_attribute} \tab Modifies a volume attribute\cr
#'  \link[paws.compute:ec2_modify_vpc_attribute]{modify_vpc_attribute} \tab Modifies the specified attribute of the specified VPC\cr
#'  \link[paws.compute:ec2_modify_vpc_block_public_access_exclusion]{modify_vpc_block_public_access_exclusion} \tab Modify VPC Block Public Access (BPA) exclusions\cr
#'  \link[paws.compute:ec2_modify_vpc_block_public_access_options]{modify_vpc_block_public_access_options} \tab Modify VPC Block Public Access (BPA) options\cr
#'  \link[paws.compute:ec2_modify_vpc_endpoint]{modify_vpc_endpoint} \tab Modifies attributes of a specified VPC endpoint\cr
#'  \link[paws.compute:ec2_modify_vpc_endpoint_connection_notification]{modify_vpc_endpoint_connection_notification} \tab Modifies a connection notification for VPC endpoint or VPC endpoint service\cr
#'  \link[paws.compute:ec2_modify_vpc_endpoint_service_configuration]{modify_vpc_endpoint_service_configuration} \tab Modifies the attributes of the specified VPC endpoint service configuration\cr
#'  \link[paws.compute:ec2_modify_vpc_endpoint_service_payer_responsibility]{modify_vpc_endpoint_service_payer_responsibility} \tab Modifies the payer responsibility for your VPC endpoint service\cr
#'  \link[paws.compute:ec2_modify_vpc_endpoint_service_permissions]{modify_vpc_endpoint_service_permissions} \tab Modifies the permissions for your VPC endpoint service\cr
#'  \link[paws.compute:ec2_modify_vpc_peering_connection_options]{modify_vpc_peering_connection_options} \tab Modifies the VPC peering connection options on one side of a VPC peering connection\cr
#'  \link[paws.compute:ec2_modify_vpc_tenancy]{modify_vpc_tenancy} \tab Modifies the instance tenancy attribute of the specified VPC\cr
#'  \link[paws.compute:ec2_modify_vpn_connection]{modify_vpn_connection} \tab Modifies the customer gateway or the target gateway of an Amazon Web Services Site-to-Site VPN connection\cr
#'  \link[paws.compute:ec2_modify_vpn_connection_options]{modify_vpn_connection_options} \tab Modifies the connection options for your Site-to-Site VPN connection\cr
#'  \link[paws.compute:ec2_modify_vpn_tunnel_certificate]{modify_vpn_tunnel_certificate} \tab Modifies the VPN tunnel endpoint certificate\cr
#'  \link[paws.compute:ec2_modify_vpn_tunnel_options]{modify_vpn_tunnel_options} \tab Modifies the options for a VPN tunnel in an Amazon Web Services Site-to-Site VPN connection\cr
#'  \link[paws.compute:ec2_monitor_instances]{monitor_instances} \tab Enables detailed monitoring for a running instance\cr
#'  \link[paws.compute:ec2_move_address_to_vpc]{move_address_to_vpc} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_move_byoip_cidr_to_ipam]{move_byoip_cidr_to_ipam} \tab Move a BYOIPv4 CIDR to IPAM from a public IPv4 pool\cr
#'  \link[paws.compute:ec2_move_capacity_reservation_instances]{move_capacity_reservation_instances} \tab Move available capacity from a source Capacity Reservation to a destination Capacity Reservation\cr
#'  \link[paws.compute:ec2_provision_byoip_cidr]{provision_byoip_cidr} \tab Provisions an IPv4 or IPv6 address range for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and creates a corresponding address pool\cr
#'  \link[paws.compute:ec2_provision_ipam_byoasn]{provision_ipam_byoasn} \tab Provisions your Autonomous System Number (ASN) for use in your Amazon Web Services account\cr
#'  \link[paws.compute:ec2_provision_ipam_pool_cidr]{provision_ipam_pool_cidr} \tab Provision a CIDR to an IPAM pool\cr
#'  \link[paws.compute:ec2_provision_public_ipv_4_pool_cidr]{provision_public_ipv_4_pool_cidr} \tab Provision a CIDR to a public IPv4 pool\cr
#'  \link[paws.compute:ec2_purchase_capacity_block]{purchase_capacity_block} \tab Purchase the Capacity Block for use with your account\cr
#'  \link[paws.compute:ec2_purchase_capacity_block_extension]{purchase_capacity_block_extension} \tab Purchase the Capacity Block extension for use with your account\cr
#'  \link[paws.compute:ec2_purchase_host_reservation]{purchase_host_reservation} \tab Purchase a reservation with configurations that match those of your Dedicated Host\cr
#'  \link[paws.compute:ec2_purchase_reserved_instances_offering]{purchase_reserved_instances_offering} \tab Purchases a Reserved Instance for use with your account\cr
#'  \link[paws.compute:ec2_purchase_scheduled_instances]{purchase_scheduled_instances} \tab You can no longer purchase Scheduled Instances\cr
#'  \link[paws.compute:ec2_reboot_instances]{reboot_instances} \tab Requests a reboot of the specified instances\cr
#'  \link[paws.compute:ec2_register_image]{register_image} \tab Registers an AMI\cr
#'  \link[paws.compute:ec2_register_instance_event_notification_attributes]{register_instance_event_notification_attributes} \tab Registers a set of tag keys to include in scheduled event notifications for your resources\cr
#'  \link[paws.compute:ec2_register_transit_gateway_multicast_group_members]{register_transit_gateway_multicast_group_members} \tab Registers members (network interfaces) with the transit gateway multicast group\cr
#'  \link[paws.compute:ec2_register_transit_gateway_multicast_group_sources]{register_transit_gateway_multicast_group_sources} \tab Registers sources (network interfaces) with the specified transit gateway multicast group\cr
#'  \link[paws.compute:ec2_reject_capacity_reservation_billing_ownership]{reject_capacity_reservation_billing_ownership} \tab Rejects a request to assign billing of the available capacity of a shared Capacity Reservation to your account\cr
#'  \link[paws.compute:ec2_reject_transit_gateway_multicast_domain_associations]{reject_transit_gateway_multicast_domain_associations} \tab Rejects a request to associate cross-account subnets with a transit gateway multicast domain\cr
#'  \link[paws.compute:ec2_reject_transit_gateway_peering_attachment]{reject_transit_gateway_peering_attachment} \tab Rejects a transit gateway peering attachment request\cr
#'  \link[paws.compute:ec2_reject_transit_gateway_vpc_attachment]{reject_transit_gateway_vpc_attachment} \tab Rejects a request to attach a VPC to a transit gateway\cr
#'  \link[paws.compute:ec2_reject_vpc_endpoint_connections]{reject_vpc_endpoint_connections} \tab Rejects VPC endpoint connection requests to your VPC endpoint service\cr
#'  \link[paws.compute:ec2_reject_vpc_peering_connection]{reject_vpc_peering_connection} \tab Rejects a VPC peering connection request\cr
#'  \link[paws.compute:ec2_release_address]{release_address} \tab Releases the specified Elastic IP address\cr
#'  \link[paws.compute:ec2_release_hosts]{release_hosts} \tab When you no longer want to use an On-Demand Dedicated Host it can be released\cr
#'  \link[paws.compute:ec2_release_ipam_pool_allocation]{release_ipam_pool_allocation} \tab Release an allocation within an IPAM pool\cr
#'  \link[paws.compute:ec2_replace_iam_instance_profile_association]{replace_iam_instance_profile_association} \tab Replaces an IAM instance profile for the specified running instance\cr
#'  \link[paws.compute:ec2_replace_image_criteria_in_allowed_images_settings]{replace_image_criteria_in_allowed_images_settings} \tab Sets or replaces the criteria for Allowed AMIs\cr
#'  \link[paws.compute:ec2_replace_network_acl_association]{replace_network_acl_association} \tab Changes which network ACL a subnet is associated with\cr
#'  \link[paws.compute:ec2_replace_network_acl_entry]{replace_network_acl_entry} \tab Replaces an entry (rule) in a network ACL\cr
#'  \link[paws.compute:ec2_replace_route]{replace_route} \tab Replaces an existing route within a route table in a VPC\cr
#'  \link[paws.compute:ec2_replace_route_table_association]{replace_route_table_association} \tab Changes the route table associated with a given subnet, internet gateway, or virtual private gateway in a VPC\cr
#'  \link[paws.compute:ec2_replace_transit_gateway_route]{replace_transit_gateway_route} \tab Replaces the specified route in the specified transit gateway route table\cr
#'  \link[paws.compute:ec2_replace_vpn_tunnel]{replace_vpn_tunnel} \tab Trigger replacement of specified VPN tunnel\cr
#'  \link[paws.compute:ec2_report_instance_status]{report_instance_status} \tab Submits feedback about the status of an instance\cr
#'  \link[paws.compute:ec2_request_spot_fleet]{request_spot_fleet} \tab Creates a Spot Fleet request\cr
#'  \link[paws.compute:ec2_request_spot_instances]{request_spot_instances} \tab Creates a Spot Instance request\cr
#'  \link[paws.compute:ec2_reset_address_attribute]{reset_address_attribute} \tab Resets the attribute of the specified IP address\cr
#'  \link[paws.compute:ec2_reset_ebs_default_kms_key_id]{reset_ebs_default_kms_key_id} \tab Resets the default KMS key for EBS encryption for your account in this Region to the Amazon Web Services managed KMS key for EBS\cr
#'  \link[paws.compute:ec2_reset_fpga_image_attribute]{reset_fpga_image_attribute} \tab Resets the specified attribute of the specified Amazon FPGA Image (AFI) to its default value\cr
#'  \link[paws.compute:ec2_reset_image_attribute]{reset_image_attribute} \tab Resets an attribute of an AMI to its default value\cr
#'  \link[paws.compute:ec2_reset_instance_attribute]{reset_instance_attribute} \tab Resets an attribute of an instance to its default value\cr
#'  \link[paws.compute:ec2_reset_network_interface_attribute]{reset_network_interface_attribute} \tab Resets a network interface attribute\cr
#'  \link[paws.compute:ec2_reset_snapshot_attribute]{reset_snapshot_attribute} \tab Resets permission settings for the specified snapshot\cr
#'  \link[paws.compute:ec2_restore_address_to_classic]{restore_address_to_classic} \tab This action is deprecated\cr
#'  \link[paws.compute:ec2_restore_image_from_recycle_bin]{restore_image_from_recycle_bin} \tab Restores an AMI from the Recycle Bin\cr
#'  \link[paws.compute:ec2_restore_managed_prefix_list_version]{restore_managed_prefix_list_version} \tab Restores the entries from a previous version of a managed prefix list to a new version of the prefix list\cr
#'  \link[paws.compute:ec2_restore_snapshot_from_recycle_bin]{restore_snapshot_from_recycle_bin} \tab Restores a snapshot from the Recycle Bin\cr
#'  \link[paws.compute:ec2_restore_snapshot_tier]{restore_snapshot_tier} \tab Restores an archived Amazon EBS snapshot for use temporarily or permanently, or modifies the restore period or restore type for a snapshot that was previously temporarily restored\cr
#'  \link[paws.compute:ec2_revoke_client_vpn_ingress]{revoke_client_vpn_ingress} \tab Removes an ingress authorization rule from a Client VPN endpoint\cr
#'  \link[paws.compute:ec2_revoke_security_group_egress]{revoke_security_group_egress} \tab Removes the specified outbound (egress) rules from the specified security group\cr
#'  \link[paws.compute:ec2_revoke_security_group_ingress]{revoke_security_group_ingress} \tab Removes the specified inbound (ingress) rules from a security group\cr
#'  \link[paws.compute:ec2_run_instances]{run_instances} \tab Launches the specified number of instances using an AMI for which you have permissions\cr
#'  \link[paws.compute:ec2_run_scheduled_instances]{run_scheduled_instances} \tab Launches the specified Scheduled Instances\cr
#'  \link[paws.compute:ec2_search_local_gateway_routes]{search_local_gateway_routes} \tab Searches for routes in the specified local gateway route table\cr
#'  \link[paws.compute:ec2_search_transit_gateway_multicast_groups]{search_transit_gateway_multicast_groups} \tab Searches one or more transit gateway multicast groups and returns the group membership information\cr
#'  \link[paws.compute:ec2_search_transit_gateway_routes]{search_transit_gateway_routes} \tab Searches for routes in the specified transit gateway route table\cr
#'  \link[paws.compute:ec2_send_diagnostic_interrupt]{send_diagnostic_interrupt} \tab Sends a diagnostic interrupt to the specified Amazon EC2 instance to trigger a kernel panic (on Linux instances), or a blue screen/stop error (on Windows instances)\cr
#'  \link[paws.compute:ec2_start_declarative_policies_report]{start_declarative_policies_report} \tab Generates an account status report\cr
#'  \link[paws.compute:ec2_start_instances]{start_instances} \tab Starts an Amazon EBS-backed instance that you've previously stopped\cr
#'  \link[paws.compute:ec2_start_network_insights_access_scope_analysis]{start_network_insights_access_scope_analysis} \tab Starts analyzing the specified Network Access Scope\cr
#'  \link[paws.compute:ec2_start_network_insights_analysis]{start_network_insights_analysis} \tab Starts analyzing the specified path\cr
#'  \link[paws.compute:ec2_start_vpc_endpoint_service_private_dns_verification]{start_vpc_endpoint_service_private_dns_verification} \tab Initiates the verification process to prove that the service provider owns the private DNS name domain for the endpoint service\cr
#'  \link[paws.compute:ec2_stop_instances]{stop_instances} \tab Stops an Amazon EBS-backed instance\cr
#'  \link[paws.compute:ec2_terminate_client_vpn_connections]{terminate_client_vpn_connections} \tab Terminates active Client VPN endpoint connections\cr
#'  \link[paws.compute:ec2_terminate_instances]{terminate_instances} \tab Shuts down the specified instances\cr
#'  \link[paws.compute:ec2_unassign_ipv_6_addresses]{unassign_ipv_6_addresses} \tab Unassigns the specified IPv6 addresses or Prefix Delegation prefixes from a network interface\cr
#'  \link[paws.compute:ec2_unassign_private_ip_addresses]{unassign_private_ip_addresses} \tab Unassigns the specified secondary private IP addresses or IPv4 Prefix Delegation prefixes from a network interface\cr
#'  \link[paws.compute:ec2_unassign_private_nat_gateway_address]{unassign_private_nat_gateway_address} \tab Unassigns secondary private IPv4 addresses from a private NAT gateway\cr
#'  \link[paws.compute:ec2_unlock_snapshot]{unlock_snapshot} \tab Unlocks a snapshot that is locked in governance mode or that is locked in compliance mode but still in the cooling-off period\cr
#'  \link[paws.compute:ec2_unmonitor_instances]{unmonitor_instances} \tab Disables detailed monitoring for a running instance\cr
#'  \link[paws.compute:ec2_update_security_group_rule_descriptions_egress]{update_security_group_rule_descriptions_egress} \tab Updates the description of an egress (outbound) security group rule\cr
#'  \link[paws.compute:ec2_update_security_group_rule_descriptions_ingress]{update_security_group_rule_descriptions_ingress} \tab Updates the description of an ingress (inbound) security group rule\cr
#'  \link[paws.compute:ec2_withdraw_byoip_cidr]{withdraw_byoip_cidr} \tab Stops advertising an address range that is provisioned as an address pool
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ec2
#' @export
ec2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::ec2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS EC2 Instance Connect
#'
#' @description
#' This is the *Amazon EC2 Instance Connect API Reference*. It provides
#' descriptions, syntax, and usage examples for each of the actions for
#' Amazon EC2 Instance Connect. Amazon EC2 Instance Connect enables system
#' administrators to publish one-time use SSH public keys to EC2, providing
#' users a simple and secure way to connect to their instances.
#' 
#' To view the Amazon EC2 Instance Connect content in the *Amazon EC2 User
#' Guide*, see [Connect to your Linux instance using EC2 Instance
#' Connect](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/connect-linux-inst-eic.html).
#' 
#' For Amazon EC2 APIs, see the [Amazon EC2 API
#' Reference](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Welcome.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ec2instanceconnect(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ec2instanceconnect()
#' # The following example pushes a sample SSH public key to the EC2 instance
#' # i-abcd1234 in AZ us-west-2b for use by the instance OS user ec2-user.
#' svc$send_ssh_public_key(
#'   AvailabilityZone = "us-west-2a",
#'   InstanceId = "i-abcd1234",
#'   InstanceOSUser = "ec2-user",
#'   SSHPublicKey = "ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC3FlHqj2eqCdrGHuA6d..."
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:ec2instanceconnect_send_serial_console_ssh_public_key]{send_serial_console_ssh_public_key} \tab Pushes an SSH public key to the specified EC2 instance\cr
#'  \link[paws.compute:ec2instanceconnect_send_ssh_public_key]{send_ssh_public_key} \tab Pushes an SSH public key to the specified EC2 instance for use by the specified user
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ec2instanceconnect
#' @export
ec2instanceconnect <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::ec2instanceconnect(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Elastic Container Registry
#'
#' @description
#' Amazon Elastic Container Registry (Amazon ECR) is a managed container
#' image registry service. Customers can use the familiar Docker CLI, or
#' their preferred client, to push, pull, and manage images. Amazon ECR
#' provides a secure, scalable, and reliable registry for your Docker or
#' Open Container Initiative (OCI) images. Amazon ECR supports private
#' repositories with resource-based permissions using IAM so that specific
#' users or Amazon EC2 instances can access repositories and images.
#' 
#' Amazon ECR has service endpoints in each supported Region. For more
#' information, see [Amazon ECR
#' endpoints](https://docs.aws.amazon.com/general/latest/gr/ecr.html) in
#' the *Amazon Web Services General Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ecr(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ecr()
#' # This example deletes images with the tags precise and trusty in a
#' # repository called ubuntu in the default registry for an account.
#' svc$batch_delete_image(
#'   imageIds = list(
#'     list(
#'       imageTag = "precise"
#'     )
#'   ),
#'   repositoryName = "ubuntu"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:ecr_batch_check_layer_availability]{batch_check_layer_availability} \tab Checks the availability of one or more image layers in a repository\cr
#'  \link[paws.compute:ecr_batch_delete_image]{batch_delete_image} \tab Deletes a list of specified images within a repository\cr
#'  \link[paws.compute:ecr_batch_get_image]{batch_get_image} \tab Gets detailed information for an image\cr
#'  \link[paws.compute:ecr_batch_get_repository_scanning_configuration]{batch_get_repository_scanning_configuration} \tab Gets the scanning configuration for one or more repositories\cr
#'  \link[paws.compute:ecr_complete_layer_upload]{complete_layer_upload} \tab Informs Amazon ECR that the image layer upload has completed for a specified registry, repository name, and upload ID\cr
#'  \link[paws.compute:ecr_create_pull_through_cache_rule]{create_pull_through_cache_rule} \tab Creates a pull through cache rule\cr
#'  \link[paws.compute:ecr_create_repository]{create_repository} \tab Creates a repository\cr
#'  \link[paws.compute:ecr_create_repository_creation_template]{create_repository_creation_template} \tab Creates a repository creation template\cr
#'  \link[paws.compute:ecr_delete_lifecycle_policy]{delete_lifecycle_policy} \tab Deletes the lifecycle policy associated with the specified repository\cr
#'  \link[paws.compute:ecr_delete_pull_through_cache_rule]{delete_pull_through_cache_rule} \tab Deletes a pull through cache rule\cr
#'  \link[paws.compute:ecr_delete_registry_policy]{delete_registry_policy} \tab Deletes the registry permissions policy\cr
#'  \link[paws.compute:ecr_delete_repository]{delete_repository} \tab Deletes a repository\cr
#'  \link[paws.compute:ecr_delete_repository_creation_template]{delete_repository_creation_template} \tab Deletes a repository creation template\cr
#'  \link[paws.compute:ecr_delete_repository_policy]{delete_repository_policy} \tab Deletes the repository policy associated with the specified repository\cr
#'  \link[paws.compute:ecr_describe_image_replication_status]{describe_image_replication_status} \tab Returns the replication status for a specified image\cr
#'  \link[paws.compute:ecr_describe_images]{describe_images} \tab Returns metadata about the images in a repository\cr
#'  \link[paws.compute:ecr_describe_image_scan_findings]{describe_image_scan_findings} \tab Returns the scan findings for the specified image\cr
#'  \link[paws.compute:ecr_describe_pull_through_cache_rules]{describe_pull_through_cache_rules} \tab Returns the pull through cache rules for a registry\cr
#'  \link[paws.compute:ecr_describe_registry]{describe_registry} \tab Describes the settings for a registry\cr
#'  \link[paws.compute:ecr_describe_repositories]{describe_repositories} \tab Describes image repositories in a registry\cr
#'  \link[paws.compute:ecr_describe_repository_creation_templates]{describe_repository_creation_templates} \tab Returns details about the repository creation templates in a registry\cr
#'  \link[paws.compute:ecr_get_account_setting]{get_account_setting} \tab Retrieves the account setting value for the specified setting name\cr
#'  \link[paws.compute:ecr_get_authorization_token]{get_authorization_token} \tab Retrieves an authorization token\cr
#'  \link[paws.compute:ecr_get_download_url_for_layer]{get_download_url_for_layer} \tab Retrieves the pre-signed Amazon S3 download URL corresponding to an image layer\cr
#'  \link[paws.compute:ecr_get_lifecycle_policy]{get_lifecycle_policy} \tab Retrieves the lifecycle policy for the specified repository\cr
#'  \link[paws.compute:ecr_get_lifecycle_policy_preview]{get_lifecycle_policy_preview} \tab Retrieves the results of the lifecycle policy preview request for the specified repository\cr
#'  \link[paws.compute:ecr_get_registry_policy]{get_registry_policy} \tab Retrieves the permissions policy for a registry\cr
#'  \link[paws.compute:ecr_get_registry_scanning_configuration]{get_registry_scanning_configuration} \tab Retrieves the scanning configuration for a registry\cr
#'  \link[paws.compute:ecr_get_repository_policy]{get_repository_policy} \tab Retrieves the repository policy for the specified repository\cr
#'  \link[paws.compute:ecr_initiate_layer_upload]{initiate_layer_upload} \tab Notifies Amazon ECR that you intend to upload an image layer\cr
#'  \link[paws.compute:ecr_list_images]{list_images} \tab Lists all the image IDs for the specified repository\cr
#'  \link[paws.compute:ecr_list_tags_for_resource]{list_tags_for_resource} \tab List the tags for an Amazon ECR resource\cr
#'  \link[paws.compute:ecr_put_account_setting]{put_account_setting} \tab Allows you to change the basic scan type version or registry policy scope\cr
#'  \link[paws.compute:ecr_put_image]{put_image} \tab Creates or updates the image manifest and tags associated with an image\cr
#'  \link[paws.compute:ecr_put_image_scanning_configuration]{put_image_scanning_configuration} \tab The PutImageScanningConfiguration API is being deprecated, in favor of specifying the image scanning configuration at the registry level\cr
#'  \link[paws.compute:ecr_put_image_tag_mutability]{put_image_tag_mutability} \tab Updates the image tag mutability settings for the specified repository\cr
#'  \link[paws.compute:ecr_put_lifecycle_policy]{put_lifecycle_policy} \tab Creates or updates the lifecycle policy for the specified repository\cr
#'  \link[paws.compute:ecr_put_registry_policy]{put_registry_policy} \tab Creates or updates the permissions policy for your registry\cr
#'  \link[paws.compute:ecr_put_registry_scanning_configuration]{put_registry_scanning_configuration} \tab Creates or updates the scanning configuration for your private registry\cr
#'  \link[paws.compute:ecr_put_replication_configuration]{put_replication_configuration} \tab Creates or updates the replication configuration for a registry\cr
#'  \link[paws.compute:ecr_set_repository_policy]{set_repository_policy} \tab Applies a repository policy to the specified repository to control access permissions\cr
#'  \link[paws.compute:ecr_start_image_scan]{start_image_scan} \tab Starts a basic image vulnerability scan\cr
#'  \link[paws.compute:ecr_start_lifecycle_policy_preview]{start_lifecycle_policy_preview} \tab Starts a preview of a lifecycle policy for the specified repository\cr
#'  \link[paws.compute:ecr_tag_resource]{tag_resource} \tab Adds specified tags to a resource with the specified ARN\cr
#'  \link[paws.compute:ecr_untag_resource]{untag_resource} \tab Deletes specified tags from a resource\cr
#'  \link[paws.compute:ecr_update_pull_through_cache_rule]{update_pull_through_cache_rule} \tab Updates an existing pull through cache rule\cr
#'  \link[paws.compute:ecr_update_repository_creation_template]{update_repository_creation_template} \tab Updates an existing repository creation template\cr
#'  \link[paws.compute:ecr_upload_layer_part]{upload_layer_part} \tab Uploads an image layer part to Amazon ECR\cr
#'  \link[paws.compute:ecr_validate_pull_through_cache_rule]{validate_pull_through_cache_rule} \tab Validates an existing pull through cache rule for an upstream registry that requires authentication
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ecr
#' @export
ecr <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::ecr(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Elastic Container Registry Public
#'
#' @description
#' Amazon Elastic Container Registry Public (Amazon ECR Public) is a
#' managed container image registry service. Amazon ECR provides both
#' public and private registries to host your container images. You can use
#' the Docker CLI or your preferred client to push, pull, and manage
#' images. Amazon ECR provides a secure, scalable, and reliable registry
#' for your Docker or Open Container Initiative (OCI) images. Amazon ECR
#' supports public repositories with this API. For information about the
#' Amazon ECR API for private repositories, see [Amazon Elastic Container
#' Registry API
#' Reference](https://docs.aws.amazon.com/AmazonECR/latest/APIReference/Welcome.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ecrpublic(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ecrpublic()
#' svc$batch_check_layer_availability(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:ecrpublic_batch_check_layer_availability]{batch_check_layer_availability} \tab Checks the availability of one or more image layers that are within a repository in a public registry\cr
#'  \link[paws.compute:ecrpublic_batch_delete_image]{batch_delete_image} \tab Deletes a list of specified images that are within a repository in a public registry\cr
#'  \link[paws.compute:ecrpublic_complete_layer_upload]{complete_layer_upload} \tab Informs Amazon ECR that the image layer upload is complete for a specified public registry, repository name, and upload ID\cr
#'  \link[paws.compute:ecrpublic_create_repository]{create_repository} \tab Creates a repository in a public registry\cr
#'  \link[paws.compute:ecrpublic_delete_repository]{delete_repository} \tab Deletes a repository in a public registry\cr
#'  \link[paws.compute:ecrpublic_delete_repository_policy]{delete_repository_policy} \tab Deletes the repository policy that's associated with the specified repository\cr
#'  \link[paws.compute:ecrpublic_describe_images]{describe_images} \tab Returns metadata that's related to the images in a repository in a public registry\cr
#'  \link[paws.compute:ecrpublic_describe_image_tags]{describe_image_tags} \tab Returns the image tag details for a repository in a public registry\cr
#'  \link[paws.compute:ecrpublic_describe_registries]{describe_registries} \tab Returns details for a public registry\cr
#'  \link[paws.compute:ecrpublic_describe_repositories]{describe_repositories} \tab Describes repositories that are in a public registry\cr
#'  \link[paws.compute:ecrpublic_get_authorization_token]{get_authorization_token} \tab Retrieves an authorization token\cr
#'  \link[paws.compute:ecrpublic_get_registry_catalog_data]{get_registry_catalog_data} \tab Retrieves catalog metadata for a public registry\cr
#'  \link[paws.compute:ecrpublic_get_repository_catalog_data]{get_repository_catalog_data} \tab Retrieve catalog metadata for a repository in a public registry\cr
#'  \link[paws.compute:ecrpublic_get_repository_policy]{get_repository_policy} \tab Retrieves the repository policy for the specified repository\cr
#'  \link[paws.compute:ecrpublic_initiate_layer_upload]{initiate_layer_upload} \tab Notifies Amazon ECR that you intend to upload an image layer\cr
#'  \link[paws.compute:ecrpublic_list_tags_for_resource]{list_tags_for_resource} \tab List the tags for an Amazon ECR Public resource\cr
#'  \link[paws.compute:ecrpublic_put_image]{put_image} \tab Creates or updates the image manifest and tags that are associated with an image\cr
#'  \link[paws.compute:ecrpublic_put_registry_catalog_data]{put_registry_catalog_data} \tab Create or update the catalog data for a public registry\cr
#'  \link[paws.compute:ecrpublic_put_repository_catalog_data]{put_repository_catalog_data} \tab Creates or updates the catalog data for a repository in a public registry\cr
#'  \link[paws.compute:ecrpublic_set_repository_policy]{set_repository_policy} \tab Applies a repository policy to the specified public repository to control access permissions\cr
#'  \link[paws.compute:ecrpublic_tag_resource]{tag_resource} \tab Associates the specified tags to a resource with the specified resourceArn\cr
#'  \link[paws.compute:ecrpublic_untag_resource]{untag_resource} \tab Deletes specified tags from a resource\cr
#'  \link[paws.compute:ecrpublic_upload_layer_part]{upload_layer_part} \tab Uploads an image layer part to Amazon ECR
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ecrpublic
#' @export
ecrpublic <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::ecrpublic(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon EC2 Container Service
#'
#' @description
#' Amazon Elastic Container Service
#' 
#' Amazon Elastic Container Service (Amazon ECS) is a highly scalable,
#' fast, container management service. It makes it easy to run, stop, and
#' manage Docker containers. You can host your cluster on a serverless
#' infrastructure that's managed by Amazon ECS by launching your services
#' or tasks on Fargate. For more control, you can host your tasks on a
#' cluster of Amazon Elastic Compute Cloud (Amazon EC2) or External
#' (on-premises) instances that you manage.
#' 
#' Amazon ECS makes it easy to launch and stop container-based applications
#' with simple API calls. This makes it easy to get the state of your
#' cluster from a centralized service, and gives you access to many
#' familiar Amazon EC2 features.
#' 
#' You can use Amazon ECS to schedule the placement of containers across
#' your cluster based on your resource needs, isolation policies, and
#' availability requirements. With Amazon ECS, you don't need to operate
#' your own cluster management and configuration management systems. You
#' also don't need to worry about scaling your management infrastructure.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ecs(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ecs()
#' # This example creates a cluster in your default region.
#' svc$create_cluster(
#'   clusterName = "my_cluster"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:ecs_create_capacity_provider]{create_capacity_provider} \tab Creates a new capacity provider\cr
#'  \link[paws.compute:ecs_create_cluster]{create_cluster} \tab Creates a new Amazon ECS cluster\cr
#'  \link[paws.compute:ecs_create_service]{create_service} \tab Runs and maintains your desired number of tasks from a specified task definition\cr
#'  \link[paws.compute:ecs_create_task_set]{create_task_set} \tab Create a task set in the specified cluster and service\cr
#'  \link[paws.compute:ecs_delete_account_setting]{delete_account_setting} \tab Disables an account setting for a specified user, role, or the root user for an account\cr
#'  \link[paws.compute:ecs_delete_attributes]{delete_attributes} \tab Deletes one or more custom attributes from an Amazon ECS resource\cr
#'  \link[paws.compute:ecs_delete_capacity_provider]{delete_capacity_provider} \tab Deletes the specified capacity provider\cr
#'  \link[paws.compute:ecs_delete_cluster]{delete_cluster} \tab Deletes the specified cluster\cr
#'  \link[paws.compute:ecs_delete_service]{delete_service} \tab Deletes a specified service within a cluster\cr
#'  \link[paws.compute:ecs_delete_task_definitions]{delete_task_definitions} \tab Deletes one or more task definitions\cr
#'  \link[paws.compute:ecs_delete_task_set]{delete_task_set} \tab Deletes a specified task set within a service\cr
#'  \link[paws.compute:ecs_deregister_container_instance]{deregister_container_instance} \tab Deregisters an Amazon ECS container instance from the specified cluster\cr
#'  \link[paws.compute:ecs_deregister_task_definition]{deregister_task_definition} \tab Deregisters the specified task definition by family and revision\cr
#'  \link[paws.compute:ecs_describe_capacity_providers]{describe_capacity_providers} \tab Describes one or more of your capacity providers\cr
#'  \link[paws.compute:ecs_describe_clusters]{describe_clusters} \tab Describes one or more of your clusters\cr
#'  \link[paws.compute:ecs_describe_container_instances]{describe_container_instances} \tab Describes one or more container instances\cr
#'  \link[paws.compute:ecs_describe_service_deployments]{describe_service_deployments} \tab Describes one or more of your service deployments\cr
#'  \link[paws.compute:ecs_describe_service_revisions]{describe_service_revisions} \tab Describes one or more service revisions\cr
#'  \link[paws.compute:ecs_describe_services]{describe_services} \tab Describes the specified services running in your cluster\cr
#'  \link[paws.compute:ecs_describe_task_definition]{describe_task_definition} \tab Describes a task definition\cr
#'  \link[paws.compute:ecs_describe_tasks]{describe_tasks} \tab Describes a specified task or tasks\cr
#'  \link[paws.compute:ecs_describe_task_sets]{describe_task_sets} \tab Describes the task sets in the specified cluster and service\cr
#'  \link[paws.compute:ecs_discover_poll_endpoint]{discover_poll_endpoint} \tab This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent\cr
#'  \link[paws.compute:ecs_execute_command]{execute_command} \tab Runs a command remotely on a container within a task\cr
#'  \link[paws.compute:ecs_get_task_protection]{get_task_protection} \tab Retrieves the protection status of tasks in an Amazon ECS service\cr
#'  \link[paws.compute:ecs_list_account_settings]{list_account_settings} \tab Lists the account settings for a specified principal\cr
#'  \link[paws.compute:ecs_list_attributes]{list_attributes} \tab Lists the attributes for Amazon ECS resources within a specified target type and cluster\cr
#'  \link[paws.compute:ecs_list_clusters]{list_clusters} \tab Returns a list of existing clusters\cr
#'  \link[paws.compute:ecs_list_container_instances]{list_container_instances} \tab Returns a list of container instances in a specified cluster\cr
#'  \link[paws.compute:ecs_list_service_deployments]{list_service_deployments} \tab This operation lists all the service deployments that meet the specified filter criteria\cr
#'  \link[paws.compute:ecs_list_services]{list_services} \tab Returns a list of services\cr
#'  \link[paws.compute:ecs_list_services_by_namespace]{list_services_by_namespace} \tab This operation lists all of the services that are associated with a Cloud Map namespace\cr
#'  \link[paws.compute:ecs_list_tags_for_resource]{list_tags_for_resource} \tab List the tags for an Amazon ECS resource\cr
#'  \link[paws.compute:ecs_list_task_definition_families]{list_task_definition_families} \tab Returns a list of task definition families that are registered to your account\cr
#'  \link[paws.compute:ecs_list_task_definitions]{list_task_definitions} \tab Returns a list of task definitions that are registered to your account\cr
#'  \link[paws.compute:ecs_list_tasks]{list_tasks} \tab Returns a list of tasks\cr
#'  \link[paws.compute:ecs_put_account_setting]{put_account_setting} \tab Modifies an account setting\cr
#'  \link[paws.compute:ecs_put_account_setting_default]{put_account_setting_default} \tab Modifies an account setting for all users on an account for whom no individual account setting has been specified\cr
#'  \link[paws.compute:ecs_put_attributes]{put_attributes} \tab Create or update an attribute on an Amazon ECS resource\cr
#'  \link[paws.compute:ecs_put_cluster_capacity_providers]{put_cluster_capacity_providers} \tab Modifies the available capacity providers and the default capacity provider strategy for a cluster\cr
#'  \link[paws.compute:ecs_register_container_instance]{register_container_instance} \tab This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent\cr
#'  \link[paws.compute:ecs_register_task_definition]{register_task_definition} \tab Registers a new task definition from the supplied family and containerDefinitions\cr
#'  \link[paws.compute:ecs_run_task]{run_task} \tab Starts a new task using the specified task definition\cr
#'  \link[paws.compute:ecs_start_task]{start_task} \tab Starts a new task from the specified task definition on the specified container instance or instances\cr
#'  \link[paws.compute:ecs_stop_task]{stop_task} \tab Stops a running task\cr
#'  \link[paws.compute:ecs_submit_attachment_state_changes]{submit_attachment_state_changes} \tab This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent\cr
#'  \link[paws.compute:ecs_submit_container_state_change]{submit_container_state_change} \tab This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent\cr
#'  \link[paws.compute:ecs_submit_task_state_change]{submit_task_state_change} \tab This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent\cr
#'  \link[paws.compute:ecs_tag_resource]{tag_resource} \tab Associates the specified tags to a resource with the specified resourceArn\cr
#'  \link[paws.compute:ecs_untag_resource]{untag_resource} \tab Deletes specified tags from a resource\cr
#'  \link[paws.compute:ecs_update_capacity_provider]{update_capacity_provider} \tab Modifies the parameters for a capacity provider\cr
#'  \link[paws.compute:ecs_update_cluster]{update_cluster} \tab Updates the cluster\cr
#'  \link[paws.compute:ecs_update_cluster_settings]{update_cluster_settings} \tab Modifies the settings to use for a cluster\cr
#'  \link[paws.compute:ecs_update_container_agent]{update_container_agent} \tab Updates the Amazon ECS container agent on a specified container instance\cr
#'  \link[paws.compute:ecs_update_container_instances_state]{update_container_instances_state} \tab Modifies the status of an Amazon ECS container instance\cr
#'  \link[paws.compute:ecs_update_service]{update_service} \tab Modifies the parameters of a service\cr
#'  \link[paws.compute:ecs_update_service_primary_task_set]{update_service_primary_task_set} \tab Modifies which task set in a service is the primary task set\cr
#'  \link[paws.compute:ecs_update_task_protection]{update_task_protection} \tab Updates the protection status of a task\cr
#'  \link[paws.compute:ecs_update_task_set]{update_task_set} \tab Modifies a task set
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ecs
#' @export
ecs <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::ecs(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Elastic Kubernetes Service
#'
#' @description
#' Amazon Elastic Kubernetes Service (Amazon EKS) is a managed service that
#' makes it easy for you to run Kubernetes on Amazon Web Services without
#' needing to setup or maintain your own Kubernetes control plane.
#' Kubernetes is an open-source system for automating the deployment,
#' scaling, and management of containerized applications.
#' 
#' Amazon EKS runs up-to-date versions of the open-source Kubernetes
#' software, so you can use all the existing plugins and tooling from the
#' Kubernetes community. Applications running on Amazon EKS are fully
#' compatible with applications running on any standard Kubernetes
#' environment, whether running in on-premises data centers or public
#' clouds. This means that you can easily migrate any standard Kubernetes
#' application to Amazon EKS without any code modification required.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- eks(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- eks()
#' # The following example creates an Amazon EKS cluster called prod.
#' svc$create_cluster(
#'   version = "1.10",
#'   name = "prod",
#'   clientRequestToken = "1d2129a1-3d38-460a-9756-e5b91fddb951",
#'   resourcesVpcConfig = list(
#'     securityGroupIds = list(
#'       "sg-6979fe18"
#'     ),
#'     subnetIds = list(
#'       "subnet-6782e71e",
#'       "subnet-e7e761ac"
#'     )
#'   ),
#'   roleArn = "arn:aws:iam::012345678910:role/eks-service-role-AWSServiceRole..."
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:eks_associate_access_policy]{associate_access_policy} \tab Associates an access policy and its scope to an access entry\cr
#'  \link[paws.compute:eks_associate_encryption_config]{associate_encryption_config} \tab Associates an encryption configuration to an existing cluster\cr
#'  \link[paws.compute:eks_associate_identity_provider_config]{associate_identity_provider_config} \tab Associates an identity provider configuration to a cluster\cr
#'  \link[paws.compute:eks_create_access_entry]{create_access_entry} \tab Creates an access entry\cr
#'  \link[paws.compute:eks_create_addon]{create_addon} \tab Creates an Amazon EKS add-on\cr
#'  \link[paws.compute:eks_create_cluster]{create_cluster} \tab Creates an Amazon EKS control plane\cr
#'  \link[paws.compute:eks_create_eks_anywhere_subscription]{create_eks_anywhere_subscription} \tab Creates an EKS Anywhere subscription\cr
#'  \link[paws.compute:eks_create_fargate_profile]{create_fargate_profile} \tab Creates an Fargate profile for your Amazon EKS cluster\cr
#'  \link[paws.compute:eks_create_nodegroup]{create_nodegroup} \tab Creates a managed node group for an Amazon EKS cluster\cr
#'  \link[paws.compute:eks_create_pod_identity_association]{create_pod_identity_association} \tab Creates an EKS Pod Identity association between a service account in an Amazon EKS cluster and an IAM role with EKS Pod Identity\cr
#'  \link[paws.compute:eks_delete_access_entry]{delete_access_entry} \tab Deletes an access entry\cr
#'  \link[paws.compute:eks_delete_addon]{delete_addon} \tab Deletes an Amazon EKS add-on\cr
#'  \link[paws.compute:eks_delete_cluster]{delete_cluster} \tab Deletes an Amazon EKS cluster control plane\cr
#'  \link[paws.compute:eks_delete_eks_anywhere_subscription]{delete_eks_anywhere_subscription} \tab Deletes an expired or inactive subscription\cr
#'  \link[paws.compute:eks_delete_fargate_profile]{delete_fargate_profile} \tab Deletes an Fargate profile\cr
#'  \link[paws.compute:eks_delete_nodegroup]{delete_nodegroup} \tab Deletes a managed node group\cr
#'  \link[paws.compute:eks_delete_pod_identity_association]{delete_pod_identity_association} \tab Deletes a EKS Pod Identity association\cr
#'  \link[paws.compute:eks_deregister_cluster]{deregister_cluster} \tab Deregisters a connected cluster to remove it from the Amazon EKS control plane\cr
#'  \link[paws.compute:eks_describe_access_entry]{describe_access_entry} \tab Describes an access entry\cr
#'  \link[paws.compute:eks_describe_addon]{describe_addon} \tab Describes an Amazon EKS add-on\cr
#'  \link[paws.compute:eks_describe_addon_configuration]{describe_addon_configuration} \tab Returns configuration options\cr
#'  \link[paws.compute:eks_describe_addon_versions]{describe_addon_versions} \tab Describes the versions for an add-on\cr
#'  \link[paws.compute:eks_describe_cluster]{describe_cluster} \tab Describes an Amazon EKS cluster\cr
#'  \link[paws.compute:eks_describe_cluster_versions]{describe_cluster_versions} \tab Lists available Kubernetes versions for Amazon EKS clusters\cr
#'  \link[paws.compute:eks_describe_eks_anywhere_subscription]{describe_eks_anywhere_subscription} \tab Returns descriptive information about a subscription\cr
#'  \link[paws.compute:eks_describe_fargate_profile]{describe_fargate_profile} \tab Describes an Fargate profile\cr
#'  \link[paws.compute:eks_describe_identity_provider_config]{describe_identity_provider_config} \tab Describes an identity provider configuration\cr
#'  \link[paws.compute:eks_describe_insight]{describe_insight} \tab Returns details about an insight that you specify using its ID\cr
#'  \link[paws.compute:eks_describe_nodegroup]{describe_nodegroup} \tab Describes a managed node group\cr
#'  \link[paws.compute:eks_describe_pod_identity_association]{describe_pod_identity_association} \tab Returns descriptive information about an EKS Pod Identity association\cr
#'  \link[paws.compute:eks_describe_update]{describe_update} \tab Describes an update to an Amazon EKS resource\cr
#'  \link[paws.compute:eks_disassociate_access_policy]{disassociate_access_policy} \tab Disassociates an access policy from an access entry\cr
#'  \link[paws.compute:eks_disassociate_identity_provider_config]{disassociate_identity_provider_config} \tab Disassociates an identity provider configuration from a cluster\cr
#'  \link[paws.compute:eks_list_access_entries]{list_access_entries} \tab Lists the access entries for your cluster\cr
#'  \link[paws.compute:eks_list_access_policies]{list_access_policies} \tab Lists the available access policies\cr
#'  \link[paws.compute:eks_list_addons]{list_addons} \tab Lists the installed add-ons\cr
#'  \link[paws.compute:eks_list_associated_access_policies]{list_associated_access_policies} \tab Lists the access policies associated with an access entry\cr
#'  \link[paws.compute:eks_list_clusters]{list_clusters} \tab Lists the Amazon EKS clusters in your Amazon Web Services account in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:eks_list_eks_anywhere_subscriptions]{list_eks_anywhere_subscriptions} \tab Displays the full description of the subscription\cr
#'  \link[paws.compute:eks_list_fargate_profiles]{list_fargate_profiles} \tab Lists the Fargate profiles associated with the specified cluster in your Amazon Web Services account in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:eks_list_identity_provider_configs]{list_identity_provider_configs} \tab Lists the identity provider configurations for your cluster\cr
#'  \link[paws.compute:eks_list_insights]{list_insights} \tab Returns a list of all insights checked for against the specified cluster\cr
#'  \link[paws.compute:eks_list_nodegroups]{list_nodegroups} \tab Lists the managed node groups associated with the specified cluster in your Amazon Web Services account in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:eks_list_pod_identity_associations]{list_pod_identity_associations} \tab List the EKS Pod Identity associations in a cluster\cr
#'  \link[paws.compute:eks_list_tags_for_resource]{list_tags_for_resource} \tab List the tags for an Amazon EKS resource\cr
#'  \link[paws.compute:eks_list_updates]{list_updates} \tab Lists the updates associated with an Amazon EKS resource in your Amazon Web Services account, in the specified Amazon Web Services Region\cr
#'  \link[paws.compute:eks_register_cluster]{register_cluster} \tab Connects a Kubernetes cluster to the Amazon EKS control plane\cr
#'  \link[paws.compute:eks_tag_resource]{tag_resource} \tab Associates the specified tags to an Amazon EKS resource with the specified resourceArn\cr
#'  \link[paws.compute:eks_untag_resource]{untag_resource} \tab Deletes specified tags from an Amazon EKS resource\cr
#'  \link[paws.compute:eks_update_access_entry]{update_access_entry} \tab Updates an access entry\cr
#'  \link[paws.compute:eks_update_addon]{update_addon} \tab Updates an Amazon EKS add-on\cr
#'  \link[paws.compute:eks_update_cluster_config]{update_cluster_config} \tab Updates an Amazon EKS cluster configuration\cr
#'  \link[paws.compute:eks_update_cluster_version]{update_cluster_version} \tab Updates an Amazon EKS cluster to the specified Kubernetes version\cr
#'  \link[paws.compute:eks_update_eks_anywhere_subscription]{update_eks_anywhere_subscription} \tab Update an EKS Anywhere Subscription\cr
#'  \link[paws.compute:eks_update_nodegroup_config]{update_nodegroup_config} \tab Updates an Amazon EKS managed node group configuration\cr
#'  \link[paws.compute:eks_update_nodegroup_version]{update_nodegroup_version} \tab Updates the Kubernetes version or AMI version of an Amazon EKS managed node group\cr
#'  \link[paws.compute:eks_update_pod_identity_association]{update_pod_identity_association} \tab Updates a EKS Pod Identity association
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname eks
#' @export
eks <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::eks(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Elastic Beanstalk
#'
#' @description
#' AWS Elastic Beanstalk makes it easy for you to create, deploy, and
#' manage scalable, fault-tolerant applications running on the Amazon Web
#' Services cloud.
#' 
#' For more information about this product, go to the [AWS Elastic
#' Beanstalk](https://aws.amazon.com/elasticbeanstalk/) details page. The
#' location of the latest AWS Elastic Beanstalk WSDL is
#' <https://elasticbeanstalk.s3.amazonaws.com/doc/2010-12-01/AWSElasticBeanstalk.wsdl>.
#' To install the Software Development Kits (SDKs), Integrated Development
#' Environment (IDE) Toolkits, and command line tools that enable you to
#' access the API, go to [Tools for Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#' 
#' **Endpoints**
#' 
#' For a list of region-specific endpoints that AWS Elastic Beanstalk
#' supports, go to [Regions and
#' Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#elasticbeanstalk_region)
#' in the *Amazon Web Services Glossary*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- elasticbeanstalk(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- elasticbeanstalk()
#' # The following code aborts a running application version deployment for
#' # an environment named my-env:
#' svc$abort_environment_update(
#'   EnvironmentName = "my-env"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:elasticbeanstalk_abort_environment_update]{abort_environment_update} \tab Cancels in-progress environment configuration update or application version deployment\cr
#'  \link[paws.compute:elasticbeanstalk_apply_environment_managed_action]{apply_environment_managed_action} \tab Applies a scheduled managed action immediately\cr
#'  \link[paws.compute:elasticbeanstalk_associate_environment_operations_role]{associate_environment_operations_role} \tab Add or change the operations role used by an environment\cr
#'  \link[paws.compute:elasticbeanstalk_check_dns_availability]{check_dns_availability} \tab Checks if the specified CNAME is available\cr
#'  \link[paws.compute:elasticbeanstalk_compose_environments]{compose_environments} \tab Create or update a group of environments that each run a separate component of a single application\cr
#'  \link[paws.compute:elasticbeanstalk_create_application]{create_application} \tab Creates an application that has one configuration template named default and no application versions\cr
#'  \link[paws.compute:elasticbeanstalk_create_application_version]{create_application_version} \tab Creates an application version for the specified application\cr
#'  \link[paws.compute:elasticbeanstalk_create_configuration_template]{create_configuration_template} \tab Creates an AWS Elastic Beanstalk configuration template, associated with a specific Elastic Beanstalk application\cr
#'  \link[paws.compute:elasticbeanstalk_create_environment]{create_environment} \tab Launches an AWS Elastic Beanstalk environment for the specified application using the specified configuration\cr
#'  \link[paws.compute:elasticbeanstalk_create_platform_version]{create_platform_version} \tab Create a new version of your custom platform\cr
#'  \link[paws.compute:elasticbeanstalk_create_storage_location]{create_storage_location} \tab Creates a bucket in Amazon S3 to store application versions, logs, and other files used by Elastic Beanstalk environments\cr
#'  \link[paws.compute:elasticbeanstalk_delete_application]{delete_application} \tab Deletes the specified application along with all associated versions and configurations\cr
#'  \link[paws.compute:elasticbeanstalk_delete_application_version]{delete_application_version} \tab Deletes the specified version from the specified application\cr
#'  \link[paws.compute:elasticbeanstalk_delete_configuration_template]{delete_configuration_template} \tab Deletes the specified configuration template\cr
#'  \link[paws.compute:elasticbeanstalk_delete_environment_configuration]{delete_environment_configuration} \tab Deletes the draft configuration associated with the running environment\cr
#'  \link[paws.compute:elasticbeanstalk_delete_platform_version]{delete_platform_version} \tab Deletes the specified version of a custom platform\cr
#'  \link[paws.compute:elasticbeanstalk_describe_account_attributes]{describe_account_attributes} \tab Returns attributes related to AWS Elastic Beanstalk that are associated with the calling AWS account\cr
#'  \link[paws.compute:elasticbeanstalk_describe_applications]{describe_applications} \tab Returns the descriptions of existing applications\cr
#'  \link[paws.compute:elasticbeanstalk_describe_application_versions]{describe_application_versions} \tab Retrieve a list of application versions\cr
#'  \link[paws.compute:elasticbeanstalk_describe_configuration_options]{describe_configuration_options} \tab Describes the configuration options that are used in a particular configuration template or environment, or that a specified solution stack defines\cr
#'  \link[paws.compute:elasticbeanstalk_describe_configuration_settings]{describe_configuration_settings} \tab Returns a description of the settings for the specified configuration set, that is, either a configuration template or the configuration set associated with a running environment\cr
#'  \link[paws.compute:elasticbeanstalk_describe_environment_health]{describe_environment_health} \tab Returns information about the overall health of the specified environment\cr
#'  \link[paws.compute:elasticbeanstalk_describe_environment_managed_action_history]{describe_environment_managed_action_history} \tab Lists an environment's completed and failed managed actions\cr
#'  \link[paws.compute:elasticbeanstalk_describe_environment_managed_actions]{describe_environment_managed_actions} \tab Lists an environment's upcoming and in-progress managed actions\cr
#'  \link[paws.compute:elasticbeanstalk_describe_environment_resources]{describe_environment_resources} \tab Returns AWS resources for this environment\cr
#'  \link[paws.compute:elasticbeanstalk_describe_environments]{describe_environments} \tab Returns descriptions for existing environments\cr
#'  \link[paws.compute:elasticbeanstalk_describe_events]{describe_events} \tab Returns list of event descriptions matching criteria up to the last 6 weeks\cr
#'  \link[paws.compute:elasticbeanstalk_describe_instances_health]{describe_instances_health} \tab Retrieves detailed information about the health of instances in your AWS Elastic Beanstalk\cr
#'  \link[paws.compute:elasticbeanstalk_describe_platform_version]{describe_platform_version} \tab Describes a platform version\cr
#'  \link[paws.compute:elasticbeanstalk_disassociate_environment_operations_role]{disassociate_environment_operations_role} \tab Disassociate the operations role from an environment\cr
#'  \link[paws.compute:elasticbeanstalk_list_available_solution_stacks]{list_available_solution_stacks} \tab Returns a list of the available solution stack names, with the public version first and then in reverse chronological order\cr
#'  \link[paws.compute:elasticbeanstalk_list_platform_branches]{list_platform_branches} \tab Lists the platform branches available for your account in an AWS Region\cr
#'  \link[paws.compute:elasticbeanstalk_list_platform_versions]{list_platform_versions} \tab Lists the platform versions available for your account in an AWS Region\cr
#'  \link[paws.compute:elasticbeanstalk_list_tags_for_resource]{list_tags_for_resource} \tab Return the tags applied to an AWS Elastic Beanstalk resource\cr
#'  \link[paws.compute:elasticbeanstalk_rebuild_environment]{rebuild_environment} \tab Deletes and recreates all of the AWS resources (for example: the Auto Scaling group, load balancer, etc\cr
#'  \link[paws.compute:elasticbeanstalk_request_environment_info]{request_environment_info} \tab Initiates a request to compile the specified type of information of the deployed environment\cr
#'  \link[paws.compute:elasticbeanstalk_restart_app_server]{restart_app_server} \tab Causes the environment to restart the application container server running on each Amazon EC2 instance\cr
#'  \link[paws.compute:elasticbeanstalk_retrieve_environment_info]{retrieve_environment_info} \tab Retrieves the compiled information from a RequestEnvironmentInfo request\cr
#'  \link[paws.compute:elasticbeanstalk_swap_environment_cnam_es]{swap_environment_cnam_es} \tab Swaps the CNAMEs of two environments\cr
#'  \link[paws.compute:elasticbeanstalk_terminate_environment]{terminate_environment} \tab Terminates the specified environment\cr
#'  \link[paws.compute:elasticbeanstalk_update_application]{update_application} \tab Updates the specified application to have the specified properties\cr
#'  \link[paws.compute:elasticbeanstalk_update_application_resource_lifecycle]{update_application_resource_lifecycle} \tab Modifies lifecycle settings for an application\cr
#'  \link[paws.compute:elasticbeanstalk_update_application_version]{update_application_version} \tab Updates the specified application version to have the specified properties\cr
#'  \link[paws.compute:elasticbeanstalk_update_configuration_template]{update_configuration_template} \tab Updates the specified configuration template to have the specified properties or configuration option values\cr
#'  \link[paws.compute:elasticbeanstalk_update_environment]{update_environment} \tab Updates the environment description, deploys a new application version, updates the configuration settings to an entirely new configuration template, or updates select configuration option values in the running environment\cr
#'  \link[paws.compute:elasticbeanstalk_update_tags_for_resource]{update_tags_for_resource} \tab Update the list of tags applied to an AWS Elastic Beanstalk resource\cr
#'  \link[paws.compute:elasticbeanstalk_validate_configuration_settings]{validate_configuration_settings} \tab Takes a set of configuration settings and either a configuration template or environment, and determines whether those values are valid
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname elasticbeanstalk
#' @export
elasticbeanstalk <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::elasticbeanstalk(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon EMR Containers
#'
#' @description
#' Amazon EMR on EKS provides a deployment option for Amazon EMR that
#' allows you to run open-source big data frameworks on Amazon Elastic
#' Kubernetes Service (Amazon EKS). With this deployment option, you can
#' focus on running analytics workloads while Amazon EMR on EKS builds,
#' configures, and manages containers for open-source applications. For
#' more information about Amazon EMR on EKS concepts and tasks, see [What
#' is Amazon EMR on
#' EKS](https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/emr-eks.html).
#' 
#' *Amazon EMR containers* is the API name for Amazon EMR on EKS. The
#' `emr-containers` prefix is used in the following scenarios:
#' 
#' -   It is the prefix in the CLI commands for Amazon EMR on EKS. For
#'     example, `aws emr-containers start-job-run`.
#' 
#' -   It is the prefix before IAM policy actions for Amazon EMR on EKS.
#'     For example, `"Action": [ "emr-containers:StartJobRun"]`. For more
#'     information, see [Policy actions for Amazon EMR on
#'     EKS](https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-actions).
#' 
#' -   It is the prefix used in Amazon EMR on EKS service endpoints. For
#'     example, `emr-containers.us-east-2.amazonaws.com`. For more
#'     information, see [Amazon EMR on EKSService
#'     Endpoints](https://docs.aws.amazon.com/emr/latest/EMR-on-EKS-DevelopmentGuide/service-quotas.html#service-endpoints).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- emrcontainers(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- emrcontainers()
#' svc$cancel_job_run(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:emrcontainers_cancel_job_run]{cancel_job_run} \tab Cancels a job run\cr
#'  \link[paws.compute:emrcontainers_create_job_template]{create_job_template} \tab Creates a job template\cr
#'  \link[paws.compute:emrcontainers_create_managed_endpoint]{create_managed_endpoint} \tab Creates a managed endpoint\cr
#'  \link[paws.compute:emrcontainers_create_security_configuration]{create_security_configuration} \tab Creates a security configuration\cr
#'  \link[paws.compute:emrcontainers_create_virtual_cluster]{create_virtual_cluster} \tab Creates a virtual cluster\cr
#'  \link[paws.compute:emrcontainers_delete_job_template]{delete_job_template} \tab Deletes a job template\cr
#'  \link[paws.compute:emrcontainers_delete_managed_endpoint]{delete_managed_endpoint} \tab Deletes a managed endpoint\cr
#'  \link[paws.compute:emrcontainers_delete_virtual_cluster]{delete_virtual_cluster} \tab Deletes a virtual cluster\cr
#'  \link[paws.compute:emrcontainers_describe_job_run]{describe_job_run} \tab Displays detailed information about a job run\cr
#'  \link[paws.compute:emrcontainers_describe_job_template]{describe_job_template} \tab Displays detailed information about a specified job template\cr
#'  \link[paws.compute:emrcontainers_describe_managed_endpoint]{describe_managed_endpoint} \tab Displays detailed information about a managed endpoint\cr
#'  \link[paws.compute:emrcontainers_describe_security_configuration]{describe_security_configuration} \tab Displays detailed information about a specified security configuration\cr
#'  \link[paws.compute:emrcontainers_describe_virtual_cluster]{describe_virtual_cluster} \tab Displays detailed information about a specified virtual cluster\cr
#'  \link[paws.compute:emrcontainers_get_managed_endpoint_session_credentials]{get_managed_endpoint_session_credentials} \tab Generate a session token to connect to a managed endpoint\cr
#'  \link[paws.compute:emrcontainers_list_job_runs]{list_job_runs} \tab Lists job runs based on a set of parameters\cr
#'  \link[paws.compute:emrcontainers_list_job_templates]{list_job_templates} \tab Lists job templates based on a set of parameters\cr
#'  \link[paws.compute:emrcontainers_list_managed_endpoints]{list_managed_endpoints} \tab Lists managed endpoints based on a set of parameters\cr
#'  \link[paws.compute:emrcontainers_list_security_configurations]{list_security_configurations} \tab Lists security configurations based on a set of parameters\cr
#'  \link[paws.compute:emrcontainers_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags assigned to the resources\cr
#'  \link[paws.compute:emrcontainers_list_virtual_clusters]{list_virtual_clusters} \tab Lists information about the specified virtual cluster\cr
#'  \link[paws.compute:emrcontainers_start_job_run]{start_job_run} \tab Starts a job run\cr
#'  \link[paws.compute:emrcontainers_tag_resource]{tag_resource} \tab Assigns tags to resources\cr
#'  \link[paws.compute:emrcontainers_untag_resource]{untag_resource} \tab Removes tags from resources
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname emrcontainers
#' @export
emrcontainers <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::emrcontainers(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' EMR Serverless
#'
#' @description
#' Amazon EMR Serverless is a new deployment option for Amazon EMR. Amazon
#' EMR Serverless provides a serverless runtime environment that simplifies
#' running analytics applications using the latest open source frameworks
#' such as Apache Spark and Apache Hive. With Amazon EMR Serverless, you
#' don’t have to configure, optimize, secure, or operate clusters to run
#' applications with these frameworks.
#' 
#' The API reference to Amazon EMR Serverless is `emr-serverless`. The
#' `emr-serverless` prefix is used in the following scenarios:
#' 
#' -   It is the prefix in the CLI commands for Amazon EMR Serverless. For
#'     example, `aws emr-serverless start-job-run`.
#' 
#' -   It is the prefix before IAM policy actions for Amazon EMR
#'     Serverless. For example, `"Action": ["emr-serverless:StartJobRun"]`.
#'     For more information, see [Policy actions for Amazon EMR
#'     Serverless](https://docs.aws.amazon.com/emr/latest/EMR-Serverless-UserGuide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-actions).
#' 
#' -   It is the prefix used in Amazon EMR Serverless service endpoints.
#'     For example, `emr-serverless.us-east-2.amazonaws.com`.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- emrserverless(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- emrserverless()
#' svc$cancel_job_run(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:emrserverless_cancel_job_run]{cancel_job_run} \tab Cancels a job run\cr
#'  \link[paws.compute:emrserverless_create_application]{create_application} \tab Creates an application\cr
#'  \link[paws.compute:emrserverless_delete_application]{delete_application} \tab Deletes an application\cr
#'  \link[paws.compute:emrserverless_get_application]{get_application} \tab Displays detailed information about a specified application\cr
#'  \link[paws.compute:emrserverless_get_dashboard_for_job_run]{get_dashboard_for_job_run} \tab Creates and returns a URL that you can use to access the application UIs for a job run\cr
#'  \link[paws.compute:emrserverless_get_job_run]{get_job_run} \tab Displays detailed information about a job run\cr
#'  \link[paws.compute:emrserverless_list_applications]{list_applications} \tab Lists applications based on a set of parameters\cr
#'  \link[paws.compute:emrserverless_list_job_run_attempts]{list_job_run_attempts} \tab Lists all attempt of a job run\cr
#'  \link[paws.compute:emrserverless_list_job_runs]{list_job_runs} \tab Lists job runs based on a set of parameters\cr
#'  \link[paws.compute:emrserverless_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags assigned to the resources\cr
#'  \link[paws.compute:emrserverless_start_application]{start_application} \tab Starts a specified application and initializes initial capacity if configured\cr
#'  \link[paws.compute:emrserverless_start_job_run]{start_job_run} \tab Starts a job run\cr
#'  \link[paws.compute:emrserverless_stop_application]{stop_application} \tab Stops a specified application and releases initial capacity if configured\cr
#'  \link[paws.compute:emrserverless_tag_resource]{tag_resource} \tab Assigns tags to resources\cr
#'  \link[paws.compute:emrserverless_untag_resource]{untag_resource} \tab Removes tags from resources\cr
#'  \link[paws.compute:emrserverless_update_application]{update_application} \tab Updates a specified application
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname emrserverless
#' @export
emrserverless <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::emrserverless(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' EC2 Image Builder
#'
#' @description
#' EC2 Image Builder is a fully managed Amazon Web Services service that
#' makes it easier to automate the creation, management, and deployment of
#' customized, secure, and up-to-date "golden" server images that are
#' pre-installed and pre-configured with software and settings to meet
#' specific IT standards.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- imagebuilder(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- imagebuilder()
#' svc$cancel_image_creation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:imagebuilder_cancel_image_creation]{cancel_image_creation} \tab CancelImageCreation cancels the creation of Image\cr
#'  \link[paws.compute:imagebuilder_cancel_lifecycle_execution]{cancel_lifecycle_execution} \tab Cancel a specific image lifecycle policy runtime instance\cr
#'  \link[paws.compute:imagebuilder_create_component]{create_component} \tab Creates a new component that can be used to build, validate, test, and assess your image\cr
#'  \link[paws.compute:imagebuilder_create_container_recipe]{create_container_recipe} \tab Creates a new container recipe\cr
#'  \link[paws.compute:imagebuilder_create_distribution_configuration]{create_distribution_configuration} \tab Creates a new distribution configuration\cr
#'  \link[paws.compute:imagebuilder_create_image]{create_image} \tab Creates a new image\cr
#'  \link[paws.compute:imagebuilder_create_image_pipeline]{create_image_pipeline} \tab Creates a new image pipeline\cr
#'  \link[paws.compute:imagebuilder_create_image_recipe]{create_image_recipe} \tab Creates a new image recipe\cr
#'  \link[paws.compute:imagebuilder_create_infrastructure_configuration]{create_infrastructure_configuration} \tab Creates a new infrastructure configuration\cr
#'  \link[paws.compute:imagebuilder_create_lifecycle_policy]{create_lifecycle_policy} \tab Create a lifecycle policy resource\cr
#'  \link[paws.compute:imagebuilder_create_workflow]{create_workflow} \tab Create a new workflow or a new version of an existing workflow\cr
#'  \link[paws.compute:imagebuilder_delete_component]{delete_component} \tab Deletes a component build version\cr
#'  \link[paws.compute:imagebuilder_delete_container_recipe]{delete_container_recipe} \tab Deletes a container recipe\cr
#'  \link[paws.compute:imagebuilder_delete_distribution_configuration]{delete_distribution_configuration} \tab Deletes a distribution configuration\cr
#'  \link[paws.compute:imagebuilder_delete_image]{delete_image} \tab Deletes an Image Builder image resource\cr
#'  \link[paws.compute:imagebuilder_delete_image_pipeline]{delete_image_pipeline} \tab Deletes an image pipeline\cr
#'  \link[paws.compute:imagebuilder_delete_image_recipe]{delete_image_recipe} \tab Deletes an image recipe\cr
#'  \link[paws.compute:imagebuilder_delete_infrastructure_configuration]{delete_infrastructure_configuration} \tab Deletes an infrastructure configuration\cr
#'  \link[paws.compute:imagebuilder_delete_lifecycle_policy]{delete_lifecycle_policy} \tab Delete the specified lifecycle policy resource\cr
#'  \link[paws.compute:imagebuilder_delete_workflow]{delete_workflow} \tab Deletes a specific workflow resource\cr
#'  \link[paws.compute:imagebuilder_get_component]{get_component} \tab Gets a component object\cr
#'  \link[paws.compute:imagebuilder_get_component_policy]{get_component_policy} \tab Gets a component policy\cr
#'  \link[paws.compute:imagebuilder_get_container_recipe]{get_container_recipe} \tab Retrieves a container recipe\cr
#'  \link[paws.compute:imagebuilder_get_container_recipe_policy]{get_container_recipe_policy} \tab Retrieves the policy for a container recipe\cr
#'  \link[paws.compute:imagebuilder_get_distribution_configuration]{get_distribution_configuration} \tab Gets a distribution configuration\cr
#'  \link[paws.compute:imagebuilder_get_image]{get_image} \tab Gets an image\cr
#'  \link[paws.compute:imagebuilder_get_image_pipeline]{get_image_pipeline} \tab Gets an image pipeline\cr
#'  \link[paws.compute:imagebuilder_get_image_policy]{get_image_policy} \tab Gets an image policy\cr
#'  \link[paws.compute:imagebuilder_get_image_recipe]{get_image_recipe} \tab Gets an image recipe\cr
#'  \link[paws.compute:imagebuilder_get_image_recipe_policy]{get_image_recipe_policy} \tab Gets an image recipe policy\cr
#'  \link[paws.compute:imagebuilder_get_infrastructure_configuration]{get_infrastructure_configuration} \tab Gets an infrastructure configuration\cr
#'  \link[paws.compute:imagebuilder_get_lifecycle_execution]{get_lifecycle_execution} \tab Get the runtime information that was logged for a specific runtime instance of the lifecycle policy\cr
#'  \link[paws.compute:imagebuilder_get_lifecycle_policy]{get_lifecycle_policy} \tab Get details for the specified image lifecycle policy\cr
#'  \link[paws.compute:imagebuilder_get_marketplace_resource]{get_marketplace_resource} \tab Verify the subscription and perform resource dependency checks on the requested Amazon Web Services Marketplace resource\cr
#'  \link[paws.compute:imagebuilder_get_workflow]{get_workflow} \tab Get a workflow resource object\cr
#'  \link[paws.compute:imagebuilder_get_workflow_execution]{get_workflow_execution} \tab Get the runtime information that was logged for a specific runtime instance of the workflow\cr
#'  \link[paws.compute:imagebuilder_get_workflow_step_execution]{get_workflow_step_execution} \tab Get the runtime information that was logged for a specific runtime instance of the workflow step\cr
#'  \link[paws.compute:imagebuilder_import_component]{import_component} \tab Imports a component and transforms its data into a component document\cr
#'  \link[paws.compute:imagebuilder_import_disk_image]{import_disk_image} \tab Import a Windows operating system image from a verified Microsoft ISO disk file\cr
#'  \link[paws.compute:imagebuilder_import_vm_image]{import_vm_image} \tab When you export your virtual machine (VM) from its virtualization environment, that process creates a set of one or more disk container files that act as snapshots of your VM’s environment, settings, and data\cr
#'  \link[paws.compute:imagebuilder_list_component_build_versions]{list_component_build_versions} \tab Returns the list of component build versions for the specified component version Amazon Resource Name (ARN)\cr
#'  \link[paws.compute:imagebuilder_list_components]{list_components} \tab Returns the list of components that can be filtered by name, or by using the listed filters to streamline results\cr
#'  \link[paws.compute:imagebuilder_list_container_recipes]{list_container_recipes} \tab Returns a list of container recipes\cr
#'  \link[paws.compute:imagebuilder_list_distribution_configurations]{list_distribution_configurations} \tab Returns a list of distribution configurations\cr
#'  \link[paws.compute:imagebuilder_list_image_build_versions]{list_image_build_versions} \tab Returns a list of image build versions\cr
#'  \link[paws.compute:imagebuilder_list_image_packages]{list_image_packages} \tab List the Packages that are associated with an Image Build Version, as determined by Amazon Web Services Systems Manager Inventory at build time\cr
#'  \link[paws.compute:imagebuilder_list_image_pipeline_images]{list_image_pipeline_images} \tab Returns a list of images created by the specified pipeline\cr
#'  \link[paws.compute:imagebuilder_list_image_pipelines]{list_image_pipelines} \tab Returns a list of image pipelines\cr
#'  \link[paws.compute:imagebuilder_list_image_recipes]{list_image_recipes} \tab Returns a list of image recipes\cr
#'  \link[paws.compute:imagebuilder_list_images]{list_images} \tab Returns the list of images that you have access to\cr
#'  \link[paws.compute:imagebuilder_list_image_scan_finding_aggregations]{list_image_scan_finding_aggregations} \tab Returns a list of image scan aggregations for your account\cr
#'  \link[paws.compute:imagebuilder_list_image_scan_findings]{list_image_scan_findings} \tab Returns a list of image scan findings for your account\cr
#'  \link[paws.compute:imagebuilder_list_infrastructure_configurations]{list_infrastructure_configurations} \tab Returns a list of infrastructure configurations\cr
#'  \link[paws.compute:imagebuilder_list_lifecycle_execution_resources]{list_lifecycle_execution_resources} \tab List resources that the runtime instance of the image lifecycle identified for lifecycle actions\cr
#'  \link[paws.compute:imagebuilder_list_lifecycle_executions]{list_lifecycle_executions} \tab Get the lifecycle runtime history for the specified resource\cr
#'  \link[paws.compute:imagebuilder_list_lifecycle_policies]{list_lifecycle_policies} \tab Get a list of lifecycle policies in your Amazon Web Services account\cr
#'  \link[paws.compute:imagebuilder_list_tags_for_resource]{list_tags_for_resource} \tab Returns the list of tags for the specified resource\cr
#'  \link[paws.compute:imagebuilder_list_waiting_workflow_steps]{list_waiting_workflow_steps} \tab Get a list of workflow steps that are waiting for action for workflows in your Amazon Web Services account\cr
#'  \link[paws.compute:imagebuilder_list_workflow_build_versions]{list_workflow_build_versions} \tab Returns a list of build versions for a specific workflow resource\cr
#'  \link[paws.compute:imagebuilder_list_workflow_executions]{list_workflow_executions} \tab Returns a list of workflow runtime instance metadata objects for a specific image build version\cr
#'  \link[paws.compute:imagebuilder_list_workflows]{list_workflows} \tab Lists workflow build versions based on filtering parameters\cr
#'  \link[paws.compute:imagebuilder_list_workflow_step_executions]{list_workflow_step_executions} \tab Returns runtime data for each step in a runtime instance of the workflow that you specify in the request\cr
#'  \link[paws.compute:imagebuilder_put_component_policy]{put_component_policy} \tab Applies a policy to a component\cr
#'  \link[paws.compute:imagebuilder_put_container_recipe_policy]{put_container_recipe_policy} \tab Applies a policy to a container image\cr
#'  \link[paws.compute:imagebuilder_put_image_policy]{put_image_policy} \tab Applies a policy to an image\cr
#'  \link[paws.compute:imagebuilder_put_image_recipe_policy]{put_image_recipe_policy} \tab Applies a policy to an image recipe\cr
#'  \link[paws.compute:imagebuilder_send_workflow_step_action]{send_workflow_step_action} \tab Pauses or resumes image creation when the associated workflow runs a WaitForAction step\cr
#'  \link[paws.compute:imagebuilder_start_image_pipeline_execution]{start_image_pipeline_execution} \tab Manually triggers a pipeline to create an image\cr
#'  \link[paws.compute:imagebuilder_start_resource_state_update]{start_resource_state_update} \tab Begin asynchronous resource state update for lifecycle changes to the specified image resources\cr
#'  \link[paws.compute:imagebuilder_tag_resource]{tag_resource} \tab Adds a tag to a resource\cr
#'  \link[paws.compute:imagebuilder_untag_resource]{untag_resource} \tab Removes a tag from a resource\cr
#'  \link[paws.compute:imagebuilder_update_distribution_configuration]{update_distribution_configuration} \tab Updates a new distribution configuration\cr
#'  \link[paws.compute:imagebuilder_update_image_pipeline]{update_image_pipeline} \tab Updates an image pipeline\cr
#'  \link[paws.compute:imagebuilder_update_infrastructure_configuration]{update_infrastructure_configuration} \tab Updates a new infrastructure configuration\cr
#'  \link[paws.compute:imagebuilder_update_lifecycle_policy]{update_lifecycle_policy} \tab Update the specified lifecycle policy
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname imagebuilder
#' @export
imagebuilder <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::imagebuilder(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Lambda
#'
#' @description
#' Lambda
#' 
#' **Overview**
#' 
#' Lambda is a compute service that lets you run code without provisioning
#' or managing servers. Lambda runs your code on a high-availability
#' compute infrastructure and performs all of the administration of the
#' compute resources, including server and operating system maintenance,
#' capacity provisioning and automatic scaling, code monitoring and
#' logging. With Lambda, you can run code for virtually any type of
#' application or backend service. For more information about the Lambda
#' service, see [What is
#' Lambda](https://docs.aws.amazon.com/lambda/latest/dg/welcome.html) in
#' the **Lambda Developer Guide**.
#' 
#' The *Lambda API Reference* provides information about each of the API
#' methods, including details about the parameters in each API request and
#' response.
#' 
#' You can use Software Development Kits (SDKs), Integrated Development
#' Environment (IDE) Toolkits, and command line tools to access the API.
#' For installation instructions, see [Tools for Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#' 
#' For a list of Region-specific endpoints that Lambda supports, see
#' [Lambda endpoints and
#' quotas](https://docs.aws.amazon.com/general/latest/gr/lambda-service.html)
#' in the *Amazon Web Services General Reference.*.
#' 
#' When making the API calls, you will need to authenticate your request by
#' providing a signature. Lambda supports signature version 4. For more
#' information, see [Signature Version 4 signing
#' process](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html)
#' in the *Amazon Web Services General Reference.*.
#' 
#' **CA certificates**
#' 
#' Because Amazon Web Services SDKs use the CA certificates from your
#' computer, changes to the certificates on the Amazon Web Services servers
#' can cause connection failures when you attempt to use an SDK. You can
#' prevent these failures by keeping your computer's CA certificates and
#' operating system up-to-date. If you encounter this issue in a corporate
#' environment and do not manage your own computer, you might need to ask
#' an administrator to assist with the update process. The following list
#' shows minimum operating system and Java versions:
#' 
#' -   Microsoft Windows versions that have updates from January 2005 or
#'     later installed contain at least one of the required CAs in their
#'     trust list.
#' 
#' -   Mac OS X 10.4 with Java for Mac OS X 10.4 Release 5 (February 2007),
#'     Mac OS X 10.5 (October 2007), and later versions contain at least
#'     one of the required CAs in their trust list.
#' 
#' -   Red Hat Enterprise Linux 5 (March 2007), 6, and 7 and CentOS 5, 6,
#'     and 7 all contain at least one of the required CAs in their default
#'     trusted CA list.
#' 
#' -   Java 1.4.2_12 (May 2006), 5 Update 2 (March 2005), and all later
#'     versions, including Java 6 (December 2006), 7, and 8, contain at
#'     least one of the required CAs in their default trusted CA list.
#' 
#' When accessing the Lambda management console or Lambda API endpoints,
#' whether through browsers or programmatically, you will need to ensure
#' your client machines support any of the following CAs:
#' 
#' -   Amazon Root CA 1
#' 
#' -   Starfield Services Root Certificate Authority - G2
#' 
#' -   Starfield Class 2 Certification Authority
#' 
#' Root certificates from the first two authorities are available from
#' [Amazon trust services](https://www.amazontrust.com/repository/), but
#' keeping your computer up-to-date is the more straightforward solution.
#' To learn more about ACM-provided certificates, see [Amazon Web Services
#' Certificate Manager
#' FAQs.](https://aws.amazon.com/certificate-manager/faqs/#certificates)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lambda(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lambda()
#' # The following example grants permission for the account 223456789012 to
#' # use version 1 of a layer named my-layer.
#' svc$add_layer_version_permission(
#'   Action = "lambda:GetLayerVersion",
#'   LayerName = "my-layer",
#'   Principal = "223456789012",
#'   StatementId = "xaccount",
#'   VersionNumber = 1L
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:lambda_add_layer_version_permission]{add_layer_version_permission} \tab Adds permissions to the resource-based policy of a version of an Lambda layer\cr
#'  \link[paws.compute:lambda_add_permission]{add_permission} \tab Grants a principal permission to use a function\cr
#'  \link[paws.compute:lambda_create_alias]{create_alias} \tab Creates an alias for a Lambda function version\cr
#'  \link[paws.compute:lambda_create_code_signing_config]{create_code_signing_config} \tab Creates a code signing configuration\cr
#'  \link[paws.compute:lambda_create_event_source_mapping]{create_event_source_mapping} \tab Creates a mapping between an event source and an Lambda function\cr
#'  \link[paws.compute:lambda_create_function]{create_function} \tab Creates a Lambda function\cr
#'  \link[paws.compute:lambda_create_function_url_config]{create_function_url_config} \tab Creates a Lambda function URL with the specified configuration parameters\cr
#'  \link[paws.compute:lambda_delete_alias]{delete_alias} \tab Deletes a Lambda function alias\cr
#'  \link[paws.compute:lambda_delete_code_signing_config]{delete_code_signing_config} \tab Deletes the code signing configuration\cr
#'  \link[paws.compute:lambda_delete_event_source_mapping]{delete_event_source_mapping} \tab Deletes an event source mapping\cr
#'  \link[paws.compute:lambda_delete_function]{delete_function} \tab Deletes a Lambda function\cr
#'  \link[paws.compute:lambda_delete_function_code_signing_config]{delete_function_code_signing_config} \tab Removes the code signing configuration from the function\cr
#'  \link[paws.compute:lambda_delete_function_concurrency]{delete_function_concurrency} \tab Removes a concurrent execution limit from a function\cr
#'  \link[paws.compute:lambda_delete_function_event_invoke_config]{delete_function_event_invoke_config} \tab Deletes the configuration for asynchronous invocation for a function, version, or alias\cr
#'  \link[paws.compute:lambda_delete_function_url_config]{delete_function_url_config} \tab Deletes a Lambda function URL\cr
#'  \link[paws.compute:lambda_delete_layer_version]{delete_layer_version} \tab Deletes a version of an Lambda layer\cr
#'  \link[paws.compute:lambda_delete_provisioned_concurrency_config]{delete_provisioned_concurrency_config} \tab Deletes the provisioned concurrency configuration for a function\cr
#'  \link[paws.compute:lambda_get_account_settings]{get_account_settings} \tab Retrieves details about your account's limits and usage in an Amazon Web Services Region\cr
#'  \link[paws.compute:lambda_get_alias]{get_alias} \tab Returns details about a Lambda function alias\cr
#'  \link[paws.compute:lambda_get_code_signing_config]{get_code_signing_config} \tab Returns information about the specified code signing configuration\cr
#'  \link[paws.compute:lambda_get_event_source_mapping]{get_event_source_mapping} \tab Returns details about an event source mapping\cr
#'  \link[paws.compute:lambda_get_function]{get_function} \tab Returns information about the function or function version, with a link to download the deployment package that's valid for 10 minutes\cr
#'  \link[paws.compute:lambda_get_function_code_signing_config]{get_function_code_signing_config} \tab Returns the code signing configuration for the specified function\cr
#'  \link[paws.compute:lambda_get_function_concurrency]{get_function_concurrency} \tab Returns details about the reserved concurrency configuration for a function\cr
#'  \link[paws.compute:lambda_get_function_configuration]{get_function_configuration} \tab Returns the version-specific settings of a Lambda function or version\cr
#'  \link[paws.compute:lambda_get_function_event_invoke_config]{get_function_event_invoke_config} \tab Retrieves the configuration for asynchronous invocation for a function, version, or alias\cr
#'  \link[paws.compute:lambda_get_function_recursion_config]{get_function_recursion_config} \tab Returns your function's recursive loop detection configuration\cr
#'  \link[paws.compute:lambda_get_function_url_config]{get_function_url_config} \tab Returns details about a Lambda function URL\cr
#'  \link[paws.compute:lambda_get_layer_version]{get_layer_version} \tab Returns information about a version of an Lambda layer, with a link to download the layer archive that's valid for 10 minutes\cr
#'  \link[paws.compute:lambda_get_layer_version_by_arn]{get_layer_version_by_arn} \tab Returns information about a version of an Lambda layer, with a link to download the layer archive that's valid for 10 minutes\cr
#'  \link[paws.compute:lambda_get_layer_version_policy]{get_layer_version_policy} \tab Returns the permission policy for a version of an Lambda layer\cr
#'  \link[paws.compute:lambda_get_policy]{get_policy} \tab Returns the resource-based IAM policy for a function, version, or alias\cr
#'  \link[paws.compute:lambda_get_provisioned_concurrency_config]{get_provisioned_concurrency_config} \tab Retrieves the provisioned concurrency configuration for a function's alias or version\cr
#'  \link[paws.compute:lambda_get_runtime_management_config]{get_runtime_management_config} \tab Retrieves the runtime management configuration for a function's version\cr
#'  \link[paws.compute:lambda_invoke]{invoke} \tab Invokes a Lambda function\cr
#'  \link[paws.compute:lambda_invoke_async]{invoke_async} \tab For asynchronous function invocation, use Invoke\cr
#'  \link[paws.compute:lambda_invoke_with_response_stream]{invoke_with_response_stream} \tab Configure your Lambda functions to stream response payloads back to clients\cr
#'  \link[paws.compute:lambda_list_aliases]{list_aliases} \tab Returns a list of aliases for a Lambda function\cr
#'  \link[paws.compute:lambda_list_code_signing_configs]{list_code_signing_configs} \tab Returns a list of code signing configurations\cr
#'  \link[paws.compute:lambda_list_event_source_mappings]{list_event_source_mappings} \tab Lists event source mappings\cr
#'  \link[paws.compute:lambda_list_function_event_invoke_configs]{list_function_event_invoke_configs} \tab Retrieves a list of configurations for asynchronous invocation for a function\cr
#'  \link[paws.compute:lambda_list_functions]{list_functions} \tab Returns a list of Lambda functions, with the version-specific configuration of each\cr
#'  \link[paws.compute:lambda_list_functions_by_code_signing_config]{list_functions_by_code_signing_config} \tab List the functions that use the specified code signing configuration\cr
#'  \link[paws.compute:lambda_list_function_url_configs]{list_function_url_configs} \tab Returns a list of Lambda function URLs for the specified function\cr
#'  \link[paws.compute:lambda_list_layers]{list_layers} \tab Lists Lambda layers and shows information about the latest version of each\cr
#'  \link[paws.compute:lambda_list_layer_versions]{list_layer_versions} \tab Lists the versions of an Lambda layer\cr
#'  \link[paws.compute:lambda_list_provisioned_concurrency_configs]{list_provisioned_concurrency_configs} \tab Retrieves a list of provisioned concurrency configurations for a function\cr
#'  \link[paws.compute:lambda_list_tags]{list_tags} \tab Returns a function, event source mapping, or code signing configuration's tags\cr
#'  \link[paws.compute:lambda_list_versions_by_function]{list_versions_by_function} \tab Returns a list of versions, with the version-specific configuration of each\cr
#'  \link[paws.compute:lambda_publish_layer_version]{publish_layer_version} \tab Creates an Lambda layer from a ZIP archive\cr
#'  \link[paws.compute:lambda_publish_version]{publish_version} \tab Creates a version from the current code and configuration of a function\cr
#'  \link[paws.compute:lambda_put_function_code_signing_config]{put_function_code_signing_config} \tab Update the code signing configuration for the function\cr
#'  \link[paws.compute:lambda_put_function_concurrency]{put_function_concurrency} \tab Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level\cr
#'  \link[paws.compute:lambda_put_function_event_invoke_config]{put_function_event_invoke_config} \tab Configures options for asynchronous invocation on a function, version, or alias\cr
#'  \link[paws.compute:lambda_put_function_recursion_config]{put_function_recursion_config} \tab Sets your function's recursive loop detection configuration\cr
#'  \link[paws.compute:lambda_put_provisioned_concurrency_config]{put_provisioned_concurrency_config} \tab Adds a provisioned concurrency configuration to a function's alias or version\cr
#'  \link[paws.compute:lambda_put_runtime_management_config]{put_runtime_management_config} \tab Sets the runtime management configuration for a function's version\cr
#'  \link[paws.compute:lambda_remove_layer_version_permission]{remove_layer_version_permission} \tab Removes a statement from the permissions policy for a version of an Lambda layer\cr
#'  \link[paws.compute:lambda_remove_permission]{remove_permission} \tab Revokes function-use permission from an Amazon Web Services service or another Amazon Web Services account\cr
#'  \link[paws.compute:lambda_tag_resource]{tag_resource} \tab Adds tags to a function, event source mapping, or code signing configuration\cr
#'  \link[paws.compute:lambda_untag_resource]{untag_resource} \tab Removes tags from a function, event source mapping, or code signing configuration\cr
#'  \link[paws.compute:lambda_update_alias]{update_alias} \tab Updates the configuration of a Lambda function alias\cr
#'  \link[paws.compute:lambda_update_code_signing_config]{update_code_signing_config} \tab Update the code signing configuration\cr
#'  \link[paws.compute:lambda_update_event_source_mapping]{update_event_source_mapping} \tab Updates an event source mapping\cr
#'  \link[paws.compute:lambda_update_function_code]{update_function_code} \tab Updates a Lambda function's code\cr
#'  \link[paws.compute:lambda_update_function_configuration]{update_function_configuration} \tab Modify the version-specific settings of a Lambda function\cr
#'  \link[paws.compute:lambda_update_function_event_invoke_config]{update_function_event_invoke_config} \tab Updates the configuration for asynchronous invocation for a function, version, or alias\cr
#'  \link[paws.compute:lambda_update_function_url_config]{update_function_url_config} \tab Updates the configuration for a Lambda function URL
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lambda
#' @export
lambda <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::lambda(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Lightsail
#'
#' @description
#' Amazon Lightsail is the easiest way to get started with Amazon Web
#' Services (Amazon Web Services) for developers who need to build websites
#' or web applications. It includes everything you need to launch your
#' project quickly - instances (virtual private servers), container
#' services, storage buckets, managed databases, SSD-based block storage,
#' static IP addresses, load balancers, content delivery network (CDN)
#' distributions, DNS management of registered domains, and resource
#' snapshots (backups) - for a low, predictable monthly price.
#' 
#' You can manage your Lightsail resources using the Lightsail console,
#' Lightsail API, Command Line Interface (CLI), or SDKs. For more
#' information about Lightsail concepts and tasks, see the [Amazon
#' Lightsail Developer
#' Guide](https://docs.aws.amazon.com/lightsail/latest/userguide/lightsail-how-to-set-up-access-keys-to-use-sdk-api-cli.html).
#' 
#' This API Reference provides detailed information about the actions, data
#' types, parameters, and errors of the Lightsail service. For more
#' information about the supported Amazon Web Services Regions, endpoints,
#' and service quotas of the Lightsail service, see [Amazon Lightsail
#' Endpoints and
#' Quotas](https://docs.aws.amazon.com/general/latest/gr/lightsail.html) in
#' the *Amazon Web Services General Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lightsail(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lightsail()
#' svc$allocate_static_ip(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:lightsail_allocate_static_ip]{allocate_static_ip} \tab Allocates a static IP address\cr
#'  \link[paws.compute:lightsail_attach_certificate_to_distribution]{attach_certificate_to_distribution} \tab Attaches an SSL/TLS certificate to your Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_attach_disk]{attach_disk} \tab Attaches a block storage disk to a running or stopped Lightsail instance and exposes it to the instance with the specified disk name\cr
#'  \link[paws.compute:lightsail_attach_instances_to_load_balancer]{attach_instances_to_load_balancer} \tab Attaches one or more Lightsail instances to a load balancer\cr
#'  \link[paws.compute:lightsail_attach_load_balancer_tls_certificate]{attach_load_balancer_tls_certificate} \tab Attaches a Transport Layer Security (TLS) certificate to your load balancer\cr
#'  \link[paws.compute:lightsail_attach_static_ip]{attach_static_ip} \tab Attaches a static IP address to a specific Amazon Lightsail instance\cr
#'  \link[paws.compute:lightsail_close_instance_public_ports]{close_instance_public_ports} \tab Closes ports for a specific Amazon Lightsail instance\cr
#'  \link[paws.compute:lightsail_copy_snapshot]{copy_snapshot} \tab Copies a manual snapshot of an instance or disk as another manual snapshot, or copies an automatic snapshot of an instance or disk as a manual snapshot\cr
#'  \link[paws.compute:lightsail_create_bucket]{create_bucket} \tab Creates an Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_create_bucket_access_key]{create_bucket_access_key} \tab Creates a new access key for the specified Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_create_certificate]{create_certificate} \tab Creates an SSL/TLS certificate for an Amazon Lightsail content delivery network (CDN) distribution and a container service\cr
#'  \link[paws.compute:lightsail_create_cloud_formation_stack]{create_cloud_formation_stack} \tab Creates an AWS CloudFormation stack, which creates a new Amazon EC2 instance from an exported Amazon Lightsail snapshot\cr
#'  \link[paws.compute:lightsail_create_contact_method]{create_contact_method} \tab Creates an email or SMS text message contact method\cr
#'  \link[paws.compute:lightsail_create_container_service]{create_container_service} \tab Creates an Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_create_container_service_deployment]{create_container_service_deployment} \tab Creates a deployment for your Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_create_container_service_registry_login]{create_container_service_registry_login} \tab Creates a temporary set of log in credentials that you can use to log in to the Docker process on your local machine\cr
#'  \link[paws.compute:lightsail_create_disk]{create_disk} \tab Creates a block storage disk that can be attached to an Amazon Lightsail instance in the same Availability Zone (us-east-2a)\cr
#'  \link[paws.compute:lightsail_create_disk_from_snapshot]{create_disk_from_snapshot} \tab Creates a block storage disk from a manual or automatic snapshot of a disk\cr
#'  \link[paws.compute:lightsail_create_disk_snapshot]{create_disk_snapshot} \tab Creates a snapshot of a block storage disk\cr
#'  \link[paws.compute:lightsail_create_distribution]{create_distribution} \tab Creates an Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_create_domain]{create_domain} \tab Creates a domain resource for the specified domain (example\cr
#'  \link[paws.compute:lightsail_create_domain_entry]{create_domain_entry} \tab Creates one of the following domain name system (DNS) records in a domain DNS zone: Address (A), canonical name (CNAME), mail exchanger (MX), name server (NS), start of authority (SOA), service locator (SRV), or text (TXT)\cr
#'  \link[paws.compute:lightsail_create_gui_session_access_details]{create_gui_session_access_details} \tab Creates two URLs that are used to access a virtual computer’s graphical user interface (GUI) session\cr
#'  \link[paws.compute:lightsail_create_instances]{create_instances} \tab Creates one or more Amazon Lightsail instances\cr
#'  \link[paws.compute:lightsail_create_instances_from_snapshot]{create_instances_from_snapshot} \tab Creates one or more new instances from a manual or automatic snapshot of an instance\cr
#'  \link[paws.compute:lightsail_create_instance_snapshot]{create_instance_snapshot} \tab Creates a snapshot of a specific virtual private server, or instance\cr
#'  \link[paws.compute:lightsail_create_key_pair]{create_key_pair} \tab Creates a custom SSH key pair that you can use with an Amazon Lightsail instance\cr
#'  \link[paws.compute:lightsail_create_load_balancer]{create_load_balancer} \tab Creates a Lightsail load balancer\cr
#'  \link[paws.compute:lightsail_create_load_balancer_tls_certificate]{create_load_balancer_tls_certificate} \tab Creates an SSL/TLS certificate for an Amazon Lightsail load balancer\cr
#'  \link[paws.compute:lightsail_create_relational_database]{create_relational_database} \tab Creates a new database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_create_relational_database_from_snapshot]{create_relational_database_from_snapshot} \tab Creates a new database from an existing database snapshot in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_create_relational_database_snapshot]{create_relational_database_snapshot} \tab Creates a snapshot of your database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_delete_alarm]{delete_alarm} \tab Deletes an alarm\cr
#'  \link[paws.compute:lightsail_delete_auto_snapshot]{delete_auto_snapshot} \tab Deletes an automatic snapshot of an instance or disk\cr
#'  \link[paws.compute:lightsail_delete_bucket]{delete_bucket} \tab Deletes a Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_delete_bucket_access_key]{delete_bucket_access_key} \tab Deletes an access key for the specified Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_delete_certificate]{delete_certificate} \tab Deletes an SSL/TLS certificate for your Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_delete_contact_method]{delete_contact_method} \tab Deletes a contact method\cr
#'  \link[paws.compute:lightsail_delete_container_image]{delete_container_image} \tab Deletes a container image that is registered to your Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_delete_container_service]{delete_container_service} \tab Deletes your Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_delete_disk]{delete_disk} \tab Deletes the specified block storage disk\cr
#'  \link[paws.compute:lightsail_delete_disk_snapshot]{delete_disk_snapshot} \tab Deletes the specified disk snapshot\cr
#'  \link[paws.compute:lightsail_delete_distribution]{delete_distribution} \tab Deletes your Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_delete_domain]{delete_domain} \tab Deletes the specified domain recordset and all of its domain records\cr
#'  \link[paws.compute:lightsail_delete_domain_entry]{delete_domain_entry} \tab Deletes a specific domain entry\cr
#'  \link[paws.compute:lightsail_delete_instance]{delete_instance} \tab Deletes an Amazon Lightsail instance\cr
#'  \link[paws.compute:lightsail_delete_instance_snapshot]{delete_instance_snapshot} \tab Deletes a specific snapshot of a virtual private server (or instance)\cr
#'  \link[paws.compute:lightsail_delete_key_pair]{delete_key_pair} \tab Deletes the specified key pair by removing the public key from Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_delete_known_host_keys]{delete_known_host_keys} \tab Deletes the known host key or certificate used by the Amazon Lightsail browser-based SSH or RDP clients to authenticate an instance\cr
#'  \link[paws.compute:lightsail_delete_load_balancer]{delete_load_balancer} \tab Deletes a Lightsail load balancer and all its associated SSL/TLS certificates\cr
#'  \link[paws.compute:lightsail_delete_load_balancer_tls_certificate]{delete_load_balancer_tls_certificate} \tab Deletes an SSL/TLS certificate associated with a Lightsail load balancer\cr
#'  \link[paws.compute:lightsail_delete_relational_database]{delete_relational_database} \tab Deletes a database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_delete_relational_database_snapshot]{delete_relational_database_snapshot} \tab Deletes a database snapshot in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_detach_certificate_from_distribution]{detach_certificate_from_distribution} \tab Detaches an SSL/TLS certificate from your Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_detach_disk]{detach_disk} \tab Detaches a stopped block storage disk from a Lightsail instance\cr
#'  \link[paws.compute:lightsail_detach_instances_from_load_balancer]{detach_instances_from_load_balancer} \tab Detaches the specified instances from a Lightsail load balancer\cr
#'  \link[paws.compute:lightsail_detach_static_ip]{detach_static_ip} \tab Detaches a static IP from the Amazon Lightsail instance to which it is attached\cr
#'  \link[paws.compute:lightsail_disable_add_on]{disable_add_on} \tab Disables an add-on for an Amazon Lightsail resource\cr
#'  \link[paws.compute:lightsail_download_default_key_pair]{download_default_key_pair} \tab Downloads the regional Amazon Lightsail default key pair\cr
#'  \link[paws.compute:lightsail_enable_add_on]{enable_add_on} \tab Enables or modifies an add-on for an Amazon Lightsail resource\cr
#'  \link[paws.compute:lightsail_export_snapshot]{export_snapshot} \tab Exports an Amazon Lightsail instance or block storage disk snapshot to Amazon Elastic Compute Cloud (Amazon EC2)\cr
#'  \link[paws.compute:lightsail_get_active_names]{get_active_names} \tab Returns the names of all active (not deleted) resources\cr
#'  \link[paws.compute:lightsail_get_alarms]{get_alarms} \tab Returns information about the configured alarms\cr
#'  \link[paws.compute:lightsail_get_auto_snapshots]{get_auto_snapshots} \tab Returns the available automatic snapshots for an instance or disk\cr
#'  \link[paws.compute:lightsail_get_blueprints]{get_blueprints} \tab Returns the list of available instance images, or blueprints\cr
#'  \link[paws.compute:lightsail_get_bucket_access_keys]{get_bucket_access_keys} \tab Returns the existing access key IDs for the specified Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_get_bucket_bundles]{get_bucket_bundles} \tab Returns the bundles that you can apply to a Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_get_bucket_metric_data]{get_bucket_metric_data} \tab Returns the data points of a specific metric for an Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_get_buckets]{get_buckets} \tab Returns information about one or more Amazon Lightsail buckets\cr
#'  \link[paws.compute:lightsail_get_bundles]{get_bundles} \tab Returns the bundles that you can apply to an Amazon Lightsail instance when you create it\cr
#'  \link[paws.compute:lightsail_get_certificates]{get_certificates} \tab Returns information about one or more Amazon Lightsail SSL/TLS certificates\cr
#'  \link[paws.compute:lightsail_get_cloud_formation_stack_records]{get_cloud_formation_stack_records} \tab Returns the CloudFormation stack record created as a result of the create cloud formation stack operation\cr
#'  \link[paws.compute:lightsail_get_contact_methods]{get_contact_methods} \tab Returns information about the configured contact methods\cr
#'  \link[paws.compute:lightsail_get_container_api_metadata]{get_container_api_metadata} \tab Returns information about Amazon Lightsail containers, such as the current version of the Lightsail Control (lightsailctl) plugin\cr
#'  \link[paws.compute:lightsail_get_container_images]{get_container_images} \tab Returns the container images that are registered to your Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_get_container_log]{get_container_log} \tab Returns the log events of a container of your Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_get_container_service_deployments]{get_container_service_deployments} \tab Returns the deployments for your Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_get_container_service_metric_data]{get_container_service_metric_data} \tab Returns the data points of a specific metric of your Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_get_container_service_powers]{get_container_service_powers} \tab Returns the list of powers that can be specified for your Amazon Lightsail container services\cr
#'  \link[paws.compute:lightsail_get_container_services]{get_container_services} \tab Returns information about one or more of your Amazon Lightsail container services\cr
#'  \link[paws.compute:lightsail_get_cost_estimate]{get_cost_estimate} \tab Retrieves information about the cost estimate for a specified resource\cr
#'  \link[paws.compute:lightsail_get_disk]{get_disk} \tab Returns information about a specific block storage disk\cr
#'  \link[paws.compute:lightsail_get_disks]{get_disks} \tab Returns information about all block storage disks in your AWS account and region\cr
#'  \link[paws.compute:lightsail_get_disk_snapshot]{get_disk_snapshot} \tab Returns information about a specific block storage disk snapshot\cr
#'  \link[paws.compute:lightsail_get_disk_snapshots]{get_disk_snapshots} \tab Returns information about all block storage disk snapshots in your AWS account and region\cr
#'  \link[paws.compute:lightsail_get_distribution_bundles]{get_distribution_bundles} \tab Returns the bundles that can be applied to your Amazon Lightsail content delivery network (CDN) distributions\cr
#'  \link[paws.compute:lightsail_get_distribution_latest_cache_reset]{get_distribution_latest_cache_reset} \tab Returns the timestamp and status of the last cache reset of a specific Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_get_distribution_metric_data]{get_distribution_metric_data} \tab Returns the data points of a specific metric for an Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_get_distributions]{get_distributions} \tab Returns information about one or more of your Amazon Lightsail content delivery network (CDN) distributions\cr
#'  \link[paws.compute:lightsail_get_domain]{get_domain} \tab Returns information about a specific domain recordset\cr
#'  \link[paws.compute:lightsail_get_domains]{get_domains} \tab Returns a list of all domains in the user's account\cr
#'  \link[paws.compute:lightsail_get_export_snapshot_records]{get_export_snapshot_records} \tab Returns all export snapshot records created as a result of the export snapshot operation\cr
#'  \link[paws.compute:lightsail_get_instance]{get_instance} \tab Returns information about a specific Amazon Lightsail instance, which is a virtual private server\cr
#'  \link[paws.compute:lightsail_get_instance_access_details]{get_instance_access_details} \tab Returns temporary SSH keys you can use to connect to a specific virtual private server, or instance\cr
#'  \link[paws.compute:lightsail_get_instance_metric_data]{get_instance_metric_data} \tab Returns the data points for the specified Amazon Lightsail instance metric, given an instance name\cr
#'  \link[paws.compute:lightsail_get_instance_port_states]{get_instance_port_states} \tab Returns the firewall port states for a specific Amazon Lightsail instance, the IP addresses allowed to connect to the instance through the ports, and the protocol\cr
#'  \link[paws.compute:lightsail_get_instances]{get_instances} \tab Returns information about all Amazon Lightsail virtual private servers, or instances\cr
#'  \link[paws.compute:lightsail_get_instance_snapshot]{get_instance_snapshot} \tab Returns information about a specific instance snapshot\cr
#'  \link[paws.compute:lightsail_get_instance_snapshots]{get_instance_snapshots} \tab Returns all instance snapshots for the user's account\cr
#'  \link[paws.compute:lightsail_get_instance_state]{get_instance_state} \tab Returns the state of a specific instance\cr
#'  \link[paws.compute:lightsail_get_key_pair]{get_key_pair} \tab Returns information about a specific key pair\cr
#'  \link[paws.compute:lightsail_get_key_pairs]{get_key_pairs} \tab Returns information about all key pairs in the user's account\cr
#'  \link[paws.compute:lightsail_get_load_balancer]{get_load_balancer} \tab Returns information about the specified Lightsail load balancer\cr
#'  \link[paws.compute:lightsail_get_load_balancer_metric_data]{get_load_balancer_metric_data} \tab Returns information about health metrics for your Lightsail load balancer\cr
#'  \link[paws.compute:lightsail_get_load_balancers]{get_load_balancers} \tab Returns information about all load balancers in an account\cr
#'  \link[paws.compute:lightsail_get_load_balancer_tls_certificates]{get_load_balancer_tls_certificates} \tab Returns information about the TLS certificates that are associated with the specified Lightsail load balancer\cr
#'  \link[paws.compute:lightsail_get_load_balancer_tls_policies]{get_load_balancer_tls_policies} \tab Returns a list of TLS security policies that you can apply to Lightsail load balancers\cr
#'  \link[paws.compute:lightsail_get_operation]{get_operation} \tab Returns information about a specific operation\cr
#'  \link[paws.compute:lightsail_get_operations]{get_operations} \tab Returns information about all operations\cr
#'  \link[paws.compute:lightsail_get_operations_for_resource]{get_operations_for_resource} \tab Gets operations for a specific resource (an instance or a static IP)\cr
#'  \link[paws.compute:lightsail_get_regions]{get_regions} \tab Returns a list of all valid regions for Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database]{get_relational_database} \tab Returns information about a specific database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_blueprints]{get_relational_database_blueprints} \tab Returns a list of available database blueprints in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_bundles]{get_relational_database_bundles} \tab Returns the list of bundles that are available in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_events]{get_relational_database_events} \tab Returns a list of events for a specific database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_log_events]{get_relational_database_log_events} \tab Returns a list of log events for a database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_log_streams]{get_relational_database_log_streams} \tab Returns a list of available log streams for a specific database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_master_user_password]{get_relational_database_master_user_password} \tab Returns the current, previous, or pending versions of the master user password for a Lightsail database\cr
#'  \link[paws.compute:lightsail_get_relational_database_metric_data]{get_relational_database_metric_data} \tab Returns the data points of the specified metric for a database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_parameters]{get_relational_database_parameters} \tab Returns all of the runtime parameters offered by the underlying database software, or engine, for a specific database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_databases]{get_relational_databases} \tab Returns information about all of your databases in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_snapshot]{get_relational_database_snapshot} \tab Returns information about a specific database snapshot in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_relational_database_snapshots]{get_relational_database_snapshots} \tab Returns information about all of your database snapshots in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_get_setup_history]{get_setup_history} \tab Returns detailed information for five of the most recent SetupInstanceHttps requests that were ran on the target instance\cr
#'  \link[paws.compute:lightsail_get_static_ip]{get_static_ip} \tab Returns information about an Amazon Lightsail static IP\cr
#'  \link[paws.compute:lightsail_get_static_ips]{get_static_ips} \tab Returns information about all static IPs in the user's account\cr
#'  \link[paws.compute:lightsail_import_key_pair]{import_key_pair} \tab Imports a public SSH key from a specific key pair\cr
#'  \link[paws.compute:lightsail_is_vpc_peered]{is_vpc_peered} \tab Returns a Boolean value indicating whether your Lightsail VPC is peered\cr
#'  \link[paws.compute:lightsail_open_instance_public_ports]{open_instance_public_ports} \tab Opens ports for a specific Amazon Lightsail instance, and specifies the IP addresses allowed to connect to the instance through the ports, and the protocol\cr
#'  \link[paws.compute:lightsail_peer_vpc]{peer_vpc} \tab Peers the Lightsail VPC with the user's default VPC\cr
#'  \link[paws.compute:lightsail_put_alarm]{put_alarm} \tab Creates or updates an alarm, and associates it with the specified metric\cr
#'  \link[paws.compute:lightsail_put_instance_public_ports]{put_instance_public_ports} \tab Opens ports for a specific Amazon Lightsail instance, and specifies the IP addresses allowed to connect to the instance through the ports, and the protocol\cr
#'  \link[paws.compute:lightsail_reboot_instance]{reboot_instance} \tab Restarts a specific instance\cr
#'  \link[paws.compute:lightsail_reboot_relational_database]{reboot_relational_database} \tab Restarts a specific database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_register_container_image]{register_container_image} \tab Registers a container image to your Amazon Lightsail container service\cr
#'  \link[paws.compute:lightsail_release_static_ip]{release_static_ip} \tab Deletes a specific static IP from your account\cr
#'  \link[paws.compute:lightsail_reset_distribution_cache]{reset_distribution_cache} \tab Deletes currently cached content from your Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_send_contact_method_verification]{send_contact_method_verification} \tab Sends a verification request to an email contact method to ensure it's owned by the requester\cr
#'  \link[paws.compute:lightsail_set_ip_address_type]{set_ip_address_type} \tab Sets the IP address type for an Amazon Lightsail resource\cr
#'  \link[paws.compute:lightsail_set_resource_access_for_bucket]{set_resource_access_for_bucket} \tab Sets the Amazon Lightsail resources that can access the specified Lightsail bucket\cr
#'  \link[paws.compute:lightsail_setup_instance_https]{setup_instance_https} \tab Creates an SSL/TLS certificate that secures traffic for your website\cr
#'  \link[paws.compute:lightsail_start_gui_session]{start_gui_session} \tab Initiates a graphical user interface (GUI) session that’s used to access a virtual computer’s operating system and application\cr
#'  \link[paws.compute:lightsail_start_instance]{start_instance} \tab Starts a specific Amazon Lightsail instance from a stopped state\cr
#'  \link[paws.compute:lightsail_start_relational_database]{start_relational_database} \tab Starts a specific database from a stopped state in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_stop_gui_session]{stop_gui_session} \tab Terminates a web-based Amazon DCV session that’s used to access a virtual computer’s operating system or application\cr
#'  \link[paws.compute:lightsail_stop_instance]{stop_instance} \tab Stops a specific Amazon Lightsail instance that is currently running\cr
#'  \link[paws.compute:lightsail_stop_relational_database]{stop_relational_database} \tab Stops a specific database that is currently running in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_tag_resource]{tag_resource} \tab Adds one or more tags to the specified Amazon Lightsail resource\cr
#'  \link[paws.compute:lightsail_test_alarm]{test_alarm} \tab Tests an alarm by displaying a banner on the Amazon Lightsail console\cr
#'  \link[paws.compute:lightsail_unpeer_vpc]{unpeer_vpc} \tab Unpeers the Lightsail VPC from the user's default VPC\cr
#'  \link[paws.compute:lightsail_untag_resource]{untag_resource} \tab Deletes the specified set of tag keys and their values from the specified Amazon Lightsail resource\cr
#'  \link[paws.compute:lightsail_update_bucket]{update_bucket} \tab Updates an existing Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_update_bucket_bundle]{update_bucket_bundle} \tab Updates the bundle, or storage plan, of an existing Amazon Lightsail bucket\cr
#'  \link[paws.compute:lightsail_update_container_service]{update_container_service} \tab Updates the configuration of your Amazon Lightsail container service, such as its power, scale, and public domain names\cr
#'  \link[paws.compute:lightsail_update_distribution]{update_distribution} \tab Updates an existing Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_update_distribution_bundle]{update_distribution_bundle} \tab Updates the bundle of your Amazon Lightsail content delivery network (CDN) distribution\cr
#'  \link[paws.compute:lightsail_update_domain_entry]{update_domain_entry} \tab Updates a domain recordset after it is created\cr
#'  \link[paws.compute:lightsail_update_instance_metadata_options]{update_instance_metadata_options} \tab Modifies the Amazon Lightsail instance metadata parameters on a running or stopped instance\cr
#'  \link[paws.compute:lightsail_update_load_balancer_attribute]{update_load_balancer_attribute} \tab Updates the specified attribute for a load balancer\cr
#'  \link[paws.compute:lightsail_update_relational_database]{update_relational_database} \tab Allows the update of one or more attributes of a database in Amazon Lightsail\cr
#'  \link[paws.compute:lightsail_update_relational_database_parameters]{update_relational_database_parameters} \tab Allows the update of one or more parameters of a database in Amazon Lightsail
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lightsail
#' @export
lightsail <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::lightsail(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Proton
#'
#' @description
#' This is the Proton Service API Reference. It provides descriptions,
#' syntax and usage examples for each of the
#' [actions](https://docs.aws.amazon.com/proton/latest/APIReference/API_Operations.html)
#' and [data
#' types](https://docs.aws.amazon.com/proton/latest/APIReference/API_Types.html)
#' for the Proton service.
#' 
#' The documentation for each action shows the Query API request parameters
#' and the XML response.
#' 
#' Alternatively, you can use the Amazon Web Services CLI to access an API.
#' For more information, see the [Amazon Web Services Command Line
#' Interface User
#' Guide](https://docs.aws.amazon.com/cli/latest/userguide/cli-chap-welcome.html).
#' 
#' The Proton service is a two-pronged automation framework. Administrators
#' create service templates to provide standardized infrastructure and
#' deployment tooling for serverless and container based applications.
#' Developers, in turn, select from the available service templates to
#' automate their application or service deployments.
#' 
#' Because administrators define the infrastructure and tooling that Proton
#' deploys and manages, they need permissions to use all of the listed API
#' operations.
#' 
#' When developers select a specific infrastructure and tooling set, Proton
#' deploys their applications. To monitor their applications that are
#' running on Proton, developers need permissions to the service *create*,
#' *list*, *update* and *delete* API operations and the service instance
#' *list* and *update* API operations.
#' 
#' To learn more about Proton, see the [Proton User
#' Guide](https://docs.aws.amazon.com/proton/latest/userguide/Welcome.html).
#' 
#' **Ensuring Idempotency**
#' 
#' When you make a mutating API request, the request typically returns a
#' result before the asynchronous workflows of the operation are complete.
#' Operations might also time out or encounter other server issues before
#' they're complete, even if the request already returned a result. This
#' might make it difficult to determine whether the request succeeded.
#' Moreover, you might need to retry the request multiple times to ensure
#' that the operation completes successfully. However, if the original
#' request and the subsequent retries are successful, the operation occurs
#' multiple times. This means that you might create more resources than you
#' intended.
#' 
#' *Idempotency* ensures that an API request action completes no more than
#' one time. With an idempotent request, if the original request action
#' completes successfully, any subsequent retries complete successfully
#' without performing any further actions. However, the result might
#' contain updated information, such as the current creation status.
#' 
#' The following lists of APIs are grouped according to methods that ensure
#' idempotency.
#' 
#' **Idempotent create APIs with a client token**
#' 
#' The API actions in this list support idempotency with the use of a
#' *client token*. The corresponding Amazon Web Services CLI commands also
#' support idempotency using a client token. A client token is a unique,
#' case-sensitive string of up to 64 ASCII characters. To make an
#' idempotent API request using one of these actions, specify a client
#' token in the request. We recommend that you *don't* reuse the same
#' client token for other API requests. If you don’t provide a client token
#' for these APIs, a default client token is automatically provided by
#' SDKs.
#' 
#' Given a request action that has succeeded:
#' 
#' If you retry the request using the same client token and the same
#' parameters, the retry succeeds without performing any further actions
#' other than returning the original resource detail data in the response.
#' 
#' If you retry the request using the same client token, but one or more of
#' the parameters are different, the retry throws a `ValidationException`
#' with an `IdempotentParameterMismatch` error.
#' 
#' Client tokens expire eight hours after a request is made. If you retry
#' the request with the expired token, a new resource is created.
#' 
#' If the original resource is deleted and you retry the request, a new
#' resource is created.
#' 
#' Idempotent create APIs with a client token:
#' 
#' -   CreateEnvironmentTemplateVersion
#' 
#' -   CreateServiceTemplateVersion
#' 
#' -   CreateEnvironmentAccountConnection
#' 
#' **Idempotent create APIs**
#' 
#' Given a request action that has succeeded:
#' 
#' If you retry the request with an API from this group, and the original
#' resource *hasn't* been modified, the retry succeeds without performing
#' any further actions other than returning the original resource detail
#' data in the response.
#' 
#' If the original resource has been modified, the retry throws a
#' `ConflictException`.
#' 
#' If you retry with different input parameters, the retry throws a
#' `ValidationException` with an `IdempotentParameterMismatch` error.
#' 
#' Idempotent create APIs:
#' 
#' -   CreateEnvironmentTemplate
#' 
#' -   CreateServiceTemplate
#' 
#' -   CreateEnvironment
#' 
#' -   CreateService
#' 
#' **Idempotent delete APIs**
#' 
#' Given a request action that has succeeded:
#' 
#' When you retry the request with an API from this group and the resource
#' was deleted, its metadata is returned in the response.
#' 
#' If you retry and the resource doesn't exist, the response is empty.
#' 
#' In both cases, the retry succeeds.
#' 
#' Idempotent delete APIs:
#' 
#' -   DeleteEnvironmentTemplate
#' 
#' -   DeleteEnvironmentTemplateVersion
#' 
#' -   DeleteServiceTemplate
#' 
#' -   DeleteServiceTemplateVersion
#' 
#' -   DeleteEnvironmentAccountConnection
#' 
#' **Asynchronous idempotent delete APIs**
#' 
#' Given a request action that has succeeded:
#' 
#' If you retry the request with an API from this group, if the original
#' request delete operation status is `DELETE_IN_PROGRESS`, the retry
#' returns the resource detail data in the response without performing any
#' further actions.
#' 
#' If the original request delete operation is complete, a retry returns an
#' empty response.
#' 
#' Asynchronous idempotent delete APIs:
#' 
#' -   DeleteEnvironment
#' 
#' -   DeleteService
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- proton(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- proton()
#' svc$accept_environment_account_connection(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:proton_accept_environment_account_connection]{accept_environment_account_connection} \tab In a management account, an environment account connection request is accepted\cr
#'  \link[paws.compute:proton_cancel_component_deployment]{cancel_component_deployment} \tab Attempts to cancel a component deployment (for a component that is in the IN_PROGRESS deployment status)\cr
#'  \link[paws.compute:proton_cancel_environment_deployment]{cancel_environment_deployment} \tab Attempts to cancel an environment deployment on an UpdateEnvironment action, if the deployment is IN_PROGRESS\cr
#'  \link[paws.compute:proton_cancel_service_instance_deployment]{cancel_service_instance_deployment} \tab Attempts to cancel a service instance deployment on an UpdateServiceInstance action, if the deployment is IN_PROGRESS\cr
#'  \link[paws.compute:proton_cancel_service_pipeline_deployment]{cancel_service_pipeline_deployment} \tab Attempts to cancel a service pipeline deployment on an UpdateServicePipeline action, if the deployment is IN_PROGRESS\cr
#'  \link[paws.compute:proton_create_component]{create_component} \tab Create an Proton component\cr
#'  \link[paws.compute:proton_create_environment]{create_environment} \tab Deploy a new environment\cr
#'  \link[paws.compute:proton_create_environment_account_connection]{create_environment_account_connection} \tab Create an environment account connection in an environment account so that environment infrastructure resources can be provisioned in the environment account from a management account\cr
#'  \link[paws.compute:proton_create_environment_template]{create_environment_template} \tab Create an environment template for Proton\cr
#'  \link[paws.compute:proton_create_environment_template_version]{create_environment_template_version} \tab Create a new major or minor version of an environment template\cr
#'  \link[paws.compute:proton_create_repository]{create_repository} \tab Create and register a link to a repository\cr
#'  \link[paws.compute:proton_create_service]{create_service} \tab Create an Proton service\cr
#'  \link[paws.compute:proton_create_service_instance]{create_service_instance} \tab Create a service instance\cr
#'  \link[paws.compute:proton_create_service_sync_config]{create_service_sync_config} \tab Create the Proton Ops configuration file\cr
#'  \link[paws.compute:proton_create_service_template]{create_service_template} \tab Create a service template\cr
#'  \link[paws.compute:proton_create_service_template_version]{create_service_template_version} \tab Create a new major or minor version of a service template\cr
#'  \link[paws.compute:proton_create_template_sync_config]{create_template_sync_config} \tab Set up a template to create new template versions automatically by tracking a linked repository\cr
#'  \link[paws.compute:proton_delete_component]{delete_component} \tab Delete an Proton component resource\cr
#'  \link[paws.compute:proton_delete_deployment]{delete_deployment} \tab Delete the deployment\cr
#'  \link[paws.compute:proton_delete_environment]{delete_environment} \tab Delete an environment\cr
#'  \link[paws.compute:proton_delete_environment_account_connection]{delete_environment_account_connection} \tab In an environment account, delete an environment account connection\cr
#'  \link[paws.compute:proton_delete_environment_template]{delete_environment_template} \tab If no other major or minor versions of an environment template exist, delete the environment template\cr
#'  \link[paws.compute:proton_delete_environment_template_version]{delete_environment_template_version} \tab If no other minor versions of an environment template exist, delete a major version of the environment template if it's not the Recommended version\cr
#'  \link[paws.compute:proton_delete_repository]{delete_repository} \tab De-register and unlink your repository\cr
#'  \link[paws.compute:proton_delete_service]{delete_service} \tab Delete a service, with its instances and pipeline\cr
#'  \link[paws.compute:proton_delete_service_sync_config]{delete_service_sync_config} \tab Delete the Proton Ops file\cr
#'  \link[paws.compute:proton_delete_service_template]{delete_service_template} \tab If no other major or minor versions of the service template exist, delete the service template\cr
#'  \link[paws.compute:proton_delete_service_template_version]{delete_service_template_version} \tab If no other minor versions of a service template exist, delete a major version of the service template if it's not the Recommended version\cr
#'  \link[paws.compute:proton_delete_template_sync_config]{delete_template_sync_config} \tab Delete a template sync configuration\cr
#'  \link[paws.compute:proton_get_account_settings]{get_account_settings} \tab Get detail data for Proton account-wide settings\cr
#'  \link[paws.compute:proton_get_component]{get_component} \tab Get detailed data for a component\cr
#'  \link[paws.compute:proton_get_deployment]{get_deployment} \tab Get detailed data for a deployment\cr
#'  \link[paws.compute:proton_get_environment]{get_environment} \tab Get detailed data for an environment\cr
#'  \link[paws.compute:proton_get_environment_account_connection]{get_environment_account_connection} \tab In an environment account, get the detailed data for an environment account connection\cr
#'  \link[paws.compute:proton_get_environment_template]{get_environment_template} \tab Get detailed data for an environment template\cr
#'  \link[paws.compute:proton_get_environment_template_version]{get_environment_template_version} \tab Get detailed data for a major or minor version of an environment template\cr
#'  \link[paws.compute:proton_get_repository]{get_repository} \tab Get detail data for a linked repository\cr
#'  \link[paws.compute:proton_get_repository_sync_status]{get_repository_sync_status} \tab Get the sync status of a repository used for Proton template sync\cr
#'  \link[paws.compute:proton_get_resources_summary]{get_resources_summary} \tab Get counts of Proton resources\cr
#'  \link[paws.compute:proton_get_service]{get_service} \tab Get detailed data for a service\cr
#'  \link[paws.compute:proton_get_service_instance]{get_service_instance} \tab Get detailed data for a service instance\cr
#'  \link[paws.compute:proton_get_service_instance_sync_status]{get_service_instance_sync_status} \tab Get the status of the synced service instance\cr
#'  \link[paws.compute:proton_get_service_sync_blocker_summary]{get_service_sync_blocker_summary} \tab Get detailed data for the service sync blocker summary\cr
#'  \link[paws.compute:proton_get_service_sync_config]{get_service_sync_config} \tab Get detailed information for the service sync configuration\cr
#'  \link[paws.compute:proton_get_service_template]{get_service_template} \tab Get detailed data for a service template\cr
#'  \link[paws.compute:proton_get_service_template_version]{get_service_template_version} \tab Get detailed data for a major or minor version of a service template\cr
#'  \link[paws.compute:proton_get_template_sync_config]{get_template_sync_config} \tab Get detail data for a template sync configuration\cr
#'  \link[paws.compute:proton_get_template_sync_status]{get_template_sync_status} \tab Get the status of a template sync\cr
#'  \link[paws.compute:proton_list_component_outputs]{list_component_outputs} \tab Get a list of component Infrastructure as Code (IaC) outputs\cr
#'  \link[paws.compute:proton_list_component_provisioned_resources]{list_component_provisioned_resources} \tab List provisioned resources for a component with details\cr
#'  \link[paws.compute:proton_list_components]{list_components} \tab List components with summary data\cr
#'  \link[paws.compute:proton_list_deployments]{list_deployments} \tab List deployments\cr
#'  \link[paws.compute:proton_list_environment_account_connections]{list_environment_account_connections} \tab View a list of environment account connections\cr
#'  \link[paws.compute:proton_list_environment_outputs]{list_environment_outputs} \tab List the infrastructure as code outputs for your environment\cr
#'  \link[paws.compute:proton_list_environment_provisioned_resources]{list_environment_provisioned_resources} \tab List the provisioned resources for your environment\cr
#'  \link[paws.compute:proton_list_environments]{list_environments} \tab List environments with detail data summaries\cr
#'  \link[paws.compute:proton_list_environment_templates]{list_environment_templates} \tab List environment templates\cr
#'  \link[paws.compute:proton_list_environment_template_versions]{list_environment_template_versions} \tab List major or minor versions of an environment template with detail data\cr
#'  \link[paws.compute:proton_list_repositories]{list_repositories} \tab List linked repositories with detail data\cr
#'  \link[paws.compute:proton_list_repository_sync_definitions]{list_repository_sync_definitions} \tab List repository sync definitions with detail data\cr
#'  \link[paws.compute:proton_list_service_instance_outputs]{list_service_instance_outputs} \tab Get a list service of instance Infrastructure as Code (IaC) outputs\cr
#'  \link[paws.compute:proton_list_service_instance_provisioned_resources]{list_service_instance_provisioned_resources} \tab List provisioned resources for a service instance with details\cr
#'  \link[paws.compute:proton_list_service_instances]{list_service_instances} \tab List service instances with summary data\cr
#'  \link[paws.compute:proton_list_service_pipeline_outputs]{list_service_pipeline_outputs} \tab Get a list of service pipeline Infrastructure as Code (IaC) outputs\cr
#'  \link[paws.compute:proton_list_service_pipeline_provisioned_resources]{list_service_pipeline_provisioned_resources} \tab List provisioned resources for a service and pipeline with details\cr
#'  \link[paws.compute:proton_list_services]{list_services} \tab List services with summaries of detail data\cr
#'  \link[paws.compute:proton_list_service_templates]{list_service_templates} \tab List service templates with detail data\cr
#'  \link[paws.compute:proton_list_service_template_versions]{list_service_template_versions} \tab List major or minor versions of a service template with detail data\cr
#'  \link[paws.compute:proton_list_tags_for_resource]{list_tags_for_resource} \tab List tags for a resource\cr
#'  \link[paws.compute:proton_notify_resource_deployment_status_change]{notify_resource_deployment_status_change} \tab Notify Proton of status changes to a provisioned resource when you use self-managed provisioning\cr
#'  \link[paws.compute:proton_reject_environment_account_connection]{reject_environment_account_connection} \tab In a management account, reject an environment account connection from another environment account\cr
#'  \link[paws.compute:proton_tag_resource]{tag_resource} \tab Tag a resource\cr
#'  \link[paws.compute:proton_untag_resource]{untag_resource} \tab Remove a customer tag from a resource\cr
#'  \link[paws.compute:proton_update_account_settings]{update_account_settings} \tab Update Proton settings that are used for multiple services in the Amazon Web Services account\cr
#'  \link[paws.compute:proton_update_component]{update_component} \tab Update a component\cr
#'  \link[paws.compute:proton_update_environment]{update_environment} \tab Update an environment\cr
#'  \link[paws.compute:proton_update_environment_account_connection]{update_environment_account_connection} \tab In an environment account, update an environment account connection to use a new IAM role\cr
#'  \link[paws.compute:proton_update_environment_template]{update_environment_template} \tab Update an environment template\cr
#'  \link[paws.compute:proton_update_environment_template_version]{update_environment_template_version} \tab Update a major or minor version of an environment template\cr
#'  \link[paws.compute:proton_update_service]{update_service} \tab Edit a service description or use a spec to add and delete service instances\cr
#'  \link[paws.compute:proton_update_service_instance]{update_service_instance} \tab Update a service instance\cr
#'  \link[paws.compute:proton_update_service_pipeline]{update_service_pipeline} \tab Update the service pipeline\cr
#'  \link[paws.compute:proton_update_service_sync_blocker]{update_service_sync_blocker} \tab Update the service sync blocker by resolving it\cr
#'  \link[paws.compute:proton_update_service_sync_config]{update_service_sync_config} \tab Update the Proton Ops config file\cr
#'  \link[paws.compute:proton_update_service_template]{update_service_template} \tab Update a service template\cr
#'  \link[paws.compute:proton_update_service_template_version]{update_service_template_version} \tab Update a major or minor version of a service template\cr
#'  \link[paws.compute:proton_update_template_sync_config]{update_template_sync_config} \tab Update template sync configuration parameters, except for the templateName and templateType
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname proton
#' @export
proton <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::proton(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWSServerlessApplicationRepository
#'
#' @description
#' The AWS Serverless Application Repository makes it easy for developers
#' and enterprises to quickly find and deploy serverless applications in
#' the AWS Cloud. For more information about serverless applications, see
#' Serverless Computing and Applications on the AWS website.
#' 
#' The AWS Serverless Application Repository is deeply integrated with the
#' AWS Lambda console, so that developers of all levels can get started
#' with serverless computing without needing to learn anything new. You can
#' use category keywords to browse for applications such as web and mobile
#' backends, data processing applications, or chatbots. You can also search
#' for applications by name, publisher, or event source. To use an
#' application, you simply choose it, configure any required fields, and
#' deploy it with a few clicks.
#' 
#' You can also easily publish applications, sharing them publicly with the
#' community at large, or privately within your team or across your
#' organization. To publish a serverless application (or app), you can use
#' the AWS Management Console, AWS Command Line Interface (AWS CLI), or AWS
#' SDKs to upload the code. Along with the code, you upload a simple
#' manifest file, also known as the AWS Serverless Application Model (AWS
#' SAM) template. For more information about AWS SAM, see AWS Serverless
#' Application Model (AWS SAM) on the AWS Labs GitHub repository.
#' 
#' The AWS Serverless Application Repository Developer Guide contains more
#' information about the two developer experiences available:
#' 
#' -   Consuming Applications – Browse for applications and view
#'     information about them, including source code and readme files. Also
#'     install, configure, and deploy applications of your choosing.
#' 
#'     Publishing Applications – Configure and upload applications to make
#'     them available to other developers, and publish new versions of
#'     applications.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- serverlessapplicationrepository(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- serverlessapplicationrepository()
#' svc$create_application(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.compute:serverlessapplicationrepository_create_application]{create_application} \tab Creates an application, optionally including an AWS SAM file to create the first application version in the same call\cr
#'  \link[paws.compute:serverlessapplicationrepository_create_application_version]{create_application_version} \tab Creates an application version\cr
#'  \link[paws.compute:serverlessapplicationrepository_create_cloud_formation_change_set]{create_cloud_formation_change_set} \tab Creates an AWS CloudFormation change set for the given application\cr
#'  \link[paws.compute:serverlessapplicationrepository_create_cloud_formation_template]{create_cloud_formation_template} \tab Creates an AWS CloudFormation template\cr
#'  \link[paws.compute:serverlessapplicationrepository_delete_application]{delete_application} \tab Deletes the specified application\cr
#'  \link[paws.compute:serverlessapplicationrepository_get_application]{get_application} \tab Gets the specified application\cr
#'  \link[paws.compute:serverlessapplicationrepository_get_application_policy]{get_application_policy} \tab Retrieves the policy for the application\cr
#'  \link[paws.compute:serverlessapplicationrepository_get_cloud_formation_template]{get_cloud_formation_template} \tab Gets the specified AWS CloudFormation template\cr
#'  \link[paws.compute:serverlessapplicationrepository_list_application_dependencies]{list_application_dependencies} \tab Retrieves the list of applications nested in the containing application\cr
#'  \link[paws.compute:serverlessapplicationrepository_list_applications]{list_applications} \tab Lists applications owned by the requester\cr
#'  \link[paws.compute:serverlessapplicationrepository_list_application_versions]{list_application_versions} \tab Lists versions for the specified application\cr
#'  \link[paws.compute:serverlessapplicationrepository_put_application_policy]{put_application_policy} \tab Sets the permission policy for an application\cr
#'  \link[paws.compute:serverlessapplicationrepository_unshare_application]{unshare_application} \tab Unshares an application from an AWS Organization\cr
#'  \link[paws.compute:serverlessapplicationrepository_update_application]{update_application} \tab Updates the specified application
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname serverlessapplicationrepository
#' @export
serverlessapplicationrepository <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.compute::serverlessapplicationrepository(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Backup
#'
#' @description
#' Backup
#' 
#' Backup is a unified backup service designed to protect Amazon Web
#' Services services and their associated data. Backup simplifies the
#' creation, migration, restoration, and deletion of backups, while also
#' providing reporting and auditing.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- backup(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- backup()
#' svc$cancel_legal_hold(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:backup_cancel_legal_hold]{cancel_legal_hold} \tab Removes the specified legal hold on a recovery point\cr
#'  \link[paws.storage:backup_create_backup_plan]{create_backup_plan} \tab Creates a backup plan using a backup plan name and backup rules\cr
#'  \link[paws.storage:backup_create_backup_selection]{create_backup_selection} \tab Creates a JSON document that specifies a set of resources to assign to a backup plan\cr
#'  \link[paws.storage:backup_create_backup_vault]{create_backup_vault} \tab Creates a logical container where backups are stored\cr
#'  \link[paws.storage:backup_create_framework]{create_framework} \tab Creates a framework with one or more controls\cr
#'  \link[paws.storage:backup_create_legal_hold]{create_legal_hold} \tab Creates a legal hold on a recovery point (backup)\cr
#'  \link[paws.storage:backup_create_logically_air_gapped_backup_vault]{create_logically_air_gapped_backup_vault} \tab Creates a logical container to where backups may be copied\cr
#'  \link[paws.storage:backup_create_report_plan]{create_report_plan} \tab Creates a report plan\cr
#'  \link[paws.storage:backup_create_restore_testing_plan]{create_restore_testing_plan} \tab Creates a restore testing plan\cr
#'  \link[paws.storage:backup_create_restore_testing_selection]{create_restore_testing_selection} \tab This request can be sent after CreateRestoreTestingPlan request returns successfully\cr
#'  \link[paws.storage:backup_delete_backup_plan]{delete_backup_plan} \tab Deletes a backup plan\cr
#'  \link[paws.storage:backup_delete_backup_selection]{delete_backup_selection} \tab Deletes the resource selection associated with a backup plan that is specified by the SelectionId\cr
#'  \link[paws.storage:backup_delete_backup_vault]{delete_backup_vault} \tab Deletes the backup vault identified by its name\cr
#'  \link[paws.storage:backup_delete_backup_vault_access_policy]{delete_backup_vault_access_policy} \tab Deletes the policy document that manages permissions on a backup vault\cr
#'  \link[paws.storage:backup_delete_backup_vault_lock_configuration]{delete_backup_vault_lock_configuration} \tab Deletes Backup Vault Lock from a backup vault specified by a backup vault name\cr
#'  \link[paws.storage:backup_delete_backup_vault_notifications]{delete_backup_vault_notifications} \tab Deletes event notifications for the specified backup vault\cr
#'  \link[paws.storage:backup_delete_framework]{delete_framework} \tab Deletes the framework specified by a framework name\cr
#'  \link[paws.storage:backup_delete_recovery_point]{delete_recovery_point} \tab Deletes the recovery point specified by a recovery point ID\cr
#'  \link[paws.storage:backup_delete_report_plan]{delete_report_plan} \tab Deletes the report plan specified by a report plan name\cr
#'  \link[paws.storage:backup_delete_restore_testing_plan]{delete_restore_testing_plan} \tab This request deletes the specified restore testing plan\cr
#'  \link[paws.storage:backup_delete_restore_testing_selection]{delete_restore_testing_selection} \tab Input the Restore Testing Plan name and Restore Testing Selection name\cr
#'  \link[paws.storage:backup_describe_backup_job]{describe_backup_job} \tab Returns backup job details for the specified BackupJobId\cr
#'  \link[paws.storage:backup_describe_backup_vault]{describe_backup_vault} \tab Returns metadata about a backup vault specified by its name\cr
#'  \link[paws.storage:backup_describe_copy_job]{describe_copy_job} \tab Returns metadata associated with creating a copy of a resource\cr
#'  \link[paws.storage:backup_describe_framework]{describe_framework} \tab Returns the framework details for the specified FrameworkName\cr
#'  \link[paws.storage:backup_describe_global_settings]{describe_global_settings} \tab Describes whether the Amazon Web Services account is opted in to cross-account backup\cr
#'  \link[paws.storage:backup_describe_protected_resource]{describe_protected_resource} \tab Returns information about a saved resource, including the last time it was backed up, its Amazon Resource Name (ARN), and the Amazon Web Services service type of the saved resource\cr
#'  \link[paws.storage:backup_describe_recovery_point]{describe_recovery_point} \tab Returns metadata associated with a recovery point, including ID, status, encryption, and lifecycle\cr
#'  \link[paws.storage:backup_describe_region_settings]{describe_region_settings} \tab Returns the current service opt-in settings for the Region\cr
#'  \link[paws.storage:backup_describe_report_job]{describe_report_job} \tab Returns the details associated with creating a report as specified by its ReportJobId\cr
#'  \link[paws.storage:backup_describe_report_plan]{describe_report_plan} \tab Returns a list of all report plans for an Amazon Web Services account and Amazon Web Services Region\cr
#'  \link[paws.storage:backup_describe_restore_job]{describe_restore_job} \tab Returns metadata associated with a restore job that is specified by a job ID\cr
#'  \link[paws.storage:backup_disassociate_recovery_point]{disassociate_recovery_point} \tab Deletes the specified continuous backup recovery point from Backup and releases control of that continuous backup to the source service, such as Amazon RDS\cr
#'  \link[paws.storage:backup_disassociate_recovery_point_from_parent]{disassociate_recovery_point_from_parent} \tab This action to a specific child (nested) recovery point removes the relationship between the specified recovery point and its parent (composite) recovery point\cr
#'  \link[paws.storage:backup_export_backup_plan_template]{export_backup_plan_template} \tab Returns the backup plan that is specified by the plan ID as a backup template\cr
#'  \link[paws.storage:backup_get_backup_plan]{get_backup_plan} \tab Returns BackupPlan details for the specified BackupPlanId\cr
#'  \link[paws.storage:backup_get_backup_plan_from_json]{get_backup_plan_from_json} \tab Returns a valid JSON document specifying a backup plan or an error\cr
#'  \link[paws.storage:backup_get_backup_plan_from_template]{get_backup_plan_from_template} \tab Returns the template specified by its templateId as a backup plan\cr
#'  \link[paws.storage:backup_get_backup_selection]{get_backup_selection} \tab Returns selection metadata and a document in JSON format that specifies a list of resources that are associated with a backup plan\cr
#'  \link[paws.storage:backup_get_backup_vault_access_policy]{get_backup_vault_access_policy} \tab Returns the access policy document that is associated with the named backup vault\cr
#'  \link[paws.storage:backup_get_backup_vault_notifications]{get_backup_vault_notifications} \tab Returns event notifications for the specified backup vault\cr
#'  \link[paws.storage:backup_get_legal_hold]{get_legal_hold} \tab This action returns details for a specified legal hold\cr
#'  \link[paws.storage:backup_get_recovery_point_index_details]{get_recovery_point_index_details} \tab This operation returns the metadata and details specific to the backup index associated with the specified recovery point\cr
#'  \link[paws.storage:backup_get_recovery_point_restore_metadata]{get_recovery_point_restore_metadata} \tab Returns a set of metadata key-value pairs that were used to create the backup\cr
#'  \link[paws.storage:backup_get_restore_job_metadata]{get_restore_job_metadata} \tab This request returns the metadata for the specified restore job\cr
#'  \link[paws.storage:backup_get_restore_testing_inferred_metadata]{get_restore_testing_inferred_metadata} \tab This request returns the minimal required set of metadata needed to start a restore job with secure default settings\cr
#'  \link[paws.storage:backup_get_restore_testing_plan]{get_restore_testing_plan} \tab Returns RestoreTestingPlan details for the specified RestoreTestingPlanName\cr
#'  \link[paws.storage:backup_get_restore_testing_selection]{get_restore_testing_selection} \tab Returns RestoreTestingSelection, which displays resources and elements of the restore testing plan\cr
#'  \link[paws.storage:backup_get_supported_resource_types]{get_supported_resource_types} \tab Returns the Amazon Web Services resource types supported by Backup\cr
#'  \link[paws.storage:backup_list_backup_jobs]{list_backup_jobs} \tab Returns a list of existing backup jobs for an authenticated account for the last 30 days\cr
#'  \link[paws.storage:backup_list_backup_job_summaries]{list_backup_job_summaries} \tab This is a request for a summary of backup jobs created or running within the most recent 30 days\cr
#'  \link[paws.storage:backup_list_backup_plans]{list_backup_plans} \tab Lists the active backup plans for the account\cr
#'  \link[paws.storage:backup_list_backup_plan_templates]{list_backup_plan_templates} \tab Lists the backup plan templates\cr
#'  \link[paws.storage:backup_list_backup_plan_versions]{list_backup_plan_versions} \tab Returns version metadata of your backup plans, including Amazon Resource Names (ARNs), backup plan IDs, creation and deletion dates, plan names, and version IDs\cr
#'  \link[paws.storage:backup_list_backup_selections]{list_backup_selections} \tab Returns an array containing metadata of the resources associated with the target backup plan\cr
#'  \link[paws.storage:backup_list_backup_vaults]{list_backup_vaults} \tab Returns a list of recovery point storage containers along with information about them\cr
#'  \link[paws.storage:backup_list_copy_jobs]{list_copy_jobs} \tab Returns metadata about your copy jobs\cr
#'  \link[paws.storage:backup_list_copy_job_summaries]{list_copy_job_summaries} \tab This request obtains a list of copy jobs created or running within the the most recent 30 days\cr
#'  \link[paws.storage:backup_list_frameworks]{list_frameworks} \tab Returns a list of all frameworks for an Amazon Web Services account and Amazon Web Services Region\cr
#'  \link[paws.storage:backup_list_indexed_recovery_points]{list_indexed_recovery_points} \tab This operation returns a list of recovery points that have an associated index, belonging to the specified account\cr
#'  \link[paws.storage:backup_list_legal_holds]{list_legal_holds} \tab This action returns metadata about active and previous legal holds\cr
#'  \link[paws.storage:backup_list_protected_resources]{list_protected_resources} \tab Returns an array of resources successfully backed up by Backup, including the time the resource was saved, an Amazon Resource Name (ARN) of the resource, and a resource type\cr
#'  \link[paws.storage:backup_list_protected_resources_by_backup_vault]{list_protected_resources_by_backup_vault} \tab This request lists the protected resources corresponding to each backup vault\cr
#'  \link[paws.storage:backup_list_recovery_points_by_backup_vault]{list_recovery_points_by_backup_vault} \tab Returns detailed information about the recovery points stored in a backup vault\cr
#'  \link[paws.storage:backup_list_recovery_points_by_legal_hold]{list_recovery_points_by_legal_hold} \tab This action returns recovery point ARNs (Amazon Resource Names) of the specified legal hold\cr
#'  \link[paws.storage:backup_list_recovery_points_by_resource]{list_recovery_points_by_resource} \tab The information about the recovery points of the type specified by a resource Amazon Resource Name (ARN)\cr
#'  \link[paws.storage:backup_list_report_jobs]{list_report_jobs} \tab Returns details about your report jobs\cr
#'  \link[paws.storage:backup_list_report_plans]{list_report_plans} \tab Returns a list of your report plans\cr
#'  \link[paws.storage:backup_list_restore_jobs]{list_restore_jobs} \tab Returns a list of jobs that Backup initiated to restore a saved resource, including details about the recovery process\cr
#'  \link[paws.storage:backup_list_restore_jobs_by_protected_resource]{list_restore_jobs_by_protected_resource} \tab This returns restore jobs that contain the specified protected resource\cr
#'  \link[paws.storage:backup_list_restore_job_summaries]{list_restore_job_summaries} \tab This request obtains a summary of restore jobs created or running within the the most recent 30 days\cr
#'  \link[paws.storage:backup_list_restore_testing_plans]{list_restore_testing_plans} \tab Returns a list of restore testing plans\cr
#'  \link[paws.storage:backup_list_restore_testing_selections]{list_restore_testing_selections} \tab Returns a list of restore testing selections\cr
#'  \link[paws.storage:backup_list_tags]{list_tags} \tab Returns the tags assigned to the resource, such as a target recovery point, backup plan, or backup vault\cr
#'  \link[paws.storage:backup_put_backup_vault_access_policy]{put_backup_vault_access_policy} \tab Sets a resource-based policy that is used to manage access permissions on the target backup vault\cr
#'  \link[paws.storage:backup_put_backup_vault_lock_configuration]{put_backup_vault_lock_configuration} \tab Applies Backup Vault Lock to a backup vault, preventing attempts to delete any recovery point stored in or created in a backup vault\cr
#'  \link[paws.storage:backup_put_backup_vault_notifications]{put_backup_vault_notifications} \tab Turns on notifications on a backup vault for the specified topic and events\cr
#'  \link[paws.storage:backup_put_restore_validation_result]{put_restore_validation_result} \tab This request allows you to send your independent self-run restore test validation results\cr
#'  \link[paws.storage:backup_start_backup_job]{start_backup_job} \tab Starts an on-demand backup job for the specified resource\cr
#'  \link[paws.storage:backup_start_copy_job]{start_copy_job} \tab Starts a job to create a one-time copy of the specified resource\cr
#'  \link[paws.storage:backup_start_report_job]{start_report_job} \tab Starts an on-demand report job for the specified report plan\cr
#'  \link[paws.storage:backup_start_restore_job]{start_restore_job} \tab Recovers the saved resource identified by an Amazon Resource Name (ARN)\cr
#'  \link[paws.storage:backup_stop_backup_job]{stop_backup_job} \tab Attempts to cancel a job to create a one-time backup of a resource\cr
#'  \link[paws.storage:backup_tag_resource]{tag_resource} \tab Assigns a set of key-value pairs to a recovery point, backup plan, or backup vault identified by an Amazon Resource Name (ARN)\cr
#'  \link[paws.storage:backup_untag_resource]{untag_resource} \tab Removes a set of key-value pairs from a recovery point, backup plan, or backup vault identified by an Amazon Resource Name (ARN)\cr
#'  \link[paws.storage:backup_update_backup_plan]{update_backup_plan} \tab Updates the specified backup plan\cr
#'  \link[paws.storage:backup_update_framework]{update_framework} \tab Updates the specified framework\cr
#'  \link[paws.storage:backup_update_global_settings]{update_global_settings} \tab Updates whether the Amazon Web Services account is opted in to cross-account backup\cr
#'  \link[paws.storage:backup_update_recovery_point_index_settings]{update_recovery_point_index_settings} \tab This operation updates the settings of a recovery point index\cr
#'  \link[paws.storage:backup_update_recovery_point_lifecycle]{update_recovery_point_lifecycle} \tab Sets the transition lifecycle of a recovery point\cr
#'  \link[paws.storage:backup_update_region_settings]{update_region_settings} \tab Updates the current service opt-in settings for the Region\cr
#'  \link[paws.storage:backup_update_report_plan]{update_report_plan} \tab Updates the specified report plan\cr
#'  \link[paws.storage:backup_update_restore_testing_plan]{update_restore_testing_plan} \tab This request will send changes to your specified restore testing plan\cr
#'  \link[paws.storage:backup_update_restore_testing_selection]{update_restore_testing_selection} \tab Updates the specified restore testing selection
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname backup
#' @export
backup <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::backup(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Data Lifecycle Manager
#'
#' @description
#' With Amazon Data Lifecycle Manager, you can manage the lifecycle of your
#' Amazon Web Services resources. You create lifecycle policies, which are
#' used to automate operations on the specified resources.
#' 
#' Amazon Data Lifecycle Manager supports Amazon EBS volumes and snapshots.
#' For information about using Amazon Data Lifecycle Manager with Amazon
#' EBS, see [Amazon Data Lifecycle
#' Manager](https://docs.aws.amazon.com/ebs/latest/userguide/snapshot-lifecycle.html)
#' in the *Amazon EC2 User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- dlm(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- dlm()
#' svc$create_lifecycle_policy(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:dlm_create_lifecycle_policy]{create_lifecycle_policy} \tab Creates an Amazon Data Lifecycle Manager lifecycle policy\cr
#'  \link[paws.storage:dlm_delete_lifecycle_policy]{delete_lifecycle_policy} \tab Deletes the specified lifecycle policy and halts the automated operations that the policy specified\cr
#'  \link[paws.storage:dlm_get_lifecycle_policies]{get_lifecycle_policies} \tab Gets summary information about all or the specified data lifecycle policies\cr
#'  \link[paws.storage:dlm_get_lifecycle_policy]{get_lifecycle_policy} \tab Gets detailed information about the specified lifecycle policy\cr
#'  \link[paws.storage:dlm_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for the specified resource\cr
#'  \link[paws.storage:dlm_tag_resource]{tag_resource} \tab Adds the specified tags to the specified resource\cr
#'  \link[paws.storage:dlm_untag_resource]{untag_resource} \tab Removes the specified tags from the specified resource\cr
#'  \link[paws.storage:dlm_update_lifecycle_policy]{update_lifecycle_policy} \tab Updates the specified lifecycle policy
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname dlm
#' @export
dlm <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::dlm(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Elastic Block Store
#'
#' @description
#' You can use the Amazon Elastic Block Store (Amazon EBS) direct APIs to
#' create Amazon EBS snapshots, write data directly to your snapshots, read
#' data on your snapshots, and identify the differences or changes between
#' two snapshots. If you’re an independent software vendor (ISV) who offers
#' backup services for Amazon EBS, the EBS direct APIs make it more
#' efficient and cost-effective to track incremental changes on your Amazon
#' EBS volumes through snapshots. This can be done without having to create
#' new volumes from snapshots, and then use Amazon Elastic Compute Cloud
#' (Amazon EC2) instances to compare the differences.
#' 
#' You can create incremental snapshots directly from data on-premises into
#' volumes and the cloud to use for quick disaster recovery. With the
#' ability to write and read snapshots, you can write your on-premises data
#' to an snapshot during a disaster. Then after recovery, you can restore
#' it back to Amazon Web Services or on-premises from the snapshot. You no
#' longer need to build and maintain complex mechanisms to copy data to and
#' from Amazon EBS.
#' 
#' This API reference provides detailed information about the actions, data
#' types, parameters, and errors of the EBS direct APIs. For more
#' information about the elements that make up the EBS direct APIs, and
#' examples of how to use them effectively, see [Accessing the Contents of
#' an Amazon EBS
#' Snapshot](https://docs.aws.amazon.com/ebs/latest/userguide/ebs-accessing-snapshot.html)
#' in the *Amazon Elastic Compute Cloud User Guide*. For more information
#' about the supported Amazon Web Services Regions, endpoints, and service
#' quotas for the EBS direct APIs, see [Amazon Elastic Block Store
#' Endpoints and
#' Quotas](https://docs.aws.amazon.com/general/latest/gr/ebs-service.html)
#' in the *Amazon Web Services General Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ebs(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ebs()
#' svc$complete_snapshot(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:ebs_complete_snapshot]{complete_snapshot} \tab Seals and completes the snapshot after all of the required blocks of data have been written to it\cr
#'  \link[paws.storage:ebs_get_snapshot_block]{get_snapshot_block} \tab Returns the data in a block in an Amazon Elastic Block Store snapshot\cr
#'  \link[paws.storage:ebs_list_changed_blocks]{list_changed_blocks} \tab Returns information about the blocks that are different between two Amazon Elastic Block Store snapshots of the same volume/snapshot lineage\cr
#'  \link[paws.storage:ebs_list_snapshot_blocks]{list_snapshot_blocks} \tab Returns information about the blocks in an Amazon Elastic Block Store snapshot\cr
#'  \link[paws.storage:ebs_put_snapshot_block]{put_snapshot_block} \tab Writes a block of data to a snapshot\cr
#'  \link[paws.storage:ebs_start_snapshot]{start_snapshot} \tab Creates a new Amazon EBS snapshot
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ebs
#' @export
ebs <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::ebs(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Elastic File System
#'
#' @description
#' Amazon Elastic File System (Amazon EFS) provides simple, scalable file
#' storage for use with Amazon EC2 Linux and Mac instances in the Amazon
#' Web Services Cloud. With Amazon EFS, storage capacity is elastic,
#' growing and shrinking automatically as you add and remove files, so that
#' your applications have the storage they need, when they need it. For
#' more information, see the [Amazon Elastic File System API
#' Reference](https://docs.aws.amazon.com/efs/latest/ug/api-reference.html)
#' and the [Amazon Elastic File System User
#' Guide](https://docs.aws.amazon.com/efs/latest/ug/whatisefs.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- efs(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- efs()
#' # This operation creates a new, encrypted file system with automatic
#' # backups enabled, and the default generalpurpose performance mode.
#' svc$create_file_system(
#'   Backup = TRUE,
#'   CreationToken = "tokenstring",
#'   Encrypted = TRUE,
#'   PerformanceMode = "generalPurpose",
#'   Tags = list(
#'     list(
#'       Key = "Name",
#'       Value = "MyFileSystem"
#'     )
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:efs_create_access_point]{create_access_point} \tab Creates an EFS access point\cr
#'  \link[paws.storage:efs_create_file_system]{create_file_system} \tab Creates a new, empty file system\cr
#'  \link[paws.storage:efs_create_mount_target]{create_mount_target} \tab Creates a mount target for a file system\cr
#'  \link[paws.storage:efs_create_replication_configuration]{create_replication_configuration} \tab Creates a replication configuration to either a new or existing EFS file system\cr
#'  \link[paws.storage:efs_create_tags]{create_tags} \tab DEPRECATED - CreateTags is deprecated and not maintained\cr
#'  \link[paws.storage:efs_delete_access_point]{delete_access_point} \tab Deletes the specified access point\cr
#'  \link[paws.storage:efs_delete_file_system]{delete_file_system} \tab Deletes a file system, permanently severing access to its contents\cr
#'  \link[paws.storage:efs_delete_file_system_policy]{delete_file_system_policy} \tab Deletes the FileSystemPolicy for the specified file system\cr
#'  \link[paws.storage:efs_delete_mount_target]{delete_mount_target} \tab Deletes the specified mount target\cr
#'  \link[paws.storage:efs_delete_replication_configuration]{delete_replication_configuration} \tab Deletes a replication configuration\cr
#'  \link[paws.storage:efs_delete_tags]{delete_tags} \tab DEPRECATED - DeleteTags is deprecated and not maintained\cr
#'  \link[paws.storage:efs_describe_access_points]{describe_access_points} \tab Returns the description of a specific Amazon EFS access point if the AccessPointId is provided\cr
#'  \link[paws.storage:efs_describe_account_preferences]{describe_account_preferences} \tab Returns the account preferences settings for the Amazon Web Services account associated with the user making the request, in the current Amazon Web Services Region\cr
#'  \link[paws.storage:efs_describe_backup_policy]{describe_backup_policy} \tab Returns the backup policy for the specified EFS file system\cr
#'  \link[paws.storage:efs_describe_file_system_policy]{describe_file_system_policy} \tab Returns the FileSystemPolicy for the specified EFS file system\cr
#'  \link[paws.storage:efs_describe_file_systems]{describe_file_systems} \tab Returns the description of a specific Amazon EFS file system if either the file system CreationToken or the FileSystemId is provided\cr
#'  \link[paws.storage:efs_describe_lifecycle_configuration]{describe_lifecycle_configuration} \tab Returns the current LifecycleConfiguration object for the specified Amazon EFS file system\cr
#'  \link[paws.storage:efs_describe_mount_targets]{describe_mount_targets} \tab Returns the descriptions of all the current mount targets, or a specific mount target, for a file system\cr
#'  \link[paws.storage:efs_describe_mount_target_security_groups]{describe_mount_target_security_groups} \tab Returns the security groups currently in effect for a mount target\cr
#'  \link[paws.storage:efs_describe_replication_configurations]{describe_replication_configurations} \tab Retrieves the replication configuration for a specific file system\cr
#'  \link[paws.storage:efs_describe_tags]{describe_tags} \tab DEPRECATED - The DescribeTags action is deprecated and not maintained\cr
#'  \link[paws.storage:efs_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags for a top-level EFS resource\cr
#'  \link[paws.storage:efs_modify_mount_target_security_groups]{modify_mount_target_security_groups} \tab Modifies the set of security groups in effect for a mount target\cr
#'  \link[paws.storage:efs_put_account_preferences]{put_account_preferences} \tab Use this operation to set the account preference in the current Amazon Web Services Region to use long 17 character (63 bit) or short 8 character (32 bit) resource IDs for new EFS file system and mount target resources\cr
#'  \link[paws.storage:efs_put_backup_policy]{put_backup_policy} \tab Updates the file system's backup policy\cr
#'  \link[paws.storage:efs_put_file_system_policy]{put_file_system_policy} \tab Applies an Amazon EFS FileSystemPolicy to an Amazon EFS file system\cr
#'  \link[paws.storage:efs_put_lifecycle_configuration]{put_lifecycle_configuration} \tab Use this action to manage storage for your file system\cr
#'  \link[paws.storage:efs_tag_resource]{tag_resource} \tab Creates a tag for an EFS resource\cr
#'  \link[paws.storage:efs_untag_resource]{untag_resource} \tab Removes tags from an EFS resource\cr
#'  \link[paws.storage:efs_update_file_system]{update_file_system} \tab Updates the throughput mode or the amount of provisioned throughput of an existing file system\cr
#'  \link[paws.storage:efs_update_file_system_protection]{update_file_system_protection} \tab Updates protection on the file system
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname efs
#' @export
efs <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::efs(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' FinSpace Public API
#'
#' @description
#' The FinSpace APIs let you take actions inside the FinSpace.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- finspacedata(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- finspacedata()
#' svc$associate_user_to_permission_group(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:finspacedata_associate_user_to_permission_group]{associate_user_to_permission_group} \tab Adds a user to a permission group to grant permissions for actions a user can perform in FinSpace\cr
#'  \link[paws.storage:finspacedata_create_changeset]{create_changeset} \tab Creates a new Changeset in a FinSpace Dataset\cr
#'  \link[paws.storage:finspacedata_create_dataset]{create_dataset} \tab Creates a new FinSpace Dataset\cr
#'  \link[paws.storage:finspacedata_create_data_view]{create_data_view} \tab Creates a Dataview for a Dataset\cr
#'  \link[paws.storage:finspacedata_create_permission_group]{create_permission_group} \tab Creates a group of permissions for various actions that a user can perform in FinSpace\cr
#'  \link[paws.storage:finspacedata_create_user]{create_user} \tab Creates a new user in FinSpace\cr
#'  \link[paws.storage:finspacedata_delete_dataset]{delete_dataset} \tab Deletes a FinSpace Dataset\cr
#'  \link[paws.storage:finspacedata_delete_permission_group]{delete_permission_group} \tab Deletes a permission group\cr
#'  \link[paws.storage:finspacedata_disable_user]{disable_user} \tab Denies access to the FinSpace web application and API for the specified user\cr
#'  \link[paws.storage:finspacedata_disassociate_user_from_permission_group]{disassociate_user_from_permission_group} \tab Removes a user from a permission group\cr
#'  \link[paws.storage:finspacedata_enable_user]{enable_user} \tab Allows the specified user to access the FinSpace web application and API\cr
#'  \link[paws.storage:finspacedata_get_changeset]{get_changeset} \tab Get information about a Changeset\cr
#'  \link[paws.storage:finspacedata_get_dataset]{get_dataset} \tab Returns information about a Dataset\cr
#'  \link[paws.storage:finspacedata_get_data_view]{get_data_view} \tab Gets information about a Dataview\cr
#'  \link[paws.storage:finspacedata_get_external_data_view_access_details]{get_external_data_view_access_details} \tab Returns the credentials to access the external Dataview from an S3 location\cr
#'  \link[paws.storage:finspacedata_get_permission_group]{get_permission_group} \tab Retrieves the details of a specific permission group\cr
#'  \link[paws.storage:finspacedata_get_programmatic_access_credentials]{get_programmatic_access_credentials} \tab Request programmatic credentials to use with FinSpace SDK\cr
#'  \link[paws.storage:finspacedata_get_user]{get_user} \tab Retrieves details for a specific user\cr
#'  \link[paws.storage:finspacedata_get_working_location]{get_working_location} \tab A temporary Amazon S3 location, where you can copy your files from a source location to stage or use as a scratch space in FinSpace notebook\cr
#'  \link[paws.storage:finspacedata_list_changesets]{list_changesets} \tab Lists the FinSpace Changesets for a Dataset\cr
#'  \link[paws.storage:finspacedata_list_datasets]{list_datasets} \tab Lists all of the active Datasets that a user has access to\cr
#'  \link[paws.storage:finspacedata_list_data_views]{list_data_views} \tab Lists all available Dataviews for a Dataset\cr
#'  \link[paws.storage:finspacedata_list_permission_groups]{list_permission_groups} \tab Lists all available permission groups in FinSpace\cr
#'  \link[paws.storage:finspacedata_list_permission_groups_by_user]{list_permission_groups_by_user} \tab Lists all the permission groups that are associated with a specific user\cr
#'  \link[paws.storage:finspacedata_list_users]{list_users} \tab Lists all available users in FinSpace\cr
#'  \link[paws.storage:finspacedata_list_users_by_permission_group]{list_users_by_permission_group} \tab Lists details of all the users in a specific permission group\cr
#'  \link[paws.storage:finspacedata_reset_user_password]{reset_user_password} \tab Resets the password for a specified user ID and generates a temporary one\cr
#'  \link[paws.storage:finspacedata_update_changeset]{update_changeset} \tab Updates a FinSpace Changeset\cr
#'  \link[paws.storage:finspacedata_update_dataset]{update_dataset} \tab Updates a FinSpace Dataset\cr
#'  \link[paws.storage:finspacedata_update_permission_group]{update_permission_group} \tab Modifies the details of a permission group\cr
#'  \link[paws.storage:finspacedata_update_user]{update_user} \tab Modifies the details of the specified user
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname finspacedata
#' @export
finspacedata <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::finspacedata(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon FSx
#'
#' @description
#' Amazon FSx is a fully managed service that makes it easy for storage and
#' application administrators to launch and use shared file storage.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- fsx(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- fsx()
#' # This operation copies an Amazon FSx backup.
#' svc$copy_backup(
#'   SourceBackupId = "backup-03e3c82e0183b7b6b",
#'   SourceRegion = "us-east-2"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:fsx_associate_file_system_aliases]{associate_file_system_aliases} \tab Use this action to associate one or more Domain Name Server (DNS) aliases with an existing Amazon FSx for Windows File Server file system\cr
#'  \link[paws.storage:fsx_cancel_data_repository_task]{cancel_data_repository_task} \tab Cancels an existing Amazon FSx for Lustre data repository task if that task is in either the PENDING or EXECUTING state\cr
#'  \link[paws.storage:fsx_copy_backup]{copy_backup} \tab Copies an existing backup within the same Amazon Web Services account to another Amazon Web Services Region (cross-Region copy) or within the same Amazon Web Services Region (in-Region copy)\cr
#'  \link[paws.storage:fsx_copy_snapshot_and_update_volume]{copy_snapshot_and_update_volume} \tab Updates an existing volume by using a snapshot from another Amazon FSx for OpenZFS file system\cr
#'  \link[paws.storage:fsx_create_backup]{create_backup} \tab Creates a backup of an existing Amazon FSx for Windows File Server file system, Amazon FSx for Lustre file system, Amazon FSx for NetApp ONTAP volume, or Amazon FSx for OpenZFS file system\cr
#'  \link[paws.storage:fsx_create_data_repository_association]{create_data_repository_association} \tab Creates an Amazon FSx for Lustre data repository association (DRA)\cr
#'  \link[paws.storage:fsx_create_data_repository_task]{create_data_repository_task} \tab Creates an Amazon FSx for Lustre data repository task\cr
#'  \link[paws.storage:fsx_create_file_cache]{create_file_cache} \tab Creates a new Amazon File Cache resource\cr
#'  \link[paws.storage:fsx_create_file_system]{create_file_system} \tab Creates a new, empty Amazon FSx file system\cr
#'  \link[paws.storage:fsx_create_file_system_from_backup]{create_file_system_from_backup} \tab Creates a new Amazon FSx for Lustre, Amazon FSx for Windows File Server, or Amazon FSx for OpenZFS file system from an existing Amazon FSx backup\cr
#'  \link[paws.storage:fsx_create_snapshot]{create_snapshot} \tab Creates a snapshot of an existing Amazon FSx for OpenZFS volume\cr
#'  \link[paws.storage:fsx_create_storage_virtual_machine]{create_storage_virtual_machine} \tab Creates a storage virtual machine (SVM) for an Amazon FSx for ONTAP file system\cr
#'  \link[paws.storage:fsx_create_volume]{create_volume} \tab Creates an FSx for ONTAP or Amazon FSx for OpenZFS storage volume\cr
#'  \link[paws.storage:fsx_create_volume_from_backup]{create_volume_from_backup} \tab Creates a new Amazon FSx for NetApp ONTAP volume from an existing Amazon FSx volume backup\cr
#'  \link[paws.storage:fsx_delete_backup]{delete_backup} \tab Deletes an Amazon FSx backup\cr
#'  \link[paws.storage:fsx_delete_data_repository_association]{delete_data_repository_association} \tab Deletes a data repository association on an Amazon FSx for Lustre file system\cr
#'  \link[paws.storage:fsx_delete_file_cache]{delete_file_cache} \tab Deletes an Amazon File Cache resource\cr
#'  \link[paws.storage:fsx_delete_file_system]{delete_file_system} \tab Deletes a file system\cr
#'  \link[paws.storage:fsx_delete_snapshot]{delete_snapshot} \tab Deletes an Amazon FSx for OpenZFS snapshot\cr
#'  \link[paws.storage:fsx_delete_storage_virtual_machine]{delete_storage_virtual_machine} \tab Deletes an existing Amazon FSx for ONTAP storage virtual machine (SVM)\cr
#'  \link[paws.storage:fsx_delete_volume]{delete_volume} \tab Deletes an Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volume\cr
#'  \link[paws.storage:fsx_describe_backups]{describe_backups} \tab Returns the description of a specific Amazon FSx backup, if a BackupIds value is provided for that backup\cr
#'  \link[paws.storage:fsx_describe_data_repository_associations]{describe_data_repository_associations} \tab Returns the description of specific Amazon FSx for Lustre or Amazon File Cache data repository associations, if one or more AssociationIds values are provided in the request, or if filters are used in the request\cr
#'  \link[paws.storage:fsx_describe_data_repository_tasks]{describe_data_repository_tasks} \tab Returns the description of specific Amazon FSx for Lustre or Amazon File Cache data repository tasks, if one or more TaskIds values are provided in the request, or if filters are used in the request\cr
#'  \link[paws.storage:fsx_describe_file_caches]{describe_file_caches} \tab Returns the description of a specific Amazon File Cache resource, if a FileCacheIds value is provided for that cache\cr
#'  \link[paws.storage:fsx_describe_file_system_aliases]{describe_file_system_aliases} \tab Returns the DNS aliases that are associated with the specified Amazon FSx for Windows File Server file system\cr
#'  \link[paws.storage:fsx_describe_file_systems]{describe_file_systems} \tab Returns the description of specific Amazon FSx file systems, if a FileSystemIds value is provided for that file system\cr
#'  \link[paws.storage:fsx_describe_shared_vpc_configuration]{describe_shared_vpc_configuration} \tab Indicates whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner\cr
#'  \link[paws.storage:fsx_describe_snapshots]{describe_snapshots} \tab Returns the description of specific Amazon FSx for OpenZFS snapshots, if a SnapshotIds value is provided\cr
#'  \link[paws.storage:fsx_describe_storage_virtual_machines]{describe_storage_virtual_machines} \tab Describes one or more Amazon FSx for NetApp ONTAP storage virtual machines (SVMs)\cr
#'  \link[paws.storage:fsx_describe_volumes]{describe_volumes} \tab Describes one or more Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volumes\cr
#'  \link[paws.storage:fsx_disassociate_file_system_aliases]{disassociate_file_system_aliases} \tab Use this action to disassociate, or remove, one or more Domain Name Service (DNS) aliases from an Amazon FSx for Windows File Server file system\cr
#'  \link[paws.storage:fsx_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags for Amazon FSx resources\cr
#'  \link[paws.storage:fsx_release_file_system_nfs_v3_locks]{release_file_system_nfs_v3_locks} \tab Releases the file system lock from an Amazon FSx for OpenZFS file system\cr
#'  \link[paws.storage:fsx_restore_volume_from_snapshot]{restore_volume_from_snapshot} \tab Returns an Amazon FSx for OpenZFS volume to the state saved by the specified snapshot\cr
#'  \link[paws.storage:fsx_start_misconfigured_state_recovery]{start_misconfigured_state_recovery} \tab After performing steps to repair the Active Directory configuration of an FSx for Windows File Server file system, use this action to initiate the process of Amazon FSx attempting to reconnect to the file system\cr
#'  \link[paws.storage:fsx_tag_resource]{tag_resource} \tab Tags an Amazon FSx resource\cr
#'  \link[paws.storage:fsx_untag_resource]{untag_resource} \tab This action removes a tag from an Amazon FSx resource\cr
#'  \link[paws.storage:fsx_update_data_repository_association]{update_data_repository_association} \tab Updates the configuration of an existing data repository association on an Amazon FSx for Lustre file system\cr
#'  \link[paws.storage:fsx_update_file_cache]{update_file_cache} \tab Updates the configuration of an existing Amazon File Cache resource\cr
#'  \link[paws.storage:fsx_update_file_system]{update_file_system} \tab Use this operation to update the configuration of an existing Amazon FSx file system\cr
#'  \link[paws.storage:fsx_update_shared_vpc_configuration]{update_shared_vpc_configuration} \tab Configures whether participant accounts in your organization can create Amazon FSx for NetApp ONTAP Multi-AZ file systems in subnets that are shared by a virtual private cloud (VPC) owner\cr
#'  \link[paws.storage:fsx_update_snapshot]{update_snapshot} \tab Updates the name of an Amazon FSx for OpenZFS snapshot\cr
#'  \link[paws.storage:fsx_update_storage_virtual_machine]{update_storage_virtual_machine} \tab Updates an FSx for ONTAP storage virtual machine (SVM)\cr
#'  \link[paws.storage:fsx_update_volume]{update_volume} \tab Updates the configuration of an Amazon FSx for NetApp ONTAP or Amazon FSx for OpenZFS volume
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname fsx
#' @export
fsx <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::fsx(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Glacier
#'
#' @description
#' Amazon S3 Glacier (Glacier) is a storage solution for "cold data."
#' 
#' Glacier is an extremely low-cost storage service that provides secure,
#' durable, and easy-to-use storage for data backup and archival. With
#' Glacier, customers can store their data cost effectively for months,
#' years, or decades. Glacier also enables customers to offload the
#' administrative burdens of operating and scaling storage to AWS, so they
#' don't have to worry about capacity planning, hardware provisioning, data
#' replication, hardware failure and recovery, or time-consuming hardware
#' migrations.
#' 
#' Glacier is a great storage choice when low storage cost is paramount and
#' your data is rarely retrieved. If your application requires fast or
#' frequent access to your data, consider using Amazon S3. For more
#' information, see [Amazon Simple Storage Service (Amazon
#' S3)](https://aws.amazon.com/s3/).
#' 
#' You can store any kind of data in any format. There is no maximum limit
#' on the total amount of data you can store in Glacier.
#' 
#' If you are a first-time user of Glacier, we recommend that you begin by
#' reading the following sections in the *Amazon S3 Glacier Developer
#' Guide*:
#' 
#' -   [What is Amazon S3
#'     Glacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/introduction.html) -
#'     This section of the Developer Guide describes the underlying data
#'     model, the operations it supports, and the AWS SDKs that you can use
#'     to interact with the service.
#' 
#' -   [Getting Started with Amazon S3
#'     Glacier](https://docs.aws.amazon.com/amazonglacier/latest/dev/amazon-glacier-getting-started.html) -
#'     The Getting Started section walks you through the process of
#'     creating a vault, uploading archives, creating jobs to download
#'     archives, retrieving the job output, and deleting archives.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- glacier(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- glacier()
#' # The example deletes an in-progress multipart upload to a vault named
#' # my-vault:
#' svc$abort_multipart_upload(
#'   accountId = "-",
#'   uploadId = "19gaRezEXAMPLES6Ry5YYdqthHOC_kGRCT03L9yetr220UmPtBYKk-OssZtLq...",
#'   vaultName = "my-vault"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:glacier_abort_multipart_upload]{abort_multipart_upload} \tab This operation aborts a multipart upload identified by the upload ID\cr
#'  \link[paws.storage:glacier_abort_vault_lock]{abort_vault_lock} \tab This operation aborts the vault locking process if the vault lock is not in the Locked state\cr
#'  \link[paws.storage:glacier_add_tags_to_vault]{add_tags_to_vault} \tab This operation adds the specified tags to a vault\cr
#'  \link[paws.storage:glacier_complete_multipart_upload]{complete_multipart_upload} \tab You call this operation to inform Amazon S3 Glacier (Glacier) that all the archive parts have been uploaded and that Glacier can now assemble the archive from the uploaded parts\cr
#'  \link[paws.storage:glacier_complete_vault_lock]{complete_vault_lock} \tab This operation completes the vault locking process by transitioning the vault lock from the InProgress state to the Locked state, which causes the vault lock policy to become unchangeable\cr
#'  \link[paws.storage:glacier_create_vault]{create_vault} \tab This operation creates a new vault with the specified name\cr
#'  \link[paws.storage:glacier_delete_archive]{delete_archive} \tab This operation deletes an archive from a vault\cr
#'  \link[paws.storage:glacier_delete_vault]{delete_vault} \tab This operation deletes a vault\cr
#'  \link[paws.storage:glacier_delete_vault_access_policy]{delete_vault_access_policy} \tab This operation deletes the access policy associated with the specified vault\cr
#'  \link[paws.storage:glacier_delete_vault_notifications]{delete_vault_notifications} \tab This operation deletes the notification configuration set for a vault\cr
#'  \link[paws.storage:glacier_describe_job]{describe_job} \tab This operation returns information about a job you previously initiated, including the job initiation date, the user who initiated the job, the job status code/message and the Amazon SNS topic to notify after Amazon S3 Glacier (Glacier) completes the job\cr
#'  \link[paws.storage:glacier_describe_vault]{describe_vault} \tab This operation returns information about a vault, including the vault's Amazon Resource Name (ARN), the date the vault was created, the number of archives it contains, and the total size of all the archives in the vault\cr
#'  \link[paws.storage:glacier_get_data_retrieval_policy]{get_data_retrieval_policy} \tab This operation returns the current data retrieval policy for the account and region specified in the GET request\cr
#'  \link[paws.storage:glacier_get_job_output]{get_job_output} \tab This operation downloads the output of the job you initiated using InitiateJob\cr
#'  \link[paws.storage:glacier_get_vault_access_policy]{get_vault_access_policy} \tab This operation retrieves the access-policy subresource set on the vault; for more information on setting this subresource, see Set Vault Access Policy (PUT access-policy)\cr
#'  \link[paws.storage:glacier_get_vault_lock]{get_vault_lock} \tab This operation retrieves the following attributes from the lock-policy subresource set on the specified vault:\cr
#'  \link[paws.storage:glacier_get_vault_notifications]{get_vault_notifications} \tab This operation retrieves the notification-configuration subresource of the specified vault\cr
#'  \link[paws.storage:glacier_initiate_job]{initiate_job} \tab This operation initiates a job of the specified type, which can be a select, an archival retrieval, or a vault retrieval\cr
#'  \link[paws.storage:glacier_initiate_multipart_upload]{initiate_multipart_upload} \tab This operation initiates a multipart upload\cr
#'  \link[paws.storage:glacier_initiate_vault_lock]{initiate_vault_lock} \tab This operation initiates the vault locking process by doing the following:\cr
#'  \link[paws.storage:glacier_list_jobs]{list_jobs} \tab This operation lists jobs for a vault, including jobs that are in-progress and jobs that have recently finished\cr
#'  \link[paws.storage:glacier_list_multipart_uploads]{list_multipart_uploads} \tab This operation lists in-progress multipart uploads for the specified vault\cr
#'  \link[paws.storage:glacier_list_parts]{list_parts} \tab This operation lists the parts of an archive that have been uploaded in a specific multipart upload\cr
#'  \link[paws.storage:glacier_list_provisioned_capacity]{list_provisioned_capacity} \tab This operation lists the provisioned capacity units for the specified AWS account\cr
#'  \link[paws.storage:glacier_list_tags_for_vault]{list_tags_for_vault} \tab This operation lists all the tags attached to a vault\cr
#'  \link[paws.storage:glacier_list_vaults]{list_vaults} \tab This operation lists all vaults owned by the calling user's account\cr
#'  \link[paws.storage:glacier_purchase_provisioned_capacity]{purchase_provisioned_capacity} \tab This operation purchases a provisioned capacity unit for an AWS account\cr
#'  \link[paws.storage:glacier_remove_tags_from_vault]{remove_tags_from_vault} \tab This operation removes one or more tags from the set of tags attached to a vault\cr
#'  \link[paws.storage:glacier_set_data_retrieval_policy]{set_data_retrieval_policy} \tab This operation sets and then enacts a data retrieval policy in the region specified in the PUT request\cr
#'  \link[paws.storage:glacier_set_vault_access_policy]{set_vault_access_policy} \tab This operation configures an access policy for a vault and will overwrite an existing policy\cr
#'  \link[paws.storage:glacier_set_vault_notifications]{set_vault_notifications} \tab This operation configures notifications that will be sent when specific events happen to a vault\cr
#'  \link[paws.storage:glacier_upload_archive]{upload_archive} \tab This operation adds an archive to a vault\cr
#'  \link[paws.storage:glacier_upload_multipart_part]{upload_multipart_part} \tab This operation uploads a part of an archive
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname glacier
#' @export
glacier <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::glacier(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Omics
#'
#' @description
#' This is the *AWS HealthOmics API Reference*. For an introduction to the
#' service, see [What is AWS
#' HealthOmics?](https://docs.aws.amazon.com/omics/latest/dev/) in the *AWS
#' HealthOmics User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- omics(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- omics()
#' svc$abort_multipart_read_set_upload(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:omics_abort_multipart_read_set_upload]{abort_multipart_read_set_upload} \tab Stops a multipart upload\cr
#'  \link[paws.storage:omics_accept_share]{accept_share} \tab Accept a resource share request\cr
#'  \link[paws.storage:omics_batch_delete_read_set]{batch_delete_read_set} \tab Deletes one or more read sets\cr
#'  \link[paws.storage:omics_cancel_annotation_import_job]{cancel_annotation_import_job} \tab Cancels an annotation import job\cr
#'  \link[paws.storage:omics_cancel_run]{cancel_run} \tab Cancels a run\cr
#'  \link[paws.storage:omics_cancel_variant_import_job]{cancel_variant_import_job} \tab Cancels a variant import job\cr
#'  \link[paws.storage:omics_complete_multipart_read_set_upload]{complete_multipart_read_set_upload} \tab Concludes a multipart upload once you have uploaded all the components\cr
#'  \link[paws.storage:omics_create_annotation_store]{create_annotation_store} \tab Creates an annotation store\cr
#'  \link[paws.storage:omics_create_annotation_store_version]{create_annotation_store_version} \tab Creates a new version of an annotation store\cr
#'  \link[paws.storage:omics_create_multipart_read_set_upload]{create_multipart_read_set_upload} \tab Begins a multipart read set upload\cr
#'  \link[paws.storage:omics_create_reference_store]{create_reference_store} \tab Creates a reference store\cr
#'  \link[paws.storage:omics_create_run_cache]{create_run_cache} \tab You can create a run cache to save the task outputs from completed tasks in a run for a private workflow\cr
#'  \link[paws.storage:omics_create_run_group]{create_run_group} \tab You can optionally create a run group to limit the compute resources for the runs that you add to the group\cr
#'  \link[paws.storage:omics_create_sequence_store]{create_sequence_store} \tab Creates a sequence store\cr
#'  \link[paws.storage:omics_create_share]{create_share} \tab Creates a cross-account shared resource\cr
#'  \link[paws.storage:omics_create_variant_store]{create_variant_store} \tab Creates a variant store\cr
#'  \link[paws.storage:omics_create_workflow]{create_workflow} \tab Creates a workflow\cr
#'  \link[paws.storage:omics_delete_annotation_store]{delete_annotation_store} \tab Deletes an annotation store\cr
#'  \link[paws.storage:omics_delete_annotation_store_versions]{delete_annotation_store_versions} \tab Deletes one or multiple versions of an annotation store\cr
#'  \link[paws.storage:omics_delete_reference]{delete_reference} \tab Deletes a genome reference\cr
#'  \link[paws.storage:omics_delete_reference_store]{delete_reference_store} \tab Deletes a genome reference store\cr
#'  \link[paws.storage:omics_delete_run]{delete_run} \tab Deletes a workflow run\cr
#'  \link[paws.storage:omics_delete_run_cache]{delete_run_cache} \tab Delete a run cache\cr
#'  \link[paws.storage:omics_delete_run_group]{delete_run_group} \tab Deletes a workflow run group\cr
#'  \link[paws.storage:omics_delete_s3_access_policy]{delete_s3_access_policy} \tab Deletes an access policy for the specified store\cr
#'  \link[paws.storage:omics_delete_sequence_store]{delete_sequence_store} \tab Deletes a sequence store\cr
#'  \link[paws.storage:omics_delete_share]{delete_share} \tab Deletes a resource share\cr
#'  \link[paws.storage:omics_delete_variant_store]{delete_variant_store} \tab Deletes a variant store\cr
#'  \link[paws.storage:omics_delete_workflow]{delete_workflow} \tab Deletes a workflow\cr
#'  \link[paws.storage:omics_get_annotation_import_job]{get_annotation_import_job} \tab Gets information about an annotation import job\cr
#'  \link[paws.storage:omics_get_annotation_store]{get_annotation_store} \tab Gets information about an annotation store\cr
#'  \link[paws.storage:omics_get_annotation_store_version]{get_annotation_store_version} \tab Retrieves the metadata for an annotation store version\cr
#'  \link[paws.storage:omics_get_read_set]{get_read_set} \tab Gets a file from a read set\cr
#'  \link[paws.storage:omics_get_read_set_activation_job]{get_read_set_activation_job} \tab Gets information about a read set activation job\cr
#'  \link[paws.storage:omics_get_read_set_export_job]{get_read_set_export_job} \tab Gets information about a read set export job\cr
#'  \link[paws.storage:omics_get_read_set_import_job]{get_read_set_import_job} \tab Gets information about a read set import job\cr
#'  \link[paws.storage:omics_get_read_set_metadata]{get_read_set_metadata} \tab Gets details about a read set\cr
#'  \link[paws.storage:omics_get_reference]{get_reference} \tab Gets a reference file\cr
#'  \link[paws.storage:omics_get_reference_import_job]{get_reference_import_job} \tab Gets information about a reference import job\cr
#'  \link[paws.storage:omics_get_reference_metadata]{get_reference_metadata} \tab Gets information about a genome reference's metadata\cr
#'  \link[paws.storage:omics_get_reference_store]{get_reference_store} \tab Gets information about a reference store\cr
#'  \link[paws.storage:omics_get_run]{get_run} \tab Gets information about a workflow run\cr
#'  \link[paws.storage:omics_get_run_cache]{get_run_cache} \tab Retrieve the details for the specified run cache\cr
#'  \link[paws.storage:omics_get_run_group]{get_run_group} \tab Gets information about a workflow run group\cr
#'  \link[paws.storage:omics_get_run_task]{get_run_task} \tab Gets information about a workflow run task\cr
#'  \link[paws.storage:omics_get_s3_access_policy]{get_s3_access_policy} \tab Retrieves details about an access policy on a given store\cr
#'  \link[paws.storage:omics_get_sequence_store]{get_sequence_store} \tab Gets information about a sequence store\cr
#'  \link[paws.storage:omics_get_share]{get_share} \tab Retrieves the metadata for the specified resource share\cr
#'  \link[paws.storage:omics_get_variant_import_job]{get_variant_import_job} \tab Gets information about a variant import job\cr
#'  \link[paws.storage:omics_get_variant_store]{get_variant_store} \tab Gets information about a variant store\cr
#'  \link[paws.storage:omics_get_workflow]{get_workflow} \tab Gets information about a workflow\cr
#'  \link[paws.storage:omics_list_annotation_import_jobs]{list_annotation_import_jobs} \tab Retrieves a list of annotation import jobs\cr
#'  \link[paws.storage:omics_list_annotation_stores]{list_annotation_stores} \tab Retrieves a list of annotation stores\cr
#'  \link[paws.storage:omics_list_annotation_store_versions]{list_annotation_store_versions} \tab Lists the versions of an annotation store\cr
#'  \link[paws.storage:omics_list_multipart_read_set_uploads]{list_multipart_read_set_uploads} \tab Lists multipart read set uploads and for in progress uploads\cr
#'  \link[paws.storage:omics_list_read_set_activation_jobs]{list_read_set_activation_jobs} \tab Retrieves a list of read set activation jobs\cr
#'  \link[paws.storage:omics_list_read_set_export_jobs]{list_read_set_export_jobs} \tab Retrieves a list of read set export jobs\cr
#'  \link[paws.storage:omics_list_read_set_import_jobs]{list_read_set_import_jobs} \tab Retrieves a list of read set import jobs\cr
#'  \link[paws.storage:omics_list_read_sets]{list_read_sets} \tab Retrieves a list of read sets\cr
#'  \link[paws.storage:omics_list_read_set_upload_parts]{list_read_set_upload_parts} \tab This operation will list all parts in a requested multipart upload for a sequence store\cr
#'  \link[paws.storage:omics_list_reference_import_jobs]{list_reference_import_jobs} \tab Retrieves a list of reference import jobs\cr
#'  \link[paws.storage:omics_list_references]{list_references} \tab Retrieves a list of references\cr
#'  \link[paws.storage:omics_list_reference_stores]{list_reference_stores} \tab Retrieves a list of reference stores\cr
#'  \link[paws.storage:omics_list_run_caches]{list_run_caches} \tab Retrieves a list of your run caches\cr
#'  \link[paws.storage:omics_list_run_groups]{list_run_groups} \tab Retrieves a list of run groups\cr
#'  \link[paws.storage:omics_list_runs]{list_runs} \tab Retrieves a list of runs\cr
#'  \link[paws.storage:omics_list_run_tasks]{list_run_tasks} \tab Retrieves a list of tasks for a run\cr
#'  \link[paws.storage:omics_list_sequence_stores]{list_sequence_stores} \tab Retrieves a list of sequence stores\cr
#'  \link[paws.storage:omics_list_shares]{list_shares} \tab Retrieves the resource shares associated with an account\cr
#'  \link[paws.storage:omics_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves a list of tags for a resource\cr
#'  \link[paws.storage:omics_list_variant_import_jobs]{list_variant_import_jobs} \tab Retrieves a list of variant import jobs\cr
#'  \link[paws.storage:omics_list_variant_stores]{list_variant_stores} \tab Retrieves a list of variant stores\cr
#'  \link[paws.storage:omics_list_workflows]{list_workflows} \tab Retrieves a list of workflows\cr
#'  \link[paws.storage:omics_put_s3_access_policy]{put_s3_access_policy} \tab Adds an access policy to the specified store\cr
#'  \link[paws.storage:omics_start_annotation_import_job]{start_annotation_import_job} \tab Starts an annotation import job\cr
#'  \link[paws.storage:omics_start_read_set_activation_job]{start_read_set_activation_job} \tab Activates an archived read set\cr
#'  \link[paws.storage:omics_start_read_set_export_job]{start_read_set_export_job} \tab Exports a read set to Amazon S3\cr
#'  \link[paws.storage:omics_start_read_set_import_job]{start_read_set_import_job} \tab Starts a read set import job\cr
#'  \link[paws.storage:omics_start_reference_import_job]{start_reference_import_job} \tab Starts a reference import job\cr
#'  \link[paws.storage:omics_start_run]{start_run} \tab Starts a workflow run\cr
#'  \link[paws.storage:omics_start_variant_import_job]{start_variant_import_job} \tab Starts a variant import job\cr
#'  \link[paws.storage:omics_tag_resource]{tag_resource} \tab Tags a resource\cr
#'  \link[paws.storage:omics_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.storage:omics_update_annotation_store]{update_annotation_store} \tab Updates an annotation store\cr
#'  \link[paws.storage:omics_update_annotation_store_version]{update_annotation_store_version} \tab Updates the description of an annotation store version\cr
#'  \link[paws.storage:omics_update_run_cache]{update_run_cache} \tab Update a run cache\cr
#'  \link[paws.storage:omics_update_run_group]{update_run_group} \tab Updates a run group\cr
#'  \link[paws.storage:omics_update_sequence_store]{update_sequence_store} \tab Update one or more parameters for the sequence store\cr
#'  \link[paws.storage:omics_update_variant_store]{update_variant_store} \tab Updates a variant store\cr
#'  \link[paws.storage:omics_update_workflow]{update_workflow} \tab Updates a workflow\cr
#'  \link[paws.storage:omics_upload_read_set_part]{upload_read_set_part} \tab This operation uploads a specific part of a read set
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname omics
#' @export
omics <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::omics(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Recycle Bin
#'
#' @description
#' This is the *Recycle Bin API Reference*. This documentation provides
#' descriptions and syntax for each of the actions and data types in
#' Recycle Bin.
#' 
#' Recycle Bin is a resource recovery feature that enables you to restore
#' accidentally deleted snapshots and EBS-backed AMIs. When using Recycle
#' Bin, if your resources are deleted, they are retained in the Recycle Bin
#' for a time period that you specify.
#' 
#' You can restore a resource from the Recycle Bin at any time before its
#' retention period expires. After you restore a resource from the Recycle
#' Bin, the resource is removed from the Recycle Bin, and you can then use
#' it in the same way you use any other resource of that type in your
#' account. If the retention period expires and the resource is not
#' restored, the resource is permanently deleted from the Recycle Bin and
#' is no longer available for recovery. For more information about Recycle
#' Bin, see [Recycle
#' Bin](https://docs.aws.amazon.com/ebs/latest/userguide/recycle-bin.html)
#' in the *Amazon Elastic Compute Cloud User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- recyclebin(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- recyclebin()
#' svc$create_rule(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:recyclebin_create_rule]{create_rule} \tab Creates a Recycle Bin retention rule\cr
#'  \link[paws.storage:recyclebin_delete_rule]{delete_rule} \tab Deletes a Recycle Bin retention rule\cr
#'  \link[paws.storage:recyclebin_get_rule]{get_rule} \tab Gets information about a Recycle Bin retention rule\cr
#'  \link[paws.storage:recyclebin_list_rules]{list_rules} \tab Lists the Recycle Bin retention rules in the Region\cr
#'  \link[paws.storage:recyclebin_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags assigned to a retention rule\cr
#'  \link[paws.storage:recyclebin_lock_rule]{lock_rule} \tab Locks a Region-level retention rule\cr
#'  \link[paws.storage:recyclebin_tag_resource]{tag_resource} \tab Assigns tags to the specified retention rule\cr
#'  \link[paws.storage:recyclebin_unlock_rule]{unlock_rule} \tab Unlocks a retention rule\cr
#'  \link[paws.storage:recyclebin_untag_resource]{untag_resource} \tab Unassigns a tag from a retention rule\cr
#'  \link[paws.storage:recyclebin_update_rule]{update_rule} \tab Updates an existing Recycle Bin retention rule
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname recyclebin
#' @export
recyclebin <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::recyclebin(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Simple Storage Service
#'
#' 
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- s3(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- s3()
#' # The following example aborts a multipart upload.
#' svc$abort_multipart_upload(
#'   Bucket = "examplebucket",
#'   Key = "bigobject",
#'   UploadId = "xadcOB_7YPBOJuoFiQ9cz4P3Pe6FIZwO4f7wN93uHsNBEw97pl5eNwzExg0LA..."
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:s3_abort_multipart_upload]{abort_multipart_upload} \tab This operation aborts a multipart upload\cr
#'  \link[paws.storage:s3_complete_multipart_upload]{complete_multipart_upload} \tab Completes a multipart upload by assembling previously uploaded parts\cr
#'  \link[paws.storage:s3_copy_object]{copy_object} \tab Creates a copy of an object that is already stored in Amazon S3\cr
#'  \link[paws.storage:s3_create_bucket]{create_bucket} \tab This action creates an Amazon S3 bucket\cr
#'  \link[paws.storage:s3_create_bucket_metadata_table_configuration]{create_bucket_metadata_table_configuration} \tab Creates a metadata table configuration for a general purpose bucket\cr
#'  \link[paws.storage:s3_create_multipart_upload]{create_multipart_upload} \tab This action initiates a multipart upload and returns an upload ID\cr
#'  \link[paws.storage:s3_create_session]{create_session} \tab Creates a session that establishes temporary security credentials to support fast authentication and authorization for the Zonal endpoint API operations on directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket]{delete_bucket} \tab Deletes the S3 bucket\cr
#'  \link[paws.storage:s3_delete_bucket_analytics_configuration]{delete_bucket_analytics_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket_cors]{delete_bucket_cors} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket_encryption]{delete_bucket_encryption} \tab This implementation of the DELETE action resets the default encryption for the bucket as server-side encryption with Amazon S3 managed keys (SSE-S3)\cr
#'  \link[paws.storage:s3_delete_bucket_intelligent_tiering_configuration]{delete_bucket_intelligent_tiering_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket_inventory_configuration]{delete_bucket_inventory_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket_lifecycle]{delete_bucket_lifecycle} \tab Deletes the lifecycle configuration from the specified bucket\cr
#'  \link[paws.storage:s3_delete_bucket_metadata_table_configuration]{delete_bucket_metadata_table_configuration} \tab Deletes a metadata table configuration from a general purpose bucket\cr
#'  \link[paws.storage:s3_delete_bucket_metrics_configuration]{delete_bucket_metrics_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket_ownership_controls]{delete_bucket_ownership_controls} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket_policy]{delete_bucket_policy} \tab Deletes the policy of a specified bucket\cr
#'  \link[paws.storage:s3_delete_bucket_replication]{delete_bucket_replication} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket_tagging]{delete_bucket_tagging} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_bucket_website]{delete_bucket_website} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_object]{delete_object} \tab Removes an object from a bucket\cr
#'  \link[paws.storage:s3_delete_objects]{delete_objects} \tab This operation enables you to delete multiple objects from a bucket using a single HTTP request\cr
#'  \link[paws.storage:s3_delete_object_tagging]{delete_object_tagging} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_delete_public_access_block]{delete_public_access_block} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_download_file]{download_file} \tab Download a file from S3 and store it at a specified file location\cr
#'  \link[paws.storage:s3_generate_presigned_url]{generate_presigned_url} \tab @title Generate a presigned url given a client, its method, and arguments\cr
#'  \link[paws.storage:s3_get_bucket_accelerate_configuration]{get_bucket_accelerate_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_acl]{get_bucket_acl} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_analytics_configuration]{get_bucket_analytics_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_cors]{get_bucket_cors} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_encryption]{get_bucket_encryption} \tab Returns the default encryption configuration for an Amazon S3 bucket\cr
#'  \link[paws.storage:s3_get_bucket_intelligent_tiering_configuration]{get_bucket_intelligent_tiering_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_inventory_configuration]{get_bucket_inventory_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_lifecycle]{get_bucket_lifecycle} \tab For an updated version of this API, see GetBucketLifecycleConfiguration\cr
#'  \link[paws.storage:s3_get_bucket_lifecycle_configuration]{get_bucket_lifecycle_configuration} \tab Returns the lifecycle configuration information set on the bucket\cr
#'  \link[paws.storage:s3_get_bucket_location]{get_bucket_location} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_logging]{get_bucket_logging} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_metadata_table_configuration]{get_bucket_metadata_table_configuration} \tab Retrieves the metadata table configuration for a general purpose bucket\cr
#'  \link[paws.storage:s3_get_bucket_metrics_configuration]{get_bucket_metrics_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_notification]{get_bucket_notification} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_notification_configuration]{get_bucket_notification_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_ownership_controls]{get_bucket_ownership_controls} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_policy]{get_bucket_policy} \tab Returns the policy of a specified bucket\cr
#'  \link[paws.storage:s3_get_bucket_policy_status]{get_bucket_policy_status} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_replication]{get_bucket_replication} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_request_payment]{get_bucket_request_payment} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_tagging]{get_bucket_tagging} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_versioning]{get_bucket_versioning} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_bucket_website]{get_bucket_website} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_object]{get_object} \tab Retrieves an object from Amazon S3\cr
#'  \link[paws.storage:s3_get_object_acl]{get_object_acl} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_object_attributes]{get_object_attributes} \tab Retrieves all the metadata from an object without returning the object itself\cr
#'  \link[paws.storage:s3_get_object_legal_hold]{get_object_legal_hold} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_object_lock_configuration]{get_object_lock_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_object_retention]{get_object_retention} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_object_tagging]{get_object_tagging} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_object_torrent]{get_object_torrent} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_get_public_access_block]{get_public_access_block} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_head_bucket]{head_bucket} \tab You can use this operation to determine if a bucket exists and if you have permission to access it\cr
#'  \link[paws.storage:s3_head_object]{head_object} \tab The HEAD operation retrieves metadata from an object without returning the object itself\cr
#'  \link[paws.storage:s3_list_bucket_analytics_configurations]{list_bucket_analytics_configurations} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_list_bucket_intelligent_tiering_configurations]{list_bucket_intelligent_tiering_configurations} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_list_bucket_inventory_configurations]{list_bucket_inventory_configurations} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_list_bucket_metrics_configurations]{list_bucket_metrics_configurations} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_list_buckets]{list_buckets} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_list_directory_buckets]{list_directory_buckets} \tab Returns a list of all Amazon S3 directory buckets owned by the authenticated sender of the request\cr
#'  \link[paws.storage:s3_list_multipart_uploads]{list_multipart_uploads} \tab This operation lists in-progress multipart uploads in a bucket\cr
#'  \link[paws.storage:s3_list_objects]{list_objects} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_list_objects_v2]{list_objects_v2} \tab Returns some or all (up to 1,000) of the objects in a bucket with each request\cr
#'  \link[paws.storage:s3_list_object_versions]{list_object_versions} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_list_parts]{list_parts} \tab Lists the parts that have been uploaded for a specific multipart upload\cr
#'  \link[paws.storage:s3_put_bucket_accelerate_configuration]{put_bucket_accelerate_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_acl]{put_bucket_acl} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_analytics_configuration]{put_bucket_analytics_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_cors]{put_bucket_cors} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_encryption]{put_bucket_encryption} \tab This operation configures default encryption and Amazon S3 Bucket Keys for an existing bucket\cr
#'  \link[paws.storage:s3_put_bucket_intelligent_tiering_configuration]{put_bucket_intelligent_tiering_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_inventory_configuration]{put_bucket_inventory_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_lifecycle]{put_bucket_lifecycle} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_lifecycle_configuration]{put_bucket_lifecycle_configuration} \tab Creates a new lifecycle configuration for the bucket or replaces an existing lifecycle configuration\cr
#'  \link[paws.storage:s3_put_bucket_logging]{put_bucket_logging} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_metrics_configuration]{put_bucket_metrics_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_notification]{put_bucket_notification} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_notification_configuration]{put_bucket_notification_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_ownership_controls]{put_bucket_ownership_controls} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_policy]{put_bucket_policy} \tab Applies an Amazon S3 bucket policy to an Amazon S3 bucket\cr
#'  \link[paws.storage:s3_put_bucket_replication]{put_bucket_replication} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_request_payment]{put_bucket_request_payment} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_tagging]{put_bucket_tagging} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_versioning]{put_bucket_versioning} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_bucket_website]{put_bucket_website} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_object]{put_object} \tab Adds an object to a bucket\cr
#'  \link[paws.storage:s3_put_object_acl]{put_object_acl} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_object_legal_hold]{put_object_legal_hold} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_object_lock_configuration]{put_object_lock_configuration} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_object_retention]{put_object_retention} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_object_tagging]{put_object_tagging} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_put_public_access_block]{put_public_access_block} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_restore_object]{restore_object} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_select_object_content]{select_object_content} \tab This operation is not supported for directory buckets\cr
#'  \link[paws.storage:s3_upload_part]{upload_part} \tab Uploads a part in a multipart upload\cr
#'  \link[paws.storage:s3_upload_part_copy]{upload_part_copy} \tab Uploads a part by copying data from an existing object as data source\cr
#'  \link[paws.storage:s3_write_get_object_response]{write_get_object_response} \tab This operation is not supported for directory buckets
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname s3
#' @export
s3 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::s3(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS S3 Control
#'
#' @description
#' Amazon Web Services S3 Control provides access to Amazon S3 control
#' plane actions.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- s3control(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- s3control()
#' svc$associate_access_grants_identity_center(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:s3control_associate_access_grants_identity_center]{associate_access_grants_identity_center} \tab Associate your S3 Access Grants instance with an Amazon Web Services IAM Identity Center instance\cr
#'  \link[paws.storage:s3control_create_access_grant]{create_access_grant} \tab Creates an access grant that gives a grantee access to your S3 data\cr
#'  \link[paws.storage:s3control_create_access_grants_instance]{create_access_grants_instance} \tab Creates an S3 Access Grants instance, which serves as a logical grouping for access grants\cr
#'  \link[paws.storage:s3control_create_access_grants_location]{create_access_grants_location} \tab The S3 data location that you would like to register in your S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_create_access_point]{create_access_point} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_create_access_point_for_object_lambda]{create_access_point_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_create_bucket]{create_bucket} \tab This action creates an Amazon S3 on Outposts bucket\cr
#'  \link[paws.storage:s3control_create_job]{create_job} \tab This operation creates an S3 Batch Operations job\cr
#'  \link[paws.storage:s3control_create_multi_region_access_point]{create_multi_region_access_point} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_create_storage_lens_group]{create_storage_lens_group} \tab Creates a new S3 Storage Lens group and associates it with the specified Amazon Web Services account ID\cr
#'  \link[paws.storage:s3control_delete_access_grant]{delete_access_grant} \tab Deletes the access grant from the S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_delete_access_grants_instance]{delete_access_grants_instance} \tab Deletes your S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_delete_access_grants_instance_resource_policy]{delete_access_grants_instance_resource_policy} \tab Deletes the resource policy of the S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_delete_access_grants_location]{delete_access_grants_location} \tab Deregisters a location from your S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_delete_access_point]{delete_access_point} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_delete_access_point_for_object_lambda]{delete_access_point_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_delete_access_point_policy]{delete_access_point_policy} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_delete_access_point_policy_for_object_lambda]{delete_access_point_policy_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_delete_bucket]{delete_bucket} \tab This action deletes an Amazon S3 on Outposts bucket\cr
#'  \link[paws.storage:s3control_delete_bucket_lifecycle_configuration]{delete_bucket_lifecycle_configuration} \tab This action deletes an Amazon S3 on Outposts bucket's lifecycle configuration\cr
#'  \link[paws.storage:s3control_delete_bucket_policy]{delete_bucket_policy} \tab This action deletes an Amazon S3 on Outposts bucket policy\cr
#'  \link[paws.storage:s3control_delete_bucket_replication]{delete_bucket_replication} \tab This operation deletes an Amazon S3 on Outposts bucket's replication configuration\cr
#'  \link[paws.storage:s3control_delete_bucket_tagging]{delete_bucket_tagging} \tab This action deletes an Amazon S3 on Outposts bucket's tags\cr
#'  \link[paws.storage:s3control_delete_job_tagging]{delete_job_tagging} \tab Removes the entire tag set from the specified S3 Batch Operations job\cr
#'  \link[paws.storage:s3control_delete_multi_region_access_point]{delete_multi_region_access_point} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_delete_public_access_block]{delete_public_access_block} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_delete_storage_lens_configuration]{delete_storage_lens_configuration} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_delete_storage_lens_configuration_tagging]{delete_storage_lens_configuration_tagging} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_delete_storage_lens_group]{delete_storage_lens_group} \tab Deletes an existing S3 Storage Lens group\cr
#'  \link[paws.storage:s3control_describe_job]{describe_job} \tab Retrieves the configuration parameters and status for a Batch Operations job\cr
#'  \link[paws.storage:s3control_describe_multi_region_access_point_operation]{describe_multi_region_access_point_operation} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_dissociate_access_grants_identity_center]{dissociate_access_grants_identity_center} \tab Dissociates the Amazon Web Services IAM Identity Center instance from the S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_get_access_grant]{get_access_grant} \tab Get the details of an access grant from your S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_get_access_grants_instance]{get_access_grants_instance} \tab Retrieves the S3 Access Grants instance for a Region in your account\cr
#'  \link[paws.storage:s3control_get_access_grants_instance_for_prefix]{get_access_grants_instance_for_prefix} \tab Retrieve the S3 Access Grants instance that contains a particular prefix\cr
#'  \link[paws.storage:s3control_get_access_grants_instance_resource_policy]{get_access_grants_instance_resource_policy} \tab Returns the resource policy of the S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_get_access_grants_location]{get_access_grants_location} \tab Retrieves the details of a particular location registered in your S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_get_access_point]{get_access_point} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_access_point_configuration_for_object_lambda]{get_access_point_configuration_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_access_point_for_object_lambda]{get_access_point_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_access_point_policy]{get_access_point_policy} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_access_point_policy_for_object_lambda]{get_access_point_policy_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_access_point_policy_status]{get_access_point_policy_status} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_access_point_policy_status_for_object_lambda]{get_access_point_policy_status_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_bucket]{get_bucket} \tab Gets an Amazon S3 on Outposts bucket\cr
#'  \link[paws.storage:s3control_get_bucket_lifecycle_configuration]{get_bucket_lifecycle_configuration} \tab This action gets an Amazon S3 on Outposts bucket's lifecycle configuration\cr
#'  \link[paws.storage:s3control_get_bucket_policy]{get_bucket_policy} \tab This action gets a bucket policy for an Amazon S3 on Outposts bucket\cr
#'  \link[paws.storage:s3control_get_bucket_replication]{get_bucket_replication} \tab This operation gets an Amazon S3 on Outposts bucket's replication configuration\cr
#'  \link[paws.storage:s3control_get_bucket_tagging]{get_bucket_tagging} \tab This action gets an Amazon S3 on Outposts bucket's tags\cr
#'  \link[paws.storage:s3control_get_bucket_versioning]{get_bucket_versioning} \tab This operation returns the versioning state for S3 on Outposts buckets only\cr
#'  \link[paws.storage:s3control_get_data_access]{get_data_access} \tab Returns a temporary access credential from S3 Access Grants to the grantee or client application\cr
#'  \link[paws.storage:s3control_get_job_tagging]{get_job_tagging} \tab Returns the tags on an S3 Batch Operations job\cr
#'  \link[paws.storage:s3control_get_multi_region_access_point]{get_multi_region_access_point} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_multi_region_access_point_policy]{get_multi_region_access_point_policy} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_multi_region_access_point_policy_status]{get_multi_region_access_point_policy_status} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_multi_region_access_point_routes]{get_multi_region_access_point_routes} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_public_access_block]{get_public_access_block} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_storage_lens_configuration]{get_storage_lens_configuration} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_storage_lens_configuration_tagging]{get_storage_lens_configuration_tagging} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_get_storage_lens_group]{get_storage_lens_group} \tab Retrieves the Storage Lens group configuration details\cr
#'  \link[paws.storage:s3control_list_access_grants]{list_access_grants} \tab Returns the list of access grants in your S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_list_access_grants_instances]{list_access_grants_instances} \tab Returns a list of S3 Access Grants instances\cr
#'  \link[paws.storage:s3control_list_access_grants_locations]{list_access_grants_locations} \tab Returns a list of the locations registered in your S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_list_access_points]{list_access_points} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_list_access_points_for_object_lambda]{list_access_points_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_list_caller_access_grants]{list_caller_access_grants} \tab Use this API to list the access grants that grant the caller access to Amazon S3 data through S3 Access Grants\cr
#'  \link[paws.storage:s3control_list_jobs]{list_jobs} \tab Lists current S3 Batch Operations jobs as well as the jobs that have ended within the last 90 days for the Amazon Web Services account making the request\cr
#'  \link[paws.storage:s3control_list_multi_region_access_points]{list_multi_region_access_points} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_list_regional_buckets]{list_regional_buckets} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_list_storage_lens_configurations]{list_storage_lens_configurations} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_list_storage_lens_groups]{list_storage_lens_groups} \tab Lists all the Storage Lens groups in the specified home Region\cr
#'  \link[paws.storage:s3control_list_tags_for_resource]{list_tags_for_resource} \tab This operation allows you to list all the Amazon Web Services resource tags for a specified resource\cr
#'  \link[paws.storage:s3control_put_access_grants_instance_resource_policy]{put_access_grants_instance_resource_policy} \tab Updates the resource policy of the S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_put_access_point_configuration_for_object_lambda]{put_access_point_configuration_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_put_access_point_policy]{put_access_point_policy} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_put_access_point_policy_for_object_lambda]{put_access_point_policy_for_object_lambda} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_put_bucket_lifecycle_configuration]{put_bucket_lifecycle_configuration} \tab This action puts a lifecycle configuration to an Amazon S3 on Outposts bucket\cr
#'  \link[paws.storage:s3control_put_bucket_policy]{put_bucket_policy} \tab This action puts a bucket policy to an Amazon S3 on Outposts bucket\cr
#'  \link[paws.storage:s3control_put_bucket_replication]{put_bucket_replication} \tab This action creates an Amazon S3 on Outposts bucket's replication configuration\cr
#'  \link[paws.storage:s3control_put_bucket_tagging]{put_bucket_tagging} \tab This action puts tags on an Amazon S3 on Outposts bucket\cr
#'  \link[paws.storage:s3control_put_bucket_versioning]{put_bucket_versioning} \tab This operation sets the versioning state for S3 on Outposts buckets only\cr
#'  \link[paws.storage:s3control_put_job_tagging]{put_job_tagging} \tab Sets the supplied tag-set on an S3 Batch Operations job\cr
#'  \link[paws.storage:s3control_put_multi_region_access_point_policy]{put_multi_region_access_point_policy} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_put_public_access_block]{put_public_access_block} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_put_storage_lens_configuration]{put_storage_lens_configuration} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_put_storage_lens_configuration_tagging]{put_storage_lens_configuration_tagging} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_submit_multi_region_access_point_routes]{submit_multi_region_access_point_routes} \tab This operation is not supported by directory buckets\cr
#'  \link[paws.storage:s3control_tag_resource]{tag_resource} \tab Creates a new Amazon Web Services resource tag or updates an existing resource tag\cr
#'  \link[paws.storage:s3control_untag_resource]{untag_resource} \tab This operation removes the specified Amazon Web Services resource tags from an S3 resource\cr
#'  \link[paws.storage:s3control_update_access_grants_location]{update_access_grants_location} \tab Updates the IAM role of a registered location in your S3 Access Grants instance\cr
#'  \link[paws.storage:s3control_update_job_priority]{update_job_priority} \tab Updates an existing S3 Batch Operations job's priority\cr
#'  \link[paws.storage:s3control_update_job_status]{update_job_status} \tab Updates the status for the specified job\cr
#'  \link[paws.storage:s3control_update_storage_lens_group]{update_storage_lens_group} \tab Updates the existing Storage Lens group
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname s3control
#' @export
s3control <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::s3control(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon S3 on Outposts
#'
#' @description
#' Amazon S3 on Outposts provides access to S3 on Outposts operations.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- s3outposts(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- s3outposts()
#' svc$create_endpoint(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:s3outposts_create_endpoint]{create_endpoint} \tab Creates an endpoint and associates it with the specified Outpost\cr
#'  \link[paws.storage:s3outposts_delete_endpoint]{delete_endpoint} \tab Deletes an endpoint\cr
#'  \link[paws.storage:s3outposts_list_endpoints]{list_endpoints} \tab Lists endpoints associated with the specified Outpost\cr
#'  \link[paws.storage:s3outposts_list_outposts_with_s3]{list_outposts_with_s3} \tab Lists the Outposts with S3 on Outposts capacity for your Amazon Web Services account\cr
#'  \link[paws.storage:s3outposts_list_shared_endpoints]{list_shared_endpoints} \tab Lists all endpoints associated with an Outpost that has been shared by Amazon Web Services Resource Access Manager (RAM)
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname s3outposts
#' @export
s3outposts <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::s3outposts(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon S3 Tables
#'
#' @description
#' An Amazon S3 table represents a structured dataset consisting of tabular
#' data in [Apache Parquet](https://parquet.apache.org/docs/) format and
#' related metadata. This data is stored inside an S3 table as a
#' subresource. All tables in a table bucket are stored in the [Apache
#' Iceberg](https://iceberg.apache.org/docs/latest/) table format. Through
#' integration with the AWS Glue Data Catalog you can interact with your
#' tables using AWS analytics services, such as Amazon Athena and Amazon
#' Redshift. Amazon S3 manages maintenance of your tables through automatic
#' file compaction and snapshot management. For more information, see
#' [Amazon S3 table
#' buckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/s3-tables-buckets.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- s3tables(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- s3tables()
#' svc$create_namespace(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:s3tables_create_namespace]{create_namespace} \tab Creates a namespace\cr
#'  \link[paws.storage:s3tables_create_table]{create_table} \tab Creates a new table associated with the given namespace in a table bucket\cr
#'  \link[paws.storage:s3tables_create_table_bucket]{create_table_bucket} \tab Creates a table bucket\cr
#'  \link[paws.storage:s3tables_delete_namespace]{delete_namespace} \tab Deletes a namespace\cr
#'  \link[paws.storage:s3tables_delete_table]{delete_table} \tab Deletes a table\cr
#'  \link[paws.storage:s3tables_delete_table_bucket]{delete_table_bucket} \tab Deletes a table bucket\cr
#'  \link[paws.storage:s3tables_delete_table_bucket_policy]{delete_table_bucket_policy} \tab Deletes a table bucket policy\cr
#'  \link[paws.storage:s3tables_delete_table_policy]{delete_table_policy} \tab Deletes a table policy\cr
#'  \link[paws.storage:s3tables_get_namespace]{get_namespace} \tab Gets details about a namespace\cr
#'  \link[paws.storage:s3tables_get_table]{get_table} \tab Gets details about a table\cr
#'  \link[paws.storage:s3tables_get_table_bucket]{get_table_bucket} \tab Gets details on a table bucket\cr
#'  \link[paws.storage:s3tables_get_table_bucket_maintenance_configuration]{get_table_bucket_maintenance_configuration} \tab Gets details about a maintenance configuration for a given table bucket\cr
#'  \link[paws.storage:s3tables_get_table_bucket_policy]{get_table_bucket_policy} \tab Gets details about a table bucket policy\cr
#'  \link[paws.storage:s3tables_get_table_maintenance_configuration]{get_table_maintenance_configuration} \tab Gets details about the maintenance configuration of a table\cr
#'  \link[paws.storage:s3tables_get_table_maintenance_job_status]{get_table_maintenance_job_status} \tab Gets the status of a maintenance job for a table\cr
#'  \link[paws.storage:s3tables_get_table_metadata_location]{get_table_metadata_location} \tab Gets the location of the table metadata\cr
#'  \link[paws.storage:s3tables_get_table_policy]{get_table_policy} \tab Gets details about a table policy\cr
#'  \link[paws.storage:s3tables_list_namespaces]{list_namespaces} \tab Lists the namespaces within a table bucket\cr
#'  \link[paws.storage:s3tables_list_table_buckets]{list_table_buckets} \tab Lists table buckets for your account\cr
#'  \link[paws.storage:s3tables_list_tables]{list_tables} \tab List tables in the given table bucket\cr
#'  \link[paws.storage:s3tables_put_table_bucket_maintenance_configuration]{put_table_bucket_maintenance_configuration} \tab Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket\cr
#'  \link[paws.storage:s3tables_put_table_bucket_policy]{put_table_bucket_policy} \tab Creates a new maintenance configuration or replaces an existing table bucket policy for a table bucket\cr
#'  \link[paws.storage:s3tables_put_table_maintenance_configuration]{put_table_maintenance_configuration} \tab Creates a new maintenance configuration or replaces an existing maintenance configuration for a table\cr
#'  \link[paws.storage:s3tables_put_table_policy]{put_table_policy} \tab Creates a new maintenance configuration or replaces an existing table policy for a table\cr
#'  \link[paws.storage:s3tables_rename_table]{rename_table} \tab Renames a table or a namespace\cr
#'  \link[paws.storage:s3tables_update_table_metadata_location]{update_table_metadata_location} \tab Updates the metadata location for a table
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname s3tables
#' @export
s3tables <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::s3tables(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Storage Gateway
#'
#' @description
#' Storage Gateway Service
#' 
#' Amazon FSx File Gateway is no longer available to new customers.
#' Existing customers of FSx File Gateway can continue to use the service
#' normally. For capabilities similar to FSx File Gateway, visit [this blog
#' post](https://aws.amazon.com/blogs/storage/switch-your-file-share-access-from-amazon-fsx-file-gateway-to-amazon-fsx-for-windows-file-server/).
#' 
#' Storage Gateway is the service that connects an on-premises software
#' appliance with cloud-based storage to provide seamless and secure
#' integration between an organization's on-premises IT environment and the
#' Amazon Web Services storage infrastructure. The service enables you to
#' securely upload data to the Amazon Web Services Cloud for cost effective
#' backup and rapid disaster recovery.
#' 
#' Use the following links to get started using the *Storage Gateway
#' Service API Reference*:
#' 
#' -   [Storage Gateway required request
#'     headers](https://docs.aws.amazon.com/storagegateway/#AWSStorageGatewayHTTPRequestsHeaders):
#'     Describes the required headers that you must send with every POST
#'     request to Storage Gateway.
#' 
#' -   [Signing
#'     requests](https://docs.aws.amazon.com/storagegateway/#AWSStorageGatewaySigningRequests):
#'     Storage Gateway requires that you authenticate every request you
#'     send; this topic describes how sign such a request.
#' 
#' -   [Error
#'     responses](https://docs.aws.amazon.com/storagegateway/#APIErrorResponses):
#'     Provides reference information about Storage Gateway errors.
#' 
#' -   [Operations in Storage
#'     Gateway](https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_Operations.html):
#'     Contains detailed descriptions of all Storage Gateway operations,
#'     their request parameters, response elements, possible errors, and
#'     examples of requests and responses.
#' 
#' -   [Storage Gateway endpoints and
#'     quotas](https://docs.aws.amazon.com/general/latest/gr/sg.html):
#'     Provides a list of each Amazon Web Services Region and the endpoints
#'     available for use with Storage Gateway.
#' 
#' Storage Gateway resource IDs are in uppercase. When you use these
#' resource IDs with the Amazon EC2 API, EC2 expects resource IDs in
#' lowercase. You must change your resource ID to lowercase to use it with
#' the EC2 API. For example, in Storage Gateway the ID for a volume might
#' be `vol-AA22BB012345DAF670`. When you use this ID with the EC2 API, you
#' must change it to `vol-aa22bb012345daf670`. Otherwise, the EC2 API might
#' not behave as expected.
#' 
#' IDs for Storage Gateway volumes and Amazon EBS snapshots created from
#' gateway volumes are changing to a longer format. Starting in December
#' 2016, all new volumes and snapshots will be created with a 17-character
#' string. Starting in April 2016, you will be able to use these longer IDs
#' so you can test your systems with the new format. For more information,
#' see [Longer EC2 and EBS resource
#' IDs](https://aws.amazon.com/ec2/faqs/#longer-ids).
#' 
#' For example, a volume Amazon Resource Name (ARN) with the longer volume
#' ID format looks like the following:
#' 
#' `arn:aws:storagegateway:us-west-2:111122223333:gateway/sgw-12A3456B/volume/vol-1122AABBCCDDEEFFG`.
#' 
#' A snapshot ID with the longer ID format looks like the following:
#' `snap-78e226633445566ee`.
#' 
#' For more information, see Announcement: Heads-up – Longer Storage
#' Gateway volume and snapshot IDs coming in 2016.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- storagegateway(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- storagegateway()
#' # Activates the gateway you previously deployed on your host.
#' svc$activate_gateway(
#'   ActivationKey = "29AV1-3OFV9-VVIUB-NKT0I-LRO6V",
#'   GatewayName = "My_Gateway",
#'   GatewayRegion = "us-east-1",
#'   GatewayTimezone = "GMT-12:00",
#'   GatewayType = "STORED",
#'   MediumChangerType = "AWS-Gateway-VTL",
#'   TapeDriveType = "IBM-ULT3580-TD5"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.storage:storagegateway_activate_gateway]{activate_gateway} \tab Activates the gateway you previously deployed on your host\cr
#'  \link[paws.storage:storagegateway_add_cache]{add_cache} \tab Configures one or more gateway local disks as cache for a gateway\cr
#'  \link[paws.storage:storagegateway_add_tags_to_resource]{add_tags_to_resource} \tab Adds one or more tags to the specified resource\cr
#'  \link[paws.storage:storagegateway_add_upload_buffer]{add_upload_buffer} \tab Configures one or more gateway local disks as upload buffer for a specified gateway\cr
#'  \link[paws.storage:storagegateway_add_working_storage]{add_working_storage} \tab Configures one or more gateway local disks as working storage for a gateway\cr
#'  \link[paws.storage:storagegateway_assign_tape_pool]{assign_tape_pool} \tab Assigns a tape to a tape pool for archiving\cr
#'  \link[paws.storage:storagegateway_associate_file_system]{associate_file_system} \tab Associate an Amazon FSx file system with the FSx File Gateway\cr
#'  \link[paws.storage:storagegateway_attach_volume]{attach_volume} \tab Connects a volume to an iSCSI connection and then attaches the volume to the specified gateway\cr
#'  \link[paws.storage:storagegateway_cancel_archival]{cancel_archival} \tab Cancels archiving of a virtual tape to the virtual tape shelf (VTS) after the archiving process is initiated\cr
#'  \link[paws.storage:storagegateway_cancel_cache_report]{cancel_cache_report} \tab Cancels generation of a specified cache report\cr
#'  \link[paws.storage:storagegateway_cancel_retrieval]{cancel_retrieval} \tab Cancels retrieval of a virtual tape from the virtual tape shelf (VTS) to a gateway after the retrieval process is initiated\cr
#'  \link[paws.storage:storagegateway_create_cachedi_scsi_volume]{create_cachedi_scsi_volume} \tab Creates a cached volume on a specified cached volume gateway\cr
#'  \link[paws.storage:storagegateway_create_nfs_file_share]{create_nfs_file_share} \tab Creates a Network File System (NFS) file share on an existing S3 File Gateway\cr
#'  \link[paws.storage:storagegateway_create_smb_file_share]{create_smb_file_share} \tab Creates a Server Message Block (SMB) file share on an existing S3 File Gateway\cr
#'  \link[paws.storage:storagegateway_create_snapshot]{create_snapshot} \tab Initiates a snapshot of a volume\cr
#'  \link[paws.storage:storagegateway_create_snapshot_from_volume_recovery_point]{create_snapshot_from_volume_recovery_point} \tab Initiates a snapshot of a gateway from a volume recovery point\cr
#'  \link[paws.storage:storagegateway_create_storedi_scsi_volume]{create_storedi_scsi_volume} \tab Creates a volume on a specified gateway\cr
#'  \link[paws.storage:storagegateway_create_tape_pool]{create_tape_pool} \tab Creates a new custom tape pool\cr
#'  \link[paws.storage:storagegateway_create_tapes]{create_tapes} \tab Creates one or more virtual tapes\cr
#'  \link[paws.storage:storagegateway_create_tape_with_barcode]{create_tape_with_barcode} \tab Creates a virtual tape by using your own barcode\cr
#'  \link[paws.storage:storagegateway_delete_automatic_tape_creation_policy]{delete_automatic_tape_creation_policy} \tab Deletes the automatic tape creation policy of a gateway\cr
#'  \link[paws.storage:storagegateway_delete_bandwidth_rate_limit]{delete_bandwidth_rate_limit} \tab Deletes the bandwidth rate limits of a gateway\cr
#'  \link[paws.storage:storagegateway_delete_cache_report]{delete_cache_report} \tab Deletes the specified cache report and any associated tags from the Storage Gateway database\cr
#'  \link[paws.storage:storagegateway_delete_chap_credentials]{delete_chap_credentials} \tab Deletes Challenge-Handshake Authentication Protocol (CHAP) credentials for a specified iSCSI target and initiator pair\cr
#'  \link[paws.storage:storagegateway_delete_file_share]{delete_file_share} \tab Deletes a file share from an S3 File Gateway\cr
#'  \link[paws.storage:storagegateway_delete_gateway]{delete_gateway} \tab Deletes a gateway\cr
#'  \link[paws.storage:storagegateway_delete_snapshot_schedule]{delete_snapshot_schedule} \tab Deletes a snapshot of a volume\cr
#'  \link[paws.storage:storagegateway_delete_tape]{delete_tape} \tab Deletes the specified virtual tape\cr
#'  \link[paws.storage:storagegateway_delete_tape_archive]{delete_tape_archive} \tab Deletes the specified virtual tape from the virtual tape shelf (VTS)\cr
#'  \link[paws.storage:storagegateway_delete_tape_pool]{delete_tape_pool} \tab Delete a custom tape pool\cr
#'  \link[paws.storage:storagegateway_delete_volume]{delete_volume} \tab Deletes the specified storage volume that you previously created using the CreateCachediSCSIVolume or CreateStorediSCSIVolume API\cr
#'  \link[paws.storage:storagegateway_describe_availability_monitor_test]{describe_availability_monitor_test} \tab Returns information about the most recent high availability monitoring test that was performed on the host in a cluster\cr
#'  \link[paws.storage:storagegateway_describe_bandwidth_rate_limit]{describe_bandwidth_rate_limit} \tab Returns the bandwidth rate limits of a gateway\cr
#'  \link[paws.storage:storagegateway_describe_bandwidth_rate_limit_schedule]{describe_bandwidth_rate_limit_schedule} \tab Returns information about the bandwidth rate limit schedule of a gateway\cr
#'  \link[paws.storage:storagegateway_describe_cache]{describe_cache} \tab Returns information about the cache of a gateway\cr
#'  \link[paws.storage:storagegateway_describe_cachedi_scsi_volumes]{describe_cachedi_scsi_volumes} \tab Returns a description of the gateway volumes specified in the request\cr
#'  \link[paws.storage:storagegateway_describe_cache_report]{describe_cache_report} \tab Returns information about the specified cache report, including completion status and generation progress\cr
#'  \link[paws.storage:storagegateway_describe_chap_credentials]{describe_chap_credentials} \tab Returns an array of Challenge-Handshake Authentication Protocol (CHAP) credentials information for a specified iSCSI target, one for each target-initiator pair\cr
#'  \link[paws.storage:storagegateway_describe_file_system_associations]{describe_file_system_associations} \tab Gets the file system association information\cr
#'  \link[paws.storage:storagegateway_describe_gateway_information]{describe_gateway_information} \tab Returns metadata about a gateway such as its name, network interfaces, time zone, status, and software version\cr
#'  \link[paws.storage:storagegateway_describe_maintenance_start_time]{describe_maintenance_start_time} \tab Returns your gateway's maintenance window schedule information, with values for monthly or weekly cadence, specific day and time to begin maintenance, and which types of updates to apply\cr
#'  \link[paws.storage:storagegateway_describe_nfs_file_shares]{describe_nfs_file_shares} \tab Gets a description for one or more Network File System (NFS) file shares from an S3 File Gateway\cr
#'  \link[paws.storage:storagegateway_describe_smb_file_shares]{describe_smb_file_shares} \tab Gets a description for one or more Server Message Block (SMB) file shares from a S3 File Gateway\cr
#'  \link[paws.storage:storagegateway_describe_smb_settings]{describe_smb_settings} \tab Gets a description of a Server Message Block (SMB) file share settings from a file gateway\cr
#'  \link[paws.storage:storagegateway_describe_snapshot_schedule]{describe_snapshot_schedule} \tab Describes the snapshot schedule for the specified gateway volume\cr
#'  \link[paws.storage:storagegateway_describe_storedi_scsi_volumes]{describe_storedi_scsi_volumes} \tab Returns the description of the gateway volumes specified in the request\cr
#'  \link[paws.storage:storagegateway_describe_tape_archives]{describe_tape_archives} \tab Returns a description of specified virtual tapes in the virtual tape shelf (VTS)\cr
#'  \link[paws.storage:storagegateway_describe_tape_recovery_points]{describe_tape_recovery_points} \tab Returns a list of virtual tape recovery points that are available for the specified tape gateway\cr
#'  \link[paws.storage:storagegateway_describe_tapes]{describe_tapes} \tab Returns a description of virtual tapes that correspond to the specified Amazon Resource Names (ARNs)\cr
#'  \link[paws.storage:storagegateway_describe_upload_buffer]{describe_upload_buffer} \tab Returns information about the upload buffer of a gateway\cr
#'  \link[paws.storage:storagegateway_describe_vtl_devices]{describe_vtl_devices} \tab Returns a description of virtual tape library (VTL) devices for the specified tape gateway\cr
#'  \link[paws.storage:storagegateway_describe_working_storage]{describe_working_storage} \tab Returns information about the working storage of a gateway\cr
#'  \link[paws.storage:storagegateway_detach_volume]{detach_volume} \tab Disconnects a volume from an iSCSI connection and then detaches the volume from the specified gateway\cr
#'  \link[paws.storage:storagegateway_disable_gateway]{disable_gateway} \tab Disables a tape gateway when the gateway is no longer functioning\cr
#'  \link[paws.storage:storagegateway_disassociate_file_system]{disassociate_file_system} \tab Disassociates an Amazon FSx file system from the specified gateway\cr
#'  \link[paws.storage:storagegateway_join_domain]{join_domain} \tab Adds a file gateway to an Active Directory domain\cr
#'  \link[paws.storage:storagegateway_list_automatic_tape_creation_policies]{list_automatic_tape_creation_policies} \tab Lists the automatic tape creation policies for a gateway\cr
#'  \link[paws.storage:storagegateway_list_cache_reports]{list_cache_reports} \tab Returns a list of existing cache reports for all file shares associated with your Amazon Web Services account\cr
#'  \link[paws.storage:storagegateway_list_file_shares]{list_file_shares} \tab Gets a list of the file shares for a specific S3 File Gateway, or the list of file shares that belong to the calling Amazon Web Services account\cr
#'  \link[paws.storage:storagegateway_list_file_system_associations]{list_file_system_associations} \tab Gets a list of FileSystemAssociationSummary objects\cr
#'  \link[paws.storage:storagegateway_list_gateways]{list_gateways} \tab Lists gateways owned by an Amazon Web Services account in an Amazon Web Services Region specified in the request\cr
#'  \link[paws.storage:storagegateway_list_local_disks]{list_local_disks} \tab Returns a list of the gateway's local disks\cr
#'  \link[paws.storage:storagegateway_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that have been added to the specified resource\cr
#'  \link[paws.storage:storagegateway_list_tape_pools]{list_tape_pools} \tab Lists custom tape pools\cr
#'  \link[paws.storage:storagegateway_list_tapes]{list_tapes} \tab Lists virtual tapes in your virtual tape library (VTL) and your virtual tape shelf (VTS)\cr
#'  \link[paws.storage:storagegateway_list_volume_initiators]{list_volume_initiators} \tab Lists iSCSI initiators that are connected to a volume\cr
#'  \link[paws.storage:storagegateway_list_volume_recovery_points]{list_volume_recovery_points} \tab Lists the recovery points for a specified gateway\cr
#'  \link[paws.storage:storagegateway_list_volumes]{list_volumes} \tab Lists the iSCSI stored volumes of a gateway\cr
#'  \link[paws.storage:storagegateway_notify_when_uploaded]{notify_when_uploaded} \tab Sends you notification through Amazon EventBridge when all files written to your file share have been uploaded to Amazon S3\cr
#'  \link[paws.storage:storagegateway_refresh_cache]{refresh_cache} \tab Refreshes the cached inventory of objects for the specified file share\cr
#'  \link[paws.storage:storagegateway_remove_tags_from_resource]{remove_tags_from_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.storage:storagegateway_reset_cache]{reset_cache} \tab Resets all cache disks that have encountered an error and makes the disks available for reconfiguration as cache storage\cr
#'  \link[paws.storage:storagegateway_retrieve_tape_archive]{retrieve_tape_archive} \tab Retrieves an archived virtual tape from the virtual tape shelf (VTS) to a tape gateway\cr
#'  \link[paws.storage:storagegateway_retrieve_tape_recovery_point]{retrieve_tape_recovery_point} \tab Retrieves the recovery point for the specified virtual tape\cr
#'  \link[paws.storage:storagegateway_set_local_console_password]{set_local_console_password} \tab Sets the password for your VM local console\cr
#'  \link[paws.storage:storagegateway_set_smb_guest_password]{set_smb_guest_password} \tab Sets the password for the guest user smbguest\cr
#'  \link[paws.storage:storagegateway_shutdown_gateway]{shutdown_gateway} \tab Shuts down a Tape Gateway or Volume Gateway\cr
#'  \link[paws.storage:storagegateway_start_availability_monitor_test]{start_availability_monitor_test} \tab Start a test that verifies that the specified gateway is configured for High Availability monitoring in your host environment\cr
#'  \link[paws.storage:storagegateway_start_cache_report]{start_cache_report} \tab Starts generating a report of the file metadata currently cached by an S3 File Gateway for a specific file share\cr
#'  \link[paws.storage:storagegateway_start_gateway]{start_gateway} \tab Starts a gateway that you previously shut down (see ShutdownGateway)\cr
#'  \link[paws.storage:storagegateway_update_automatic_tape_creation_policy]{update_automatic_tape_creation_policy} \tab Updates the automatic tape creation policy of a gateway\cr
#'  \link[paws.storage:storagegateway_update_bandwidth_rate_limit]{update_bandwidth_rate_limit} \tab Updates the bandwidth rate limits of a gateway\cr
#'  \link[paws.storage:storagegateway_update_bandwidth_rate_limit_schedule]{update_bandwidth_rate_limit_schedule} \tab Updates the bandwidth rate limit schedule for a specified gateway\cr
#'  \link[paws.storage:storagegateway_update_chap_credentials]{update_chap_credentials} \tab Updates the Challenge-Handshake Authentication Protocol (CHAP) credentials for a specified iSCSI target\cr
#'  \link[paws.storage:storagegateway_update_file_system_association]{update_file_system_association} \tab Updates a file system association\cr
#'  \link[paws.storage:storagegateway_update_gateway_information]{update_gateway_information} \tab Updates a gateway's metadata, which includes the gateway's name, time zone, and metadata cache size\cr
#'  \link[paws.storage:storagegateway_update_gateway_software_now]{update_gateway_software_now} \tab Updates the gateway virtual machine (VM) software\cr
#'  \link[paws.storage:storagegateway_update_maintenance_start_time]{update_maintenance_start_time} \tab Updates a gateway's maintenance window schedule, with settings for monthly or weekly cadence, specific day and time to begin maintenance, and which types of updates to apply\cr
#'  \link[paws.storage:storagegateway_update_nfs_file_share]{update_nfs_file_share} \tab Updates a Network File System (NFS) file share\cr
#'  \link[paws.storage:storagegateway_update_smb_file_share]{update_smb_file_share} \tab Updates a Server Message Block (SMB) file share\cr
#'  \link[paws.storage:storagegateway_update_smb_file_share_visibility]{update_smb_file_share_visibility} \tab Controls whether the shares on an S3 File Gateway are visible in a net view or browse list\cr
#'  \link[paws.storage:storagegateway_update_smb_local_groups]{update_smb_local_groups} \tab Updates the list of Active Directory users and groups that have special permissions for SMB file shares on the gateway\cr
#'  \link[paws.storage:storagegateway_update_smb_security_strategy]{update_smb_security_strategy} \tab Updates the SMB security strategy level for an Amazon S3 file gateway\cr
#'  \link[paws.storage:storagegateway_update_snapshot_schedule]{update_snapshot_schedule} \tab Updates a snapshot schedule configured for a gateway volume\cr
#'  \link[paws.storage:storagegateway_update_vtl_device_type]{update_vtl_device_type} \tab Updates the type of medium changer in a tape gateway
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname storagegateway
#' @export
storagegateway <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.storage::storagegateway(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon DynamoDB Accelerator (DAX)
#'
#' @description
#' DAX is a managed caching service engineered for Amazon DynamoDB. DAX
#' dramatically speeds up database reads by caching frequently-accessed
#' data from DynamoDB, so applications can access that data with
#' sub-millisecond latency. You can create a DAX cluster easily, using the
#' AWS Management Console. With a few simple modifications to your code,
#' your application can begin taking advantage of the DAX cluster and
#' realize significant improvements in read performance.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- dax(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- dax()
#' svc$create_cluster(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:dax_create_cluster]{create_cluster} \tab Creates a DAX cluster\cr
#'  \link[paws.database:dax_create_parameter_group]{create_parameter_group} \tab Creates a new parameter group\cr
#'  \link[paws.database:dax_create_subnet_group]{create_subnet_group} \tab Creates a new subnet group\cr
#'  \link[paws.database:dax_decrease_replication_factor]{decrease_replication_factor} \tab Removes one or more nodes from a DAX cluster\cr
#'  \link[paws.database:dax_delete_cluster]{delete_cluster} \tab Deletes a previously provisioned DAX cluster\cr
#'  \link[paws.database:dax_delete_parameter_group]{delete_parameter_group} \tab Deletes the specified parameter group\cr
#'  \link[paws.database:dax_delete_subnet_group]{delete_subnet_group} \tab Deletes a subnet group\cr
#'  \link[paws.database:dax_describe_clusters]{describe_clusters} \tab Returns information about all provisioned DAX clusters if no cluster identifier is specified, or about a specific DAX cluster if a cluster identifier is supplied\cr
#'  \link[paws.database:dax_describe_default_parameters]{describe_default_parameters} \tab Returns the default system parameter information for the DAX caching software\cr
#'  \link[paws.database:dax_describe_events]{describe_events} \tab Returns events related to DAX clusters and parameter groups\cr
#'  \link[paws.database:dax_describe_parameter_groups]{describe_parameter_groups} \tab Returns a list of parameter group descriptions\cr
#'  \link[paws.database:dax_describe_parameters]{describe_parameters} \tab Returns the detailed parameter list for a particular parameter group\cr
#'  \link[paws.database:dax_describe_subnet_groups]{describe_subnet_groups} \tab Returns a list of subnet group descriptions\cr
#'  \link[paws.database:dax_increase_replication_factor]{increase_replication_factor} \tab Adds one or more nodes to a DAX cluster\cr
#'  \link[paws.database:dax_list_tags]{list_tags} \tab List all of the tags for a DAX cluster\cr
#'  \link[paws.database:dax_reboot_node]{reboot_node} \tab Reboots a single node of a DAX cluster\cr
#'  \link[paws.database:dax_tag_resource]{tag_resource} \tab Associates a set of tags with a DAX resource\cr
#'  \link[paws.database:dax_untag_resource]{untag_resource} \tab Removes the association of tags from a DAX resource\cr
#'  \link[paws.database:dax_update_cluster]{update_cluster} \tab Modifies the settings for a DAX cluster\cr
#'  \link[paws.database:dax_update_parameter_group]{update_parameter_group} \tab Modifies the parameters of a parameter group\cr
#'  \link[paws.database:dax_update_subnet_group]{update_subnet_group} \tab Modifies an existing subnet group
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname dax
#' @export
dax <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::dax(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon DocumentDB with MongoDB compatibility
#'
#' @description
#' Amazon DocumentDB is a fast, reliable, and fully managed database
#' service. Amazon DocumentDB makes it easy to set up, operate, and scale
#' MongoDB-compatible databases in the cloud. With Amazon DocumentDB, you
#' can run the same application code and use the same drivers and tools
#' that you use with MongoDB.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- docdb(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- docdb()
#' svc$add_source_identifier_to_subscription(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:docdb_add_source_identifier_to_subscription]{add_source_identifier_to_subscription} \tab Adds a source identifier to an existing event notification subscription\cr
#'  \link[paws.database:docdb_add_tags_to_resource]{add_tags_to_resource} \tab Adds metadata tags to an Amazon DocumentDB resource\cr
#'  \link[paws.database:docdb_apply_pending_maintenance_action]{apply_pending_maintenance_action} \tab Applies a pending maintenance action to a resource (for example, to an Amazon DocumentDB instance)\cr
#'  \link[paws.database:docdb_copy_db_cluster_parameter_group]{copy_db_cluster_parameter_group} \tab Copies the specified cluster parameter group\cr
#'  \link[paws.database:docdb_copy_db_cluster_snapshot]{copy_db_cluster_snapshot} \tab Copies a snapshot of a cluster\cr
#'  \link[paws.database:docdb_create_db_cluster]{create_db_cluster} \tab Creates a new Amazon DocumentDB cluster\cr
#'  \link[paws.database:docdb_create_db_cluster_parameter_group]{create_db_cluster_parameter_group} \tab Creates a new cluster parameter group\cr
#'  \link[paws.database:docdb_create_db_cluster_snapshot]{create_db_cluster_snapshot} \tab Creates a snapshot of a cluster\cr
#'  \link[paws.database:docdb_create_db_instance]{create_db_instance} \tab Creates a new instance\cr
#'  \link[paws.database:docdb_create_db_subnet_group]{create_db_subnet_group} \tab Creates a new subnet group\cr
#'  \link[paws.database:docdb_create_event_subscription]{create_event_subscription} \tab Creates an Amazon DocumentDB event notification subscription\cr
#'  \link[paws.database:docdb_create_global_cluster]{create_global_cluster} \tab Creates an Amazon DocumentDB global cluster that can span multiple multiple Amazon Web Services Regions\cr
#'  \link[paws.database:docdb_delete_db_cluster]{delete_db_cluster} \tab Deletes a previously provisioned cluster\cr
#'  \link[paws.database:docdb_delete_db_cluster_parameter_group]{delete_db_cluster_parameter_group} \tab Deletes a specified cluster parameter group\cr
#'  \link[paws.database:docdb_delete_db_cluster_snapshot]{delete_db_cluster_snapshot} \tab Deletes a cluster snapshot\cr
#'  \link[paws.database:docdb_delete_db_instance]{delete_db_instance} \tab Deletes a previously provisioned instance\cr
#'  \link[paws.database:docdb_delete_db_subnet_group]{delete_db_subnet_group} \tab Deletes a subnet group\cr
#'  \link[paws.database:docdb_delete_event_subscription]{delete_event_subscription} \tab Deletes an Amazon DocumentDB event notification subscription\cr
#'  \link[paws.database:docdb_delete_global_cluster]{delete_global_cluster} \tab Deletes a global cluster\cr
#'  \link[paws.database:docdb_describe_certificates]{describe_certificates} \tab Returns a list of certificate authority (CA) certificates provided by Amazon DocumentDB for this Amazon Web Services account\cr
#'  \link[paws.database:docdb_describe_db_cluster_parameter_groups]{describe_db_cluster_parameter_groups} \tab Returns a list of DBClusterParameterGroup descriptions\cr
#'  \link[paws.database:docdb_describe_db_cluster_parameters]{describe_db_cluster_parameters} \tab Returns the detailed parameter list for a particular cluster parameter group\cr
#'  \link[paws.database:docdb_describe_db_clusters]{describe_db_clusters} \tab Returns information about provisioned Amazon DocumentDB clusters\cr
#'  \link[paws.database:docdb_describe_db_cluster_snapshot_attributes]{describe_db_cluster_snapshot_attributes} \tab Returns a list of cluster snapshot attribute names and values for a manual DB cluster snapshot\cr
#'  \link[paws.database:docdb_describe_db_cluster_snapshots]{describe_db_cluster_snapshots} \tab Returns information about cluster snapshots\cr
#'  \link[paws.database:docdb_describe_db_engine_versions]{describe_db_engine_versions} \tab Returns a list of the available engines\cr
#'  \link[paws.database:docdb_describe_db_instances]{describe_db_instances} \tab Returns information about provisioned Amazon DocumentDB instances\cr
#'  \link[paws.database:docdb_describe_db_subnet_groups]{describe_db_subnet_groups} \tab Returns a list of DBSubnetGroup descriptions\cr
#'  \link[paws.database:docdb_describe_engine_default_cluster_parameters]{describe_engine_default_cluster_parameters} \tab Returns the default engine and system parameter information for the cluster database engine\cr
#'  \link[paws.database:docdb_describe_event_categories]{describe_event_categories} \tab Displays a list of categories for all event source types, or, if specified, for a specified source type\cr
#'  \link[paws.database:docdb_describe_events]{describe_events} \tab Returns events related to instances, security groups, snapshots, and DB parameter groups for the past 14 days\cr
#'  \link[paws.database:docdb_describe_event_subscriptions]{describe_event_subscriptions} \tab Lists all the subscription descriptions for a customer account\cr
#'  \link[paws.database:docdb_describe_global_clusters]{describe_global_clusters} \tab Returns information about Amazon DocumentDB global clusters\cr
#'  \link[paws.database:docdb_describe_orderable_db_instance_options]{describe_orderable_db_instance_options} \tab Returns a list of orderable instance options for the specified engine\cr
#'  \link[paws.database:docdb_describe_pending_maintenance_actions]{describe_pending_maintenance_actions} \tab Returns a list of resources (for example, instances) that have at least one pending maintenance action\cr
#'  \link[paws.database:docdb_failover_db_cluster]{failover_db_cluster} \tab Forces a failover for a cluster\cr
#'  \link[paws.database:docdb_failover_global_cluster]{failover_global_cluster} \tab Promotes the specified secondary DB cluster to be the primary DB cluster in the global cluster when failing over a global cluster occurs\cr
#'  \link[paws.database:docdb_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags on an Amazon DocumentDB resource\cr
#'  \link[paws.database:docdb_modify_db_cluster]{modify_db_cluster} \tab Modifies a setting for an Amazon DocumentDB cluster\cr
#'  \link[paws.database:docdb_modify_db_cluster_parameter_group]{modify_db_cluster_parameter_group} \tab Modifies the parameters of a cluster parameter group\cr
#'  \link[paws.database:docdb_modify_db_cluster_snapshot_attribute]{modify_db_cluster_snapshot_attribute} \tab Adds an attribute and values to, or removes an attribute and values from, a manual cluster snapshot\cr
#'  \link[paws.database:docdb_modify_db_instance]{modify_db_instance} \tab Modifies settings for an instance\cr
#'  \link[paws.database:docdb_modify_db_subnet_group]{modify_db_subnet_group} \tab Modifies an existing subnet group\cr
#'  \link[paws.database:docdb_modify_event_subscription]{modify_event_subscription} \tab Modifies an existing Amazon DocumentDB event notification subscription\cr
#'  \link[paws.database:docdb_modify_global_cluster]{modify_global_cluster} \tab Modify a setting for an Amazon DocumentDB global cluster\cr
#'  \link[paws.database:docdb_reboot_db_instance]{reboot_db_instance} \tab You might need to reboot your instance, usually for maintenance reasons\cr
#'  \link[paws.database:docdb_remove_from_global_cluster]{remove_from_global_cluster} \tab Detaches an Amazon DocumentDB secondary cluster from a global cluster\cr
#'  \link[paws.database:docdb_remove_source_identifier_from_subscription]{remove_source_identifier_from_subscription} \tab Removes a source identifier from an existing Amazon DocumentDB event notification subscription\cr
#'  \link[paws.database:docdb_remove_tags_from_resource]{remove_tags_from_resource} \tab Removes metadata tags from an Amazon DocumentDB resource\cr
#'  \link[paws.database:docdb_reset_db_cluster_parameter_group]{reset_db_cluster_parameter_group} \tab Modifies the parameters of a cluster parameter group to the default value\cr
#'  \link[paws.database:docdb_restore_db_cluster_from_snapshot]{restore_db_cluster_from_snapshot} \tab Creates a new cluster from a snapshot or cluster snapshot\cr
#'  \link[paws.database:docdb_restore_db_cluster_to_point_in_time]{restore_db_cluster_to_point_in_time} \tab Restores a cluster to an arbitrary point in time\cr
#'  \link[paws.database:docdb_start_db_cluster]{start_db_cluster} \tab Restarts the stopped cluster that is specified by DBClusterIdentifier\cr
#'  \link[paws.database:docdb_stop_db_cluster]{stop_db_cluster} \tab Stops the running cluster that is specified by DBClusterIdentifier\cr
#'  \link[paws.database:docdb_switchover_global_cluster]{switchover_global_cluster} \tab Switches over the specified secondary Amazon DocumentDB cluster to be the new primary Amazon DocumentDB cluster in the global database cluster
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname docdb
#' @export
docdb <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::docdb(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon DocumentDB Elastic Clusters
#'
#' @description
#' Amazon DocumentDB elastic clusters
#' 
#' Amazon DocumentDB elastic-clusters support workloads with millions of
#' reads/writes per second and petabytes of storage capacity. Amazon
#' DocumentDB elastic clusters also simplify how developers interact with
#' Amazon DocumentDB elastic-clusters by eliminating the need to choose,
#' manage or upgrade instances.
#' 
#' Amazon DocumentDB elastic-clusters were created to:
#' 
#' -   provide a solution for customers looking for a database that
#'     provides virtually limitless scale with rich query capabilities and
#'     MongoDB API compatibility.
#' 
#' -   give customers higher connection limits, and to reduce downtime from
#'     patching.
#' 
#' -   continue investing in a cloud-native, elastic, and class leading
#'     architecture for JSON workloads.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- docdbelastic(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- docdbelastic()
#' svc$apply_pending_maintenance_action(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:docdbelastic_apply_pending_maintenance_action]{apply_pending_maintenance_action} \tab The type of pending maintenance action to be applied to the resource\cr
#'  \link[paws.database:docdbelastic_copy_cluster_snapshot]{copy_cluster_snapshot} \tab Copies a snapshot of an elastic cluster\cr
#'  \link[paws.database:docdbelastic_create_cluster]{create_cluster} \tab Creates a new Amazon DocumentDB elastic cluster and returns its cluster structure\cr
#'  \link[paws.database:docdbelastic_create_cluster_snapshot]{create_cluster_snapshot} \tab Creates a snapshot of an elastic cluster\cr
#'  \link[paws.database:docdbelastic_delete_cluster]{delete_cluster} \tab Delete an elastic cluster\cr
#'  \link[paws.database:docdbelastic_delete_cluster_snapshot]{delete_cluster_snapshot} \tab Delete an elastic cluster snapshot\cr
#'  \link[paws.database:docdbelastic_get_cluster]{get_cluster} \tab Returns information about a specific elastic cluster\cr
#'  \link[paws.database:docdbelastic_get_cluster_snapshot]{get_cluster_snapshot} \tab Returns information about a specific elastic cluster snapshot\cr
#'  \link[paws.database:docdbelastic_get_pending_maintenance_action]{get_pending_maintenance_action} \tab Retrieves all maintenance actions that are pending\cr
#'  \link[paws.database:docdbelastic_list_clusters]{list_clusters} \tab Returns information about provisioned Amazon DocumentDB elastic clusters\cr
#'  \link[paws.database:docdbelastic_list_cluster_snapshots]{list_cluster_snapshots} \tab Returns information about snapshots for a specified elastic cluster\cr
#'  \link[paws.database:docdbelastic_list_pending_maintenance_actions]{list_pending_maintenance_actions} \tab Retrieves a list of all maintenance actions that are pending\cr
#'  \link[paws.database:docdbelastic_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags on a elastic cluster resource\cr
#'  \link[paws.database:docdbelastic_restore_cluster_from_snapshot]{restore_cluster_from_snapshot} \tab Restores an elastic cluster from a snapshot\cr
#'  \link[paws.database:docdbelastic_start_cluster]{start_cluster} \tab Restarts the stopped elastic cluster that is specified by clusterARN\cr
#'  \link[paws.database:docdbelastic_stop_cluster]{stop_cluster} \tab Stops the running elastic cluster that is specified by clusterArn\cr
#'  \link[paws.database:docdbelastic_tag_resource]{tag_resource} \tab Adds metadata tags to an elastic cluster resource\cr
#'  \link[paws.database:docdbelastic_untag_resource]{untag_resource} \tab Removes metadata tags from an elastic cluster resource\cr
#'  \link[paws.database:docdbelastic_update_cluster]{update_cluster} \tab Modifies an elastic cluster
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname docdbelastic
#' @export
docdbelastic <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::docdbelastic(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon DynamoDB
#'
#' @description
#' Amazon DynamoDB is a fully managed NoSQL database service that provides
#' fast and predictable performance with seamless scalability. DynamoDB
#' lets you offload the administrative burdens of operating and scaling a
#' distributed database, so that you don't have to worry about hardware
#' provisioning, setup and configuration, replication, software patching,
#' or cluster scaling.
#' 
#' With DynamoDB, you can create database tables that can store and
#' retrieve any amount of data, and serve any level of request traffic. You
#' can scale up or scale down your tables' throughput capacity without
#' downtime or performance degradation, and use the Amazon Web Services
#' Management Console to monitor resource utilization and performance
#' metrics.
#' 
#' DynamoDB automatically spreads the data and traffic for your tables over
#' a sufficient number of servers to handle your throughput and storage
#' requirements, while maintaining consistent and fast performance. All of
#' your data is stored on solid state disks (SSDs) and automatically
#' replicated across multiple Availability Zones in an Amazon Web Services
#' Region, providing built-in high availability and data durability.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- dynamodb(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- dynamodb()
#' # This example reads multiple items from the Music table using a batch of
#' # three GetItem requests.  Only the AlbumTitle attribute is returned.
#' svc$batch_get_item(
#'   RequestItems = list(
#'     Music = list(
#'       Keys = list(
#'         list(
#'           Artist = list(
#'             S = "No One You Know"
#'           ),
#'           SongTitle = list(
#'             S = "Call Me Today"
#'           )
#'         ),
#'         list(
#'           Artist = list(
#'             S = "Acme Band"
#'           ),
#'           SongTitle = list(
#'             S = "Happy Day"
#'           )
#'         ),
#'         list(
#'           Artist = list(
#'             S = "No One You Know"
#'           ),
#'           SongTitle = list(
#'             S = "Scared of My Shadow"
#'           )
#'         )
#'       ),
#'       ProjectionExpression = "AlbumTitle"
#'     )
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:dynamodb_batch_execute_statement]{batch_execute_statement} \tab This operation allows you to perform batch reads or writes on data stored in DynamoDB, using PartiQL\cr
#'  \link[paws.database:dynamodb_batch_get_item]{batch_get_item} \tab The BatchGetItem operation returns the attributes of one or more items from one or more tables\cr
#'  \link[paws.database:dynamodb_batch_write_item]{batch_write_item} \tab The BatchWriteItem operation puts or deletes multiple items in one or more tables\cr
#'  \link[paws.database:dynamodb_create_backup]{create_backup} \tab Creates a backup for an existing table\cr
#'  \link[paws.database:dynamodb_create_global_table]{create_global_table} \tab Creates a global table from an existing table\cr
#'  \link[paws.database:dynamodb_create_table]{create_table} \tab The CreateTable operation adds a new table to your account\cr
#'  \link[paws.database:dynamodb_delete_backup]{delete_backup} \tab Deletes an existing backup of a table\cr
#'  \link[paws.database:dynamodb_delete_item]{delete_item} \tab Deletes a single item in a table by primary key\cr
#'  \link[paws.database:dynamodb_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource-based policy attached to the resource, which can be a table or stream\cr
#'  \link[paws.database:dynamodb_delete_table]{delete_table} \tab The DeleteTable operation deletes a table and all of its items\cr
#'  \link[paws.database:dynamodb_describe_backup]{describe_backup} \tab Describes an existing backup of a table\cr
#'  \link[paws.database:dynamodb_describe_continuous_backups]{describe_continuous_backups} \tab Checks the status of continuous backups and point in time recovery on the specified table\cr
#'  \link[paws.database:dynamodb_describe_contributor_insights]{describe_contributor_insights} \tab Returns information about contributor insights for a given table or global secondary index\cr
#'  \link[paws.database:dynamodb_describe_endpoints]{describe_endpoints} \tab Returns the regional endpoint information\cr
#'  \link[paws.database:dynamodb_describe_export]{describe_export} \tab Describes an existing table export\cr
#'  \link[paws.database:dynamodb_describe_global_table]{describe_global_table} \tab Returns information about the specified global table\cr
#'  \link[paws.database:dynamodb_describe_global_table_settings]{describe_global_table_settings} \tab Describes Region-specific settings for a global table\cr
#'  \link[paws.database:dynamodb_describe_import]{describe_import} \tab Represents the properties of the import\cr
#'  \link[paws.database:dynamodb_describe_kinesis_streaming_destination]{describe_kinesis_streaming_destination} \tab Returns information about the status of Kinesis streaming\cr
#'  \link[paws.database:dynamodb_describe_limits]{describe_limits} \tab Returns the current provisioned-capacity quotas for your Amazon Web Services account in a Region, both for the Region as a whole and for any one DynamoDB table that you create there\cr
#'  \link[paws.database:dynamodb_describe_table]{describe_table} \tab Returns information about the table, including the current status of the table, when it was created, the primary key schema, and any indexes on the table\cr
#'  \link[paws.database:dynamodb_describe_table_replica_auto_scaling]{describe_table_replica_auto_scaling} \tab Describes auto scaling settings across replicas of the global table at once\cr
#'  \link[paws.database:dynamodb_describe_time_to_live]{describe_time_to_live} \tab Gives a description of the Time to Live (TTL) status on the specified table\cr
#'  \link[paws.database:dynamodb_disable_kinesis_streaming_destination]{disable_kinesis_streaming_destination} \tab Stops replication from the DynamoDB table to the Kinesis data stream\cr
#'  \link[paws.database:dynamodb_enable_kinesis_streaming_destination]{enable_kinesis_streaming_destination} \tab Starts table data replication to the specified Kinesis data stream at a timestamp chosen during the enable workflow\cr
#'  \link[paws.database:dynamodb_execute_statement]{execute_statement} \tab This operation allows you to perform reads and singleton writes on data stored in DynamoDB, using PartiQL\cr
#'  \link[paws.database:dynamodb_execute_transaction]{execute_transaction} \tab This operation allows you to perform transactional reads or writes on data stored in DynamoDB, using PartiQL\cr
#'  \link[paws.database:dynamodb_export_table_to_point_in_time]{export_table_to_point_in_time} \tab Exports table data to an S3 bucket\cr
#'  \link[paws.database:dynamodb_get_item]{get_item} \tab The GetItem operation returns a set of attributes for the item with the given primary key\cr
#'  \link[paws.database:dynamodb_get_resource_policy]{get_resource_policy} \tab Returns the resource-based policy document attached to the resource, which can be a table or stream, in JSON format\cr
#'  \link[paws.database:dynamodb_import_table]{import_table} \tab Imports table data from an S3 bucket\cr
#'  \link[paws.database:dynamodb_list_backups]{list_backups} \tab List DynamoDB backups that are associated with an Amazon Web Services account and weren't made with Amazon Web Services Backup\cr
#'  \link[paws.database:dynamodb_list_contributor_insights]{list_contributor_insights} \tab Returns a list of ContributorInsightsSummary for a table and all its global secondary indexes\cr
#'  \link[paws.database:dynamodb_list_exports]{list_exports} \tab Lists completed exports within the past 90 days\cr
#'  \link[paws.database:dynamodb_list_global_tables]{list_global_tables} \tab Lists all global tables that have a replica in the specified Region\cr
#'  \link[paws.database:dynamodb_list_imports]{list_imports} \tab Lists completed imports within the past 90 days\cr
#'  \link[paws.database:dynamodb_list_tables]{list_tables} \tab Returns an array of table names associated with the current account and endpoint\cr
#'  \link[paws.database:dynamodb_list_tags_of_resource]{list_tags_of_resource} \tab List all tags on an Amazon DynamoDB resource\cr
#'  \link[paws.database:dynamodb_put_item]{put_item} \tab Creates a new item, or replaces an old item with a new item\cr
#'  \link[paws.database:dynamodb_put_resource_policy]{put_resource_policy} \tab Attaches a resource-based policy document to the resource, which can be a table or stream\cr
#'  \link[paws.database:dynamodb_query]{query} \tab You must provide the name of the partition key attribute and a single value for that attribute\cr
#'  \link[paws.database:dynamodb_restore_table_from_backup]{restore_table_from_backup} \tab Creates a new table from an existing backup\cr
#'  \link[paws.database:dynamodb_restore_table_to_point_in_time]{restore_table_to_point_in_time} \tab Restores the specified table to the specified point in time within EarliestRestorableDateTime and LatestRestorableDateTime\cr
#'  \link[paws.database:dynamodb_scan]{scan} \tab The Scan operation returns one or more items and item attributes by accessing every item in a table or a secondary index\cr
#'  \link[paws.database:dynamodb_tag_resource]{tag_resource} \tab Associate a set of tags with an Amazon DynamoDB resource\cr
#'  \link[paws.database:dynamodb_transact_get_items]{transact_get_items} \tab TransactGetItems is a synchronous operation that atomically retrieves multiple items from one or more tables (but not from indexes) in a single account and Region\cr
#'  \link[paws.database:dynamodb_transact_write_items]{transact_write_items} \tab TransactWriteItems is a synchronous write operation that groups up to 100 action requests\cr
#'  \link[paws.database:dynamodb_untag_resource]{untag_resource} \tab Removes the association of tags from an Amazon DynamoDB resource\cr
#'  \link[paws.database:dynamodb_update_continuous_backups]{update_continuous_backups} \tab UpdateContinuousBackups enables or disables point in time recovery for the specified table\cr
#'  \link[paws.database:dynamodb_update_contributor_insights]{update_contributor_insights} \tab Updates the status for contributor insights for a specific table or index\cr
#'  \link[paws.database:dynamodb_update_global_table]{update_global_table} \tab Adds or removes replicas in the specified global table\cr
#'  \link[paws.database:dynamodb_update_global_table_settings]{update_global_table_settings} \tab Updates settings for a global table\cr
#'  \link[paws.database:dynamodb_update_item]{update_item} \tab Edits an existing item's attributes, or adds a new item to the table if it does not already exist\cr
#'  \link[paws.database:dynamodb_update_kinesis_streaming_destination]{update_kinesis_streaming_destination} \tab The command to update the Kinesis stream destination\cr
#'  \link[paws.database:dynamodb_update_table]{update_table} \tab Modifies the provisioned throughput settings, global secondary indexes, or DynamoDB Streams settings for a given table\cr
#'  \link[paws.database:dynamodb_update_table_replica_auto_scaling]{update_table_replica_auto_scaling} \tab Updates auto scaling settings on your global tables at once\cr
#'  \link[paws.database:dynamodb_update_time_to_live]{update_time_to_live} \tab The UpdateTimeToLive method enables or disables Time to Live (TTL) for the specified table
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname dynamodb
#' @export
dynamodb <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::dynamodb(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon DynamoDB Streams
#'
#' @description
#' Amazon DynamoDB
#' 
#' Amazon DynamoDB Streams provides API actions for accessing streams and
#' processing stream records. To learn more about application development
#' with Streams, see [Capturing Table Activity with DynamoDB
#' Streams](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Streams.html)
#' in the Amazon DynamoDB Developer Guide.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- dynamodbstreams(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- dynamodbstreams()
#' # The following example describes a stream with a given stream ARN.
#' svc$describe_stream(
#'   StreamArn = "arn:aws:dynamodb:us-west-2:111122223333:table/Forum/stream/2..."
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:dynamodbstreams_describe_stream]{describe_stream} \tab Returns information about a stream, including the current status of the stream, its Amazon Resource Name (ARN), the composition of its shards, and its corresponding DynamoDB table\cr
#'  \link[paws.database:dynamodbstreams_get_records]{get_records} \tab Retrieves the stream records from a given shard\cr
#'  \link[paws.database:dynamodbstreams_get_shard_iterator]{get_shard_iterator} \tab Returns a shard iterator\cr
#'  \link[paws.database:dynamodbstreams_list_streams]{list_streams} \tab Returns an array of stream ARNs associated with the current account and endpoint
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname dynamodbstreams
#' @export
dynamodbstreams <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::dynamodbstreams(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon ElastiCache
#'
#' @description
#' Amazon ElastiCache is a web service that makes it easier to set up,
#' operate, and scale a distributed cache in the cloud.
#' 
#' With ElastiCache, customers get all of the benefits of a
#' high-performance, in-memory cache with less of the administrative burden
#' involved in launching and managing a distributed cache. The service
#' makes setup, scaling, and cluster failure handling much simpler than in
#' a self-managed cache deployment.
#' 
#' In addition, through integration with Amazon CloudWatch, customers get
#' enhanced visibility into the key performance statistics associated with
#' their cache and can receive alarms if a part of their cache runs hot.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- elasticache(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- elasticache()
#' # Adds up to 10 tags, key/value pairs, to a cluster or snapshot resource.
#' svc$add_tags_to_resource(
#'   ResourceName = "arn:aws:elasticache:us-east-1:1234567890:cluster:my-mem-cluster",
#'   Tags = list(
#'     list(
#'       Key = "APIVersion",
#'       Value = "20150202"
#'     ),
#'     list(
#'       Key = "Service",
#'       Value = "ElastiCache"
#'     )
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:elasticache_add_tags_to_resource]{add_tags_to_resource} \tab A tag is a key-value pair where the key and value are case-sensitive\cr
#'  \link[paws.database:elasticache_authorize_cache_security_group_ingress]{authorize_cache_security_group_ingress} \tab Allows network ingress to a cache security group\cr
#'  \link[paws.database:elasticache_batch_apply_update_action]{batch_apply_update_action} \tab Apply the service update\cr
#'  \link[paws.database:elasticache_batch_stop_update_action]{batch_stop_update_action} \tab Stop the service update\cr
#'  \link[paws.database:elasticache_complete_migration]{complete_migration} \tab Complete the migration of data\cr
#'  \link[paws.database:elasticache_copy_serverless_cache_snapshot]{copy_serverless_cache_snapshot} \tab Creates a copy of an existing serverless cache’s snapshot\cr
#'  \link[paws.database:elasticache_copy_snapshot]{copy_snapshot} \tab Makes a copy of an existing snapshot\cr
#'  \link[paws.database:elasticache_create_cache_cluster]{create_cache_cluster} \tab Creates a cluster\cr
#'  \link[paws.database:elasticache_create_cache_parameter_group]{create_cache_parameter_group} \tab Creates a new Amazon ElastiCache cache parameter group\cr
#'  \link[paws.database:elasticache_create_cache_security_group]{create_cache_security_group} \tab Creates a new cache security group\cr
#'  \link[paws.database:elasticache_create_cache_subnet_group]{create_cache_subnet_group} \tab Creates a new cache subnet group\cr
#'  \link[paws.database:elasticache_create_global_replication_group]{create_global_replication_group} \tab Global Datastore offers fully managed, fast, reliable and secure cross-region replication\cr
#'  \link[paws.database:elasticache_create_replication_group]{create_replication_group} \tab Creates a Valkey or Redis OSS (cluster mode disabled) or a Valkey or Redis OSS (cluster mode enabled) replication group\cr
#'  \link[paws.database:elasticache_create_serverless_cache]{create_serverless_cache} \tab Creates a serverless cache\cr
#'  \link[paws.database:elasticache_create_serverless_cache_snapshot]{create_serverless_cache_snapshot} \tab This API creates a copy of an entire ServerlessCache at a specific moment in time\cr
#'  \link[paws.database:elasticache_create_snapshot]{create_snapshot} \tab Creates a copy of an entire cluster or replication group at a specific moment in time\cr
#'  \link[paws.database:elasticache_create_user]{create_user} \tab For Valkey engine version 7\cr
#'  \link[paws.database:elasticache_create_user_group]{create_user_group} \tab For Valkey engine version 7\cr
#'  \link[paws.database:elasticache_decrease_node_groups_in_global_replication_group]{decrease_node_groups_in_global_replication_group} \tab Decreases the number of node groups in a Global datastore\cr
#'  \link[paws.database:elasticache_decrease_replica_count]{decrease_replica_count} \tab Dynamically decreases the number of replicas in a Valkey or Redis OSS (cluster mode disabled) replication group or the number of replica nodes in one or more node groups (shards) of a Valkey or Redis OSS (cluster mode enabled) replication group\cr
#'  \link[paws.database:elasticache_delete_cache_cluster]{delete_cache_cluster} \tab Deletes a previously provisioned cluster\cr
#'  \link[paws.database:elasticache_delete_cache_parameter_group]{delete_cache_parameter_group} \tab Deletes the specified cache parameter group\cr
#'  \link[paws.database:elasticache_delete_cache_security_group]{delete_cache_security_group} \tab Deletes a cache security group\cr
#'  \link[paws.database:elasticache_delete_cache_subnet_group]{delete_cache_subnet_group} \tab Deletes a cache subnet group\cr
#'  \link[paws.database:elasticache_delete_global_replication_group]{delete_global_replication_group} \tab Deleting a Global datastore is a two-step process:\cr
#'  \link[paws.database:elasticache_delete_replication_group]{delete_replication_group} \tab Deletes an existing replication group\cr
#'  \link[paws.database:elasticache_delete_serverless_cache]{delete_serverless_cache} \tab Deletes a specified existing serverless cache\cr
#'  \link[paws.database:elasticache_delete_serverless_cache_snapshot]{delete_serverless_cache_snapshot} \tab Deletes an existing serverless cache snapshot\cr
#'  \link[paws.database:elasticache_delete_snapshot]{delete_snapshot} \tab Deletes an existing snapshot\cr
#'  \link[paws.database:elasticache_delete_user]{delete_user} \tab For Valkey engine version 7\cr
#'  \link[paws.database:elasticache_delete_user_group]{delete_user_group} \tab For Valkey engine version 7\cr
#'  \link[paws.database:elasticache_describe_cache_clusters]{describe_cache_clusters} \tab Returns information about all provisioned clusters if no cluster identifier is specified, or about a specific cache cluster if a cluster identifier is supplied\cr
#'  \link[paws.database:elasticache_describe_cache_engine_versions]{describe_cache_engine_versions} \tab Returns a list of the available cache engines and their versions\cr
#'  \link[paws.database:elasticache_describe_cache_parameter_groups]{describe_cache_parameter_groups} \tab Returns a list of cache parameter group descriptions\cr
#'  \link[paws.database:elasticache_describe_cache_parameters]{describe_cache_parameters} \tab Returns the detailed parameter list for a particular cache parameter group\cr
#'  \link[paws.database:elasticache_describe_cache_security_groups]{describe_cache_security_groups} \tab Returns a list of cache security group descriptions\cr
#'  \link[paws.database:elasticache_describe_cache_subnet_groups]{describe_cache_subnet_groups} \tab Returns a list of cache subnet group descriptions\cr
#'  \link[paws.database:elasticache_describe_engine_default_parameters]{describe_engine_default_parameters} \tab Returns the default engine and system parameter information for the specified cache engine\cr
#'  \link[paws.database:elasticache_describe_events]{describe_events} \tab Returns events related to clusters, cache security groups, and cache parameter groups\cr
#'  \link[paws.database:elasticache_describe_global_replication_groups]{describe_global_replication_groups} \tab Returns information about a particular global replication group\cr
#'  \link[paws.database:elasticache_describe_replication_groups]{describe_replication_groups} \tab Returns information about a particular replication group\cr
#'  \link[paws.database:elasticache_describe_reserved_cache_nodes]{describe_reserved_cache_nodes} \tab Returns information about reserved cache nodes for this account, or about a specified reserved cache node\cr
#'  \link[paws.database:elasticache_describe_reserved_cache_nodes_offerings]{describe_reserved_cache_nodes_offerings} \tab Lists available reserved cache node offerings\cr
#'  \link[paws.database:elasticache_describe_serverless_caches]{describe_serverless_caches} \tab Returns information about a specific serverless cache\cr
#'  \link[paws.database:elasticache_describe_serverless_cache_snapshots]{describe_serverless_cache_snapshots} \tab Returns information about serverless cache snapshots\cr
#'  \link[paws.database:elasticache_describe_service_updates]{describe_service_updates} \tab Returns details of the service updates\cr
#'  \link[paws.database:elasticache_describe_snapshots]{describe_snapshots} \tab Returns information about cluster or replication group snapshots\cr
#'  \link[paws.database:elasticache_describe_update_actions]{describe_update_actions} \tab Returns details of the update actions\cr
#'  \link[paws.database:elasticache_describe_user_groups]{describe_user_groups} \tab Returns a list of user groups\cr
#'  \link[paws.database:elasticache_describe_users]{describe_users} \tab Returns a list of users\cr
#'  \link[paws.database:elasticache_disassociate_global_replication_group]{disassociate_global_replication_group} \tab Remove a secondary cluster from the Global datastore using the Global datastore name\cr
#'  \link[paws.database:elasticache_export_serverless_cache_snapshot]{export_serverless_cache_snapshot} \tab Provides the functionality to export the serverless cache snapshot data to Amazon S3\cr
#'  \link[paws.database:elasticache_failover_global_replication_group]{failover_global_replication_group} \tab Used to failover the primary region to a secondary region\cr
#'  \link[paws.database:elasticache_increase_node_groups_in_global_replication_group]{increase_node_groups_in_global_replication_group} \tab Increase the number of node groups in the Global datastore\cr
#'  \link[paws.database:elasticache_increase_replica_count]{increase_replica_count} \tab Dynamically increases the number of replicas in a Valkey or Redis OSS (cluster mode disabled) replication group or the number of replica nodes in one or more node groups (shards) of a Valkey or Redis OSS (cluster mode enabled) replication group\cr
#'  \link[paws.database:elasticache_list_allowed_node_type_modifications]{list_allowed_node_type_modifications} \tab Lists all available node types that you can scale with your cluster's replication group's current node type\cr
#'  \link[paws.database:elasticache_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags currently on a named resource\cr
#'  \link[paws.database:elasticache_modify_cache_cluster]{modify_cache_cluster} \tab Modifies the settings for a cluster\cr
#'  \link[paws.database:elasticache_modify_cache_parameter_group]{modify_cache_parameter_group} \tab Modifies the parameters of a cache parameter group\cr
#'  \link[paws.database:elasticache_modify_cache_subnet_group]{modify_cache_subnet_group} \tab Modifies an existing cache subnet group\cr
#'  \link[paws.database:elasticache_modify_global_replication_group]{modify_global_replication_group} \tab Modifies the settings for a Global datastore\cr
#'  \link[paws.database:elasticache_modify_replication_group]{modify_replication_group} \tab Modifies the settings for a replication group\cr
#'  \link[paws.database:elasticache_modify_replication_group_shard_configuration]{modify_replication_group_shard_configuration} \tab Modifies a replication group's shards (node groups) by allowing you to add shards, remove shards, or rebalance the keyspaces among existing shards\cr
#'  \link[paws.database:elasticache_modify_serverless_cache]{modify_serverless_cache} \tab This API modifies the attributes of a serverless cache\cr
#'  \link[paws.database:elasticache_modify_user]{modify_user} \tab Changes user password(s) and/or access string\cr
#'  \link[paws.database:elasticache_modify_user_group]{modify_user_group} \tab Changes the list of users that belong to the user group\cr
#'  \link[paws.database:elasticache_purchase_reserved_cache_nodes_offering]{purchase_reserved_cache_nodes_offering} \tab Allows you to purchase a reserved cache node offering\cr
#'  \link[paws.database:elasticache_rebalance_slots_in_global_replication_group]{rebalance_slots_in_global_replication_group} \tab Redistribute slots to ensure uniform distribution across existing shards in the cluster\cr
#'  \link[paws.database:elasticache_reboot_cache_cluster]{reboot_cache_cluster} \tab Reboots some, or all, of the cache nodes within a provisioned cluster\cr
#'  \link[paws.database:elasticache_remove_tags_from_resource]{remove_tags_from_resource} \tab Removes the tags identified by the TagKeys list from the named resource\cr
#'  \link[paws.database:elasticache_reset_cache_parameter_group]{reset_cache_parameter_group} \tab Modifies the parameters of a cache parameter group to the engine or system default value\cr
#'  \link[paws.database:elasticache_revoke_cache_security_group_ingress]{revoke_cache_security_group_ingress} \tab Revokes ingress from a cache security group\cr
#'  \link[paws.database:elasticache_start_migration]{start_migration} \tab Start the migration of data\cr
#'  \link[paws.database:elasticache_test_failover]{test_failover} \tab Represents the input of a TestFailover operation which tests automatic failover on a specified node group (called shard in the console) in a replication group (called cluster in the console)\cr
#'  \link[paws.database:elasticache_test_migration]{test_migration} \tab Async API to test connection between source and target replication group
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname elasticache
#' @export
elasticache <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::elasticache(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Keyspaces
#'
#' @description
#' Amazon Keyspaces (for Apache Cassandra) is a scalable, highly available,
#' and managed Apache Cassandra-compatible database service. Amazon
#' Keyspaces makes it easy to migrate, run, and scale Cassandra workloads
#' in the Amazon Web Services Cloud. With just a few clicks on the Amazon
#' Web Services Management Console or a few lines of code, you can create
#' keyspaces and tables in Amazon Keyspaces, without deploying any
#' infrastructure or installing software.
#' 
#' In addition to supporting Cassandra Query Language (CQL) requests via
#' open-source Cassandra drivers, Amazon Keyspaces supports data definition
#' language (DDL) operations to manage keyspaces and tables using the
#' Amazon Web Services SDK and CLI, as well as infrastructure as code (IaC)
#' services and tools such as CloudFormation and Terraform. This API
#' reference describes the supported DDL operations in detail.
#' 
#' For the list of all supported CQL APIs, see [Supported Cassandra APIs,
#' operations, and data types in Amazon
#' Keyspaces](https://docs.aws.amazon.com/keyspaces/latest/devguide/cassandra-apis.html)
#' in the *Amazon Keyspaces Developer Guide*.
#' 
#' To learn how Amazon Keyspaces API actions are recorded with CloudTrail,
#' see [Amazon Keyspaces information in
#' CloudTrail](https://docs.aws.amazon.com/keyspaces/latest/devguide/logging-using-cloudtrail.html#service-name-info-in-cloudtrail)
#' in the *Amazon Keyspaces Developer Guide*.
#' 
#' For more information about Amazon Web Services APIs, for example how to
#' implement retry logic or how to sign Amazon Web Services API requests,
#' see [Amazon Web Services
#' APIs](https://docs.aws.amazon.com/general/latest/gr/) in the *General
#' Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- keyspaces(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- keyspaces()
#' svc$create_keyspace(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:keyspaces_create_keyspace]{create_keyspace} \tab The CreateKeyspace operation adds a new keyspace to your account\cr
#'  \link[paws.database:keyspaces_create_table]{create_table} \tab The CreateTable operation adds a new table to the specified keyspace\cr
#'  \link[paws.database:keyspaces_create_type]{create_type} \tab The CreateType operation creates a new user-defined type in the specified keyspace\cr
#'  \link[paws.database:keyspaces_delete_keyspace]{delete_keyspace} \tab The DeleteKeyspace operation deletes a keyspace and all of its tables\cr
#'  \link[paws.database:keyspaces_delete_table]{delete_table} \tab The DeleteTable operation deletes a table and all of its data\cr
#'  \link[paws.database:keyspaces_delete_type]{delete_type} \tab The DeleteType operation deletes a user-defined type (UDT)\cr
#'  \link[paws.database:keyspaces_get_keyspace]{get_keyspace} \tab Returns the name of the specified keyspace, the Amazon Resource Name (ARN), the replication strategy, the Amazon Web Services Regions of a multi-Region keyspace, and the status of newly added Regions after an UpdateKeyspace operation\cr
#'  \link[paws.database:keyspaces_get_table]{get_table} \tab Returns information about the table, including the table's name and current status, the keyspace name, configuration settings, and metadata\cr
#'  \link[paws.database:keyspaces_get_table_auto_scaling_settings]{get_table_auto_scaling_settings} \tab Returns auto scaling related settings of the specified table in JSON format\cr
#'  \link[paws.database:keyspaces_get_type]{get_type} \tab The GetType operation returns information about the type, for example the field definitions, the timestamp when the type was last modified, the level of nesting, the status, and details about if the type is used in other types and tables\cr
#'  \link[paws.database:keyspaces_list_keyspaces]{list_keyspaces} \tab The ListKeyspaces operation returns a list of keyspaces\cr
#'  \link[paws.database:keyspaces_list_tables]{list_tables} \tab The ListTables operation returns a list of tables for a specified keyspace\cr
#'  \link[paws.database:keyspaces_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of all tags associated with the specified Amazon Keyspaces resource\cr
#'  \link[paws.database:keyspaces_list_types]{list_types} \tab The ListTypes operation returns a list of types for a specified keyspace\cr
#'  \link[paws.database:keyspaces_restore_table]{restore_table} \tab Restores the table to the specified point in time within the earliest_restorable_timestamp and the current time\cr
#'  \link[paws.database:keyspaces_tag_resource]{tag_resource} \tab Associates a set of tags with a Amazon Keyspaces resource\cr
#'  \link[paws.database:keyspaces_untag_resource]{untag_resource} \tab Removes the association of tags from a Amazon Keyspaces resource\cr
#'  \link[paws.database:keyspaces_update_keyspace]{update_keyspace} \tab Adds a new Amazon Web Services Region to the keyspace\cr
#'  \link[paws.database:keyspaces_update_table]{update_table} \tab Adds new columns to the table or updates one of the table's settings, for example capacity mode, auto scaling, encryption, point-in-time recovery, or ttl settings
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname keyspaces
#' @export
keyspaces <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::keyspaces(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Lake Formation
#'
#' @description
#' Lake Formation
#' 
#' Defines the public endpoint for the Lake Formation service.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lakeformation(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lakeformation()
#' svc$add_lf_tags_to_resource(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:lakeformation_add_lf_tags_to_resource]{add_lf_tags_to_resource} \tab Attaches one or more LF-tags to an existing resource\cr
#'  \link[paws.database:lakeformation_assume_decorated_role_with_saml]{assume_decorated_role_with_saml} \tab Allows a caller to assume an IAM role decorated as the SAML user specified in the SAML assertion included in the request\cr
#'  \link[paws.database:lakeformation_batch_grant_permissions]{batch_grant_permissions} \tab Batch operation to grant permissions to the principal\cr
#'  \link[paws.database:lakeformation_batch_revoke_permissions]{batch_revoke_permissions} \tab Batch operation to revoke permissions from the principal\cr
#'  \link[paws.database:lakeformation_cancel_transaction]{cancel_transaction} \tab Attempts to cancel the specified transaction\cr
#'  \link[paws.database:lakeformation_commit_transaction]{commit_transaction} \tab Attempts to commit the specified transaction\cr
#'  \link[paws.database:lakeformation_create_data_cells_filter]{create_data_cells_filter} \tab Creates a data cell filter to allow one to grant access to certain columns on certain rows\cr
#'  \link[paws.database:lakeformation_create_lake_formation_identity_center_configuration]{create_lake_formation_identity_center_configuration} \tab Creates an IAM Identity Center connection with Lake Formation to allow IAM Identity Center users and groups to access Data Catalog resources\cr
#'  \link[paws.database:lakeformation_create_lake_formation_opt_in]{create_lake_formation_opt_in} \tab Enforce Lake Formation permissions for the given databases, tables, and principals\cr
#'  \link[paws.database:lakeformation_create_lf_tag]{create_lf_tag} \tab Creates an LF-tag with the specified name and values\cr
#'  \link[paws.database:lakeformation_create_lf_tag_expression]{create_lf_tag_expression} \tab Creates a new LF-Tag expression with the provided name, description, catalog ID, and expression body\cr
#'  \link[paws.database:lakeformation_delete_data_cells_filter]{delete_data_cells_filter} \tab Deletes a data cell filter\cr
#'  \link[paws.database:lakeformation_delete_lake_formation_identity_center_configuration]{delete_lake_formation_identity_center_configuration} \tab Deletes an IAM Identity Center connection with Lake Formation\cr
#'  \link[paws.database:lakeformation_delete_lake_formation_opt_in]{delete_lake_formation_opt_in} \tab Remove the Lake Formation permissions enforcement of the given databases, tables, and principals\cr
#'  \link[paws.database:lakeformation_delete_lf_tag]{delete_lf_tag} \tab Deletes the specified LF-tag given a key name\cr
#'  \link[paws.database:lakeformation_delete_lf_tag_expression]{delete_lf_tag_expression} \tab Deletes the LF-Tag expression\cr
#'  \link[paws.database:lakeformation_delete_objects_on_cancel]{delete_objects_on_cancel} \tab For a specific governed table, provides a list of Amazon S3 objects that will be written during the current transaction and that can be automatically deleted if the transaction is canceled\cr
#'  \link[paws.database:lakeformation_deregister_resource]{deregister_resource} \tab Deregisters the resource as managed by the Data Catalog\cr
#'  \link[paws.database:lakeformation_describe_lake_formation_identity_center_configuration]{describe_lake_formation_identity_center_configuration} \tab Retrieves the instance ARN and application ARN for the connection\cr
#'  \link[paws.database:lakeformation_describe_resource]{describe_resource} \tab Retrieves the current data access role for the given resource registered in Lake Formation\cr
#'  \link[paws.database:lakeformation_describe_transaction]{describe_transaction} \tab Returns the details of a single transaction\cr
#'  \link[paws.database:lakeformation_extend_transaction]{extend_transaction} \tab Indicates to the service that the specified transaction is still active and should not be treated as idle and aborted\cr
#'  \link[paws.database:lakeformation_get_data_cells_filter]{get_data_cells_filter} \tab Returns a data cells filter\cr
#'  \link[paws.database:lakeformation_get_data_lake_principal]{get_data_lake_principal} \tab Returns the identity of the invoking principal\cr
#'  \link[paws.database:lakeformation_get_data_lake_settings]{get_data_lake_settings} \tab Retrieves the list of the data lake administrators of a Lake Formation-managed data lake\cr
#'  \link[paws.database:lakeformation_get_effective_permissions_for_path]{get_effective_permissions_for_path} \tab Returns the Lake Formation permissions for a specified table or database resource located at a path in Amazon S3\cr
#'  \link[paws.database:lakeformation_get_lf_tag]{get_lf_tag} \tab Returns an LF-tag definition\cr
#'  \link[paws.database:lakeformation_get_lf_tag_expression]{get_lf_tag_expression} \tab Returns the details about the LF-Tag expression\cr
#'  \link[paws.database:lakeformation_get_query_state]{get_query_state} \tab Returns the state of a query previously submitted\cr
#'  \link[paws.database:lakeformation_get_query_statistics]{get_query_statistics} \tab Retrieves statistics on the planning and execution of a query\cr
#'  \link[paws.database:lakeformation_get_resource_lf_tags]{get_resource_lf_tags} \tab Returns the LF-tags applied to a resource\cr
#'  \link[paws.database:lakeformation_get_table_objects]{get_table_objects} \tab Returns the set of Amazon S3 objects that make up the specified governed table\cr
#'  \link[paws.database:lakeformation_get_temporary_glue_partition_credentials]{get_temporary_glue_partition_credentials} \tab This API is identical to GetTemporaryTableCredentials except that this is used when the target Data Catalog resource is of type Partition\cr
#'  \link[paws.database:lakeformation_get_temporary_glue_table_credentials]{get_temporary_glue_table_credentials} \tab Allows a caller in a secure environment to assume a role with permission to access Amazon S3\cr
#'  \link[paws.database:lakeformation_get_work_unit_results]{get_work_unit_results} \tab Returns the work units resulting from the query\cr
#'  \link[paws.database:lakeformation_get_work_units]{get_work_units} \tab Retrieves the work units generated by the StartQueryPlanning operation\cr
#'  \link[paws.database:lakeformation_grant_permissions]{grant_permissions} \tab Grants permissions to the principal to access metadata in the Data Catalog and data organized in underlying data storage such as Amazon S3\cr
#'  \link[paws.database:lakeformation_list_data_cells_filter]{list_data_cells_filter} \tab Lists all the data cell filters on a table\cr
#'  \link[paws.database:lakeformation_list_lake_formation_opt_ins]{list_lake_formation_opt_ins} \tab Retrieve the current list of resources and principals that are opt in to enforce Lake Formation permissions\cr
#'  \link[paws.database:lakeformation_list_lf_tag_expressions]{list_lf_tag_expressions} \tab Returns the LF-Tag expressions in caller’s account filtered based on caller's permissions\cr
#'  \link[paws.database:lakeformation_list_lf_tags]{list_lf_tags} \tab Lists LF-tags that the requester has permission to view\cr
#'  \link[paws.database:lakeformation_list_permissions]{list_permissions} \tab Returns a list of the principal permissions on the resource, filtered by the permissions of the caller\cr
#'  \link[paws.database:lakeformation_list_resources]{list_resources} \tab Lists the resources registered to be managed by the Data Catalog\cr
#'  \link[paws.database:lakeformation_list_table_storage_optimizers]{list_table_storage_optimizers} \tab Returns the configuration of all storage optimizers associated with a specified table\cr
#'  \link[paws.database:lakeformation_list_transactions]{list_transactions} \tab Returns metadata about transactions and their status\cr
#'  \link[paws.database:lakeformation_put_data_lake_settings]{put_data_lake_settings} \tab Sets the list of data lake administrators who have admin privileges on all resources managed by Lake Formation\cr
#'  \link[paws.database:lakeformation_register_resource]{register_resource} \tab Registers the resource as managed by the Data Catalog\cr
#'  \link[paws.database:lakeformation_remove_lf_tags_from_resource]{remove_lf_tags_from_resource} \tab Removes an LF-tag from the resource\cr
#'  \link[paws.database:lakeformation_revoke_permissions]{revoke_permissions} \tab Revokes permissions to the principal to access metadata in the Data Catalog and data organized in underlying data storage such as Amazon S3\cr
#'  \link[paws.database:lakeformation_search_databases_by_lf_tags]{search_databases_by_lf_tags} \tab This operation allows a search on DATABASE resources by TagCondition\cr
#'  \link[paws.database:lakeformation_search_tables_by_lf_tags]{search_tables_by_lf_tags} \tab This operation allows a search on TABLE resources by LFTags\cr
#'  \link[paws.database:lakeformation_start_query_planning]{start_query_planning} \tab Submits a request to process a query statement\cr
#'  \link[paws.database:lakeformation_start_transaction]{start_transaction} \tab Starts a new transaction and returns its transaction ID\cr
#'  \link[paws.database:lakeformation_update_data_cells_filter]{update_data_cells_filter} \tab Updates a data cell filter\cr
#'  \link[paws.database:lakeformation_update_lake_formation_identity_center_configuration]{update_lake_formation_identity_center_configuration} \tab Updates the IAM Identity Center connection parameters\cr
#'  \link[paws.database:lakeformation_update_lf_tag]{update_lf_tag} \tab Updates the list of possible values for the specified LF-tag key\cr
#'  \link[paws.database:lakeformation_update_lf_tag_expression]{update_lf_tag_expression} \tab Updates the name of the LF-Tag expression to the new description and expression body provided\cr
#'  \link[paws.database:lakeformation_update_resource]{update_resource} \tab Updates the data access role used for vending access to the given (registered) resource in Lake Formation\cr
#'  \link[paws.database:lakeformation_update_table_objects]{update_table_objects} \tab Updates the manifest of Amazon S3 objects that make up the specified governed table\cr
#'  \link[paws.database:lakeformation_update_table_storage_optimizer]{update_table_storage_optimizer} \tab Updates the configuration of the storage optimizers for a table
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lakeformation
#' @export
lakeformation <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::lakeformation(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon MemoryDB
#'
#' @description
#' MemoryDB is a fully managed, Redis OSS-compatible, in-memory database
#' that delivers ultra-fast performance and Multi-AZ durability for modern
#' applications built using microservices architectures. MemoryDB stores
#' the entire database in-memory, enabling low latency and high throughput
#' data access. It is compatible with Redis OSS, a popular open source data
#' store, enabling you to leverage Redis OSS’ flexible and friendly data
#' structures, APIs, and commands.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- memorydb(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- memorydb()
#' svc$batch_update_cluster(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:memorydb_batch_update_cluster]{batch_update_cluster} \tab Apply the service update to a list of clusters supplied\cr
#'  \link[paws.database:memorydb_copy_snapshot]{copy_snapshot} \tab Makes a copy of an existing snapshot\cr
#'  \link[paws.database:memorydb_create_acl]{create_acl} \tab Creates an Access Control List\cr
#'  \link[paws.database:memorydb_create_cluster]{create_cluster} \tab Creates a cluster\cr
#'  \link[paws.database:memorydb_create_multi_region_cluster]{create_multi_region_cluster} \tab Creates a new multi-Region cluster\cr
#'  \link[paws.database:memorydb_create_parameter_group]{create_parameter_group} \tab Creates a new MemoryDB parameter group\cr
#'  \link[paws.database:memorydb_create_snapshot]{create_snapshot} \tab Creates a copy of an entire cluster at a specific moment in time\cr
#'  \link[paws.database:memorydb_create_subnet_group]{create_subnet_group} \tab Creates a subnet group\cr
#'  \link[paws.database:memorydb_create_user]{create_user} \tab Creates a MemoryDB user\cr
#'  \link[paws.database:memorydb_delete_acl]{delete_acl} \tab Deletes an Access Control List\cr
#'  \link[paws.database:memorydb_delete_cluster]{delete_cluster} \tab Deletes a cluster\cr
#'  \link[paws.database:memorydb_delete_multi_region_cluster]{delete_multi_region_cluster} \tab Deletes an existing multi-Region cluster\cr
#'  \link[paws.database:memorydb_delete_parameter_group]{delete_parameter_group} \tab Deletes the specified parameter group\cr
#'  \link[paws.database:memorydb_delete_snapshot]{delete_snapshot} \tab Deletes an existing snapshot\cr
#'  \link[paws.database:memorydb_delete_subnet_group]{delete_subnet_group} \tab Deletes a subnet group\cr
#'  \link[paws.database:memorydb_delete_user]{delete_user} \tab Deletes a user\cr
#'  \link[paws.database:memorydb_describe_ac_ls]{describe_ac_ls} \tab Returns a list of ACLs\cr
#'  \link[paws.database:memorydb_describe_clusters]{describe_clusters} \tab Returns information about all provisioned clusters if no cluster identifier is specified, or about a specific cluster if a cluster name is supplied\cr
#'  \link[paws.database:memorydb_describe_engine_versions]{describe_engine_versions} \tab Returns a list of the available Redis OSS engine versions\cr
#'  \link[paws.database:memorydb_describe_events]{describe_events} \tab Returns events related to clusters, security groups, and parameter groups\cr
#'  \link[paws.database:memorydb_describe_multi_region_clusters]{describe_multi_region_clusters} \tab Returns details about one or more multi-Region clusters\cr
#'  \link[paws.database:memorydb_describe_parameter_groups]{describe_parameter_groups} \tab Returns a list of parameter group descriptions\cr
#'  \link[paws.database:memorydb_describe_parameters]{describe_parameters} \tab Returns the detailed parameter list for a particular parameter group\cr
#'  \link[paws.database:memorydb_describe_reserved_nodes]{describe_reserved_nodes} \tab Returns information about reserved nodes for this account, or about a specified reserved node\cr
#'  \link[paws.database:memorydb_describe_reserved_nodes_offerings]{describe_reserved_nodes_offerings} \tab Lists available reserved node offerings\cr
#'  \link[paws.database:memorydb_describe_service_updates]{describe_service_updates} \tab Returns details of the service updates\cr
#'  \link[paws.database:memorydb_describe_snapshots]{describe_snapshots} \tab Returns information about cluster snapshots\cr
#'  \link[paws.database:memorydb_describe_subnet_groups]{describe_subnet_groups} \tab Returns a list of subnet group descriptions\cr
#'  \link[paws.database:memorydb_describe_users]{describe_users} \tab Returns a list of users\cr
#'  \link[paws.database:memorydb_failover_shard]{failover_shard} \tab Used to failover a shard\cr
#'  \link[paws.database:memorydb_list_allowed_multi_region_cluster_updates]{list_allowed_multi_region_cluster_updates} \tab Lists the allowed updates for a multi-Region cluster\cr
#'  \link[paws.database:memorydb_list_allowed_node_type_updates]{list_allowed_node_type_updates} \tab Lists all available node types that you can scale to from your cluster's current node type\cr
#'  \link[paws.database:memorydb_list_tags]{list_tags} \tab Lists all tags currently on a named resource\cr
#'  \link[paws.database:memorydb_purchase_reserved_nodes_offering]{purchase_reserved_nodes_offering} \tab Allows you to purchase a reserved node offering\cr
#'  \link[paws.database:memorydb_reset_parameter_group]{reset_parameter_group} \tab Modifies the parameters of a parameter group to the engine or system default value\cr
#'  \link[paws.database:memorydb_tag_resource]{tag_resource} \tab A tag is a key-value pair where the key and value are case-sensitive\cr
#'  \link[paws.database:memorydb_untag_resource]{untag_resource} \tab Use this operation to remove tags on a resource\cr
#'  \link[paws.database:memorydb_update_acl]{update_acl} \tab Changes the list of users that belong to the Access Control List\cr
#'  \link[paws.database:memorydb_update_cluster]{update_cluster} \tab Modifies the settings for a cluster\cr
#'  \link[paws.database:memorydb_update_multi_region_cluster]{update_multi_region_cluster} \tab Updates the configuration of an existing multi-Region cluster\cr
#'  \link[paws.database:memorydb_update_parameter_group]{update_parameter_group} \tab Updates the parameters of a parameter group\cr
#'  \link[paws.database:memorydb_update_subnet_group]{update_subnet_group} \tab Updates a subnet group\cr
#'  \link[paws.database:memorydb_update_user]{update_user} \tab Changes user password(s) and/or access string
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname memorydb
#' @export
memorydb <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::memorydb(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Neptune
#'
#' @description
#' Amazon Neptune is a fast, reliable, fully-managed graph database service
#' that makes it easy to build and run applications that work with highly
#' connected datasets. The core of Amazon Neptune is a purpose-built,
#' high-performance graph database engine optimized for storing billions of
#' relationships and querying the graph with milliseconds latency. Amazon
#' Neptune supports popular graph models Property Graph and W3C's RDF, and
#' their respective query languages Apache TinkerPop Gremlin and SPARQL,
#' allowing you to easily build queries that efficiently navigate highly
#' connected datasets. Neptune powers graph use cases such as
#' recommendation engines, fraud detection, knowledge graphs, drug
#' discovery, and network security.
#' 
#' This interface reference for Amazon Neptune contains documentation for a
#' programming or command line interface you can use to manage Amazon
#' Neptune. Note that Amazon Neptune is asynchronous, which means that some
#' interfaces might require techniques such as polling or callback
#' functions to determine when a command has been applied. In this
#' reference, the parameter descriptions indicate whether a command is
#' applied immediately, on the next instance reboot, or during the
#' maintenance window. The reference structure is as follows, and we list
#' following some related topics from the user guide.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- neptune(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- neptune()
#' svc$add_role_to_db_cluster(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:neptune_add_role_to_db_cluster]{add_role_to_db_cluster} \tab Associates an Identity and Access Management (IAM) role with an Neptune DB cluster\cr
#'  \link[paws.database:neptune_add_source_identifier_to_subscription]{add_source_identifier_to_subscription} \tab Adds a source identifier to an existing event notification subscription\cr
#'  \link[paws.database:neptune_add_tags_to_resource]{add_tags_to_resource} \tab Adds metadata tags to an Amazon Neptune resource\cr
#'  \link[paws.database:neptune_apply_pending_maintenance_action]{apply_pending_maintenance_action} \tab Applies a pending maintenance action to a resource (for example, to a DB instance)\cr
#'  \link[paws.database:neptune_copy_db_cluster_parameter_group]{copy_db_cluster_parameter_group} \tab Copies the specified DB cluster parameter group\cr
#'  \link[paws.database:neptune_copy_db_cluster_snapshot]{copy_db_cluster_snapshot} \tab Copies a snapshot of a DB cluster\cr
#'  \link[paws.database:neptune_copy_db_parameter_group]{copy_db_parameter_group} \tab Copies the specified DB parameter group\cr
#'  \link[paws.database:neptune_create_db_cluster]{create_db_cluster} \tab Creates a new Amazon Neptune DB cluster\cr
#'  \link[paws.database:neptune_create_db_cluster_endpoint]{create_db_cluster_endpoint} \tab Creates a new custom endpoint and associates it with an Amazon Neptune DB cluster\cr
#'  \link[paws.database:neptune_create_db_cluster_parameter_group]{create_db_cluster_parameter_group} \tab Creates a new DB cluster parameter group\cr
#'  \link[paws.database:neptune_create_db_cluster_snapshot]{create_db_cluster_snapshot} \tab Creates a snapshot of a DB cluster\cr
#'  \link[paws.database:neptune_create_db_instance]{create_db_instance} \tab Creates a new DB instance\cr
#'  \link[paws.database:neptune_create_db_parameter_group]{create_db_parameter_group} \tab Creates a new DB parameter group\cr
#'  \link[paws.database:neptune_create_db_subnet_group]{create_db_subnet_group} \tab Creates a new DB subnet group\cr
#'  \link[paws.database:neptune_create_event_subscription]{create_event_subscription} \tab Creates an event notification subscription\cr
#'  \link[paws.database:neptune_create_global_cluster]{create_global_cluster} \tab Creates a Neptune global database spread across multiple Amazon Regions\cr
#'  \link[paws.database:neptune_delete_db_cluster]{delete_db_cluster} \tab The DeleteDBCluster action deletes a previously provisioned DB cluster\cr
#'  \link[paws.database:neptune_delete_db_cluster_endpoint]{delete_db_cluster_endpoint} \tab Deletes a custom endpoint and removes it from an Amazon Neptune DB cluster\cr
#'  \link[paws.database:neptune_delete_db_cluster_parameter_group]{delete_db_cluster_parameter_group} \tab Deletes a specified DB cluster parameter group\cr
#'  \link[paws.database:neptune_delete_db_cluster_snapshot]{delete_db_cluster_snapshot} \tab Deletes a DB cluster snapshot\cr
#'  \link[paws.database:neptune_delete_db_instance]{delete_db_instance} \tab The DeleteDBInstance action deletes a previously provisioned DB instance\cr
#'  \link[paws.database:neptune_delete_db_parameter_group]{delete_db_parameter_group} \tab Deletes a specified DBParameterGroup\cr
#'  \link[paws.database:neptune_delete_db_subnet_group]{delete_db_subnet_group} \tab Deletes a DB subnet group\cr
#'  \link[paws.database:neptune_delete_event_subscription]{delete_event_subscription} \tab Deletes an event notification subscription\cr
#'  \link[paws.database:neptune_delete_global_cluster]{delete_global_cluster} \tab Deletes a global database\cr
#'  \link[paws.database:neptune_describe_db_cluster_endpoints]{describe_db_cluster_endpoints} \tab Returns information about endpoints for an Amazon Neptune DB cluster\cr
#'  \link[paws.database:neptune_describe_db_cluster_parameter_groups]{describe_db_cluster_parameter_groups} \tab Returns a list of DBClusterParameterGroup descriptions\cr
#'  \link[paws.database:neptune_describe_db_cluster_parameters]{describe_db_cluster_parameters} \tab Returns the detailed parameter list for a particular DB cluster parameter group\cr
#'  \link[paws.database:neptune_describe_db_clusters]{describe_db_clusters} \tab Returns information about provisioned DB clusters, and supports pagination\cr
#'  \link[paws.database:neptune_describe_db_cluster_snapshot_attributes]{describe_db_cluster_snapshot_attributes} \tab Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot\cr
#'  \link[paws.database:neptune_describe_db_cluster_snapshots]{describe_db_cluster_snapshots} \tab Returns information about DB cluster snapshots\cr
#'  \link[paws.database:neptune_describe_db_engine_versions]{describe_db_engine_versions} \tab Returns a list of the available DB engines\cr
#'  \link[paws.database:neptune_describe_db_instances]{describe_db_instances} \tab Returns information about provisioned instances, and supports pagination\cr
#'  \link[paws.database:neptune_describe_db_parameter_groups]{describe_db_parameter_groups} \tab Returns a list of DBParameterGroup descriptions\cr
#'  \link[paws.database:neptune_describe_db_parameters]{describe_db_parameters} \tab Returns the detailed parameter list for a particular DB parameter group\cr
#'  \link[paws.database:neptune_describe_db_subnet_groups]{describe_db_subnet_groups} \tab Returns a list of DBSubnetGroup descriptions\cr
#'  \link[paws.database:neptune_describe_engine_default_cluster_parameters]{describe_engine_default_cluster_parameters} \tab Returns the default engine and system parameter information for the cluster database engine\cr
#'  \link[paws.database:neptune_describe_engine_default_parameters]{describe_engine_default_parameters} \tab Returns the default engine and system parameter information for the specified database engine\cr
#'  \link[paws.database:neptune_describe_event_categories]{describe_event_categories} \tab Displays a list of categories for all event source types, or, if specified, for a specified source type\cr
#'  \link[paws.database:neptune_describe_events]{describe_events} \tab Returns events related to DB instances, DB security groups, DB snapshots, and DB parameter groups for the past 14 days\cr
#'  \link[paws.database:neptune_describe_event_subscriptions]{describe_event_subscriptions} \tab Lists all the subscription descriptions for a customer account\cr
#'  \link[paws.database:neptune_describe_global_clusters]{describe_global_clusters} \tab Returns information about Neptune global database clusters\cr
#'  \link[paws.database:neptune_describe_orderable_db_instance_options]{describe_orderable_db_instance_options} \tab Returns a list of orderable DB instance options for the specified engine\cr
#'  \link[paws.database:neptune_describe_pending_maintenance_actions]{describe_pending_maintenance_actions} \tab Returns a list of resources (for example, DB instances) that have at least one pending maintenance action\cr
#'  \link[paws.database:neptune_describe_valid_db_instance_modifications]{describe_valid_db_instance_modifications} \tab You can call DescribeValidDBInstanceModifications to learn what modifications you can make to your DB instance\cr
#'  \link[paws.database:neptune_failover_db_cluster]{failover_db_cluster} \tab Forces a failover for a DB cluster\cr
#'  \link[paws.database:neptune_failover_global_cluster]{failover_global_cluster} \tab Initiates the failover process for a Neptune global database\cr
#'  \link[paws.database:neptune_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags on an Amazon Neptune resource\cr
#'  \link[paws.database:neptune_modify_db_cluster]{modify_db_cluster} \tab Modify a setting for a DB cluster\cr
#'  \link[paws.database:neptune_modify_db_cluster_endpoint]{modify_db_cluster_endpoint} \tab Modifies the properties of an endpoint in an Amazon Neptune DB cluster\cr
#'  \link[paws.database:neptune_modify_db_cluster_parameter_group]{modify_db_cluster_parameter_group} \tab Modifies the parameters of a DB cluster parameter group\cr
#'  \link[paws.database:neptune_modify_db_cluster_snapshot_attribute]{modify_db_cluster_snapshot_attribute} \tab Adds an attribute and values to, or removes an attribute and values from, a manual DB cluster snapshot\cr
#'  \link[paws.database:neptune_modify_db_instance]{modify_db_instance} \tab Modifies settings for a DB instance\cr
#'  \link[paws.database:neptune_modify_db_parameter_group]{modify_db_parameter_group} \tab Modifies the parameters of a DB parameter group\cr
#'  \link[paws.database:neptune_modify_db_subnet_group]{modify_db_subnet_group} \tab Modifies an existing DB subnet group\cr
#'  \link[paws.database:neptune_modify_event_subscription]{modify_event_subscription} \tab Modifies an existing event notification subscription\cr
#'  \link[paws.database:neptune_modify_global_cluster]{modify_global_cluster} \tab Modify a setting for an Amazon Neptune global cluster\cr
#'  \link[paws.database:neptune_promote_read_replica_db_cluster]{promote_read_replica_db_cluster} \tab Not supported\cr
#'  \link[paws.database:neptune_reboot_db_instance]{reboot_db_instance} \tab You might need to reboot your DB instance, usually for maintenance reasons\cr
#'  \link[paws.database:neptune_remove_from_global_cluster]{remove_from_global_cluster} \tab Detaches a Neptune DB cluster from a Neptune global database\cr
#'  \link[paws.database:neptune_remove_role_from_db_cluster]{remove_role_from_db_cluster} \tab Disassociates an Identity and Access Management (IAM) role from a DB cluster\cr
#'  \link[paws.database:neptune_remove_source_identifier_from_subscription]{remove_source_identifier_from_subscription} \tab Removes a source identifier from an existing event notification subscription\cr
#'  \link[paws.database:neptune_remove_tags_from_resource]{remove_tags_from_resource} \tab Removes metadata tags from an Amazon Neptune resource\cr
#'  \link[paws.database:neptune_reset_db_cluster_parameter_group]{reset_db_cluster_parameter_group} \tab Modifies the parameters of a DB cluster parameter group to the default value\cr
#'  \link[paws.database:neptune_reset_db_parameter_group]{reset_db_parameter_group} \tab Modifies the parameters of a DB parameter group to the engine/system default value\cr
#'  \link[paws.database:neptune_restore_db_cluster_from_snapshot]{restore_db_cluster_from_snapshot} \tab Creates a new DB cluster from a DB snapshot or DB cluster snapshot\cr
#'  \link[paws.database:neptune_restore_db_cluster_to_point_in_time]{restore_db_cluster_to_point_in_time} \tab Restores a DB cluster to an arbitrary point in time\cr
#'  \link[paws.database:neptune_start_db_cluster]{start_db_cluster} \tab Starts an Amazon Neptune DB cluster that was stopped using the Amazon console, the Amazon CLI stop-db-cluster command, or the StopDBCluster API\cr
#'  \link[paws.database:neptune_stop_db_cluster]{stop_db_cluster} \tab Stops an Amazon Neptune DB cluster
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname neptune
#' @export
neptune <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::neptune(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon NeptuneData
#'
#' @description
#' Neptune Data API
#' 
#' The Amazon Neptune data API provides SDK support for more than 40 of
#' Neptune's data operations, including data loading, query execution, data
#' inquiry, and machine learning. It supports the Gremlin and openCypher
#' query languages, and is available in all SDK languages. It automatically
#' signs API requests and greatly simplifies integrating Neptune into your
#' applications.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- neptunedata(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- neptunedata()
#' svc$cancel_gremlin_query(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:neptunedata_cancel_gremlin_query]{cancel_gremlin_query} \tab Cancels a Gremlin query\cr
#'  \link[paws.database:neptunedata_cancel_loader_job]{cancel_loader_job} \tab Cancels a specified load job\cr
#'  \link[paws.database:neptunedata_cancel_ml_data_processing_job]{cancel_ml_data_processing_job} \tab Cancels a Neptune ML data processing job\cr
#'  \link[paws.database:neptunedata_cancel_ml_model_training_job]{cancel_ml_model_training_job} \tab Cancels a Neptune ML model training job\cr
#'  \link[paws.database:neptunedata_cancel_ml_model_transform_job]{cancel_ml_model_transform_job} \tab Cancels a specified model transform job\cr
#'  \link[paws.database:neptunedata_cancel_open_cypher_query]{cancel_open_cypher_query} \tab Cancels a specified openCypher query\cr
#'  \link[paws.database:neptunedata_create_ml_endpoint]{create_ml_endpoint} \tab Creates a new Neptune ML inference endpoint that lets you query one specific model that the model-training process constructed\cr
#'  \link[paws.database:neptunedata_delete_ml_endpoint]{delete_ml_endpoint} \tab Cancels the creation of a Neptune ML inference endpoint\cr
#'  \link[paws.database:neptunedata_delete_propertygraph_statistics]{delete_propertygraph_statistics} \tab Deletes statistics for Gremlin and openCypher (property graph) data\cr
#'  \link[paws.database:neptunedata_delete_sparql_statistics]{delete_sparql_statistics} \tab Deletes SPARQL statistics\cr
#'  \link[paws.database:neptunedata_execute_fast_reset]{execute_fast_reset} \tab The fast reset REST API lets you reset a Neptune graph quicky and easily, removing all of its data\cr
#'  \link[paws.database:neptunedata_execute_gremlin_explain_query]{execute_gremlin_explain_query} \tab Executes a Gremlin Explain query\cr
#'  \link[paws.database:neptunedata_execute_gremlin_profile_query]{execute_gremlin_profile_query} \tab Executes a Gremlin Profile query, which runs a specified traversal, collects various metrics about the run, and produces a profile report as output\cr
#'  \link[paws.database:neptunedata_execute_gremlin_query]{execute_gremlin_query} \tab This commands executes a Gremlin query\cr
#'  \link[paws.database:neptunedata_execute_open_cypher_explain_query]{execute_open_cypher_explain_query} \tab Executes an openCypher explain request\cr
#'  \link[paws.database:neptunedata_execute_open_cypher_query]{execute_open_cypher_query} \tab Executes an openCypher query\cr
#'  \link[paws.database:neptunedata_get_engine_status]{get_engine_status} \tab Retrieves the status of the graph database on the host\cr
#'  \link[paws.database:neptunedata_get_gremlin_query_status]{get_gremlin_query_status} \tab Gets the status of a specified Gremlin query\cr
#'  \link[paws.database:neptunedata_get_loader_job_status]{get_loader_job_status} \tab Gets status information about a specified load job\cr
#'  \link[paws.database:neptunedata_get_ml_data_processing_job]{get_ml_data_processing_job} \tab Retrieves information about a specified data processing job\cr
#'  \link[paws.database:neptunedata_get_ml_endpoint]{get_ml_endpoint} \tab Retrieves details about an inference endpoint\cr
#'  \link[paws.database:neptunedata_get_ml_model_training_job]{get_ml_model_training_job} \tab Retrieves information about a Neptune ML model training job\cr
#'  \link[paws.database:neptunedata_get_ml_model_transform_job]{get_ml_model_transform_job} \tab Gets information about a specified model transform job\cr
#'  \link[paws.database:neptunedata_get_open_cypher_query_status]{get_open_cypher_query_status} \tab Retrieves the status of a specified openCypher query\cr
#'  \link[paws.database:neptunedata_get_propertygraph_statistics]{get_propertygraph_statistics} \tab Gets property graph statistics (Gremlin and openCypher)\cr
#'  \link[paws.database:neptunedata_get_propertygraph_stream]{get_propertygraph_stream} \tab Gets a stream for a property graph\cr
#'  \link[paws.database:neptunedata_get_propertygraph_summary]{get_propertygraph_summary} \tab Gets a graph summary for a property graph\cr
#'  \link[paws.database:neptunedata_get_rdf_graph_summary]{get_rdf_graph_summary} \tab Gets a graph summary for an RDF graph\cr
#'  \link[paws.database:neptunedata_get_sparql_statistics]{get_sparql_statistics} \tab Gets RDF statistics (SPARQL)\cr
#'  \link[paws.database:neptunedata_get_sparql_stream]{get_sparql_stream} \tab Gets a stream for an RDF graph\cr
#'  \link[paws.database:neptunedata_list_gremlin_queries]{list_gremlin_queries} \tab Lists active Gremlin queries\cr
#'  \link[paws.database:neptunedata_list_loader_jobs]{list_loader_jobs} \tab Retrieves a list of the loadIds for all active loader jobs\cr
#'  \link[paws.database:neptunedata_list_ml_data_processing_jobs]{list_ml_data_processing_jobs} \tab Returns a list of Neptune ML data processing jobs\cr
#'  \link[paws.database:neptunedata_list_ml_endpoints]{list_ml_endpoints} \tab Lists existing inference endpoints\cr
#'  \link[paws.database:neptunedata_list_ml_model_training_jobs]{list_ml_model_training_jobs} \tab Lists Neptune ML model-training jobs\cr
#'  \link[paws.database:neptunedata_list_ml_model_transform_jobs]{list_ml_model_transform_jobs} \tab Returns a list of model transform job IDs\cr
#'  \link[paws.database:neptunedata_list_open_cypher_queries]{list_open_cypher_queries} \tab Lists active openCypher queries\cr
#'  \link[paws.database:neptunedata_manage_propertygraph_statistics]{manage_propertygraph_statistics} \tab Manages the generation and use of property graph statistics\cr
#'  \link[paws.database:neptunedata_manage_sparql_statistics]{manage_sparql_statistics} \tab Manages the generation and use of RDF graph statistics\cr
#'  \link[paws.database:neptunedata_start_loader_job]{start_loader_job} \tab Starts a Neptune bulk loader job to load data from an Amazon S3 bucket into a Neptune DB instance\cr
#'  \link[paws.database:neptunedata_start_ml_data_processing_job]{start_ml_data_processing_job} \tab Creates a new Neptune ML data processing job for processing the graph data exported from Neptune for training\cr
#'  \link[paws.database:neptunedata_start_ml_model_training_job]{start_ml_model_training_job} \tab Creates a new Neptune ML model training job\cr
#'  \link[paws.database:neptunedata_start_ml_model_transform_job]{start_ml_model_transform_job} \tab Creates a new model transform job
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname neptunedata
#' @export
neptunedata <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::neptunedata(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon QLDB
#'
#' @description
#' The resource management API for Amazon QLDB
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- qldb(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- qldb()
#' svc$cancel_journal_kinesis_stream(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:qldb_cancel_journal_kinesis_stream]{cancel_journal_kinesis_stream} \tab Ends a given Amazon QLDB journal stream\cr
#'  \link[paws.database:qldb_create_ledger]{create_ledger} \tab Creates a new ledger in your Amazon Web Services account in the current Region\cr
#'  \link[paws.database:qldb_delete_ledger]{delete_ledger} \tab Deletes a ledger and all of its contents\cr
#'  \link[paws.database:qldb_describe_journal_kinesis_stream]{describe_journal_kinesis_stream} \tab Returns detailed information about a given Amazon QLDB journal stream\cr
#'  \link[paws.database:qldb_describe_journal_s3_export]{describe_journal_s3_export} \tab Returns information about a journal export job, including the ledger name, export ID, creation time, current status, and the parameters of the original export creation request\cr
#'  \link[paws.database:qldb_describe_ledger]{describe_ledger} \tab Returns information about a ledger, including its state, permissions mode, encryption at rest settings, and when it was created\cr
#'  \link[paws.database:qldb_export_journal_to_s3]{export_journal_to_s3} \tab Exports journal contents within a date and time range from a ledger into a specified Amazon Simple Storage Service (Amazon S3) bucket\cr
#'  \link[paws.database:qldb_get_block]{get_block} \tab Returns a block object at a specified address in a journal\cr
#'  \link[paws.database:qldb_get_digest]{get_digest} \tab Returns the digest of a ledger at the latest committed block in the journal\cr
#'  \link[paws.database:qldb_get_revision]{get_revision} \tab Returns a revision data object for a specified document ID and block address\cr
#'  \link[paws.database:qldb_list_journal_kinesis_streams_for_ledger]{list_journal_kinesis_streams_for_ledger} \tab Returns all Amazon QLDB journal streams for a given ledger\cr
#'  \link[paws.database:qldb_list_journal_s3_exports]{list_journal_s3_exports} \tab Returns all journal export jobs for all ledgers that are associated with the current Amazon Web Services account and Region\cr
#'  \link[paws.database:qldb_list_journal_s3_exports_for_ledger]{list_journal_s3_exports_for_ledger} \tab Returns all journal export jobs for a specified ledger\cr
#'  \link[paws.database:qldb_list_ledgers]{list_ledgers} \tab Returns all ledgers that are associated with the current Amazon Web Services account and Region\cr
#'  \link[paws.database:qldb_list_tags_for_resource]{list_tags_for_resource} \tab Returns all tags for a specified Amazon QLDB resource\cr
#'  \link[paws.database:qldb_stream_journal_to_kinesis]{stream_journal_to_kinesis} \tab Creates a journal stream for a given Amazon QLDB ledger\cr
#'  \link[paws.database:qldb_tag_resource]{tag_resource} \tab Adds one or more tags to a specified Amazon QLDB resource\cr
#'  \link[paws.database:qldb_untag_resource]{untag_resource} \tab Removes one or more tags from a specified Amazon QLDB resource\cr
#'  \link[paws.database:qldb_update_ledger]{update_ledger} \tab Updates properties on a ledger\cr
#'  \link[paws.database:qldb_update_ledger_permissions_mode]{update_ledger_permissions_mode} \tab Updates the permissions mode of a ledger
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname qldb
#' @export
qldb <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::qldb(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon QLDB Session
#'
#' @description
#' The transactional data APIs for Amazon QLDB
#' 
#' Instead of interacting directly with this API, we recommend using the
#' QLDB driver or the QLDB shell to execute data transactions on a ledger.
#' 
#' -   If you are working with an AWS SDK, use the QLDB driver. The driver
#'     provides a high-level abstraction layer above this *QLDB Session*
#'     data plane and manages `send_command`
#'     API calls for you. For information and a list of supported
#'     programming languages, see [Getting started with the
#'     driver](https://docs.aws.amazon.com/qldb/latest/developerguide/getting-started-driver.html)
#'     in the *Amazon QLDB Developer Guide*.
#' 
#' -   If you are working with the AWS Command Line Interface (AWS CLI),
#'     use the QLDB shell. The shell is a command line interface that uses
#'     the QLDB driver to interact with a ledger. For information, see
#'     [Accessing Amazon QLDB using the QLDB
#'     shell](https://docs.aws.amazon.com/qldb/latest/developerguide/data-shell.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- qldbsession(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- qldbsession()
#' svc$send_command(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:qldbsession_send_command]{send_command} \tab Sends a command to an Amazon QLDB ledger
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname qldbsession
#' @export
qldbsession <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::qldbsession(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Relational Database Service
#'
#' @description
#' Amazon Relational Database Service (Amazon RDS) is a web service that
#' makes it easier to set up, operate, and scale a relational database in
#' the cloud. It provides cost-efficient, resizeable capacity for an
#' industry-standard relational database and manages common database
#' administration tasks, freeing up developers to focus on what makes their
#' applications and businesses unique.
#' 
#' Amazon RDS gives you access to the capabilities of a MySQL, MariaDB,
#' PostgreSQL, Microsoft SQL Server, Oracle, Db2, or Amazon Aurora database
#' server. These capabilities mean that the code, applications, and tools
#' you already use today with your existing databases work with Amazon RDS
#' without modification. Amazon RDS automatically backs up your database
#' and maintains the database software that powers your DB instance. Amazon
#' RDS is flexible: you can scale your DB instance's compute resources and
#' storage capacity to meet your application's demand. As with all Amazon
#' Web Services, there are no up-front investments, and you pay only for
#' the resources you use.
#' 
#' This interface reference for Amazon RDS contains documentation for a
#' programming or command line interface you can use to manage Amazon RDS.
#' Amazon RDS is asynchronous, which means that some interfaces might
#' require techniques such as polling or callback functions to determine
#' when a command has been applied. In this reference, the parameter
#' descriptions indicate whether a command is applied immediately, on the
#' next instance reboot, or during the maintenance window. The reference
#' structure is as follows, and we list following some related topics from
#' the user guide.
#' 
#' **Amazon RDS API Reference**
#' 
#' -   For the alphabetical list of API actions, see [API
#'     Actions](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_Operations.html).
#' 
#' -   For the alphabetical list of data types, see [Data
#'     Types](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_Types.html).
#' 
#' -   For a list of common query parameters, see [Common
#'     Parameters](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/CommonParameters.html).
#' 
#' -   For descriptions of the error codes, see [Common
#'     Errors](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/CommonErrors.html).
#' 
#' **Amazon RDS User Guide**
#' 
#' -   For a summary of the Amazon RDS interfaces, see [Available RDS
#'     Interfaces](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Welcome.html#Welcome.Interfaces).
#' 
#' -   For more information about how to use the Query API, see [Using the
#'     Query
#'     API](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Using_the_Query_API.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- rds(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- rds()
#' # This example add a source identifier to an event notification
#' # subscription.
#' svc$add_source_identifier_to_subscription(
#'   SourceIdentifier = "mymysqlinstance",
#'   SubscriptionName = "mymysqleventsubscription"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:rds_add_role_to_db_cluster]{add_role_to_db_cluster} \tab Associates an Identity and Access Management (IAM) role with a DB cluster\cr
#'  \link[paws.database:rds_add_role_to_db_instance]{add_role_to_db_instance} \tab Associates an Amazon Web Services Identity and Access Management (IAM) role with a DB instance\cr
#'  \link[paws.database:rds_add_source_identifier_to_subscription]{add_source_identifier_to_subscription} \tab Adds a source identifier to an existing RDS event notification subscription\cr
#'  \link[paws.database:rds_add_tags_to_resource]{add_tags_to_resource} \tab Adds metadata tags to an Amazon RDS resource\cr
#'  \link[paws.database:rds_apply_pending_maintenance_action]{apply_pending_maintenance_action} \tab Applies a pending maintenance action to a resource (for example, to a DB instance)\cr
#'  \link[paws.database:rds_authorize_db_security_group_ingress]{authorize_db_security_group_ingress} \tab Enables ingress to a DBSecurityGroup using one of two forms of authorization\cr
#'  \link[paws.database:rds_backtrack_db_cluster]{backtrack_db_cluster} \tab Backtracks a DB cluster to a specific time, without creating a new DB cluster\cr
#'  \link[paws.database:rds_build_auth_token]{build_auth_token} \tab Return an authentication token for a database connection\cr
#'  \link[paws.database:rds_build_auth_token_v2]{build_auth_token_v2} \tab Generates an auth token used to connect to a db with IAM credentials\cr
#'  \link[paws.database:rds_cancel_export_task]{cancel_export_task} \tab Cancels an export task in progress that is exporting a snapshot or cluster to Amazon S3\cr
#'  \link[paws.database:rds_copy_db_cluster_parameter_group]{copy_db_cluster_parameter_group} \tab Copies the specified DB cluster parameter group\cr
#'  \link[paws.database:rds_copy_db_cluster_snapshot]{copy_db_cluster_snapshot} \tab Copies a snapshot of a DB cluster\cr
#'  \link[paws.database:rds_copy_db_parameter_group]{copy_db_parameter_group} \tab Copies the specified DB parameter group\cr
#'  \link[paws.database:rds_copy_db_snapshot]{copy_db_snapshot} \tab Copies the specified DB snapshot\cr
#'  \link[paws.database:rds_copy_option_group]{copy_option_group} \tab Copies the specified option group\cr
#'  \link[paws.database:rds_create_blue_green_deployment]{create_blue_green_deployment} \tab Creates a blue/green deployment\cr
#'  \link[paws.database:rds_create_custom_db_engine_version]{create_custom_db_engine_version} \tab Creates a custom DB engine version (CEV)\cr
#'  \link[paws.database:rds_create_db_cluster]{create_db_cluster} \tab Creates a new Amazon Aurora DB cluster or Multi-AZ DB cluster\cr
#'  \link[paws.database:rds_create_db_cluster_endpoint]{create_db_cluster_endpoint} \tab Creates a new custom endpoint and associates it with an Amazon Aurora DB cluster\cr
#'  \link[paws.database:rds_create_db_cluster_parameter_group]{create_db_cluster_parameter_group} \tab Creates a new DB cluster parameter group\cr
#'  \link[paws.database:rds_create_db_cluster_snapshot]{create_db_cluster_snapshot} \tab Creates a snapshot of a DB cluster\cr
#'  \link[paws.database:rds_create_db_instance]{create_db_instance} \tab Creates a new DB instance\cr
#'  \link[paws.database:rds_create_db_instance_read_replica]{create_db_instance_read_replica} \tab Creates a new DB instance that acts as a read replica for an existing source DB instance or Multi-AZ DB cluster\cr
#'  \link[paws.database:rds_create_db_parameter_group]{create_db_parameter_group} \tab Creates a new DB parameter group\cr
#'  \link[paws.database:rds_create_db_proxy]{create_db_proxy} \tab Creates a new DB proxy\cr
#'  \link[paws.database:rds_create_db_proxy_endpoint]{create_db_proxy_endpoint} \tab Creates a DBProxyEndpoint\cr
#'  \link[paws.database:rds_create_db_security_group]{create_db_security_group} \tab Creates a new DB security group\cr
#'  \link[paws.database:rds_create_db_shard_group]{create_db_shard_group} \tab Creates a new DB shard group for Aurora Limitless Database\cr
#'  \link[paws.database:rds_create_db_snapshot]{create_db_snapshot} \tab Creates a snapshot of a DB instance\cr
#'  \link[paws.database:rds_create_db_subnet_group]{create_db_subnet_group} \tab Creates a new DB subnet group\cr
#'  \link[paws.database:rds_create_event_subscription]{create_event_subscription} \tab Creates an RDS event notification subscription\cr
#'  \link[paws.database:rds_create_global_cluster]{create_global_cluster} \tab Creates an Aurora global database spread across multiple Amazon Web Services Regions\cr
#'  \link[paws.database:rds_create_integration]{create_integration} \tab Creates a zero-ETL integration with Amazon Redshift\cr
#'  \link[paws.database:rds_create_option_group]{create_option_group} \tab Creates a new option group\cr
#'  \link[paws.database:rds_create_tenant_database]{create_tenant_database} \tab Creates a tenant database in a DB instance that uses the multi-tenant configuration\cr
#'  \link[paws.database:rds_delete_blue_green_deployment]{delete_blue_green_deployment} \tab Deletes a blue/green deployment\cr
#'  \link[paws.database:rds_delete_custom_db_engine_version]{delete_custom_db_engine_version} \tab Deletes a custom engine version\cr
#'  \link[paws.database:rds_delete_db_cluster]{delete_db_cluster} \tab The DeleteDBCluster action deletes a previously provisioned DB cluster\cr
#'  \link[paws.database:rds_delete_db_cluster_automated_backup]{delete_db_cluster_automated_backup} \tab Deletes automated backups using the DbClusterResourceId value of the source DB cluster or the Amazon Resource Name (ARN) of the automated backups\cr
#'  \link[paws.database:rds_delete_db_cluster_endpoint]{delete_db_cluster_endpoint} \tab Deletes a custom endpoint and removes it from an Amazon Aurora DB cluster\cr
#'  \link[paws.database:rds_delete_db_cluster_parameter_group]{delete_db_cluster_parameter_group} \tab Deletes a specified DB cluster parameter group\cr
#'  \link[paws.database:rds_delete_db_cluster_snapshot]{delete_db_cluster_snapshot} \tab Deletes a DB cluster snapshot\cr
#'  \link[paws.database:rds_delete_db_instance]{delete_db_instance} \tab Deletes a previously provisioned DB instance\cr
#'  \link[paws.database:rds_delete_db_instance_automated_backup]{delete_db_instance_automated_backup} \tab Deletes automated backups using the DbiResourceId value of the source DB instance or the Amazon Resource Name (ARN) of the automated backups\cr
#'  \link[paws.database:rds_delete_db_parameter_group]{delete_db_parameter_group} \tab Deletes a specified DB parameter group\cr
#'  \link[paws.database:rds_delete_db_proxy]{delete_db_proxy} \tab Deletes an existing DB proxy\cr
#'  \link[paws.database:rds_delete_db_proxy_endpoint]{delete_db_proxy_endpoint} \tab Deletes a DBProxyEndpoint\cr
#'  \link[paws.database:rds_delete_db_security_group]{delete_db_security_group} \tab Deletes a DB security group\cr
#'  \link[paws.database:rds_delete_db_shard_group]{delete_db_shard_group} \tab Deletes an Aurora Limitless Database DB shard group\cr
#'  \link[paws.database:rds_delete_db_snapshot]{delete_db_snapshot} \tab Deletes a DB snapshot\cr
#'  \link[paws.database:rds_delete_db_subnet_group]{delete_db_subnet_group} \tab Deletes a DB subnet group\cr
#'  \link[paws.database:rds_delete_event_subscription]{delete_event_subscription} \tab Deletes an RDS event notification subscription\cr
#'  \link[paws.database:rds_delete_global_cluster]{delete_global_cluster} \tab Deletes a global database cluster\cr
#'  \link[paws.database:rds_delete_integration]{delete_integration} \tab Deletes a zero-ETL integration with Amazon Redshift\cr
#'  \link[paws.database:rds_delete_option_group]{delete_option_group} \tab Deletes an existing option group\cr
#'  \link[paws.database:rds_delete_tenant_database]{delete_tenant_database} \tab Deletes a tenant database from your DB instance\cr
#'  \link[paws.database:rds_deregister_db_proxy_targets]{deregister_db_proxy_targets} \tab Remove the association between one or more DBProxyTarget data structures and a DBProxyTargetGroup\cr
#'  \link[paws.database:rds_describe_account_attributes]{describe_account_attributes} \tab Lists all of the attributes for a customer account\cr
#'  \link[paws.database:rds_describe_blue_green_deployments]{describe_blue_green_deployments} \tab Describes one or more blue/green deployments\cr
#'  \link[paws.database:rds_describe_certificates]{describe_certificates} \tab Lists the set of certificate authority (CA) certificates provided by Amazon RDS for this Amazon Web Services account\cr
#'  \link[paws.database:rds_describe_db_cluster_automated_backups]{describe_db_cluster_automated_backups} \tab Displays backups for both current and deleted DB clusters\cr
#'  \link[paws.database:rds_describe_db_cluster_backtracks]{describe_db_cluster_backtracks} \tab Returns information about backtracks for a DB cluster\cr
#'  \link[paws.database:rds_describe_db_cluster_endpoints]{describe_db_cluster_endpoints} \tab Returns information about endpoints for an Amazon Aurora DB cluster\cr
#'  \link[paws.database:rds_describe_db_cluster_parameter_groups]{describe_db_cluster_parameter_groups} \tab Returns a list of DBClusterParameterGroup descriptions\cr
#'  \link[paws.database:rds_describe_db_cluster_parameters]{describe_db_cluster_parameters} \tab Returns the detailed parameter list for a particular DB cluster parameter group\cr
#'  \link[paws.database:rds_describe_db_clusters]{describe_db_clusters} \tab Describes existing Amazon Aurora DB clusters and Multi-AZ DB clusters\cr
#'  \link[paws.database:rds_describe_db_cluster_snapshot_attributes]{describe_db_cluster_snapshot_attributes} \tab Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot\cr
#'  \link[paws.database:rds_describe_db_cluster_snapshots]{describe_db_cluster_snapshots} \tab Returns information about DB cluster snapshots\cr
#'  \link[paws.database:rds_describe_db_engine_versions]{describe_db_engine_versions} \tab Describes the properties of specific versions of DB engines\cr
#'  \link[paws.database:rds_describe_db_instance_automated_backups]{describe_db_instance_automated_backups} \tab Displays backups for both current and deleted instances\cr
#'  \link[paws.database:rds_describe_db_instances]{describe_db_instances} \tab Describes provisioned RDS instances\cr
#'  \link[paws.database:rds_describe_db_log_files]{describe_db_log_files} \tab Returns a list of DB log files for the DB instance\cr
#'  \link[paws.database:rds_describe_db_parameter_groups]{describe_db_parameter_groups} \tab Returns a list of DBParameterGroup descriptions\cr
#'  \link[paws.database:rds_describe_db_parameters]{describe_db_parameters} \tab Returns the detailed parameter list for a particular DB parameter group\cr
#'  \link[paws.database:rds_describe_db_proxies]{describe_db_proxies} \tab Returns information about DB proxies\cr
#'  \link[paws.database:rds_describe_db_proxy_endpoints]{describe_db_proxy_endpoints} \tab Returns information about DB proxy endpoints\cr
#'  \link[paws.database:rds_describe_db_proxy_target_groups]{describe_db_proxy_target_groups} \tab Returns information about DB proxy target groups, represented by DBProxyTargetGroup data structures\cr
#'  \link[paws.database:rds_describe_db_proxy_targets]{describe_db_proxy_targets} \tab Returns information about DBProxyTarget objects\cr
#'  \link[paws.database:rds_describe_db_recommendations]{describe_db_recommendations} \tab Describes the recommendations to resolve the issues for your DB instances, DB clusters, and DB parameter groups\cr
#'  \link[paws.database:rds_describe_db_security_groups]{describe_db_security_groups} \tab Returns a list of DBSecurityGroup descriptions\cr
#'  \link[paws.database:rds_describe_db_shard_groups]{describe_db_shard_groups} \tab Describes existing Aurora Limitless Database DB shard groups\cr
#'  \link[paws.database:rds_describe_db_snapshot_attributes]{describe_db_snapshot_attributes} \tab Returns a list of DB snapshot attribute names and values for a manual DB snapshot\cr
#'  \link[paws.database:rds_describe_db_snapshots]{describe_db_snapshots} \tab Returns information about DB snapshots\cr
#'  \link[paws.database:rds_describe_db_snapshot_tenant_databases]{describe_db_snapshot_tenant_databases} \tab Describes the tenant databases that exist in a DB snapshot\cr
#'  \link[paws.database:rds_describe_db_subnet_groups]{describe_db_subnet_groups} \tab Returns a list of DBSubnetGroup descriptions\cr
#'  \link[paws.database:rds_describe_engine_default_cluster_parameters]{describe_engine_default_cluster_parameters} \tab Returns the default engine and system parameter information for the cluster database engine\cr
#'  \link[paws.database:rds_describe_engine_default_parameters]{describe_engine_default_parameters} \tab Returns the default engine and system parameter information for the specified database engine\cr
#'  \link[paws.database:rds_describe_event_categories]{describe_event_categories} \tab Displays a list of categories for all event source types, or, if specified, for a specified source type\cr
#'  \link[paws.database:rds_describe_events]{describe_events} \tab Returns events related to DB instances, DB clusters, DB parameter groups, DB security groups, DB snapshots, DB cluster snapshots, and RDS Proxies for the past 14 days\cr
#'  \link[paws.database:rds_describe_event_subscriptions]{describe_event_subscriptions} \tab Lists all the subscription descriptions for a customer account\cr
#'  \link[paws.database:rds_describe_export_tasks]{describe_export_tasks} \tab Returns information about a snapshot or cluster export to Amazon S3\cr
#'  \link[paws.database:rds_describe_global_clusters]{describe_global_clusters} \tab Returns information about Aurora global database clusters\cr
#'  \link[paws.database:rds_describe_integrations]{describe_integrations} \tab Describe one or more zero-ETL integrations with Amazon Redshift\cr
#'  \link[paws.database:rds_describe_option_group_options]{describe_option_group_options} \tab Describes all available options for the specified engine\cr
#'  \link[paws.database:rds_describe_option_groups]{describe_option_groups} \tab Describes the available option groups\cr
#'  \link[paws.database:rds_describe_orderable_db_instance_options]{describe_orderable_db_instance_options} \tab Describes the orderable DB instance options for a specified DB engine\cr
#'  \link[paws.database:rds_describe_pending_maintenance_actions]{describe_pending_maintenance_actions} \tab Returns a list of resources (for example, DB instances) that have at least one pending maintenance action\cr
#'  \link[paws.database:rds_describe_reserved_db_instances]{describe_reserved_db_instances} \tab Returns information about reserved DB instances for this account, or about a specified reserved DB instance\cr
#'  \link[paws.database:rds_describe_reserved_db_instances_offerings]{describe_reserved_db_instances_offerings} \tab Lists available reserved DB instance offerings\cr
#'  \link[paws.database:rds_describe_source_regions]{describe_source_regions} \tab Returns a list of the source Amazon Web Services Regions where the current Amazon Web Services Region can create a read replica, copy a DB snapshot from, or replicate automated backups from\cr
#'  \link[paws.database:rds_describe_tenant_databases]{describe_tenant_databases} \tab Describes the tenant databases in a DB instance that uses the multi-tenant configuration\cr
#'  \link[paws.database:rds_describe_valid_db_instance_modifications]{describe_valid_db_instance_modifications} \tab You can call DescribeValidDBInstanceModifications to learn what modifications you can make to your DB instance\cr
#'  \link[paws.database:rds_disable_http_endpoint]{disable_http_endpoint} \tab Disables the HTTP endpoint for the specified DB cluster\cr
#'  \link[paws.database:rds_download_db_log_file_portion]{download_db_log_file_portion} \tab Downloads all or a portion of the specified log file, up to 1 MB in size\cr
#'  \link[paws.database:rds_enable_http_endpoint]{enable_http_endpoint} \tab Enables the HTTP endpoint for the DB cluster\cr
#'  \link[paws.database:rds_failover_db_cluster]{failover_db_cluster} \tab Forces a failover for a DB cluster\cr
#'  \link[paws.database:rds_failover_global_cluster]{failover_global_cluster} \tab Promotes the specified secondary DB cluster to be the primary DB cluster in the global database cluster to fail over or switch over a global database\cr
#'  \link[paws.database:rds_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags on an Amazon RDS resource\cr
#'  \link[paws.database:rds_modify_activity_stream]{modify_activity_stream} \tab Changes the audit policy state of a database activity stream to either locked (default) or unlocked\cr
#'  \link[paws.database:rds_modify_certificates]{modify_certificates} \tab Override the system-default Secure Sockets Layer/Transport Layer Security (SSL/TLS) certificate for Amazon RDS for new DB instances, or remove the override\cr
#'  \link[paws.database:rds_modify_current_db_cluster_capacity]{modify_current_db_cluster_capacity} \tab Set the capacity of an Aurora Serverless v1 DB cluster to a specific value\cr
#'  \link[paws.database:rds_modify_custom_db_engine_version]{modify_custom_db_engine_version} \tab Modifies the status of a custom engine version (CEV)\cr
#'  \link[paws.database:rds_modify_db_cluster]{modify_db_cluster} \tab Modifies the settings of an Amazon Aurora DB cluster or a Multi-AZ DB cluster\cr
#'  \link[paws.database:rds_modify_db_cluster_endpoint]{modify_db_cluster_endpoint} \tab Modifies the properties of an endpoint in an Amazon Aurora DB cluster\cr
#'  \link[paws.database:rds_modify_db_cluster_parameter_group]{modify_db_cluster_parameter_group} \tab Modifies the parameters of a DB cluster parameter group\cr
#'  \link[paws.database:rds_modify_db_cluster_snapshot_attribute]{modify_db_cluster_snapshot_attribute} \tab Adds an attribute and values to, or removes an attribute and values from, a manual DB cluster snapshot\cr
#'  \link[paws.database:rds_modify_db_instance]{modify_db_instance} \tab Modifies settings for a DB instance\cr
#'  \link[paws.database:rds_modify_db_parameter_group]{modify_db_parameter_group} \tab Modifies the parameters of a DB parameter group\cr
#'  \link[paws.database:rds_modify_db_proxy]{modify_db_proxy} \tab Changes the settings for an existing DB proxy\cr
#'  \link[paws.database:rds_modify_db_proxy_endpoint]{modify_db_proxy_endpoint} \tab Changes the settings for an existing DB proxy endpoint\cr
#'  \link[paws.database:rds_modify_db_proxy_target_group]{modify_db_proxy_target_group} \tab Modifies the properties of a DBProxyTargetGroup\cr
#'  \link[paws.database:rds_modify_db_recommendation]{modify_db_recommendation} \tab Updates the recommendation status and recommended action status for the specified recommendation\cr
#'  \link[paws.database:rds_modify_db_shard_group]{modify_db_shard_group} \tab Modifies the settings of an Aurora Limitless Database DB shard group\cr
#'  \link[paws.database:rds_modify_db_snapshot]{modify_db_snapshot} \tab Updates a manual DB snapshot with a new engine version\cr
#'  \link[paws.database:rds_modify_db_snapshot_attribute]{modify_db_snapshot_attribute} \tab Adds an attribute and values to, or removes an attribute and values from, a manual DB snapshot\cr
#'  \link[paws.database:rds_modify_db_subnet_group]{modify_db_subnet_group} \tab Modifies an existing DB subnet group\cr
#'  \link[paws.database:rds_modify_event_subscription]{modify_event_subscription} \tab Modifies an existing RDS event notification subscription\cr
#'  \link[paws.database:rds_modify_global_cluster]{modify_global_cluster} \tab Modifies a setting for an Amazon Aurora global database cluster\cr
#'  \link[paws.database:rds_modify_integration]{modify_integration} \tab Modifies a zero-ETL integration with Amazon Redshift\cr
#'  \link[paws.database:rds_modify_option_group]{modify_option_group} \tab Modifies an existing option group\cr
#'  \link[paws.database:rds_modify_tenant_database]{modify_tenant_database} \tab Modifies an existing tenant database in a DB instance\cr
#'  \link[paws.database:rds_promote_read_replica]{promote_read_replica} \tab Promotes a read replica DB instance to a standalone DB instance\cr
#'  \link[paws.database:rds_promote_read_replica_db_cluster]{promote_read_replica_db_cluster} \tab Promotes a read replica DB cluster to a standalone DB cluster\cr
#'  \link[paws.database:rds_purchase_reserved_db_instances_offering]{purchase_reserved_db_instances_offering} \tab Purchases a reserved DB instance offering\cr
#'  \link[paws.database:rds_reboot_db_cluster]{reboot_db_cluster} \tab You might need to reboot your DB cluster, usually for maintenance reasons\cr
#'  \link[paws.database:rds_reboot_db_instance]{reboot_db_instance} \tab You might need to reboot your DB instance, usually for maintenance reasons\cr
#'  \link[paws.database:rds_reboot_db_shard_group]{reboot_db_shard_group} \tab You might need to reboot your DB shard group, usually for maintenance reasons\cr
#'  \link[paws.database:rds_register_db_proxy_targets]{register_db_proxy_targets} \tab Associate one or more DBProxyTarget data structures with a DBProxyTargetGroup\cr
#'  \link[paws.database:rds_remove_from_global_cluster]{remove_from_global_cluster} \tab Detaches an Aurora secondary cluster from an Aurora global database cluster\cr
#'  \link[paws.database:rds_remove_role_from_db_cluster]{remove_role_from_db_cluster} \tab Removes the asssociation of an Amazon Web Services Identity and Access Management (IAM) role from a DB cluster\cr
#'  \link[paws.database:rds_remove_role_from_db_instance]{remove_role_from_db_instance} \tab Disassociates an Amazon Web Services Identity and Access Management (IAM) role from a DB instance\cr
#'  \link[paws.database:rds_remove_source_identifier_from_subscription]{remove_source_identifier_from_subscription} \tab Removes a source identifier from an existing RDS event notification subscription\cr
#'  \link[paws.database:rds_remove_tags_from_resource]{remove_tags_from_resource} \tab Removes metadata tags from an Amazon RDS resource\cr
#'  \link[paws.database:rds_reset_db_cluster_parameter_group]{reset_db_cluster_parameter_group} \tab Modifies the parameters of a DB cluster parameter group to the default value\cr
#'  \link[paws.database:rds_reset_db_parameter_group]{reset_db_parameter_group} \tab Modifies the parameters of a DB parameter group to the engine/system default value\cr
#'  \link[paws.database:rds_restore_db_cluster_from_s3]{restore_db_cluster_from_s3} \tab Creates an Amazon Aurora DB cluster from MySQL data stored in an Amazon S3 bucket\cr
#'  \link[paws.database:rds_restore_db_cluster_from_snapshot]{restore_db_cluster_from_snapshot} \tab Creates a new DB cluster from a DB snapshot or DB cluster snapshot\cr
#'  \link[paws.database:rds_restore_db_cluster_to_point_in_time]{restore_db_cluster_to_point_in_time} \tab Restores a DB cluster to an arbitrary point in time\cr
#'  \link[paws.database:rds_restore_db_instance_from_db_snapshot]{restore_db_instance_from_db_snapshot} \tab Creates a new DB instance from a DB snapshot\cr
#'  \link[paws.database:rds_restore_db_instance_from_s3]{restore_db_instance_from_s3} \tab Amazon Relational Database Service (Amazon RDS) supports importing MySQL databases by using backup files\cr
#'  \link[paws.database:rds_restore_db_instance_to_point_in_time]{restore_db_instance_to_point_in_time} \tab Restores a DB instance to an arbitrary point in time\cr
#'  \link[paws.database:rds_revoke_db_security_group_ingress]{revoke_db_security_group_ingress} \tab Revokes ingress from a DBSecurityGroup for previously authorized IP ranges or EC2 or VPC security groups\cr
#'  \link[paws.database:rds_start_activity_stream]{start_activity_stream} \tab Starts a database activity stream to monitor activity on the database\cr
#'  \link[paws.database:rds_start_db_cluster]{start_db_cluster} \tab Starts an Amazon Aurora DB cluster that was stopped using the Amazon Web Services console, the stop-db-cluster CLI command, or the StopDBCluster operation\cr
#'  \link[paws.database:rds_start_db_instance]{start_db_instance} \tab Starts an Amazon RDS DB instance that was stopped using the Amazon Web Services console, the stop-db-instance CLI command, or the StopDBInstance operation\cr
#'  \link[paws.database:rds_start_db_instance_automated_backups_replication]{start_db_instance_automated_backups_replication} \tab Enables replication of automated backups to a different Amazon Web Services Region\cr
#'  \link[paws.database:rds_start_export_task]{start_export_task} \tab Starts an export of DB snapshot or DB cluster data to Amazon S3\cr
#'  \link[paws.database:rds_stop_activity_stream]{stop_activity_stream} \tab Stops a database activity stream that was started using the Amazon Web Services console, the start-activity-stream CLI command, or the StartActivityStream operation\cr
#'  \link[paws.database:rds_stop_db_cluster]{stop_db_cluster} \tab Stops an Amazon Aurora DB cluster\cr
#'  \link[paws.database:rds_stop_db_instance]{stop_db_instance} \tab Stops an Amazon RDS DB instance temporarily\cr
#'  \link[paws.database:rds_stop_db_instance_automated_backups_replication]{stop_db_instance_automated_backups_replication} \tab Stops automated backup replication for a DB instance\cr
#'  \link[paws.database:rds_switchover_blue_green_deployment]{switchover_blue_green_deployment} \tab Switches over a blue/green deployment\cr
#'  \link[paws.database:rds_switchover_global_cluster]{switchover_global_cluster} \tab Switches over the specified secondary DB cluster to be the new primary DB cluster in the global database cluster\cr
#'  \link[paws.database:rds_switchover_read_replica]{switchover_read_replica} \tab Switches over an Oracle standby database in an Oracle Data Guard environment, making it the new primary database
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname rds
#' @export
rds <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::rds(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS RDS DataService
#'
#' @description
#' RDS Data API
#' 
#' Amazon RDS provides an HTTP endpoint to run SQL statements on an Amazon
#' Aurora DB cluster. To run these statements, you use the RDS Data API
#' (Data API).
#' 
#' Data API is available with the following types of Aurora databases:
#' 
#' -   Aurora PostgreSQL - Serverless v2, provisioned, and Serverless v1
#' 
#' -   Aurora MySQL - Serverless v2, provisioned, and Serverless v1
#' 
#' For more information about the Data API, see [Using RDS Data
#' API](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/data-api.html)
#' in the *Amazon Aurora User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- rdsdataservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- rdsdataservice()
#' svc$batch_execute_statement(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:rdsdataservice_batch_execute_statement]{batch_execute_statement} \tab Runs a batch SQL statement over an array of data\cr
#'  \link[paws.database:rdsdataservice_begin_transaction]{begin_transaction} \tab Starts a SQL transaction\cr
#'  \link[paws.database:rdsdataservice_commit_transaction]{commit_transaction} \tab Ends a SQL transaction started with the BeginTransaction operation and commits the changes\cr
#'  \link[paws.database:rdsdataservice_execute_sql]{execute_sql} \tab Runs one or more SQL statements\cr
#'  \link[paws.database:rdsdataservice_execute_statement]{execute_statement} \tab Runs a SQL statement against a database\cr
#'  \link[paws.database:rdsdataservice_rollback_transaction]{rollback_transaction} \tab Performs a rollback of a transaction
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname rdsdataservice
#' @export
rdsdataservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::rdsdataservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Redshift
#'
#' @description
#' **Overview**
#' 
#' This is an interface reference for Amazon Redshift. It contains
#' documentation for one of the programming or command line interfaces you
#' can use to manage Amazon Redshift clusters. Note that Amazon Redshift is
#' asynchronous, which means that some interfaces may require techniques,
#' such as polling or asynchronous callback handlers, to determine when a
#' command has been applied. In this reference, the parameter descriptions
#' indicate whether a change is applied immediately, on the next instance
#' reboot, or during the next maintenance window. For a summary of the
#' Amazon Redshift cluster management interfaces, go to [Using the Amazon
#' Redshift Management
#' Interfaces](https://docs.aws.amazon.com/redshift/latest/mgmt/using-aws-sdk.html).
#' 
#' Amazon Redshift manages all the work of setting up, operating, and
#' scaling a data warehouse: provisioning capacity, monitoring and backing
#' up the cluster, and applying patches and upgrades to the Amazon Redshift
#' engine. You can focus on using your data to acquire new insights for
#' your business and customers.
#' 
#' If you are a first-time user of Amazon Redshift, we recommend that you
#' begin by reading the [Amazon Redshift Getting Started
#' Guide](https://docs.aws.amazon.com/redshift/latest/gsg/getting-started.html).
#' 
#' If you are a database developer, the [Amazon Redshift Database Developer
#' Guide](https://docs.aws.amazon.com/redshift/latest/dg/welcome.html)
#' explains how to design, build, query, and maintain the databases that
#' make up your data warehouse.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- redshift(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- redshift()
#' svc$accept_reserved_node_exchange(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:redshift_accept_reserved_node_exchange]{accept_reserved_node_exchange} \tab Exchanges a DC1 Reserved Node for a DC2 Reserved Node with no changes to the configuration (term, payment type, or number of nodes) and no additional costs\cr
#'  \link[paws.database:redshift_add_partner]{add_partner} \tab Adds a partner integration to a cluster\cr
#'  \link[paws.database:redshift_associate_data_share_consumer]{associate_data_share_consumer} \tab From a datashare consumer account, associates a datashare with the account (AssociateEntireAccount) or the specified namespace (ConsumerArn)\cr
#'  \link[paws.database:redshift_authorize_cluster_security_group_ingress]{authorize_cluster_security_group_ingress} \tab Adds an inbound (ingress) rule to an Amazon Redshift security group\cr
#'  \link[paws.database:redshift_authorize_data_share]{authorize_data_share} \tab From a data producer account, authorizes the sharing of a datashare with one or more consumer accounts or managing entities\cr
#'  \link[paws.database:redshift_authorize_endpoint_access]{authorize_endpoint_access} \tab Grants access to a cluster\cr
#'  \link[paws.database:redshift_authorize_snapshot_access]{authorize_snapshot_access} \tab Authorizes the specified Amazon Web Services account to restore the specified snapshot\cr
#'  \link[paws.database:redshift_batch_delete_cluster_snapshots]{batch_delete_cluster_snapshots} \tab Deletes a set of cluster snapshots\cr
#'  \link[paws.database:redshift_batch_modify_cluster_snapshots]{batch_modify_cluster_snapshots} \tab Modifies the settings for a set of cluster snapshots\cr
#'  \link[paws.database:redshift_cancel_resize]{cancel_resize} \tab Cancels a resize operation for a cluster\cr
#'  \link[paws.database:redshift_copy_cluster_snapshot]{copy_cluster_snapshot} \tab Copies the specified automated cluster snapshot to a new manual cluster snapshot\cr
#'  \link[paws.database:redshift_create_authentication_profile]{create_authentication_profile} \tab Creates an authentication profile with the specified parameters\cr
#'  \link[paws.database:redshift_create_cluster]{create_cluster} \tab Creates a new cluster with the specified parameters\cr
#'  \link[paws.database:redshift_create_cluster_parameter_group]{create_cluster_parameter_group} \tab Creates an Amazon Redshift parameter group\cr
#'  \link[paws.database:redshift_create_cluster_security_group]{create_cluster_security_group} \tab Creates a new Amazon Redshift security group\cr
#'  \link[paws.database:redshift_create_cluster_snapshot]{create_cluster_snapshot} \tab Creates a manual snapshot of the specified cluster\cr
#'  \link[paws.database:redshift_create_cluster_subnet_group]{create_cluster_subnet_group} \tab Creates a new Amazon Redshift subnet group\cr
#'  \link[paws.database:redshift_create_custom_domain_association]{create_custom_domain_association} \tab Used to create a custom domain name for a cluster\cr
#'  \link[paws.database:redshift_create_endpoint_access]{create_endpoint_access} \tab Creates a Redshift-managed VPC endpoint\cr
#'  \link[paws.database:redshift_create_event_subscription]{create_event_subscription} \tab Creates an Amazon Redshift event notification subscription\cr
#'  \link[paws.database:redshift_create_hsm_client_certificate]{create_hsm_client_certificate} \tab Creates an HSM client certificate that an Amazon Redshift cluster will use to connect to the client's HSM in order to store and retrieve the keys used to encrypt the cluster databases\cr
#'  \link[paws.database:redshift_create_hsm_configuration]{create_hsm_configuration} \tab Creates an HSM configuration that contains the information required by an Amazon Redshift cluster to store and use database encryption keys in a Hardware Security Module (HSM)\cr
#'  \link[paws.database:redshift_create_integration]{create_integration} \tab Creates a zero-ETL integration or S3 event integration with Amazon Redshift\cr
#'  \link[paws.database:redshift_create_redshift_idc_application]{create_redshift_idc_application} \tab Creates an Amazon Redshift application for use with IAM Identity Center\cr
#'  \link[paws.database:redshift_create_scheduled_action]{create_scheduled_action} \tab Creates a scheduled action\cr
#'  \link[paws.database:redshift_create_snapshot_copy_grant]{create_snapshot_copy_grant} \tab Creates a snapshot copy grant that permits Amazon Redshift to use an encrypted symmetric key from Key Management Service (KMS) to encrypt copied snapshots in a destination region\cr
#'  \link[paws.database:redshift_create_snapshot_schedule]{create_snapshot_schedule} \tab Create a snapshot schedule that can be associated to a cluster and which overrides the default system backup schedule\cr
#'  \link[paws.database:redshift_create_tags]{create_tags} \tab Adds tags to a cluster\cr
#'  \link[paws.database:redshift_create_usage_limit]{create_usage_limit} \tab Creates a usage limit for a specified Amazon Redshift feature on a cluster\cr
#'  \link[paws.database:redshift_deauthorize_data_share]{deauthorize_data_share} \tab From a datashare producer account, removes authorization from the specified datashare\cr
#'  \link[paws.database:redshift_delete_authentication_profile]{delete_authentication_profile} \tab Deletes an authentication profile\cr
#'  \link[paws.database:redshift_delete_cluster]{delete_cluster} \tab Deletes a previously provisioned cluster without its final snapshot being created\cr
#'  \link[paws.database:redshift_delete_cluster_parameter_group]{delete_cluster_parameter_group} \tab Deletes a specified Amazon Redshift parameter group\cr
#'  \link[paws.database:redshift_delete_cluster_security_group]{delete_cluster_security_group} \tab Deletes an Amazon Redshift security group\cr
#'  \link[paws.database:redshift_delete_cluster_snapshot]{delete_cluster_snapshot} \tab Deletes the specified manual snapshot\cr
#'  \link[paws.database:redshift_delete_cluster_subnet_group]{delete_cluster_subnet_group} \tab Deletes the specified cluster subnet group\cr
#'  \link[paws.database:redshift_delete_custom_domain_association]{delete_custom_domain_association} \tab Contains information about deleting a custom domain association for a cluster\cr
#'  \link[paws.database:redshift_delete_endpoint_access]{delete_endpoint_access} \tab Deletes a Redshift-managed VPC endpoint\cr
#'  \link[paws.database:redshift_delete_event_subscription]{delete_event_subscription} \tab Deletes an Amazon Redshift event notification subscription\cr
#'  \link[paws.database:redshift_delete_hsm_client_certificate]{delete_hsm_client_certificate} \tab Deletes the specified HSM client certificate\cr
#'  \link[paws.database:redshift_delete_hsm_configuration]{delete_hsm_configuration} \tab Deletes the specified Amazon Redshift HSM configuration\cr
#'  \link[paws.database:redshift_delete_integration]{delete_integration} \tab Deletes a zero-ETL integration or S3 event integration with Amazon Redshift\cr
#'  \link[paws.database:redshift_delete_partner]{delete_partner} \tab Deletes a partner integration from a cluster\cr
#'  \link[paws.database:redshift_delete_redshift_idc_application]{delete_redshift_idc_application} \tab Deletes an Amazon Redshift IAM Identity Center application\cr
#'  \link[paws.database:redshift_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource policy for a specified resource\cr
#'  \link[paws.database:redshift_delete_scheduled_action]{delete_scheduled_action} \tab Deletes a scheduled action\cr
#'  \link[paws.database:redshift_delete_snapshot_copy_grant]{delete_snapshot_copy_grant} \tab Deletes the specified snapshot copy grant\cr
#'  \link[paws.database:redshift_delete_snapshot_schedule]{delete_snapshot_schedule} \tab Deletes a snapshot schedule\cr
#'  \link[paws.database:redshift_delete_tags]{delete_tags} \tab Deletes tags from a resource\cr
#'  \link[paws.database:redshift_delete_usage_limit]{delete_usage_limit} \tab Deletes a usage limit from a cluster\cr
#'  \link[paws.database:redshift_deregister_namespace]{deregister_namespace} \tab Deregisters a cluster or serverless namespace from the Amazon Web Services Glue Data Catalog\cr
#'  \link[paws.database:redshift_describe_account_attributes]{describe_account_attributes} \tab Returns a list of attributes attached to an account\cr
#'  \link[paws.database:redshift_describe_authentication_profiles]{describe_authentication_profiles} \tab Describes an authentication profile\cr
#'  \link[paws.database:redshift_describe_cluster_db_revisions]{describe_cluster_db_revisions} \tab Returns an array of ClusterDbRevision objects\cr
#'  \link[paws.database:redshift_describe_cluster_parameter_groups]{describe_cluster_parameter_groups} \tab Returns a list of Amazon Redshift parameter groups, including parameter groups you created and the default parameter group\cr
#'  \link[paws.database:redshift_describe_cluster_parameters]{describe_cluster_parameters} \tab Returns a detailed list of parameters contained within the specified Amazon Redshift parameter group\cr
#'  \link[paws.database:redshift_describe_clusters]{describe_clusters} \tab Returns properties of provisioned clusters including general cluster properties, cluster database properties, maintenance and backup properties, and security and access properties\cr
#'  \link[paws.database:redshift_describe_cluster_security_groups]{describe_cluster_security_groups} \tab Returns information about Amazon Redshift security groups\cr
#'  \link[paws.database:redshift_describe_cluster_snapshots]{describe_cluster_snapshots} \tab Returns one or more snapshot objects, which contain metadata about your cluster snapshots\cr
#'  \link[paws.database:redshift_describe_cluster_subnet_groups]{describe_cluster_subnet_groups} \tab Returns one or more cluster subnet group objects, which contain metadata about your cluster subnet groups\cr
#'  \link[paws.database:redshift_describe_cluster_tracks]{describe_cluster_tracks} \tab Returns a list of all the available maintenance tracks\cr
#'  \link[paws.database:redshift_describe_cluster_versions]{describe_cluster_versions} \tab Returns descriptions of the available Amazon Redshift cluster versions\cr
#'  \link[paws.database:redshift_describe_custom_domain_associations]{describe_custom_domain_associations} \tab Contains information about custom domain associations for a cluster\cr
#'  \link[paws.database:redshift_describe_data_shares]{describe_data_shares} \tab Shows the status of any inbound or outbound datashares available in the specified account\cr
#'  \link[paws.database:redshift_describe_data_shares_for_consumer]{describe_data_shares_for_consumer} \tab Returns a list of datashares where the account identifier being called is a consumer account identifier\cr
#'  \link[paws.database:redshift_describe_data_shares_for_producer]{describe_data_shares_for_producer} \tab Returns a list of datashares when the account identifier being called is a producer account identifier\cr
#'  \link[paws.database:redshift_describe_default_cluster_parameters]{describe_default_cluster_parameters} \tab Returns a list of parameter settings for the specified parameter group family\cr
#'  \link[paws.database:redshift_describe_endpoint_access]{describe_endpoint_access} \tab Describes a Redshift-managed VPC endpoint\cr
#'  \link[paws.database:redshift_describe_endpoint_authorization]{describe_endpoint_authorization} \tab Describes an endpoint authorization\cr
#'  \link[paws.database:redshift_describe_event_categories]{describe_event_categories} \tab Displays a list of event categories for all event source types, or for a specified source type\cr
#'  \link[paws.database:redshift_describe_events]{describe_events} \tab Returns events related to clusters, security groups, snapshots, and parameter groups for the past 14 days\cr
#'  \link[paws.database:redshift_describe_event_subscriptions]{describe_event_subscriptions} \tab Lists descriptions of all the Amazon Redshift event notification subscriptions for a customer account\cr
#'  \link[paws.database:redshift_describe_hsm_client_certificates]{describe_hsm_client_certificates} \tab Returns information about the specified HSM client certificate\cr
#'  \link[paws.database:redshift_describe_hsm_configurations]{describe_hsm_configurations} \tab Returns information about the specified Amazon Redshift HSM configuration\cr
#'  \link[paws.database:redshift_describe_inbound_integrations]{describe_inbound_integrations} \tab Returns a list of inbound integrations\cr
#'  \link[paws.database:redshift_describe_integrations]{describe_integrations} \tab Describes one or more zero-ETL or S3 event integrations with Amazon Redshift\cr
#'  \link[paws.database:redshift_describe_logging_status]{describe_logging_status} \tab Describes whether information, such as queries and connection attempts, is being logged for the specified Amazon Redshift cluster\cr
#'  \link[paws.database:redshift_describe_node_configuration_options]{describe_node_configuration_options} \tab Returns properties of possible node configurations such as node type, number of nodes, and disk usage for the specified action type\cr
#'  \link[paws.database:redshift_describe_orderable_cluster_options]{describe_orderable_cluster_options} \tab Returns a list of orderable cluster options\cr
#'  \link[paws.database:redshift_describe_partners]{describe_partners} \tab Returns information about the partner integrations defined for a cluster\cr
#'  \link[paws.database:redshift_describe_redshift_idc_applications]{describe_redshift_idc_applications} \tab Lists the Amazon Redshift IAM Identity Center applications\cr
#'  \link[paws.database:redshift_describe_reserved_node_exchange_status]{describe_reserved_node_exchange_status} \tab Returns exchange status details and associated metadata for a reserved-node exchange\cr
#'  \link[paws.database:redshift_describe_reserved_node_offerings]{describe_reserved_node_offerings} \tab Returns a list of the available reserved node offerings by Amazon Redshift with their descriptions including the node type, the fixed and recurring costs of reserving the node and duration the node will be reserved for you\cr
#'  \link[paws.database:redshift_describe_reserved_nodes]{describe_reserved_nodes} \tab Returns the descriptions of the reserved nodes\cr
#'  \link[paws.database:redshift_describe_resize]{describe_resize} \tab Returns information about the last resize operation for the specified cluster\cr
#'  \link[paws.database:redshift_describe_scheduled_actions]{describe_scheduled_actions} \tab Describes properties of scheduled actions\cr
#'  \link[paws.database:redshift_describe_snapshot_copy_grants]{describe_snapshot_copy_grants} \tab Returns a list of snapshot copy grants owned by the Amazon Web Services account in the destination region\cr
#'  \link[paws.database:redshift_describe_snapshot_schedules]{describe_snapshot_schedules} \tab Returns a list of snapshot schedules\cr
#'  \link[paws.database:redshift_describe_storage]{describe_storage} \tab Returns account level backups storage size and provisional storage\cr
#'  \link[paws.database:redshift_describe_table_restore_status]{describe_table_restore_status} \tab Lists the status of one or more table restore requests made using the RestoreTableFromClusterSnapshot API action\cr
#'  \link[paws.database:redshift_describe_tags]{describe_tags} \tab Returns a list of tags\cr
#'  \link[paws.database:redshift_describe_usage_limits]{describe_usage_limits} \tab Shows usage limits on a cluster\cr
#'  \link[paws.database:redshift_disable_logging]{disable_logging} \tab Stops logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster\cr
#'  \link[paws.database:redshift_disable_snapshot_copy]{disable_snapshot_copy} \tab Disables the automatic copying of snapshots from one region to another region for a specified cluster\cr
#'  \link[paws.database:redshift_disassociate_data_share_consumer]{disassociate_data_share_consumer} \tab From a datashare consumer account, remove association for the specified datashare\cr
#'  \link[paws.database:redshift_enable_logging]{enable_logging} \tab Starts logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster\cr
#'  \link[paws.database:redshift_enable_snapshot_copy]{enable_snapshot_copy} \tab Enables the automatic copy of snapshots from one region to another region for a specified cluster\cr
#'  \link[paws.database:redshift_failover_primary_compute]{failover_primary_compute} \tab Fails over the primary compute unit of the specified Multi-AZ cluster to another Availability Zone\cr
#'  \link[paws.database:redshift_get_cluster_credentials]{get_cluster_credentials} \tab Returns a database user name and temporary password with temporary authorization to log on to an Amazon Redshift database\cr
#'  \link[paws.database:redshift_get_cluster_credentials_with_iam]{get_cluster_credentials_with_iam} \tab Returns a database user name and temporary password with temporary authorization to log in to an Amazon Redshift database\cr
#'  \link[paws.database:redshift_get_reserved_node_exchange_configuration_options]{get_reserved_node_exchange_configuration_options} \tab Gets the configuration options for the reserved-node exchange\cr
#'  \link[paws.database:redshift_get_reserved_node_exchange_offerings]{get_reserved_node_exchange_offerings} \tab Returns an array of DC2 ReservedNodeOfferings that matches the payment type, term, and usage price of the given DC1 reserved node\cr
#'  \link[paws.database:redshift_get_resource_policy]{get_resource_policy} \tab Get the resource policy for a specified resource\cr
#'  \link[paws.database:redshift_list_recommendations]{list_recommendations} \tab List the Amazon Redshift Advisor recommendations for one or multiple Amazon Redshift clusters in an Amazon Web Services account\cr
#'  \link[paws.database:redshift_modify_aqua_configuration]{modify_aqua_configuration} \tab This operation is retired\cr
#'  \link[paws.database:redshift_modify_authentication_profile]{modify_authentication_profile} \tab Modifies an authentication profile\cr
#'  \link[paws.database:redshift_modify_cluster]{modify_cluster} \tab Modifies the settings for a cluster\cr
#'  \link[paws.database:redshift_modify_cluster_db_revision]{modify_cluster_db_revision} \tab Modifies the database revision of a cluster\cr
#'  \link[paws.database:redshift_modify_cluster_iam_roles]{modify_cluster_iam_roles} \tab Modifies the list of Identity and Access Management (IAM) roles that can be used by the cluster to access other Amazon Web Services services\cr
#'  \link[paws.database:redshift_modify_cluster_maintenance]{modify_cluster_maintenance} \tab Modifies the maintenance settings of a cluster\cr
#'  \link[paws.database:redshift_modify_cluster_parameter_group]{modify_cluster_parameter_group} \tab Modifies the parameters of a parameter group\cr
#'  \link[paws.database:redshift_modify_cluster_snapshot]{modify_cluster_snapshot} \tab Modifies the settings for a snapshot\cr
#'  \link[paws.database:redshift_modify_cluster_snapshot_schedule]{modify_cluster_snapshot_schedule} \tab Modifies a snapshot schedule for a cluster\cr
#'  \link[paws.database:redshift_modify_cluster_subnet_group]{modify_cluster_subnet_group} \tab Modifies a cluster subnet group to include the specified list of VPC subnets\cr
#'  \link[paws.database:redshift_modify_custom_domain_association]{modify_custom_domain_association} \tab Contains information for changing a custom domain association\cr
#'  \link[paws.database:redshift_modify_endpoint_access]{modify_endpoint_access} \tab Modifies a Redshift-managed VPC endpoint\cr
#'  \link[paws.database:redshift_modify_event_subscription]{modify_event_subscription} \tab Modifies an existing Amazon Redshift event notification subscription\cr
#'  \link[paws.database:redshift_modify_integration]{modify_integration} \tab Modifies a zero-ETL integration or S3 event integration with Amazon Redshift\cr
#'  \link[paws.database:redshift_modify_redshift_idc_application]{modify_redshift_idc_application} \tab Changes an existing Amazon Redshift IAM Identity Center application\cr
#'  \link[paws.database:redshift_modify_scheduled_action]{modify_scheduled_action} \tab Modifies a scheduled action\cr
#'  \link[paws.database:redshift_modify_snapshot_copy_retention_period]{modify_snapshot_copy_retention_period} \tab Modifies the number of days to retain snapshots in the destination Amazon Web Services Region after they are copied from the source Amazon Web Services Region\cr
#'  \link[paws.database:redshift_modify_snapshot_schedule]{modify_snapshot_schedule} \tab Modifies a snapshot schedule\cr
#'  \link[paws.database:redshift_modify_usage_limit]{modify_usage_limit} \tab Modifies a usage limit in a cluster\cr
#'  \link[paws.database:redshift_pause_cluster]{pause_cluster} \tab Pauses a cluster\cr
#'  \link[paws.database:redshift_purchase_reserved_node_offering]{purchase_reserved_node_offering} \tab Allows you to purchase reserved nodes\cr
#'  \link[paws.database:redshift_put_resource_policy]{put_resource_policy} \tab Updates the resource policy for a specified resource\cr
#'  \link[paws.database:redshift_reboot_cluster]{reboot_cluster} \tab Reboots a cluster\cr
#'  \link[paws.database:redshift_register_namespace]{register_namespace} \tab Registers a cluster or serverless namespace to the Amazon Web Services Glue Data Catalog\cr
#'  \link[paws.database:redshift_reject_data_share]{reject_data_share} \tab From a datashare consumer account, rejects the specified datashare\cr
#'  \link[paws.database:redshift_reset_cluster_parameter_group]{reset_cluster_parameter_group} \tab Sets one or more parameters of the specified parameter group to their default values and sets the source values of the parameters to "engine-default"\cr
#'  \link[paws.database:redshift_resize_cluster]{resize_cluster} \tab Changes the size of the cluster\cr
#'  \link[paws.database:redshift_restore_from_cluster_snapshot]{restore_from_cluster_snapshot} \tab Creates a new cluster from a snapshot\cr
#'  \link[paws.database:redshift_restore_table_from_cluster_snapshot]{restore_table_from_cluster_snapshot} \tab Creates a new table from a table in an Amazon Redshift cluster snapshot\cr
#'  \link[paws.database:redshift_resume_cluster]{resume_cluster} \tab Resumes a paused cluster\cr
#'  \link[paws.database:redshift_revoke_cluster_security_group_ingress]{revoke_cluster_security_group_ingress} \tab Revokes an ingress rule in an Amazon Redshift security group for a previously authorized IP range or Amazon EC2 security group\cr
#'  \link[paws.database:redshift_revoke_endpoint_access]{revoke_endpoint_access} \tab Revokes access to a cluster\cr
#'  \link[paws.database:redshift_revoke_snapshot_access]{revoke_snapshot_access} \tab Removes the ability of the specified Amazon Web Services account to restore the specified snapshot\cr
#'  \link[paws.database:redshift_rotate_encryption_key]{rotate_encryption_key} \tab Rotates the encryption keys for a cluster\cr
#'  \link[paws.database:redshift_update_partner_status]{update_partner_status} \tab Updates the status of a partner integration
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname redshift
#' @export
redshift <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::redshift(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Redshift Data API Service
#'
#' @description
#' You can use the Amazon Redshift Data API to run queries on Amazon
#' Redshift tables. You can run SQL statements, which are committed if the
#' statement succeeds.
#' 
#' For more information about the Amazon Redshift Data API and CLI usage
#' examples, see [Using the Amazon Redshift Data
#' API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in
#' the *Amazon Redshift Management Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- redshiftdataapiservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- redshiftdataapiservice()
#' svc$batch_execute_statement(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:redshiftdataapiservice_batch_execute_statement]{batch_execute_statement} \tab Runs one or more SQL statements, which can be data manipulation language (DML) or data definition language (DDL)\cr
#'  \link[paws.database:redshiftdataapiservice_cancel_statement]{cancel_statement} \tab Cancels a running query\cr
#'  \link[paws.database:redshiftdataapiservice_describe_statement]{describe_statement} \tab Describes the details about a specific instance when a query was run by the Amazon Redshift Data API\cr
#'  \link[paws.database:redshiftdataapiservice_describe_table]{describe_table} \tab Describes the detailed information about a table from metadata in the cluster\cr
#'  \link[paws.database:redshiftdataapiservice_execute_statement]{execute_statement} \tab Runs an SQL statement, which can be data manipulation language (DML) or data definition language (DDL)\cr
#'  \link[paws.database:redshiftdataapiservice_get_statement_result]{get_statement_result} \tab Fetches the temporarily cached result of an SQL statement in JSON format\cr
#'  \link[paws.database:redshiftdataapiservice_get_statement_result_v2]{get_statement_result_v2} \tab Fetches the temporarily cached result of an SQL statement in CSV format\cr
#'  \link[paws.database:redshiftdataapiservice_list_databases]{list_databases} \tab List the databases in a cluster\cr
#'  \link[paws.database:redshiftdataapiservice_list_schemas]{list_schemas} \tab Lists the schemas in a database\cr
#'  \link[paws.database:redshiftdataapiservice_list_statements]{list_statements} \tab List of SQL statements\cr
#'  \link[paws.database:redshiftdataapiservice_list_tables]{list_tables} \tab List the tables in a database
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname redshiftdataapiservice
#' @export
redshiftdataapiservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::redshiftdataapiservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Redshift Serverless
#'
#' @description
#' This is an interface reference for Amazon Redshift Serverless. It
#' contains documentation for one of the programming or command line
#' interfaces you can use to manage Amazon Redshift Serverless.
#' 
#' Amazon Redshift Serverless automatically provisions data warehouse
#' capacity and intelligently scales the underlying resources based on
#' workload demands. Amazon Redshift Serverless adjusts capacity in seconds
#' to deliver consistently high performance and simplified operations for
#' even the most demanding and volatile workloads. Amazon Redshift
#' Serverless lets you focus on using your data to acquire new insights for
#' your business and customers.
#' 
#' To learn more about Amazon Redshift Serverless, see [What is Amazon
#' Redshift
#' Serverless?](https://docs.aws.amazon.com/redshift/latest/mgmt/serverless-whatis.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- redshiftserverless(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- redshiftserverless()
#' svc$convert_recovery_point_to_snapshot(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:redshiftserverless_convert_recovery_point_to_snapshot]{convert_recovery_point_to_snapshot} \tab Converts a recovery point to a snapshot\cr
#'  \link[paws.database:redshiftserverless_create_custom_domain_association]{create_custom_domain_association} \tab Creates a custom domain association for Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_create_endpoint_access]{create_endpoint_access} \tab Creates an Amazon Redshift Serverless managed VPC endpoint\cr
#'  \link[paws.database:redshiftserverless_create_namespace]{create_namespace} \tab Creates a namespace in Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_create_scheduled_action]{create_scheduled_action} \tab Creates a scheduled action\cr
#'  \link[paws.database:redshiftserverless_create_snapshot]{create_snapshot} \tab Creates a snapshot of all databases in a namespace\cr
#'  \link[paws.database:redshiftserverless_create_snapshot_copy_configuration]{create_snapshot_copy_configuration} \tab Creates a snapshot copy configuration that lets you copy snapshots to another Amazon Web Services Region\cr
#'  \link[paws.database:redshiftserverless_create_usage_limit]{create_usage_limit} \tab Creates a usage limit for a specified Amazon Redshift Serverless usage type\cr
#'  \link[paws.database:redshiftserverless_create_workgroup]{create_workgroup} \tab Creates an workgroup in Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_delete_custom_domain_association]{delete_custom_domain_association} \tab Deletes a custom domain association for Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_delete_endpoint_access]{delete_endpoint_access} \tab Deletes an Amazon Redshift Serverless managed VPC endpoint\cr
#'  \link[paws.database:redshiftserverless_delete_namespace]{delete_namespace} \tab Deletes a namespace from Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_delete_resource_policy]{delete_resource_policy} \tab Deletes the specified resource policy\cr
#'  \link[paws.database:redshiftserverless_delete_scheduled_action]{delete_scheduled_action} \tab Deletes a scheduled action\cr
#'  \link[paws.database:redshiftserverless_delete_snapshot]{delete_snapshot} \tab Deletes a snapshot from Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_delete_snapshot_copy_configuration]{delete_snapshot_copy_configuration} \tab Deletes a snapshot copy configuration\cr
#'  \link[paws.database:redshiftserverless_delete_usage_limit]{delete_usage_limit} \tab Deletes a usage limit from Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_delete_workgroup]{delete_workgroup} \tab Deletes a workgroup\cr
#'  \link[paws.database:redshiftserverless_get_credentials]{get_credentials} \tab Returns a database user name and temporary password with temporary authorization to log in to Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_get_custom_domain_association]{get_custom_domain_association} \tab Gets information about a specific custom domain association\cr
#'  \link[paws.database:redshiftserverless_get_endpoint_access]{get_endpoint_access} \tab Returns information, such as the name, about a VPC endpoint\cr
#'  \link[paws.database:redshiftserverless_get_namespace]{get_namespace} \tab Returns information about a namespace in Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_get_recovery_point]{get_recovery_point} \tab Returns information about a recovery point\cr
#'  \link[paws.database:redshiftserverless_get_resource_policy]{get_resource_policy} \tab Returns a resource policy\cr
#'  \link[paws.database:redshiftserverless_get_scheduled_action]{get_scheduled_action} \tab Returns information about a scheduled action\cr
#'  \link[paws.database:redshiftserverless_get_snapshot]{get_snapshot} \tab Returns information about a specific snapshot\cr
#'  \link[paws.database:redshiftserverless_get_table_restore_status]{get_table_restore_status} \tab Returns information about a TableRestoreStatus object\cr
#'  \link[paws.database:redshiftserverless_get_usage_limit]{get_usage_limit} \tab Returns information about a usage limit\cr
#'  \link[paws.database:redshiftserverless_get_workgroup]{get_workgroup} \tab Returns information about a specific workgroup\cr
#'  \link[paws.database:redshiftserverless_list_custom_domain_associations]{list_custom_domain_associations} \tab Lists custom domain associations for Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_list_endpoint_access]{list_endpoint_access} \tab Returns an array of EndpointAccess objects and relevant information\cr
#'  \link[paws.database:redshiftserverless_list_managed_workgroups]{list_managed_workgroups} \tab Returns information about a list of specified managed workgroups in your account\cr
#'  \link[paws.database:redshiftserverless_list_namespaces]{list_namespaces} \tab Returns information about a list of specified namespaces\cr
#'  \link[paws.database:redshiftserverless_list_recovery_points]{list_recovery_points} \tab Returns an array of recovery points\cr
#'  \link[paws.database:redshiftserverless_list_scheduled_actions]{list_scheduled_actions} \tab Returns a list of scheduled actions\cr
#'  \link[paws.database:redshiftserverless_list_snapshot_copy_configurations]{list_snapshot_copy_configurations} \tab Returns a list of snapshot copy configurations\cr
#'  \link[paws.database:redshiftserverless_list_snapshots]{list_snapshots} \tab Returns a list of snapshots\cr
#'  \link[paws.database:redshiftserverless_list_table_restore_status]{list_table_restore_status} \tab Returns information about an array of TableRestoreStatus objects\cr
#'  \link[paws.database:redshiftserverless_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags assigned to a resource\cr
#'  \link[paws.database:redshiftserverless_list_usage_limits]{list_usage_limits} \tab Lists all usage limits within Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_list_workgroups]{list_workgroups} \tab Returns information about a list of specified workgroups\cr
#'  \link[paws.database:redshiftserverless_put_resource_policy]{put_resource_policy} \tab Creates or updates a resource policy\cr
#'  \link[paws.database:redshiftserverless_restore_from_recovery_point]{restore_from_recovery_point} \tab Restore the data from a recovery point\cr
#'  \link[paws.database:redshiftserverless_restore_from_snapshot]{restore_from_snapshot} \tab Restores a namespace from a snapshot\cr
#'  \link[paws.database:redshiftserverless_restore_table_from_recovery_point]{restore_table_from_recovery_point} \tab Restores a table from a recovery point to your Amazon Redshift Serverless instance\cr
#'  \link[paws.database:redshiftserverless_restore_table_from_snapshot]{restore_table_from_snapshot} \tab Restores a table from a snapshot to your Amazon Redshift Serverless instance\cr
#'  \link[paws.database:redshiftserverless_tag_resource]{tag_resource} \tab Assigns one or more tags to a resource\cr
#'  \link[paws.database:redshiftserverless_untag_resource]{untag_resource} \tab Removes a tag or set of tags from a resource\cr
#'  \link[paws.database:redshiftserverless_update_custom_domain_association]{update_custom_domain_association} \tab Updates an Amazon Redshift Serverless certificate associated with a custom domain\cr
#'  \link[paws.database:redshiftserverless_update_endpoint_access]{update_endpoint_access} \tab Updates an Amazon Redshift Serverless managed endpoint\cr
#'  \link[paws.database:redshiftserverless_update_namespace]{update_namespace} \tab Updates a namespace with the specified settings\cr
#'  \link[paws.database:redshiftserverless_update_scheduled_action]{update_scheduled_action} \tab Updates a scheduled action\cr
#'  \link[paws.database:redshiftserverless_update_snapshot]{update_snapshot} \tab Updates a snapshot\cr
#'  \link[paws.database:redshiftserverless_update_snapshot_copy_configuration]{update_snapshot_copy_configuration} \tab Updates a snapshot copy configuration\cr
#'  \link[paws.database:redshiftserverless_update_usage_limit]{update_usage_limit} \tab Update a usage limit in Amazon Redshift Serverless\cr
#'  \link[paws.database:redshiftserverless_update_workgroup]{update_workgroup} \tab Updates a workgroup with the specified configuration settings
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname redshiftserverless
#' @export
redshiftserverless <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::redshiftserverless(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon SimpleDB
#'
#' @description
#' Amazon SimpleDB is a web service providing the core database functions
#' of data indexing and querying in the cloud. By offloading the time and
#' effort associated with building and operating a web-scale database,
#' SimpleDB provides developers the freedom to focus on application
#' development.
#' 
#' A traditional, clustered relational database requires a sizable upfront
#' capital outlay, is complex to design, and often requires extensive and
#' repetitive database administration. Amazon SimpleDB is dramatically
#' simpler, requiring no schema, automatically indexing your data and
#' providing a simple API for storage and access. This approach eliminates
#' the administrative burden of data modeling, index maintenance, and
#' performance tuning. Developers gain access to this functionality within
#' Amazon's proven computing environment, are able to scale instantly, and
#' pay only for what they use.
#' 
#' Visit
#' [http://aws.amazon.com/simpledb/](https://aws.amazon.com/simpledb/) for
#' more information.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- simpledb(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- simpledb()
#' svc$batch_delete_attributes(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:simpledb_batch_delete_attributes]{batch_delete_attributes} \tab Performs multiple DeleteAttributes operations in a single call, which reduces round trips and latencies\cr
#'  \link[paws.database:simpledb_batch_put_attributes]{batch_put_attributes} \tab The BatchPutAttributes operation creates or replaces attributes within one or more items\cr
#'  \link[paws.database:simpledb_create_domain]{create_domain} \tab The CreateDomain operation creates a new domain\cr
#'  \link[paws.database:simpledb_delete_attributes]{delete_attributes} \tab Deletes one or more attributes associated with an item\cr
#'  \link[paws.database:simpledb_delete_domain]{delete_domain} \tab The DeleteDomain operation deletes a domain\cr
#'  \link[paws.database:simpledb_domain_metadata]{domain_metadata} \tab Returns information about the domain, including when the domain was created, the number of items and attributes in the domain, and the size of the attribute names and values\cr
#'  \link[paws.database:simpledb_get_attributes]{get_attributes} \tab Returns all of the attributes associated with the specified item\cr
#'  \link[paws.database:simpledb_list_domains]{list_domains} \tab The ListDomains operation lists all domains associated with the Access Key ID\cr
#'  \link[paws.database:simpledb_put_attributes]{put_attributes} \tab The PutAttributes operation creates or replaces attributes in an item\cr
#'  \link[paws.database:simpledb_select]{select} \tab The Select operation returns a set of attributes for ItemNames that match the select expression
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname simpledb
#' @export
simpledb <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::simpledb(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Timestream Query
#'
#' @description
#' Amazon Timestream Query
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- timestreamquery(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- timestreamquery()
#' svc$cancel_query(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:timestreamquery_cancel_query]{cancel_query} \tab Cancels a query that has been issued\cr
#'  \link[paws.database:timestreamquery_create_scheduled_query]{create_scheduled_query} \tab Create a scheduled query that will be run on your behalf at the configured schedule\cr
#'  \link[paws.database:timestreamquery_delete_scheduled_query]{delete_scheduled_query} \tab Deletes a given scheduled query\cr
#'  \link[paws.database:timestreamquery_describe_account_settings]{describe_account_settings} \tab Describes the settings for your account that include the query pricing model and the configured maximum TCUs the service can use for your query workload\cr
#'  \link[paws.database:timestreamquery_describe_endpoints]{describe_endpoints} \tab DescribeEndpoints returns a list of available endpoints to make Timestream API calls against\cr
#'  \link[paws.database:timestreamquery_describe_scheduled_query]{describe_scheduled_query} \tab Provides detailed information about a scheduled query\cr
#'  \link[paws.database:timestreamquery_execute_scheduled_query]{execute_scheduled_query} \tab You can use this API to run a scheduled query manually\cr
#'  \link[paws.database:timestreamquery_list_scheduled_queries]{list_scheduled_queries} \tab Gets a list of all scheduled queries in the caller's Amazon account and Region\cr
#'  \link[paws.database:timestreamquery_list_tags_for_resource]{list_tags_for_resource} \tab List all tags on a Timestream query resource\cr
#'  \link[paws.database:timestreamquery_prepare_query]{prepare_query} \tab A synchronous operation that allows you to submit a query with parameters to be stored by Timestream for later running\cr
#'  \link[paws.database:timestreamquery_query]{query} \tab Query is a synchronous operation that enables you to run a query against your Amazon Timestream data\cr
#'  \link[paws.database:timestreamquery_tag_resource]{tag_resource} \tab Associate a set of tags with a Timestream resource\cr
#'  \link[paws.database:timestreamquery_untag_resource]{untag_resource} \tab Removes the association of tags from a Timestream query resource\cr
#'  \link[paws.database:timestreamquery_update_account_settings]{update_account_settings} \tab Transitions your account to use TCUs for query pricing and modifies the maximum query compute units that you've configured\cr
#'  \link[paws.database:timestreamquery_update_scheduled_query]{update_scheduled_query} \tab Update a scheduled query
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname timestreamquery
#' @export
timestreamquery <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::timestreamquery(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Timestream Write
#'
#' @description
#' Amazon Timestream is a fast, scalable, fully managed time-series
#' database service that makes it easy to store and analyze trillions of
#' time-series data points per day. With Timestream, you can easily store
#' and analyze IoT sensor data to derive insights from your IoT
#' applications. You can analyze industrial telemetry to streamline
#' equipment management and maintenance. You can also store and analyze log
#' data and metrics to improve the performance and availability of your
#' applications.
#' 
#' Timestream is built from the ground up to effectively ingest, process,
#' and store time-series data. It organizes data to optimize query
#' processing. It automatically scales based on the volume of data ingested
#' and on the query volume to ensure you receive optimal performance while
#' inserting and querying data. As your data grows over time, Timestream’s
#' adaptive query processing engine spans across storage tiers to provide
#' fast analysis while reducing costs.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- timestreamwrite(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- timestreamwrite()
#' svc$create_batch_load_task(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.database:timestreamwrite_create_batch_load_task]{create_batch_load_task} \tab Creates a new Timestream batch load task\cr
#'  \link[paws.database:timestreamwrite_create_database]{create_database} \tab Creates a new Timestream database\cr
#'  \link[paws.database:timestreamwrite_create_table]{create_table} \tab Adds a new table to an existing database in your account\cr
#'  \link[paws.database:timestreamwrite_delete_database]{delete_database} \tab Deletes a given Timestream database\cr
#'  \link[paws.database:timestreamwrite_delete_table]{delete_table} \tab Deletes a given Timestream table\cr
#'  \link[paws.database:timestreamwrite_describe_batch_load_task]{describe_batch_load_task} \tab Returns information about the batch load task, including configurations, mappings, progress, and other details\cr
#'  \link[paws.database:timestreamwrite_describe_database]{describe_database} \tab Returns information about the database, including the database name, time that the database was created, and the total number of tables found within the database\cr
#'  \link[paws.database:timestreamwrite_describe_endpoints]{describe_endpoints} \tab Returns a list of available endpoints to make Timestream API calls against\cr
#'  \link[paws.database:timestreamwrite_describe_table]{describe_table} \tab Returns information about the table, including the table name, database name, retention duration of the memory store and the magnetic store\cr
#'  \link[paws.database:timestreamwrite_list_batch_load_tasks]{list_batch_load_tasks} \tab Provides a list of batch load tasks, along with the name, status, when the task is resumable until, and other details\cr
#'  \link[paws.database:timestreamwrite_list_databases]{list_databases} \tab Returns a list of your Timestream databases\cr
#'  \link[paws.database:timestreamwrite_list_tables]{list_tables} \tab Provides a list of tables, along with the name, status, and retention properties of each table\cr
#'  \link[paws.database:timestreamwrite_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags on a Timestream resource\cr
#'  \link[paws.database:timestreamwrite_resume_batch_load_task]{resume_batch_load_task} \tab Resume batch load task\cr
#'  \link[paws.database:timestreamwrite_tag_resource]{tag_resource} \tab Associates a set of tags with a Timestream resource\cr
#'  \link[paws.database:timestreamwrite_untag_resource]{untag_resource} \tab Removes the association of tags from a Timestream resource\cr
#'  \link[paws.database:timestreamwrite_update_database]{update_database} \tab Modifies the KMS key for an existing database\cr
#'  \link[paws.database:timestreamwrite_update_table]{update_table} \tab Modifies the retention duration of the memory store and magnetic store for your Timestream table\cr
#'  \link[paws.database:timestreamwrite_write_records]{write_records} \tab Enables you to write your time-series data into Timestream
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname timestreamwrite
#' @export
timestreamwrite <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.database::timestreamwrite(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon API Gateway
#'
#' @description
#' Amazon API Gateway helps developers deliver robust, secure, and scalable
#' mobile and web application back ends. API Gateway allows developers to
#' securely connect mobile and web applications to APIs that run on Lambda,
#' Amazon EC2, or other publicly addressable web services that are hosted
#' outside of AWS.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- apigateway(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- apigateway()
#' svc$create_api_key(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:apigateway_create_api_key]{create_api_key} \tab Create an ApiKey resource\cr
#'  \link[paws.networking:apigateway_create_authorizer]{create_authorizer} \tab Adds a new Authorizer resource to an existing RestApi resource\cr
#'  \link[paws.networking:apigateway_create_base_path_mapping]{create_base_path_mapping} \tab Creates a new BasePathMapping resource\cr
#'  \link[paws.networking:apigateway_create_deployment]{create_deployment} \tab Creates a Deployment resource, which makes a specified RestApi callable over the internet\cr
#'  \link[paws.networking:apigateway_create_documentation_part]{create_documentation_part} \tab Creates a documentation part\cr
#'  \link[paws.networking:apigateway_create_documentation_version]{create_documentation_version} \tab Creates a documentation version\cr
#'  \link[paws.networking:apigateway_create_domain_name]{create_domain_name} \tab Creates a new domain name\cr
#'  \link[paws.networking:apigateway_create_domain_name_access_association]{create_domain_name_access_association} \tab Creates a domain name access association resource between an access association source and a private custom domain name\cr
#'  \link[paws.networking:apigateway_create_model]{create_model} \tab Adds a new Model resource to an existing RestApi resource\cr
#'  \link[paws.networking:apigateway_create_request_validator]{create_request_validator} \tab Creates a RequestValidator of a given RestApi\cr
#'  \link[paws.networking:apigateway_create_resource]{create_resource} \tab Creates a Resource resource\cr
#'  \link[paws.networking:apigateway_create_rest_api]{create_rest_api} \tab Creates a new RestApi resource\cr
#'  \link[paws.networking:apigateway_create_stage]{create_stage} \tab Creates a new Stage resource that references a pre-existing Deployment for the API\cr
#'  \link[paws.networking:apigateway_create_usage_plan]{create_usage_plan} \tab Creates a usage plan with the throttle and quota limits, as well as the associated API stages, specified in the payload\cr
#'  \link[paws.networking:apigateway_create_usage_plan_key]{create_usage_plan_key} \tab Creates a usage plan key for adding an existing API key to a usage plan\cr
#'  \link[paws.networking:apigateway_create_vpc_link]{create_vpc_link} \tab Creates a VPC link, under the caller's account in a selected region, in an asynchronous operation that typically takes 2-4 minutes to complete and become operational\cr
#'  \link[paws.networking:apigateway_delete_api_key]{delete_api_key} \tab Deletes the ApiKey resource\cr
#'  \link[paws.networking:apigateway_delete_authorizer]{delete_authorizer} \tab Deletes an existing Authorizer resource\cr
#'  \link[paws.networking:apigateway_delete_base_path_mapping]{delete_base_path_mapping} \tab Deletes the BasePathMapping resource\cr
#'  \link[paws.networking:apigateway_delete_client_certificate]{delete_client_certificate} \tab Deletes the ClientCertificate resource\cr
#'  \link[paws.networking:apigateway_delete_deployment]{delete_deployment} \tab Deletes a Deployment resource\cr
#'  \link[paws.networking:apigateway_delete_documentation_part]{delete_documentation_part} \tab Deletes a documentation part\cr
#'  \link[paws.networking:apigateway_delete_documentation_version]{delete_documentation_version} \tab Deletes a documentation version\cr
#'  \link[paws.networking:apigateway_delete_domain_name]{delete_domain_name} \tab Deletes the DomainName resource\cr
#'  \link[paws.networking:apigateway_delete_domain_name_access_association]{delete_domain_name_access_association} \tab Deletes the DomainNameAccessAssociation resource\cr
#'  \link[paws.networking:apigateway_delete_gateway_response]{delete_gateway_response} \tab Clears any customization of a GatewayResponse of a specified response type on the given RestApi and resets it with the default settings\cr
#'  \link[paws.networking:apigateway_delete_integration]{delete_integration} \tab Represents a delete integration\cr
#'  \link[paws.networking:apigateway_delete_integration_response]{delete_integration_response} \tab Represents a delete integration response\cr
#'  \link[paws.networking:apigateway_delete_method]{delete_method} \tab Deletes an existing Method resource\cr
#'  \link[paws.networking:apigateway_delete_method_response]{delete_method_response} \tab Deletes an existing MethodResponse resource\cr
#'  \link[paws.networking:apigateway_delete_model]{delete_model} \tab Deletes a model\cr
#'  \link[paws.networking:apigateway_delete_request_validator]{delete_request_validator} \tab Deletes a RequestValidator of a given RestApi\cr
#'  \link[paws.networking:apigateway_delete_resource]{delete_resource} \tab Deletes a Resource resource\cr
#'  \link[paws.networking:apigateway_delete_rest_api]{delete_rest_api} \tab Deletes the specified API\cr
#'  \link[paws.networking:apigateway_delete_stage]{delete_stage} \tab Deletes a Stage resource\cr
#'  \link[paws.networking:apigateway_delete_usage_plan]{delete_usage_plan} \tab Deletes a usage plan of a given plan Id\cr
#'  \link[paws.networking:apigateway_delete_usage_plan_key]{delete_usage_plan_key} \tab Deletes a usage plan key and remove the underlying API key from the associated usage plan\cr
#'  \link[paws.networking:apigateway_delete_vpc_link]{delete_vpc_link} \tab Deletes an existing VpcLink of a specified identifier\cr
#'  \link[paws.networking:apigateway_flush_stage_authorizers_cache]{flush_stage_authorizers_cache} \tab Flushes all authorizer cache entries on a stage\cr
#'  \link[paws.networking:apigateway_flush_stage_cache]{flush_stage_cache} \tab Flushes a stage's cache\cr
#'  \link[paws.networking:apigateway_generate_client_certificate]{generate_client_certificate} \tab Generates a ClientCertificate resource\cr
#'  \link[paws.networking:apigateway_get_account]{get_account} \tab Gets information about the current Account resource\cr
#'  \link[paws.networking:apigateway_get_api_key]{get_api_key} \tab Gets information about the current ApiKey resource\cr
#'  \link[paws.networking:apigateway_get_api_keys]{get_api_keys} \tab Gets information about the current ApiKeys resource\cr
#'  \link[paws.networking:apigateway_get_authorizer]{get_authorizer} \tab Describe an existing Authorizer resource\cr
#'  \link[paws.networking:apigateway_get_authorizers]{get_authorizers} \tab Describe an existing Authorizers resource\cr
#'  \link[paws.networking:apigateway_get_base_path_mapping]{get_base_path_mapping} \tab Describe a BasePathMapping resource\cr
#'  \link[paws.networking:apigateway_get_base_path_mappings]{get_base_path_mappings} \tab Represents a collection of BasePathMapping resources\cr
#'  \link[paws.networking:apigateway_get_client_certificate]{get_client_certificate} \tab Gets information about the current ClientCertificate resource\cr
#'  \link[paws.networking:apigateway_get_client_certificates]{get_client_certificates} \tab Gets a collection of ClientCertificate resources\cr
#'  \link[paws.networking:apigateway_get_deployment]{get_deployment} \tab Gets information about a Deployment resource\cr
#'  \link[paws.networking:apigateway_get_deployments]{get_deployments} \tab Gets information about a Deployments collection\cr
#'  \link[paws.networking:apigateway_get_documentation_part]{get_documentation_part} \tab Gets a documentation part\cr
#'  \link[paws.networking:apigateway_get_documentation_parts]{get_documentation_parts} \tab Gets documentation parts\cr
#'  \link[paws.networking:apigateway_get_documentation_version]{get_documentation_version} \tab Gets a documentation version\cr
#'  \link[paws.networking:apigateway_get_documentation_versions]{get_documentation_versions} \tab Gets documentation versions\cr
#'  \link[paws.networking:apigateway_get_domain_name]{get_domain_name} \tab Represents a domain name that is contained in a simpler, more intuitive URL that can be called\cr
#'  \link[paws.networking:apigateway_get_domain_name_access_associations]{get_domain_name_access_associations} \tab Represents a collection on DomainNameAccessAssociations resources\cr
#'  \link[paws.networking:apigateway_get_domain_names]{get_domain_names} \tab Represents a collection of DomainName resources\cr
#'  \link[paws.networking:apigateway_get_export]{get_export} \tab Exports a deployed version of a RestApi in a specified format\cr
#'  \link[paws.networking:apigateway_get_gateway_response]{get_gateway_response} \tab Gets a GatewayResponse of a specified response type on the given RestApi\cr
#'  \link[paws.networking:apigateway_get_gateway_responses]{get_gateway_responses} \tab Gets the GatewayResponses collection on the given RestApi\cr
#'  \link[paws.networking:apigateway_get_integration]{get_integration} \tab Get the integration settings\cr
#'  \link[paws.networking:apigateway_get_integration_response]{get_integration_response} \tab Represents a get integration response\cr
#'  \link[paws.networking:apigateway_get_method]{get_method} \tab Describe an existing Method resource\cr
#'  \link[paws.networking:apigateway_get_method_response]{get_method_response} \tab Describes a MethodResponse resource\cr
#'  \link[paws.networking:apigateway_get_model]{get_model} \tab Describes an existing model defined for a RestApi resource\cr
#'  \link[paws.networking:apigateway_get_models]{get_models} \tab Describes existing Models defined for a RestApi resource\cr
#'  \link[paws.networking:apigateway_get_model_template]{get_model_template} \tab Generates a sample mapping template that can be used to transform a payload into the structure of a model\cr
#'  \link[paws.networking:apigateway_get_request_validator]{get_request_validator} \tab Gets a RequestValidator of a given RestApi\cr
#'  \link[paws.networking:apigateway_get_request_validators]{get_request_validators} \tab Gets the RequestValidators collection of a given RestApi\cr
#'  \link[paws.networking:apigateway_get_resource]{get_resource} \tab Lists information about a resource\cr
#'  \link[paws.networking:apigateway_get_resources]{get_resources} \tab Lists information about a collection of Resource resources\cr
#'  \link[paws.networking:apigateway_get_rest_api]{get_rest_api} \tab Lists the RestApi resource in the collection\cr
#'  \link[paws.networking:apigateway_get_rest_apis]{get_rest_apis} \tab Lists the RestApis resources for your collection\cr
#'  \link[paws.networking:apigateway_get_sdk]{get_sdk} \tab Generates a client SDK for a RestApi and Stage\cr
#'  \link[paws.networking:apigateway_get_sdk_type]{get_sdk_type} \tab Gets an SDK type\cr
#'  \link[paws.networking:apigateway_get_sdk_types]{get_sdk_types} \tab Gets SDK types\cr
#'  \link[paws.networking:apigateway_get_stage]{get_stage} \tab Gets information about a Stage resource\cr
#'  \link[paws.networking:apigateway_get_stages]{get_stages} \tab Gets information about one or more Stage resources\cr
#'  \link[paws.networking:apigateway_get_tags]{get_tags} \tab Gets the Tags collection for a given resource\cr
#'  \link[paws.networking:apigateway_get_usage]{get_usage} \tab Gets the usage data of a usage plan in a specified time interval\cr
#'  \link[paws.networking:apigateway_get_usage_plan]{get_usage_plan} \tab Gets a usage plan of a given plan identifier\cr
#'  \link[paws.networking:apigateway_get_usage_plan_key]{get_usage_plan_key} \tab Gets a usage plan key of a given key identifier\cr
#'  \link[paws.networking:apigateway_get_usage_plan_keys]{get_usage_plan_keys} \tab Gets all the usage plan keys representing the API keys added to a specified usage plan\cr
#'  \link[paws.networking:apigateway_get_usage_plans]{get_usage_plans} \tab Gets all the usage plans of the caller's account\cr
#'  \link[paws.networking:apigateway_get_vpc_link]{get_vpc_link} \tab Gets a specified VPC link under the caller's account in a region\cr
#'  \link[paws.networking:apigateway_get_vpc_links]{get_vpc_links} \tab Gets the VpcLinks collection under the caller's account in a selected region\cr
#'  \link[paws.networking:apigateway_import_api_keys]{import_api_keys} \tab Import API keys from an external source, such as a CSV-formatted file\cr
#'  \link[paws.networking:apigateway_import_documentation_parts]{import_documentation_parts} \tab Imports documentation parts\cr
#'  \link[paws.networking:apigateway_import_rest_api]{import_rest_api} \tab A feature of the API Gateway control service for creating a new API from an external API definition file\cr
#'  \link[paws.networking:apigateway_put_gateway_response]{put_gateway_response} \tab Creates a customization of a GatewayResponse of a specified response type and status code on the given RestApi\cr
#'  \link[paws.networking:apigateway_put_integration]{put_integration} \tab Sets up a method's integration\cr
#'  \link[paws.networking:apigateway_put_integration_response]{put_integration_response} \tab Represents a put integration\cr
#'  \link[paws.networking:apigateway_put_method]{put_method} \tab Add a method to an existing Resource resource\cr
#'  \link[paws.networking:apigateway_put_method_response]{put_method_response} \tab Adds a MethodResponse to an existing Method resource\cr
#'  \link[paws.networking:apigateway_put_rest_api]{put_rest_api} \tab A feature of the API Gateway control service for updating an existing API with an input of external API definitions\cr
#'  \link[paws.networking:apigateway_reject_domain_name_access_association]{reject_domain_name_access_association} \tab Rejects a domain name access association with a private custom domain name\cr
#'  \link[paws.networking:apigateway_tag_resource]{tag_resource} \tab Adds or updates a tag on a given resource\cr
#'  \link[paws.networking:apigateway_test_invoke_authorizer]{test_invoke_authorizer} \tab Simulate the execution of an Authorizer in your RestApi with headers, parameters, and an incoming request body\cr
#'  \link[paws.networking:apigateway_test_invoke_method]{test_invoke_method} \tab Simulate the invocation of a Method in your RestApi with headers, parameters, and an incoming request body\cr
#'  \link[paws.networking:apigateway_untag_resource]{untag_resource} \tab Removes a tag from a given resource\cr
#'  \link[paws.networking:apigateway_update_account]{update_account} \tab Changes information about the current Account resource\cr
#'  \link[paws.networking:apigateway_update_api_key]{update_api_key} \tab Changes information about an ApiKey resource\cr
#'  \link[paws.networking:apigateway_update_authorizer]{update_authorizer} \tab Updates an existing Authorizer resource\cr
#'  \link[paws.networking:apigateway_update_base_path_mapping]{update_base_path_mapping} \tab Changes information about the BasePathMapping resource\cr
#'  \link[paws.networking:apigateway_update_client_certificate]{update_client_certificate} \tab Changes information about an ClientCertificate resource\cr
#'  \link[paws.networking:apigateway_update_deployment]{update_deployment} \tab Changes information about a Deployment resource\cr
#'  \link[paws.networking:apigateway_update_documentation_part]{update_documentation_part} \tab Updates a documentation part\cr
#'  \link[paws.networking:apigateway_update_documentation_version]{update_documentation_version} \tab Updates a documentation version\cr
#'  \link[paws.networking:apigateway_update_domain_name]{update_domain_name} \tab Changes information about the DomainName resource\cr
#'  \link[paws.networking:apigateway_update_gateway_response]{update_gateway_response} \tab Updates a GatewayResponse of a specified response type on the given RestApi\cr
#'  \link[paws.networking:apigateway_update_integration]{update_integration} \tab Represents an update integration\cr
#'  \link[paws.networking:apigateway_update_integration_response]{update_integration_response} \tab Represents an update integration response\cr
#'  \link[paws.networking:apigateway_update_method]{update_method} \tab Updates an existing Method resource\cr
#'  \link[paws.networking:apigateway_update_method_response]{update_method_response} \tab Updates an existing MethodResponse resource\cr
#'  \link[paws.networking:apigateway_update_model]{update_model} \tab Changes information about a model\cr
#'  \link[paws.networking:apigateway_update_request_validator]{update_request_validator} \tab Updates a RequestValidator of a given RestApi\cr
#'  \link[paws.networking:apigateway_update_resource]{update_resource} \tab Changes information about a Resource resource\cr
#'  \link[paws.networking:apigateway_update_rest_api]{update_rest_api} \tab Changes information about the specified API\cr
#'  \link[paws.networking:apigateway_update_stage]{update_stage} \tab Changes information about a Stage resource\cr
#'  \link[paws.networking:apigateway_update_usage]{update_usage} \tab Grants a temporary extension to the remaining quota of a usage plan associated with a specified API key\cr
#'  \link[paws.networking:apigateway_update_usage_plan]{update_usage_plan} \tab Updates a usage plan of a given plan Id\cr
#'  \link[paws.networking:apigateway_update_vpc_link]{update_vpc_link} \tab Updates an existing VpcLink of a specified identifier
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname apigateway
#' @export
apigateway <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::apigateway(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AmazonApiGatewayManagementApi
#'
#' @description
#' The Amazon API Gateway Management API allows you to directly manage
#' runtime aspects of your deployed APIs. To use it, you must explicitly
#' set the SDK's endpoint to point to the endpoint of your deployed API.
#' The endpoint will be of the form
#' https://\{api-id\}.execute-api.\{region\}.amazonaws.com/\{stage\},
#' or will be the endpoint corresponding to your API's custom domain and
#' base path, if applicable.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- apigatewaymanagementapi(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- apigatewaymanagementapi()
#' svc$delete_connection(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:apigatewaymanagementapi_delete_connection]{delete_connection} \tab Delete the connection with the provided id\cr
#'  \link[paws.networking:apigatewaymanagementapi_get_connection]{get_connection} \tab Get information about the connection with the provided id\cr
#'  \link[paws.networking:apigatewaymanagementapi_post_to_connection]{post_to_connection} \tab Sends the provided data to the specified connection
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname apigatewaymanagementapi
#' @export
apigatewaymanagementapi <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::apigatewaymanagementapi(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AmazonApiGatewayV2
#'
#' @description
#' Amazon API Gateway V2
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- apigatewayv2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- apigatewayv2()
#' svc$create_api(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:apigatewayv2_create_api]{create_api} \tab Creates an Api resource\cr
#'  \link[paws.networking:apigatewayv2_create_api_mapping]{create_api_mapping} \tab Creates an API mapping\cr
#'  \link[paws.networking:apigatewayv2_create_authorizer]{create_authorizer} \tab Creates an Authorizer for an API\cr
#'  \link[paws.networking:apigatewayv2_create_deployment]{create_deployment} \tab Creates a Deployment for an API\cr
#'  \link[paws.networking:apigatewayv2_create_domain_name]{create_domain_name} \tab Creates a domain name\cr
#'  \link[paws.networking:apigatewayv2_create_integration]{create_integration} \tab Creates an Integration\cr
#'  \link[paws.networking:apigatewayv2_create_integration_response]{create_integration_response} \tab Creates an IntegrationResponses\cr
#'  \link[paws.networking:apigatewayv2_create_model]{create_model} \tab Creates a Model for an API\cr
#'  \link[paws.networking:apigatewayv2_create_route]{create_route} \tab Creates a Route for an API\cr
#'  \link[paws.networking:apigatewayv2_create_route_response]{create_route_response} \tab Creates a RouteResponse for a Route\cr
#'  \link[paws.networking:apigatewayv2_create_stage]{create_stage} \tab Creates a Stage for an API\cr
#'  \link[paws.networking:apigatewayv2_create_vpc_link]{create_vpc_link} \tab Creates a VPC link\cr
#'  \link[paws.networking:apigatewayv2_delete_access_log_settings]{delete_access_log_settings} \tab Deletes the AccessLogSettings for a Stage\cr
#'  \link[paws.networking:apigatewayv2_delete_api]{delete_api} \tab Deletes an Api resource\cr
#'  \link[paws.networking:apigatewayv2_delete_api_mapping]{delete_api_mapping} \tab Deletes an API mapping\cr
#'  \link[paws.networking:apigatewayv2_delete_authorizer]{delete_authorizer} \tab Deletes an Authorizer\cr
#'  \link[paws.networking:apigatewayv2_delete_cors_configuration]{delete_cors_configuration} \tab Deletes a CORS configuration\cr
#'  \link[paws.networking:apigatewayv2_delete_deployment]{delete_deployment} \tab Deletes a Deployment\cr
#'  \link[paws.networking:apigatewayv2_delete_domain_name]{delete_domain_name} \tab Deletes a domain name\cr
#'  \link[paws.networking:apigatewayv2_delete_integration]{delete_integration} \tab Deletes an Integration\cr
#'  \link[paws.networking:apigatewayv2_delete_integration_response]{delete_integration_response} \tab Deletes an IntegrationResponses\cr
#'  \link[paws.networking:apigatewayv2_delete_model]{delete_model} \tab Deletes a Model\cr
#'  \link[paws.networking:apigatewayv2_delete_route]{delete_route} \tab Deletes a Route\cr
#'  \link[paws.networking:apigatewayv2_delete_route_request_parameter]{delete_route_request_parameter} \tab Deletes a route request parameter\cr
#'  \link[paws.networking:apigatewayv2_delete_route_response]{delete_route_response} \tab Deletes a RouteResponse\cr
#'  \link[paws.networking:apigatewayv2_delete_route_settings]{delete_route_settings} \tab Deletes the RouteSettings for a stage\cr
#'  \link[paws.networking:apigatewayv2_delete_stage]{delete_stage} \tab Deletes a Stage\cr
#'  \link[paws.networking:apigatewayv2_delete_vpc_link]{delete_vpc_link} \tab Deletes a VPC link\cr
#'  \link[paws.networking:apigatewayv2_export_api]{export_api} \tab Export api\cr
#'  \link[paws.networking:apigatewayv2_get_api]{get_api} \tab Gets an Api resource\cr
#'  \link[paws.networking:apigatewayv2_get_api_mapping]{get_api_mapping} \tab Gets an API mapping\cr
#'  \link[paws.networking:apigatewayv2_get_api_mappings]{get_api_mappings} \tab Gets API mappings\cr
#'  \link[paws.networking:apigatewayv2_get_apis]{get_apis} \tab Gets a collection of Api resources\cr
#'  \link[paws.networking:apigatewayv2_get_authorizer]{get_authorizer} \tab Gets an Authorizer\cr
#'  \link[paws.networking:apigatewayv2_get_authorizers]{get_authorizers} \tab Gets the Authorizers for an API\cr
#'  \link[paws.networking:apigatewayv2_get_deployment]{get_deployment} \tab Gets a Deployment\cr
#'  \link[paws.networking:apigatewayv2_get_deployments]{get_deployments} \tab Gets the Deployments for an API\cr
#'  \link[paws.networking:apigatewayv2_get_domain_name]{get_domain_name} \tab Gets a domain name\cr
#'  \link[paws.networking:apigatewayv2_get_domain_names]{get_domain_names} \tab Gets the domain names for an AWS account\cr
#'  \link[paws.networking:apigatewayv2_get_integration]{get_integration} \tab Gets an Integration\cr
#'  \link[paws.networking:apigatewayv2_get_integration_response]{get_integration_response} \tab Gets an IntegrationResponses\cr
#'  \link[paws.networking:apigatewayv2_get_integration_responses]{get_integration_responses} \tab Gets the IntegrationResponses for an Integration\cr
#'  \link[paws.networking:apigatewayv2_get_integrations]{get_integrations} \tab Gets the Integrations for an API\cr
#'  \link[paws.networking:apigatewayv2_get_model]{get_model} \tab Gets a Model\cr
#'  \link[paws.networking:apigatewayv2_get_models]{get_models} \tab Gets the Models for an API\cr
#'  \link[paws.networking:apigatewayv2_get_model_template]{get_model_template} \tab Gets a model template\cr
#'  \link[paws.networking:apigatewayv2_get_route]{get_route} \tab Gets a Route\cr
#'  \link[paws.networking:apigatewayv2_get_route_response]{get_route_response} \tab Gets a RouteResponse\cr
#'  \link[paws.networking:apigatewayv2_get_route_responses]{get_route_responses} \tab Gets the RouteResponses for a Route\cr
#'  \link[paws.networking:apigatewayv2_get_routes]{get_routes} \tab Gets the Routes for an API\cr
#'  \link[paws.networking:apigatewayv2_get_stage]{get_stage} \tab Gets a Stage\cr
#'  \link[paws.networking:apigatewayv2_get_stages]{get_stages} \tab Gets the Stages for an API\cr
#'  \link[paws.networking:apigatewayv2_get_tags]{get_tags} \tab Gets a collection of Tag resources\cr
#'  \link[paws.networking:apigatewayv2_get_vpc_link]{get_vpc_link} \tab Gets a VPC link\cr
#'  \link[paws.networking:apigatewayv2_get_vpc_links]{get_vpc_links} \tab Gets a collection of VPC links\cr
#'  \link[paws.networking:apigatewayv2_import_api]{import_api} \tab Imports an API\cr
#'  \link[paws.networking:apigatewayv2_reimport_api]{reimport_api} \tab Puts an Api resource\cr
#'  \link[paws.networking:apigatewayv2_reset_authorizers_cache]{reset_authorizers_cache} \tab Resets all authorizer cache entries on a stage\cr
#'  \link[paws.networking:apigatewayv2_tag_resource]{tag_resource} \tab Creates a new Tag resource to represent a tag\cr
#'  \link[paws.networking:apigatewayv2_untag_resource]{untag_resource} \tab Deletes a Tag\cr
#'  \link[paws.networking:apigatewayv2_update_api]{update_api} \tab Updates an Api resource\cr
#'  \link[paws.networking:apigatewayv2_update_api_mapping]{update_api_mapping} \tab The API mapping\cr
#'  \link[paws.networking:apigatewayv2_update_authorizer]{update_authorizer} \tab Updates an Authorizer\cr
#'  \link[paws.networking:apigatewayv2_update_deployment]{update_deployment} \tab Updates a Deployment\cr
#'  \link[paws.networking:apigatewayv2_update_domain_name]{update_domain_name} \tab Updates a domain name\cr
#'  \link[paws.networking:apigatewayv2_update_integration]{update_integration} \tab Updates an Integration\cr
#'  \link[paws.networking:apigatewayv2_update_integration_response]{update_integration_response} \tab Updates an IntegrationResponses\cr
#'  \link[paws.networking:apigatewayv2_update_model]{update_model} \tab Updates a Model\cr
#'  \link[paws.networking:apigatewayv2_update_route]{update_route} \tab Updates a Route\cr
#'  \link[paws.networking:apigatewayv2_update_route_response]{update_route_response} \tab Updates a RouteResponse\cr
#'  \link[paws.networking:apigatewayv2_update_stage]{update_stage} \tab Updates a Stage\cr
#'  \link[paws.networking:apigatewayv2_update_vpc_link]{update_vpc_link} \tab Updates a VPC link
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname apigatewayv2
#' @export
apigatewayv2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::apigatewayv2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AppFabric
#'
#' @description
#' Amazon Web Services AppFabric quickly connects software as a service
#' (SaaS) applications across your organization. This allows IT and
#' security teams to easily manage and secure applications using a standard
#' schema, and employees can complete everyday tasks faster using
#' generative artificial intelligence (AI). You can use these APIs to
#' complete AppFabric tasks, such as setting up audit log ingestions or
#' viewing user access. For more information about AppFabric, including the
#' required permissions to use the service, see the [Amazon Web Services
#' AppFabric Administration
#' Guide](https://docs.aws.amazon.com/appfabric/latest/adminguide/). For
#' more information about using the Command Line Interface (CLI) to manage
#' your AppFabric resources, see the [AppFabric section of the CLI
#' Reference](https://docs.aws.amazon.com/cli/latest/reference/appfabric/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- appfabric(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- appfabric()
#' svc$batch_get_user_access_tasks(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:appfabric_batch_get_user_access_tasks]{batch_get_user_access_tasks} \tab Gets user access details in a batch request\cr
#'  \link[paws.networking:appfabric_connect_app_authorization]{connect_app_authorization} \tab Establishes a connection between Amazon Web Services AppFabric and an application, which allows AppFabric to call the APIs of the application\cr
#'  \link[paws.networking:appfabric_create_app_authorization]{create_app_authorization} \tab Creates an app authorization within an app bundle, which allows AppFabric to connect to an application\cr
#'  \link[paws.networking:appfabric_create_app_bundle]{create_app_bundle} \tab Creates an app bundle to collect data from an application using AppFabric\cr
#'  \link[paws.networking:appfabric_create_ingestion]{create_ingestion} \tab Creates a data ingestion for an application\cr
#'  \link[paws.networking:appfabric_create_ingestion_destination]{create_ingestion_destination} \tab Creates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered\cr
#'  \link[paws.networking:appfabric_delete_app_authorization]{delete_app_authorization} \tab Deletes an app authorization\cr
#'  \link[paws.networking:appfabric_delete_app_bundle]{delete_app_bundle} \tab Deletes an app bundle\cr
#'  \link[paws.networking:appfabric_delete_ingestion]{delete_ingestion} \tab Deletes an ingestion\cr
#'  \link[paws.networking:appfabric_delete_ingestion_destination]{delete_ingestion_destination} \tab Deletes an ingestion destination\cr
#'  \link[paws.networking:appfabric_get_app_authorization]{get_app_authorization} \tab Returns information about an app authorization\cr
#'  \link[paws.networking:appfabric_get_app_bundle]{get_app_bundle} \tab Returns information about an app bundle\cr
#'  \link[paws.networking:appfabric_get_ingestion]{get_ingestion} \tab Returns information about an ingestion\cr
#'  \link[paws.networking:appfabric_get_ingestion_destination]{get_ingestion_destination} \tab Returns information about an ingestion destination\cr
#'  \link[paws.networking:appfabric_list_app_authorizations]{list_app_authorizations} \tab Returns a list of all app authorizations configured for an app bundle\cr
#'  \link[paws.networking:appfabric_list_app_bundles]{list_app_bundles} \tab Returns a list of app bundles\cr
#'  \link[paws.networking:appfabric_list_ingestion_destinations]{list_ingestion_destinations} \tab Returns a list of all ingestion destinations configured for an ingestion\cr
#'  \link[paws.networking:appfabric_list_ingestions]{list_ingestions} \tab Returns a list of all ingestions configured for an app bundle\cr
#'  \link[paws.networking:appfabric_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags for a resource\cr
#'  \link[paws.networking:appfabric_start_ingestion]{start_ingestion} \tab Starts (enables) an ingestion, which collects data from an application\cr
#'  \link[paws.networking:appfabric_start_user_access_tasks]{start_user_access_tasks} \tab Starts the tasks to search user access status for a specific email address\cr
#'  \link[paws.networking:appfabric_stop_ingestion]{stop_ingestion} \tab Stops (disables) an ingestion\cr
#'  \link[paws.networking:appfabric_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified resource\cr
#'  \link[paws.networking:appfabric_untag_resource]{untag_resource} \tab Removes a tag or tags from a resource\cr
#'  \link[paws.networking:appfabric_update_app_authorization]{update_app_authorization} \tab Updates an app authorization within an app bundle, which allows AppFabric to connect to an application\cr
#'  \link[paws.networking:appfabric_update_ingestion_destination]{update_ingestion_destination} \tab Updates an ingestion destination, which specifies how an application's ingested data is processed by Amazon Web Services AppFabric and where it's delivered
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname appfabric
#' @export
appfabric <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::appfabric(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS App Mesh
#'
#' @description
#' App Mesh is a service mesh based on the Envoy proxy that makes it easy
#' to monitor and control microservices. App Mesh standardizes how your
#' microservices communicate, giving you end-to-end visibility and helping
#' to ensure high availability for your applications.
#' 
#' App Mesh gives you consistent visibility and network traffic controls
#' for every microservice in an application. You can use App Mesh with
#' Amazon Web Services Fargate, Amazon ECS, Amazon EKS, Kubernetes on
#' Amazon Web Services, and Amazon EC2.
#' 
#' App Mesh supports microservice applications that use service discovery
#' naming for their components. For more information about service
#' discovery on Amazon ECS, see [Service
#' Discovery](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-discovery.html)
#' in the *Amazon Elastic Container Service Developer Guide*. Kubernetes
#' `kube-dns` and `coredns` are supported. For more information, see [DNS
#' for Services and
#' Pods](https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/)
#' in the Kubernetes documentation.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- appmesh(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- appmesh()
#' svc$create_gateway_route(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:appmesh_create_gateway_route]{create_gateway_route} \tab Creates a gateway route\cr
#'  \link[paws.networking:appmesh_create_mesh]{create_mesh} \tab Creates a service mesh\cr
#'  \link[paws.networking:appmesh_create_route]{create_route} \tab Creates a route that is associated with a virtual router\cr
#'  \link[paws.networking:appmesh_create_virtual_gateway]{create_virtual_gateway} \tab Creates a virtual gateway\cr
#'  \link[paws.networking:appmesh_create_virtual_node]{create_virtual_node} \tab Creates a virtual node within a service mesh\cr
#'  \link[paws.networking:appmesh_create_virtual_router]{create_virtual_router} \tab Creates a virtual router within a service mesh\cr
#'  \link[paws.networking:appmesh_create_virtual_service]{create_virtual_service} \tab Creates a virtual service within a service mesh\cr
#'  \link[paws.networking:appmesh_delete_gateway_route]{delete_gateway_route} \tab Deletes an existing gateway route\cr
#'  \link[paws.networking:appmesh_delete_mesh]{delete_mesh} \tab Deletes an existing service mesh\cr
#'  \link[paws.networking:appmesh_delete_route]{delete_route} \tab Deletes an existing route\cr
#'  \link[paws.networking:appmesh_delete_virtual_gateway]{delete_virtual_gateway} \tab Deletes an existing virtual gateway\cr
#'  \link[paws.networking:appmesh_delete_virtual_node]{delete_virtual_node} \tab Deletes an existing virtual node\cr
#'  \link[paws.networking:appmesh_delete_virtual_router]{delete_virtual_router} \tab Deletes an existing virtual router\cr
#'  \link[paws.networking:appmesh_delete_virtual_service]{delete_virtual_service} \tab Deletes an existing virtual service\cr
#'  \link[paws.networking:appmesh_describe_gateway_route]{describe_gateway_route} \tab Describes an existing gateway route\cr
#'  \link[paws.networking:appmesh_describe_mesh]{describe_mesh} \tab Describes an existing service mesh\cr
#'  \link[paws.networking:appmesh_describe_route]{describe_route} \tab Describes an existing route\cr
#'  \link[paws.networking:appmesh_describe_virtual_gateway]{describe_virtual_gateway} \tab Describes an existing virtual gateway\cr
#'  \link[paws.networking:appmesh_describe_virtual_node]{describe_virtual_node} \tab Describes an existing virtual node\cr
#'  \link[paws.networking:appmesh_describe_virtual_router]{describe_virtual_router} \tab Describes an existing virtual router\cr
#'  \link[paws.networking:appmesh_describe_virtual_service]{describe_virtual_service} \tab Describes an existing virtual service\cr
#'  \link[paws.networking:appmesh_list_gateway_routes]{list_gateway_routes} \tab Returns a list of existing gateway routes that are associated to a virtual gateway\cr
#'  \link[paws.networking:appmesh_list_meshes]{list_meshes} \tab Returns a list of existing service meshes\cr
#'  \link[paws.networking:appmesh_list_routes]{list_routes} \tab Returns a list of existing routes in a service mesh\cr
#'  \link[paws.networking:appmesh_list_tags_for_resource]{list_tags_for_resource} \tab List the tags for an App Mesh resource\cr
#'  \link[paws.networking:appmesh_list_virtual_gateways]{list_virtual_gateways} \tab Returns a list of existing virtual gateways in a service mesh\cr
#'  \link[paws.networking:appmesh_list_virtual_nodes]{list_virtual_nodes} \tab Returns a list of existing virtual nodes\cr
#'  \link[paws.networking:appmesh_list_virtual_routers]{list_virtual_routers} \tab Returns a list of existing virtual routers in a service mesh\cr
#'  \link[paws.networking:appmesh_list_virtual_services]{list_virtual_services} \tab Returns a list of existing virtual services in a service mesh\cr
#'  \link[paws.networking:appmesh_tag_resource]{tag_resource} \tab Associates the specified tags to a resource with the specified resourceArn\cr
#'  \link[paws.networking:appmesh_untag_resource]{untag_resource} \tab Deletes specified tags from a resource\cr
#'  \link[paws.networking:appmesh_update_gateway_route]{update_gateway_route} \tab Updates an existing gateway route that is associated to a specified virtual gateway in a service mesh\cr
#'  \link[paws.networking:appmesh_update_mesh]{update_mesh} \tab Updates an existing service mesh\cr
#'  \link[paws.networking:appmesh_update_route]{update_route} \tab Updates an existing route for a specified service mesh and virtual router\cr
#'  \link[paws.networking:appmesh_update_virtual_gateway]{update_virtual_gateway} \tab Updates an existing virtual gateway in a specified service mesh\cr
#'  \link[paws.networking:appmesh_update_virtual_node]{update_virtual_node} \tab Updates an existing virtual node in a specified service mesh\cr
#'  \link[paws.networking:appmesh_update_virtual_router]{update_virtual_router} \tab Updates an existing virtual router in a specified service mesh\cr
#'  \link[paws.networking:appmesh_update_virtual_service]{update_virtual_service} \tab Updates an existing virtual service in a specified service mesh
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname appmesh
#' @export
appmesh <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::appmesh(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS ARC - Zonal Shift
#'
#' @description
#' Welcome to the API Reference Guide for zonal shift and zonal autoshift
#' in Amazon Route 53 Application Recovery Controller (Route 53 ARC).
#' 
#' You can start a zonal shift to move traffic for a load balancer resource
#' away from an Availability Zone to help your application recover quickly
#' from an impairment in an Availability Zone. For example, you can recover
#' your application from a developer's bad code deployment or from an
#' Amazon Web Services infrastructure failure in a single Availability
#' Zone.
#' 
#' You can also configure zonal autoshift for supported load balancer
#' resources. Zonal autoshift is a capability in Route 53 ARC where you
#' authorize Amazon Web Services to shift away application resource traffic
#' from an Availability Zone during events, on your behalf, to help reduce
#' your time to recovery. Amazon Web Services starts an autoshift when
#' internal telemetry indicates that there is an Availability Zone
#' impairment that could potentially impact customers.
#' 
#' To help make sure that zonal autoshift is safe for your application, you
#' must also configure practice runs when you enable zonal autoshift for a
#' resource. Practice runs start weekly zonal shifts for a resource, to
#' shift traffic for the resource away from an Availability Zone. Practice
#' runs help you to make sure, on a regular basis, that you have enough
#' capacity in all the Availability Zones in an Amazon Web Services Region
#' for your application to continue to operate normally when traffic for a
#' resource is shifted away from one Availability Zone.
#' 
#' Before you configure practice runs or enable zonal autoshift, we
#' strongly recommend that you prescale your application resource capacity
#' in all Availability Zones in the Region where your application resources
#' are deployed. You should not rely on scaling on demand when an autoshift
#' or practice run starts. Zonal autoshift, including practice runs, works
#' independently, and does not wait for auto scaling actions to complete.
#' Relying on auto scaling, instead of pre-scaling, can result in loss of
#' availability.
#' 
#' If you use auto scaling to handle regular cycles of traffic, we strongly
#' recommend that you configure the minimum capacity of your auto scaling
#' to continue operating normally with the loss of an Availability Zone.
#' 
#' Be aware that Route 53 ARC does not inspect the health of individual
#' resources. Amazon Web Services only starts an autoshift when Amazon Web
#' Services telemetry detects that there is an Availability Zone impairment
#' that could potentially impact customers. In some cases, resources might
#' be shifted away that are not experiencing impact.
#' 
#' For more information about using zonal shift and zonal autoshift, see
#' the [Amazon Route 53 Application Recovery Controller Developer
#' Guide](https://docs.aws.amazon.com/r53recovery/latest/dg/what-is-route53-recovery.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- arczonalshift(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- arczonalshift()
#' svc$cancel_zonal_shift(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:arczonalshift_cancel_zonal_shift]{cancel_zonal_shift} \tab Cancel a zonal shift in Amazon Route 53 Application Recovery Controller\cr
#'  \link[paws.networking:arczonalshift_create_practice_run_configuration]{create_practice_run_configuration} \tab A practice run configuration for zonal autoshift is required when you enable zonal autoshift\cr
#'  \link[paws.networking:arczonalshift_delete_practice_run_configuration]{delete_practice_run_configuration} \tab Deletes the practice run configuration for a resource\cr
#'  \link[paws.networking:arczonalshift_get_autoshift_observer_notification_status]{get_autoshift_observer_notification_status} \tab Returns the status of autoshift observer notification\cr
#'  \link[paws.networking:arczonalshift_get_managed_resource]{get_managed_resource} \tab Get information about a resource that's been registered for zonal shifts with Amazon Route 53 Application Recovery Controller in this Amazon Web Services Region\cr
#'  \link[paws.networking:arczonalshift_list_autoshifts]{list_autoshifts} \tab Returns a list of autoshifts for an Amazon Web Services Region\cr
#'  \link[paws.networking:arczonalshift_list_managed_resources]{list_managed_resources} \tab Lists all the resources in your Amazon Web Services account in this Amazon Web Services Region that are managed for zonal shifts in Amazon Route 53 Application Recovery Controller, and information about them\cr
#'  \link[paws.networking:arczonalshift_list_zonal_shifts]{list_zonal_shifts} \tab Lists all active and completed zonal shifts in Amazon Route 53 Application Recovery Controller in your Amazon Web Services account in this Amazon Web Services Region\cr
#'  \link[paws.networking:arczonalshift_start_zonal_shift]{start_zonal_shift} \tab You start a zonal shift to temporarily move load balancer traffic away from an Availability Zone in an Amazon Web Services Region, to help your application recover immediately, for example, from a developer's bad code deployment or from an Amazon Web Services infrastructure failure in a single Availability Zone\cr
#'  \link[paws.networking:arczonalshift_update_autoshift_observer_notification_status]{update_autoshift_observer_notification_status} \tab Update the status of autoshift observer notification\cr
#'  \link[paws.networking:arczonalshift_update_practice_run_configuration]{update_practice_run_configuration} \tab Update a practice run configuration to change one or more of the following: add, change, or remove the blocking alarm; change the outcome alarm; or add, change, or remove blocking dates or time windows\cr
#'  \link[paws.networking:arczonalshift_update_zonal_autoshift_configuration]{update_zonal_autoshift_configuration} \tab The zonal autoshift configuration for a resource includes the practice run configuration and the status for running autoshifts, zonal autoshift status\cr
#'  \link[paws.networking:arczonalshift_update_zonal_shift]{update_zonal_shift} \tab Update an active zonal shift in Amazon Route 53 Application Recovery Controller in your Amazon Web Services account
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname arczonalshift
#' @export
arczonalshift <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::arczonalshift(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Backup Gateway
#'
#' @description
#' Backup gateway
#' 
#' Backup gateway connects Backup to your hypervisor, so you can create,
#' store, and restore backups of your virtual machines (VMs) anywhere,
#' whether on-premises or in the VMware Cloud (VMC) on Amazon Web Services.
#' 
#' Add on-premises resources by connecting to a hypervisor through a
#' gateway. Backup will automatically discover the resources in your
#' hypervisor.
#' 
#' Use Backup to assign virtual or on-premises resources to a backup plan,
#' or run on-demand backups. Once you have backed up your resources, you
#' can view them and restore them like any resource supported by Backup.
#' 
#' To download the Amazon Web Services software to get started, navigate to
#' the Backup console, choose **Gateways**, then choose **Create gateway**.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- backupgateway(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- backupgateway()
#' svc$associate_gateway_to_server(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:backupgateway_associate_gateway_to_server]{associate_gateway_to_server} \tab Associates a backup gateway with your server\cr
#'  \link[paws.networking:backupgateway_create_gateway]{create_gateway} \tab Creates a backup gateway\cr
#'  \link[paws.networking:backupgateway_delete_gateway]{delete_gateway} \tab Deletes a backup gateway\cr
#'  \link[paws.networking:backupgateway_delete_hypervisor]{delete_hypervisor} \tab Deletes a hypervisor\cr
#'  \link[paws.networking:backupgateway_disassociate_gateway_from_server]{disassociate_gateway_from_server} \tab Disassociates a backup gateway from the specified server\cr
#'  \link[paws.networking:backupgateway_get_bandwidth_rate_limit_schedule]{get_bandwidth_rate_limit_schedule} \tab Retrieves the bandwidth rate limit schedule for a specified gateway\cr
#'  \link[paws.networking:backupgateway_get_gateway]{get_gateway} \tab By providing the ARN (Amazon Resource Name), this API returns the gateway\cr
#'  \link[paws.networking:backupgateway_get_hypervisor]{get_hypervisor} \tab This action requests information about the specified hypervisor to which the gateway will connect\cr
#'  \link[paws.networking:backupgateway_get_hypervisor_property_mappings]{get_hypervisor_property_mappings} \tab This action retrieves the property mappings for the specified hypervisor\cr
#'  \link[paws.networking:backupgateway_get_virtual_machine]{get_virtual_machine} \tab By providing the ARN (Amazon Resource Name), this API returns the virtual machine\cr
#'  \link[paws.networking:backupgateway_import_hypervisor_configuration]{import_hypervisor_configuration} \tab Connect to a hypervisor by importing its configuration\cr
#'  \link[paws.networking:backupgateway_list_gateways]{list_gateways} \tab Lists backup gateways owned by an Amazon Web Services account in an Amazon Web Services Region\cr
#'  \link[paws.networking:backupgateway_list_hypervisors]{list_hypervisors} \tab Lists your hypervisors\cr
#'  \link[paws.networking:backupgateway_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags applied to the resource identified by its Amazon Resource Name (ARN)\cr
#'  \link[paws.networking:backupgateway_list_virtual_machines]{list_virtual_machines} \tab Lists your virtual machines\cr
#'  \link[paws.networking:backupgateway_put_bandwidth_rate_limit_schedule]{put_bandwidth_rate_limit_schedule} \tab This action sets the bandwidth rate limit schedule for a specified gateway\cr
#'  \link[paws.networking:backupgateway_put_hypervisor_property_mappings]{put_hypervisor_property_mappings} \tab This action sets the property mappings for the specified hypervisor\cr
#'  \link[paws.networking:backupgateway_put_maintenance_start_time]{put_maintenance_start_time} \tab Set the maintenance start time for a gateway\cr
#'  \link[paws.networking:backupgateway_start_virtual_machines_metadata_sync]{start_virtual_machines_metadata_sync} \tab This action sends a request to sync metadata across the specified virtual machines\cr
#'  \link[paws.networking:backupgateway_tag_resource]{tag_resource} \tab Tag the resource\cr
#'  \link[paws.networking:backupgateway_test_hypervisor_configuration]{test_hypervisor_configuration} \tab Tests your hypervisor configuration to validate that backup gateway can connect with the hypervisor and its resources\cr
#'  \link[paws.networking:backupgateway_untag_resource]{untag_resource} \tab Removes tags from the resource\cr
#'  \link[paws.networking:backupgateway_update_gateway_information]{update_gateway_information} \tab Updates a gateway's name\cr
#'  \link[paws.networking:backupgateway_update_gateway_software_now]{update_gateway_software_now} \tab Updates the gateway virtual machine (VM) software\cr
#'  \link[paws.networking:backupgateway_update_hypervisor]{update_hypervisor} \tab Updates a hypervisor metadata, including its host, username, and password
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname backupgateway
#' @export
backupgateway <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::backupgateway(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudFront
#'
#' @description
#' This is the *Amazon CloudFront API Reference*. This guide is for
#' developers who need detailed information about CloudFront API actions,
#' data types, and errors. For detailed information about CloudFront
#' features, see the [Amazon CloudFront Developer
#' Guide](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Introduction.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudfront(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudfront()
#' svc$associate_alias(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:cloudfront_associate_alias]{associate_alias} \tab Associates an alias (also known as a CNAME or an alternate domain name) with a CloudFront distribution\cr
#'  \link[paws.networking:cloudfront_copy_distribution]{copy_distribution} \tab Creates a staging distribution using the configuration of the provided primary distribution\cr
#'  \link[paws.networking:cloudfront_create_anycast_ip_list]{create_anycast_ip_list} \tab Creates an Anycast static IP list\cr
#'  \link[paws.networking:cloudfront_create_cache_policy]{create_cache_policy} \tab Creates a cache policy\cr
#'  \link[paws.networking:cloudfront_create_cloud_front_origin_access_identity]{create_cloud_front_origin_access_identity} \tab Creates a new origin access identity\cr
#'  \link[paws.networking:cloudfront_create_continuous_deployment_policy]{create_continuous_deployment_policy} \tab Creates a continuous deployment policy that distributes traffic for a custom domain name to two different CloudFront distributions\cr
#'  \link[paws.networking:cloudfront_create_distribution]{create_distribution} \tab Creates a CloudFront distribution\cr
#'  \link[paws.networking:cloudfront_create_distribution_with_tags]{create_distribution_with_tags} \tab Create a new distribution with tags\cr
#'  \link[paws.networking:cloudfront_create_field_level_encryption_config]{create_field_level_encryption_config} \tab Create a new field-level encryption configuration\cr
#'  \link[paws.networking:cloudfront_create_field_level_encryption_profile]{create_field_level_encryption_profile} \tab Create a field-level encryption profile\cr
#'  \link[paws.networking:cloudfront_create_function]{create_function} \tab Creates a CloudFront function\cr
#'  \link[paws.networking:cloudfront_create_invalidation]{create_invalidation} \tab Create a new invalidation\cr
#'  \link[paws.networking:cloudfront_create_key_group]{create_key_group} \tab Creates a key group that you can use with CloudFront signed URLs and signed cookies\cr
#'  \link[paws.networking:cloudfront_create_key_value_store]{create_key_value_store} \tab Specifies the key value store resource to add to your account\cr
#'  \link[paws.networking:cloudfront_create_monitoring_subscription]{create_monitoring_subscription} \tab Enables additional CloudWatch metrics for the specified CloudFront distribution\cr
#'  \link[paws.networking:cloudfront_create_origin_access_control]{create_origin_access_control} \tab Creates a new origin access control in CloudFront\cr
#'  \link[paws.networking:cloudfront_create_origin_request_policy]{create_origin_request_policy} \tab Creates an origin request policy\cr
#'  \link[paws.networking:cloudfront_create_public_key]{create_public_key} \tab Uploads a public key to CloudFront that you can use with signed URLs and signed cookies, or with field-level encryption\cr
#'  \link[paws.networking:cloudfront_create_realtime_log_config]{create_realtime_log_config} \tab Creates a real-time log configuration\cr
#'  \link[paws.networking:cloudfront_create_response_headers_policy]{create_response_headers_policy} \tab Creates a response headers policy\cr
#'  \link[paws.networking:cloudfront_create_streaming_distribution]{create_streaming_distribution} \tab This API is deprecated\cr
#'  \link[paws.networking:cloudfront_create_streaming_distribution_with_tags]{create_streaming_distribution_with_tags} \tab This API is deprecated\cr
#'  \link[paws.networking:cloudfront_create_vpc_origin]{create_vpc_origin} \tab Create an Amazon CloudFront VPC origin\cr
#'  \link[paws.networking:cloudfront_delete_anycast_ip_list]{delete_anycast_ip_list} \tab Deletes an Anycast static IP list\cr
#'  \link[paws.networking:cloudfront_delete_cache_policy]{delete_cache_policy} \tab Deletes a cache policy\cr
#'  \link[paws.networking:cloudfront_delete_cloud_front_origin_access_identity]{delete_cloud_front_origin_access_identity} \tab Delete an origin access identity\cr
#'  \link[paws.networking:cloudfront_delete_continuous_deployment_policy]{delete_continuous_deployment_policy} \tab Deletes a continuous deployment policy\cr
#'  \link[paws.networking:cloudfront_delete_distribution]{delete_distribution} \tab Delete a distribution\cr
#'  \link[paws.networking:cloudfront_delete_field_level_encryption_config]{delete_field_level_encryption_config} \tab Remove a field-level encryption configuration\cr
#'  \link[paws.networking:cloudfront_delete_field_level_encryption_profile]{delete_field_level_encryption_profile} \tab Remove a field-level encryption profile\cr
#'  \link[paws.networking:cloudfront_delete_function]{delete_function} \tab Deletes a CloudFront function\cr
#'  \link[paws.networking:cloudfront_delete_key_group]{delete_key_group} \tab Deletes a key group\cr
#'  \link[paws.networking:cloudfront_delete_key_value_store]{delete_key_value_store} \tab Specifies the key value store to delete\cr
#'  \link[paws.networking:cloudfront_delete_monitoring_subscription]{delete_monitoring_subscription} \tab Disables additional CloudWatch metrics for the specified CloudFront distribution\cr
#'  \link[paws.networking:cloudfront_delete_origin_access_control]{delete_origin_access_control} \tab Deletes a CloudFront origin access control\cr
#'  \link[paws.networking:cloudfront_delete_origin_request_policy]{delete_origin_request_policy} \tab Deletes an origin request policy\cr
#'  \link[paws.networking:cloudfront_delete_public_key]{delete_public_key} \tab Remove a public key you previously added to CloudFront\cr
#'  \link[paws.networking:cloudfront_delete_realtime_log_config]{delete_realtime_log_config} \tab Deletes a real-time log configuration\cr
#'  \link[paws.networking:cloudfront_delete_response_headers_policy]{delete_response_headers_policy} \tab Deletes a response headers policy\cr
#'  \link[paws.networking:cloudfront_delete_streaming_distribution]{delete_streaming_distribution} \tab Delete a streaming distribution\cr
#'  \link[paws.networking:cloudfront_delete_vpc_origin]{delete_vpc_origin} \tab Delete an Amazon CloudFront VPC origin\cr
#'  \link[paws.networking:cloudfront_describe_function]{describe_function} \tab Gets configuration information and metadata about a CloudFront function, but not the function's code\cr
#'  \link[paws.networking:cloudfront_describe_key_value_store]{describe_key_value_store} \tab Specifies the key value store and its configuration\cr
#'  \link[paws.networking:cloudfront_get_anycast_ip_list]{get_anycast_ip_list} \tab Gets an Anycast static IP list\cr
#'  \link[paws.networking:cloudfront_get_cache_policy]{get_cache_policy} \tab Gets a cache policy, including the following metadata:\cr
#'  \link[paws.networking:cloudfront_get_cache_policy_config]{get_cache_policy_config} \tab Gets a cache policy configuration\cr
#'  \link[paws.networking:cloudfront_get_cloud_front_origin_access_identity]{get_cloud_front_origin_access_identity} \tab Get the information about an origin access identity\cr
#'  \link[paws.networking:cloudfront_get_cloud_front_origin_access_identity_config]{get_cloud_front_origin_access_identity_config} \tab Get the configuration information about an origin access identity\cr
#'  \link[paws.networking:cloudfront_get_continuous_deployment_policy]{get_continuous_deployment_policy} \tab Gets a continuous deployment policy, including metadata (the policy's identifier and the date and time when the policy was last modified)\cr
#'  \link[paws.networking:cloudfront_get_continuous_deployment_policy_config]{get_continuous_deployment_policy_config} \tab Gets configuration information about a continuous deployment policy\cr
#'  \link[paws.networking:cloudfront_get_distribution]{get_distribution} \tab Get the information about a distribution\cr
#'  \link[paws.networking:cloudfront_get_distribution_config]{get_distribution_config} \tab Get the configuration information about a distribution\cr
#'  \link[paws.networking:cloudfront_get_field_level_encryption]{get_field_level_encryption} \tab Get the field-level encryption configuration information\cr
#'  \link[paws.networking:cloudfront_get_field_level_encryption_config]{get_field_level_encryption_config} \tab Get the field-level encryption configuration information\cr
#'  \link[paws.networking:cloudfront_get_field_level_encryption_profile]{get_field_level_encryption_profile} \tab Get the field-level encryption profile information\cr
#'  \link[paws.networking:cloudfront_get_field_level_encryption_profile_config]{get_field_level_encryption_profile_config} \tab Get the field-level encryption profile configuration information\cr
#'  \link[paws.networking:cloudfront_get_function]{get_function} \tab Gets the code of a CloudFront function\cr
#'  \link[paws.networking:cloudfront_get_invalidation]{get_invalidation} \tab Get the information about an invalidation\cr
#'  \link[paws.networking:cloudfront_get_key_group]{get_key_group} \tab Gets a key group, including the date and time when the key group was last modified\cr
#'  \link[paws.networking:cloudfront_get_key_group_config]{get_key_group_config} \tab Gets a key group configuration\cr
#'  \link[paws.networking:cloudfront_get_monitoring_subscription]{get_monitoring_subscription} \tab Gets information about whether additional CloudWatch metrics are enabled for the specified CloudFront distribution\cr
#'  \link[paws.networking:cloudfront_get_origin_access_control]{get_origin_access_control} \tab Gets a CloudFront origin access control, including its unique identifier\cr
#'  \link[paws.networking:cloudfront_get_origin_access_control_config]{get_origin_access_control_config} \tab Gets a CloudFront origin access control configuration\cr
#'  \link[paws.networking:cloudfront_get_origin_request_policy]{get_origin_request_policy} \tab Gets an origin request policy, including the following metadata:\cr
#'  \link[paws.networking:cloudfront_get_origin_request_policy_config]{get_origin_request_policy_config} \tab Gets an origin request policy configuration\cr
#'  \link[paws.networking:cloudfront_get_public_key]{get_public_key} \tab Gets a public key\cr
#'  \link[paws.networking:cloudfront_get_public_key_config]{get_public_key_config} \tab Gets a public key configuration\cr
#'  \link[paws.networking:cloudfront_get_realtime_log_config]{get_realtime_log_config} \tab Gets a real-time log configuration\cr
#'  \link[paws.networking:cloudfront_get_response_headers_policy]{get_response_headers_policy} \tab Gets a response headers policy, including metadata (the policy's identifier and the date and time when the policy was last modified)\cr
#'  \link[paws.networking:cloudfront_get_response_headers_policy_config]{get_response_headers_policy_config} \tab Gets a response headers policy configuration\cr
#'  \link[paws.networking:cloudfront_get_streaming_distribution]{get_streaming_distribution} \tab Gets information about a specified RTMP distribution, including the distribution configuration\cr
#'  \link[paws.networking:cloudfront_get_streaming_distribution_config]{get_streaming_distribution_config} \tab Get the configuration information about a streaming distribution\cr
#'  \link[paws.networking:cloudfront_get_vpc_origin]{get_vpc_origin} \tab Get the details of an Amazon CloudFront VPC origin\cr
#'  \link[paws.networking:cloudfront_list_anycast_ip_lists]{list_anycast_ip_lists} \tab Lists your Anycast static IP lists\cr
#'  \link[paws.networking:cloudfront_list_cache_policies]{list_cache_policies} \tab Gets a list of cache policies\cr
#'  \link[paws.networking:cloudfront_list_cloud_front_origin_access_identities]{list_cloud_front_origin_access_identities} \tab Lists origin access identities\cr
#'  \link[paws.networking:cloudfront_list_conflicting_aliases]{list_conflicting_aliases} \tab Gets a list of aliases (also called CNAMEs or alternate domain names) that conflict or overlap with the provided alias, and the associated CloudFront distributions and Amazon Web Services accounts for each conflicting alias\cr
#'  \link[paws.networking:cloudfront_list_continuous_deployment_policies]{list_continuous_deployment_policies} \tab Gets a list of the continuous deployment policies in your Amazon Web Services account\cr
#'  \link[paws.networking:cloudfront_list_distributions]{list_distributions} \tab List CloudFront distributions\cr
#'  \link[paws.networking:cloudfront_list_distributions_by_anycast_ip_list_id]{list_distributions_by_anycast_ip_list_id} \tab Lists the distributions in your account that are associated with the specified AnycastIpListId\cr
#'  \link[paws.networking:cloudfront_list_distributions_by_cache_policy_id]{list_distributions_by_cache_policy_id} \tab Gets a list of distribution IDs for distributions that have a cache behavior that's associated with the specified cache policy\cr
#'  \link[paws.networking:cloudfront_list_distributions_by_key_group]{list_distributions_by_key_group} \tab Gets a list of distribution IDs for distributions that have a cache behavior that references the specified key group\cr
#'  \link[paws.networking:cloudfront_list_distributions_by_origin_request_policy_id]{list_distributions_by_origin_request_policy_id} \tab Gets a list of distribution IDs for distributions that have a cache behavior that's associated with the specified origin request policy\cr
#'  \link[paws.networking:cloudfront_list_distributions_by_realtime_log_config]{list_distributions_by_realtime_log_config} \tab Gets a list of distributions that have a cache behavior that's associated with the specified real-time log configuration\cr
#'  \link[paws.networking:cloudfront_list_distributions_by_response_headers_policy_id]{list_distributions_by_response_headers_policy_id} \tab Gets a list of distribution IDs for distributions that have a cache behavior that's associated with the specified response headers policy\cr
#'  \link[paws.networking:cloudfront_list_distributions_by_vpc_origin_id]{list_distributions_by_vpc_origin_id} \tab List CloudFront distributions by their VPC origin ID\cr
#'  \link[paws.networking:cloudfront_list_distributions_by_web_acl_id]{list_distributions_by_web_acl_id} \tab List the distributions that are associated with a specified WAF web ACL\cr
#'  \link[paws.networking:cloudfront_list_field_level_encryption_configs]{list_field_level_encryption_configs} \tab List all field-level encryption configurations that have been created in CloudFront for this account\cr
#'  \link[paws.networking:cloudfront_list_field_level_encryption_profiles]{list_field_level_encryption_profiles} \tab Request a list of field-level encryption profiles that have been created in CloudFront for this account\cr
#'  \link[paws.networking:cloudfront_list_functions]{list_functions} \tab Gets a list of all CloudFront functions in your Amazon Web Services account\cr
#'  \link[paws.networking:cloudfront_list_invalidations]{list_invalidations} \tab Lists invalidation batches\cr
#'  \link[paws.networking:cloudfront_list_key_groups]{list_key_groups} \tab Gets a list of key groups\cr
#'  \link[paws.networking:cloudfront_list_key_value_stores]{list_key_value_stores} \tab Specifies the key value stores to list\cr
#'  \link[paws.networking:cloudfront_list_origin_access_controls]{list_origin_access_controls} \tab Gets the list of CloudFront origin access controls (OACs) in this Amazon Web Services account\cr
#'  \link[paws.networking:cloudfront_list_origin_request_policies]{list_origin_request_policies} \tab Gets a list of origin request policies\cr
#'  \link[paws.networking:cloudfront_list_public_keys]{list_public_keys} \tab List all public keys that have been added to CloudFront for this account\cr
#'  \link[paws.networking:cloudfront_list_realtime_log_configs]{list_realtime_log_configs} \tab Gets a list of real-time log configurations\cr
#'  \link[paws.networking:cloudfront_list_response_headers_policies]{list_response_headers_policies} \tab Gets a list of response headers policies\cr
#'  \link[paws.networking:cloudfront_list_streaming_distributions]{list_streaming_distributions} \tab List streaming distributions\cr
#'  \link[paws.networking:cloudfront_list_tags_for_resource]{list_tags_for_resource} \tab List tags for a CloudFront resource\cr
#'  \link[paws.networking:cloudfront_list_vpc_origins]{list_vpc_origins} \tab List the CloudFront VPC origins in your account\cr
#'  \link[paws.networking:cloudfront_publish_function]{publish_function} \tab Publishes a CloudFront function by copying the function code from the DEVELOPMENT stage to LIVE\cr
#'  \link[paws.networking:cloudfront_tag_resource]{tag_resource} \tab Add tags to a CloudFront resource\cr
#'  \link[paws.networking:cloudfront_test_function]{test_function} \tab Tests a CloudFront function\cr
#'  \link[paws.networking:cloudfront_untag_resource]{untag_resource} \tab Remove tags from a CloudFront resource\cr
#'  \link[paws.networking:cloudfront_update_cache_policy]{update_cache_policy} \tab Updates a cache policy configuration\cr
#'  \link[paws.networking:cloudfront_update_cloud_front_origin_access_identity]{update_cloud_front_origin_access_identity} \tab Update an origin access identity\cr
#'  \link[paws.networking:cloudfront_update_continuous_deployment_policy]{update_continuous_deployment_policy} \tab Updates a continuous deployment policy\cr
#'  \link[paws.networking:cloudfront_update_distribution]{update_distribution} \tab Updates the configuration for a CloudFront distribution\cr
#'  \link[paws.networking:cloudfront_update_distribution_with_staging_config]{update_distribution_with_staging_config} \tab Copies the staging distribution's configuration to its corresponding primary distribution\cr
#'  \link[paws.networking:cloudfront_update_field_level_encryption_config]{update_field_level_encryption_config} \tab Update a field-level encryption configuration\cr
#'  \link[paws.networking:cloudfront_update_field_level_encryption_profile]{update_field_level_encryption_profile} \tab Update a field-level encryption profile\cr
#'  \link[paws.networking:cloudfront_update_function]{update_function} \tab Updates a CloudFront function\cr
#'  \link[paws.networking:cloudfront_update_key_group]{update_key_group} \tab Updates a key group\cr
#'  \link[paws.networking:cloudfront_update_key_value_store]{update_key_value_store} \tab Specifies the key value store to update\cr
#'  \link[paws.networking:cloudfront_update_origin_access_control]{update_origin_access_control} \tab Updates a CloudFront origin access control\cr
#'  \link[paws.networking:cloudfront_update_origin_request_policy]{update_origin_request_policy} \tab Updates an origin request policy configuration\cr
#'  \link[paws.networking:cloudfront_update_public_key]{update_public_key} \tab Update public key information\cr
#'  \link[paws.networking:cloudfront_update_realtime_log_config]{update_realtime_log_config} \tab Updates a real-time log configuration\cr
#'  \link[paws.networking:cloudfront_update_response_headers_policy]{update_response_headers_policy} \tab Updates a response headers policy\cr
#'  \link[paws.networking:cloudfront_update_streaming_distribution]{update_streaming_distribution} \tab Update a streaming distribution\cr
#'  \link[paws.networking:cloudfront_update_vpc_origin]{update_vpc_origin} \tab Update an Amazon CloudFront VPC origin in your account
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudfront
#' @export
cloudfront <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::cloudfront(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudFront KeyValueStore
#'
#' @description
#' Amazon CloudFront KeyValueStore Service to View and Update Data in a KVS
#' Resource
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudfrontkeyvaluestore(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudfrontkeyvaluestore()
#' svc$delete_key(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:cloudfrontkeyvaluestore_delete_key]{delete_key} \tab Deletes the key value pair specified by the key\cr
#'  \link[paws.networking:cloudfrontkeyvaluestore_describe_key_value_store]{describe_key_value_store} \tab Returns metadata information about Key Value Store\cr
#'  \link[paws.networking:cloudfrontkeyvaluestore_get_key]{get_key} \tab Returns a key value pair\cr
#'  \link[paws.networking:cloudfrontkeyvaluestore_list_keys]{list_keys} \tab Returns a list of key value pairs\cr
#'  \link[paws.networking:cloudfrontkeyvaluestore_put_key]{put_key} \tab Creates a new key value pair or replaces the value of an existing key\cr
#'  \link[paws.networking:cloudfrontkeyvaluestore_update_keys]{update_keys} \tab Puts or Deletes multiple key value pairs in a single, all-or-nothing operation
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudfrontkeyvaluestore
#' @export
cloudfrontkeyvaluestore <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::cloudfrontkeyvaluestore(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Direct Connect
#'
#' @description
#' Direct Connect links your internal network to an Direct Connect location
#' over a standard Ethernet fiber-optic cable. One end of the cable is
#' connected to your router, the other to an Direct Connect router. With
#' this connection in place, you can create virtual interfaces directly to
#' the Amazon Web Services Cloud (for example, to Amazon EC2 and Amazon S3)
#' and to Amazon VPC, bypassing Internet service providers in your network
#' path. A connection provides access to all Amazon Web Services Regions
#' except the China (Beijing) and (China) Ningxia Regions. Amazon Web
#' Services resources in the China Regions can only be accessed through
#' locations associated with those Regions.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- directconnect(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- directconnect()
#' svc$accept_direct_connect_gateway_association_proposal(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:directconnect_accept_direct_connect_gateway_association_proposal]{accept_direct_connect_gateway_association_proposal} \tab Accepts a proposal request to attach a virtual private gateway or transit gateway to a Direct Connect gateway\cr
#'  \link[paws.networking:directconnect_allocate_connection_on_interconnect]{allocate_connection_on_interconnect} \tab Deprecated\cr
#'  \link[paws.networking:directconnect_allocate_hosted_connection]{allocate_hosted_connection} \tab Creates a hosted connection on the specified interconnect or a link aggregation group (LAG) of interconnects\cr
#'  \link[paws.networking:directconnect_allocate_private_virtual_interface]{allocate_private_virtual_interface} \tab Provisions a private virtual interface to be owned by the specified Amazon Web Services account\cr
#'  \link[paws.networking:directconnect_allocate_public_virtual_interface]{allocate_public_virtual_interface} \tab Provisions a public virtual interface to be owned by the specified Amazon Web Services account\cr
#'  \link[paws.networking:directconnect_allocate_transit_virtual_interface]{allocate_transit_virtual_interface} \tab Provisions a transit virtual interface to be owned by the specified Amazon Web Services account\cr
#'  \link[paws.networking:directconnect_associate_connection_with_lag]{associate_connection_with_lag} \tab Associates an existing connection with a link aggregation group (LAG)\cr
#'  \link[paws.networking:directconnect_associate_hosted_connection]{associate_hosted_connection} \tab Associates a hosted connection and its virtual interfaces with a link aggregation group (LAG) or interconnect\cr
#'  \link[paws.networking:directconnect_associate_mac_sec_key]{associate_mac_sec_key} \tab Associates a MAC Security (MACsec) Connection Key Name (CKN)/ Connectivity Association Key (CAK) pair with an Direct Connect dedicated connection\cr
#'  \link[paws.networking:directconnect_associate_virtual_interface]{associate_virtual_interface} \tab Associates a virtual interface with a specified link aggregation group (LAG) or connection\cr
#'  \link[paws.networking:directconnect_confirm_connection]{confirm_connection} \tab Confirms the creation of the specified hosted connection on an interconnect\cr
#'  \link[paws.networking:directconnect_confirm_customer_agreement]{confirm_customer_agreement} \tab The confirmation of the terms of agreement when creating the connection/link aggregation group (LAG)\cr
#'  \link[paws.networking:directconnect_confirm_private_virtual_interface]{confirm_private_virtual_interface} \tab Accepts ownership of a private virtual interface created by another Amazon Web Services account\cr
#'  \link[paws.networking:directconnect_confirm_public_virtual_interface]{confirm_public_virtual_interface} \tab Accepts ownership of a public virtual interface created by another Amazon Web Services account\cr
#'  \link[paws.networking:directconnect_confirm_transit_virtual_interface]{confirm_transit_virtual_interface} \tab Accepts ownership of a transit virtual interface created by another Amazon Web Services account\cr
#'  \link[paws.networking:directconnect_create_bgp_peer]{create_bgp_peer} \tab Creates a BGP peer on the specified virtual interface\cr
#'  \link[paws.networking:directconnect_create_connection]{create_connection} \tab Creates a connection between a customer network and a specific Direct Connect location\cr
#'  \link[paws.networking:directconnect_create_direct_connect_gateway]{create_direct_connect_gateway} \tab Creates a Direct Connect gateway, which is an intermediate object that enables you to connect a set of virtual interfaces and virtual private gateways\cr
#'  \link[paws.networking:directconnect_create_direct_connect_gateway_association]{create_direct_connect_gateway_association} \tab Creates an association between a Direct Connect gateway and a virtual private gateway\cr
#'  \link[paws.networking:directconnect_create_direct_connect_gateway_association_proposal]{create_direct_connect_gateway_association_proposal} \tab Creates a proposal to associate the specified virtual private gateway or transit gateway with the specified Direct Connect gateway\cr
#'  \link[paws.networking:directconnect_create_interconnect]{create_interconnect} \tab Creates an interconnect between an Direct Connect Partner's network and a specific Direct Connect location\cr
#'  \link[paws.networking:directconnect_create_lag]{create_lag} \tab Creates a link aggregation group (LAG) with the specified number of bundled physical dedicated connections between the customer network and a specific Direct Connect location\cr
#'  \link[paws.networking:directconnect_create_private_virtual_interface]{create_private_virtual_interface} \tab Creates a private virtual interface\cr
#'  \link[paws.networking:directconnect_create_public_virtual_interface]{create_public_virtual_interface} \tab Creates a public virtual interface\cr
#'  \link[paws.networking:directconnect_create_transit_virtual_interface]{create_transit_virtual_interface} \tab Creates a transit virtual interface\cr
#'  \link[paws.networking:directconnect_delete_bgp_peer]{delete_bgp_peer} \tab Deletes the specified BGP peer on the specified virtual interface with the specified customer address and ASN\cr
#'  \link[paws.networking:directconnect_delete_connection]{delete_connection} \tab Deletes the specified connection\cr
#'  \link[paws.networking:directconnect_delete_direct_connect_gateway]{delete_direct_connect_gateway} \tab Deletes the specified Direct Connect gateway\cr
#'  \link[paws.networking:directconnect_delete_direct_connect_gateway_association]{delete_direct_connect_gateway_association} \tab Deletes the association between the specified Direct Connect gateway and virtual private gateway\cr
#'  \link[paws.networking:directconnect_delete_direct_connect_gateway_association_proposal]{delete_direct_connect_gateway_association_proposal} \tab Deletes the association proposal request between the specified Direct Connect gateway and virtual private gateway or transit gateway\cr
#'  \link[paws.networking:directconnect_delete_interconnect]{delete_interconnect} \tab Deletes the specified interconnect\cr
#'  \link[paws.networking:directconnect_delete_lag]{delete_lag} \tab Deletes the specified link aggregation group (LAG)\cr
#'  \link[paws.networking:directconnect_delete_virtual_interface]{delete_virtual_interface} \tab Deletes a virtual interface\cr
#'  \link[paws.networking:directconnect_describe_connection_loa]{describe_connection_loa} \tab Deprecated\cr
#'  \link[paws.networking:directconnect_describe_connections]{describe_connections} \tab Displays the specified connection or all connections in this Region\cr
#'  \link[paws.networking:directconnect_describe_connections_on_interconnect]{describe_connections_on_interconnect} \tab Deprecated\cr
#'  \link[paws.networking:directconnect_describe_customer_metadata]{describe_customer_metadata} \tab Get and view a list of customer agreements, along with their signed status and whether the customer is an NNIPartner, NNIPartnerV2, or a nonPartner\cr
#'  \link[paws.networking:directconnect_describe_direct_connect_gateway_association_proposals]{describe_direct_connect_gateway_association_proposals} \tab Describes one or more association proposals for connection between a virtual private gateway or transit gateway and a Direct Connect gateway\cr
#'  \link[paws.networking:directconnect_describe_direct_connect_gateway_associations]{describe_direct_connect_gateway_associations} \tab Lists the associations between your Direct Connect gateways and virtual private gateways and transit gateways\cr
#'  \link[paws.networking:directconnect_describe_direct_connect_gateway_attachments]{describe_direct_connect_gateway_attachments} \tab Lists the attachments between your Direct Connect gateways and virtual interfaces\cr
#'  \link[paws.networking:directconnect_describe_direct_connect_gateways]{describe_direct_connect_gateways} \tab Lists all your Direct Connect gateways or only the specified Direct Connect gateway\cr
#'  \link[paws.networking:directconnect_describe_hosted_connections]{describe_hosted_connections} \tab Lists the hosted connections that have been provisioned on the specified interconnect or link aggregation group (LAG)\cr
#'  \link[paws.networking:directconnect_describe_interconnect_loa]{describe_interconnect_loa} \tab Deprecated\cr
#'  \link[paws.networking:directconnect_describe_interconnects]{describe_interconnects} \tab Lists the interconnects owned by the Amazon Web Services account or only the specified interconnect\cr
#'  \link[paws.networking:directconnect_describe_lags]{describe_lags} \tab Describes all your link aggregation groups (LAG) or the specified LAG\cr
#'  \link[paws.networking:directconnect_describe_loa]{describe_loa} \tab Gets the LOA-CFA for a connection, interconnect, or link aggregation group (LAG)\cr
#'  \link[paws.networking:directconnect_describe_locations]{describe_locations} \tab Lists the Direct Connect locations in the current Amazon Web Services Region\cr
#'  \link[paws.networking:directconnect_describe_router_configuration]{describe_router_configuration} \tab Details about the router\cr
#'  \link[paws.networking:directconnect_describe_tags]{describe_tags} \tab Describes the tags associated with the specified Direct Connect resources\cr
#'  \link[paws.networking:directconnect_describe_virtual_gateways]{describe_virtual_gateways} \tab Deprecated\cr
#'  \link[paws.networking:directconnect_describe_virtual_interfaces]{describe_virtual_interfaces} \tab Displays all virtual interfaces for an Amazon Web Services account\cr
#'  \link[paws.networking:directconnect_disassociate_connection_from_lag]{disassociate_connection_from_lag} \tab Disassociates a connection from a link aggregation group (LAG)\cr
#'  \link[paws.networking:directconnect_disassociate_mac_sec_key]{disassociate_mac_sec_key} \tab Removes the association between a MAC Security (MACsec) security key and an Direct Connect dedicated connection\cr
#'  \link[paws.networking:directconnect_list_virtual_interface_test_history]{list_virtual_interface_test_history} \tab Lists the virtual interface failover test history\cr
#'  \link[paws.networking:directconnect_start_bgp_failover_test]{start_bgp_failover_test} \tab Starts the virtual interface failover test that verifies your configuration meets your resiliency requirements by placing the BGP peering session in the DOWN state\cr
#'  \link[paws.networking:directconnect_stop_bgp_failover_test]{stop_bgp_failover_test} \tab Stops the virtual interface failover test\cr
#'  \link[paws.networking:directconnect_tag_resource]{tag_resource} \tab Adds the specified tags to the specified Direct Connect resource\cr
#'  \link[paws.networking:directconnect_untag_resource]{untag_resource} \tab Removes one or more tags from the specified Direct Connect resource\cr
#'  \link[paws.networking:directconnect_update_connection]{update_connection} \tab Updates the Direct Connect dedicated connection configuration\cr
#'  \link[paws.networking:directconnect_update_direct_connect_gateway]{update_direct_connect_gateway} \tab Updates the name of a current Direct Connect gateway\cr
#'  \link[paws.networking:directconnect_update_direct_connect_gateway_association]{update_direct_connect_gateway_association} \tab Updates the specified attributes of the Direct Connect gateway association\cr
#'  \link[paws.networking:directconnect_update_lag]{update_lag} \tab Updates the attributes of the specified link aggregation group (LAG)\cr
#'  \link[paws.networking:directconnect_update_virtual_interface_attributes]{update_virtual_interface_attributes} \tab Updates the specified attributes of the specified virtual private interface
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname directconnect
#' @export
directconnect <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::directconnect(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Elastic Load Balancing
#'
#' @description
#' A load balancer can distribute incoming traffic across your EC2
#' instances. This enables you to increase the availability of your
#' application. The load balancer also monitors the health of its
#' registered instances and ensures that it routes traffic only to healthy
#' instances. You configure your load balancer to accept incoming traffic
#' by specifying one or more listeners, which are configured with a
#' protocol and port number for connections from clients to the load
#' balancer and a protocol and port number for connections from the load
#' balancer to the instances.
#' 
#' Elastic Load Balancing supports three types of load balancers:
#' Application Load Balancers, Network Load Balancers, and Classic Load
#' Balancers. You can select a load balancer based on your application
#' needs. For more information, see the [Elastic Load Balancing User
#' Guide](https://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/).
#' 
#' This reference covers the 2012-06-01 API, which supports Classic Load
#' Balancers. The 2015-12-01 API supports Application Load Balancers and
#' Network Load Balancers.
#' 
#' To get started, create a load balancer with one or more listeners using
#' `create_load_balancer`. Register your
#' instances with the load balancer using
#' `register_instances_with_load_balancer`.
#' 
#' All Elastic Load Balancing operations are *idempotent*, which means that
#' they complete at most one time. If you repeat an operation, it succeeds
#' with a 200 OK response code.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- elb(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- elb()
#' # This example adds two tags to the specified load balancer.
#' svc$add_tags(
#'   LoadBalancerNames = list(
#'     "my-load-balancer"
#'   ),
#'   Tags = list(
#'     list(
#'       Key = "project",
#'       Value = "lima"
#'     ),
#'     list(
#'       Key = "department",
#'       Value = "digital-media"
#'     )
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:elb_add_tags]{add_tags} \tab Adds the specified tags to the specified load balancer\cr
#'  \link[paws.networking:elb_apply_security_groups_to_load_balancer]{apply_security_groups_to_load_balancer} \tab Associates one or more security groups with your load balancer in a virtual private cloud (VPC)\cr
#'  \link[paws.networking:elb_attach_load_balancer_to_subnets]{attach_load_balancer_to_subnets} \tab Adds one or more subnets to the set of configured subnets for the specified load balancer\cr
#'  \link[paws.networking:elb_configure_health_check]{configure_health_check} \tab Specifies the health check settings to use when evaluating the health state of your EC2 instances\cr
#'  \link[paws.networking:elb_create_app_cookie_stickiness_policy]{create_app_cookie_stickiness_policy} \tab Generates a stickiness policy with sticky session lifetimes that follow that of an application-generated cookie\cr
#'  \link[paws.networking:elb_create_lb_cookie_stickiness_policy]{create_lb_cookie_stickiness_policy} \tab Generates a stickiness policy with sticky session lifetimes controlled by the lifetime of the browser (user-agent) or a specified expiration period\cr
#'  \link[paws.networking:elb_create_load_balancer]{create_load_balancer} \tab Creates a Classic Load Balancer\cr
#'  \link[paws.networking:elb_create_load_balancer_listeners]{create_load_balancer_listeners} \tab Creates one or more listeners for the specified load balancer\cr
#'  \link[paws.networking:elb_create_load_balancer_policy]{create_load_balancer_policy} \tab Creates a policy with the specified attributes for the specified load balancer\cr
#'  \link[paws.networking:elb_delete_load_balancer]{delete_load_balancer} \tab Deletes the specified load balancer\cr
#'  \link[paws.networking:elb_delete_load_balancer_listeners]{delete_load_balancer_listeners} \tab Deletes the specified listeners from the specified load balancer\cr
#'  \link[paws.networking:elb_delete_load_balancer_policy]{delete_load_balancer_policy} \tab Deletes the specified policy from the specified load balancer\cr
#'  \link[paws.networking:elb_deregister_instances_from_load_balancer]{deregister_instances_from_load_balancer} \tab Deregisters the specified instances from the specified load balancer\cr
#'  \link[paws.networking:elb_describe_account_limits]{describe_account_limits} \tab Describes the current Elastic Load Balancing resource limits for your AWS account\cr
#'  \link[paws.networking:elb_describe_instance_health]{describe_instance_health} \tab Describes the state of the specified instances with respect to the specified load balancer\cr
#'  \link[paws.networking:elb_describe_load_balancer_attributes]{describe_load_balancer_attributes} \tab Describes the attributes for the specified load balancer\cr
#'  \link[paws.networking:elb_describe_load_balancer_policies]{describe_load_balancer_policies} \tab Describes the specified policies\cr
#'  \link[paws.networking:elb_describe_load_balancer_policy_types]{describe_load_balancer_policy_types} \tab Describes the specified load balancer policy types or all load balancer policy types\cr
#'  \link[paws.networking:elb_describe_load_balancers]{describe_load_balancers} \tab Describes the specified the load balancers\cr
#'  \link[paws.networking:elb_describe_tags]{describe_tags} \tab Describes the tags associated with the specified load balancers\cr
#'  \link[paws.networking:elb_detach_load_balancer_from_subnets]{detach_load_balancer_from_subnets} \tab Removes the specified subnets from the set of configured subnets for the load balancer\cr
#'  \link[paws.networking:elb_disable_availability_zones_for_load_balancer]{disable_availability_zones_for_load_balancer} \tab Removes the specified Availability Zones from the set of Availability Zones for the specified load balancer in EC2-Classic or a default VPC\cr
#'  \link[paws.networking:elb_enable_availability_zones_for_load_balancer]{enable_availability_zones_for_load_balancer} \tab Adds the specified Availability Zones to the set of Availability Zones for the specified load balancer in EC2-Classic or a default VPC\cr
#'  \link[paws.networking:elb_modify_load_balancer_attributes]{modify_load_balancer_attributes} \tab Modifies the attributes of the specified load balancer\cr
#'  \link[paws.networking:elb_register_instances_with_load_balancer]{register_instances_with_load_balancer} \tab Adds the specified instances to the specified load balancer\cr
#'  \link[paws.networking:elb_remove_tags]{remove_tags} \tab Removes one or more tags from the specified load balancer\cr
#'  \link[paws.networking:elb_set_load_balancer_listener_ssl_certificate]{set_load_balancer_listener_ssl_certificate} \tab Sets the certificate that terminates the specified listener's SSL connections\cr
#'  \link[paws.networking:elb_set_load_balancer_policies_for_backend_server]{set_load_balancer_policies_for_backend_server} \tab Replaces the set of policies associated with the specified port on which the EC2 instance is listening with a new set of policies\cr
#'  \link[paws.networking:elb_set_load_balancer_policies_of_listener]{set_load_balancer_policies_of_listener} \tab Replaces the current set of policies for the specified load balancer port with the specified set of policies
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname elb
#' @export
elb <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::elb(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Elastic Load Balancing
#'
#' @description
#' A load balancer distributes incoming traffic across targets, such as
#' your EC2 instances. This enables you to increase the availability of
#' your application. The load balancer also monitors the health of its
#' registered targets and ensures that it routes traffic only to healthy
#' targets. You configure your load balancer to accept incoming traffic by
#' specifying one or more listeners, which are configured with a protocol
#' and port number for connections from clients to the load balancer. You
#' configure a target group with a protocol and port number for connections
#' from the load balancer to the targets, and with health check settings to
#' be used when checking the health status of the targets.
#' 
#' Elastic Load Balancing supports the following types of load balancers:
#' Application Load Balancers, Network Load Balancers, Gateway Load
#' Balancers, and Classic Load Balancers. This reference covers the
#' following load balancer types:
#' 
#' -   Application Load Balancer - Operates at the application layer
#'     (layer 7) and supports HTTP and HTTPS.
#' 
#' -   Network Load Balancer - Operates at the transport layer (layer 4)
#'     and supports TCP, TLS, and UDP.
#' 
#' -   Gateway Load Balancer - Operates at the network layer (layer 3).
#' 
#' For more information, see the [Elastic Load Balancing User
#' Guide](https://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/).
#' 
#' All Elastic Load Balancing operations are idempotent, which means that
#' they complete at most one time. If you repeat an operation, it succeeds.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- elbv2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- elbv2()
#' # This example adds the specified tags to the specified load balancer.
#' svc$add_tags(
#'   ResourceArns = list(
#'     "arn:aws:elasticloadbalancing:us-west-2:123456789012:loadbalancer/app/m..."
#'   ),
#'   Tags = list(
#'     list(
#'       Key = "project",
#'       Value = "lima"
#'     ),
#'     list(
#'       Key = "department",
#'       Value = "digital-media"
#'     )
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:elbv2_add_listener_certificates]{add_listener_certificates} \tab Adds the specified SSL server certificate to the certificate list for the specified HTTPS or TLS listener\cr
#'  \link[paws.networking:elbv2_add_tags]{add_tags} \tab Adds the specified tags to the specified Elastic Load Balancing resource\cr
#'  \link[paws.networking:elbv2_add_trust_store_revocations]{add_trust_store_revocations} \tab Adds the specified revocation file to the specified trust store\cr
#'  \link[paws.networking:elbv2_create_listener]{create_listener} \tab Creates a listener for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer\cr
#'  \link[paws.networking:elbv2_create_load_balancer]{create_load_balancer} \tab Creates an Application Load Balancer, Network Load Balancer, or Gateway Load Balancer\cr
#'  \link[paws.networking:elbv2_create_rule]{create_rule} \tab Creates a rule for the specified listener\cr
#'  \link[paws.networking:elbv2_create_target_group]{create_target_group} \tab Creates a target group\cr
#'  \link[paws.networking:elbv2_create_trust_store]{create_trust_store} \tab Creates a trust store\cr
#'  \link[paws.networking:elbv2_delete_listener]{delete_listener} \tab Deletes the specified listener\cr
#'  \link[paws.networking:elbv2_delete_load_balancer]{delete_load_balancer} \tab Deletes the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer\cr
#'  \link[paws.networking:elbv2_delete_rule]{delete_rule} \tab Deletes the specified rule\cr
#'  \link[paws.networking:elbv2_delete_shared_trust_store_association]{delete_shared_trust_store_association} \tab Deletes a shared trust store association\cr
#'  \link[paws.networking:elbv2_delete_target_group]{delete_target_group} \tab Deletes the specified target group\cr
#'  \link[paws.networking:elbv2_delete_trust_store]{delete_trust_store} \tab Deletes a trust store\cr
#'  \link[paws.networking:elbv2_deregister_targets]{deregister_targets} \tab Deregisters the specified targets from the specified target group\cr
#'  \link[paws.networking:elbv2_describe_account_limits]{describe_account_limits} \tab Describes the current Elastic Load Balancing resource limits for your Amazon Web Services account\cr
#'  \link[paws.networking:elbv2_describe_capacity_reservation]{describe_capacity_reservation} \tab Describes the capacity reservation status for the specified load balancer\cr
#'  \link[paws.networking:elbv2_describe_listener_attributes]{describe_listener_attributes} \tab Describes the attributes for the specified listener\cr
#'  \link[paws.networking:elbv2_describe_listener_certificates]{describe_listener_certificates} \tab Describes the default certificate and the certificate list for the specified HTTPS or TLS listener\cr
#'  \link[paws.networking:elbv2_describe_listeners]{describe_listeners} \tab Describes the specified listeners or the listeners for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer\cr
#'  \link[paws.networking:elbv2_describe_load_balancer_attributes]{describe_load_balancer_attributes} \tab Describes the attributes for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer\cr
#'  \link[paws.networking:elbv2_describe_load_balancers]{describe_load_balancers} \tab Describes the specified load balancers or all of your load balancers\cr
#'  \link[paws.networking:elbv2_describe_rules]{describe_rules} \tab Describes the specified rules or the rules for the specified listener\cr
#'  \link[paws.networking:elbv2_describe_ssl_policies]{describe_ssl_policies} \tab Describes the specified policies or all policies used for SSL negotiation\cr
#'  \link[paws.networking:elbv2_describe_tags]{describe_tags} \tab Describes the tags for the specified Elastic Load Balancing resources\cr
#'  \link[paws.networking:elbv2_describe_target_group_attributes]{describe_target_group_attributes} \tab Describes the attributes for the specified target group\cr
#'  \link[paws.networking:elbv2_describe_target_groups]{describe_target_groups} \tab Describes the specified target groups or all of your target groups\cr
#'  \link[paws.networking:elbv2_describe_target_health]{describe_target_health} \tab Describes the health of the specified targets or all of your targets\cr
#'  \link[paws.networking:elbv2_describe_trust_store_associations]{describe_trust_store_associations} \tab Describes all resources associated with the specified trust store\cr
#'  \link[paws.networking:elbv2_describe_trust_store_revocations]{describe_trust_store_revocations} \tab Describes the revocation files in use by the specified trust store or revocation files\cr
#'  \link[paws.networking:elbv2_describe_trust_stores]{describe_trust_stores} \tab Describes all trust stores for the specified account\cr
#'  \link[paws.networking:elbv2_get_resource_policy]{get_resource_policy} \tab Retrieves the resource policy for a specified resource\cr
#'  \link[paws.networking:elbv2_get_trust_store_ca_certificates_bundle]{get_trust_store_ca_certificates_bundle} \tab Retrieves the ca certificate bundle\cr
#'  \link[paws.networking:elbv2_get_trust_store_revocation_content]{get_trust_store_revocation_content} \tab Retrieves the specified revocation file\cr
#'  \link[paws.networking:elbv2_modify_capacity_reservation]{modify_capacity_reservation} \tab Modifies the capacity reservation of the specified load balancer\cr
#'  \link[paws.networking:elbv2_modify_listener]{modify_listener} \tab Replaces the specified properties of the specified listener\cr
#'  \link[paws.networking:elbv2_modify_listener_attributes]{modify_listener_attributes} \tab Modifies the specified attributes of the specified listener\cr
#'  \link[paws.networking:elbv2_modify_load_balancer_attributes]{modify_load_balancer_attributes} \tab Modifies the specified attributes of the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer\cr
#'  \link[paws.networking:elbv2_modify_rule]{modify_rule} \tab Replaces the specified properties of the specified rule\cr
#'  \link[paws.networking:elbv2_modify_target_group]{modify_target_group} \tab Modifies the health checks used when evaluating the health state of the targets in the specified target group\cr
#'  \link[paws.networking:elbv2_modify_target_group_attributes]{modify_target_group_attributes} \tab Modifies the specified attributes of the specified target group\cr
#'  \link[paws.networking:elbv2_modify_trust_store]{modify_trust_store} \tab Update the ca certificate bundle for the specified trust store\cr
#'  \link[paws.networking:elbv2_register_targets]{register_targets} \tab Registers the specified targets with the specified target group\cr
#'  \link[paws.networking:elbv2_remove_listener_certificates]{remove_listener_certificates} \tab Removes the specified certificate from the certificate list for the specified HTTPS or TLS listener\cr
#'  \link[paws.networking:elbv2_remove_tags]{remove_tags} \tab Removes the specified tags from the specified Elastic Load Balancing resources\cr
#'  \link[paws.networking:elbv2_remove_trust_store_revocations]{remove_trust_store_revocations} \tab Removes the specified revocation file from the specified trust store\cr
#'  \link[paws.networking:elbv2_set_ip_address_type]{set_ip_address_type} \tab Sets the type of IP addresses used by the subnets of the specified load balancer\cr
#'  \link[paws.networking:elbv2_set_rule_priorities]{set_rule_priorities} \tab Sets the priorities of the specified rules\cr
#'  \link[paws.networking:elbv2_set_security_groups]{set_security_groups} \tab Associates the specified security groups with the specified Application Load Balancer or Network Load Balancer\cr
#'  \link[paws.networking:elbv2_set_subnets]{set_subnets} \tab Enables the Availability Zones for the specified public subnets for the specified Application Load Balancer, Network Load Balancer or Gateway Load Balancer
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname elbv2
#' @export
elbv2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::elbv2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Global Accelerator
#'
#' @description
#' Global Accelerator
#' 
#' This is the *Global Accelerator API Reference*. This guide is for
#' developers who need detailed information about Global Accelerator API
#' actions, data types, and errors. For more information about Global
#' Accelerator features, see the [Global Accelerator Developer
#' Guide](https://docs.aws.amazon.com/global-accelerator/latest/dg/what-is-global-accelerator.html).
#' 
#' Global Accelerator is a service in which you create *accelerators* to
#' improve the performance of your applications for local and global users.
#' Depending on the type of accelerator you choose, you can gain additional
#' benefits.
#' 
#' -   By using a standard accelerator, you can improve availability of
#'     your internet applications that are used by a global audience. With
#'     a standard accelerator, Global Accelerator directs traffic to
#'     optimal endpoints over the Amazon Web Services global network.
#' 
#' -   For other scenarios, you might choose a custom routing accelerator.
#'     With a custom routing accelerator, you can use application logic to
#'     directly map one or more users to a specific endpoint among many
#'     endpoints.
#' 
#' Global Accelerator is a global service that supports endpoints in
#' multiple Amazon Web Services Regions but you must specify the US West
#' (Oregon) Region to create, update, or otherwise work with accelerators.
#' That is, for example, specify `--region us-west-2` on Amazon Web
#' Services CLI commands.
#' 
#' By default, Global Accelerator provides you with static IP addresses
#' that you associate with your accelerator. The static IP addresses are
#' anycast from the Amazon Web Services edge network. For IPv4, Global
#' Accelerator provides two static IPv4 addresses. For dual-stack, Global
#' Accelerator provides a total of four addresses: two static IPv4
#' addresses and two static IPv6 addresses. With a standard accelerator for
#' IPv4, instead of using the addresses that Global Accelerator provides,
#' you can configure these entry points to be IPv4 addresses from your own
#' IP address ranges that you bring to Global Accelerator (BYOIP).
#' 
#' For a standard accelerator, they distribute incoming application traffic
#' across multiple endpoint resources in multiple Amazon Web Services
#' Regions , which increases the availability of your applications.
#' Endpoints for standard accelerators can be Network Load Balancers,
#' Application Load Balancers, Amazon EC2 instances, or Elastic IP
#' addresses that are located in one Amazon Web Services Region or multiple
#' Amazon Web Services Regions. For custom routing accelerators, you map
#' traffic that arrives to the static IP addresses to specific Amazon EC2
#' servers in endpoints that are virtual private cloud (VPC) subnets.
#' 
#' The static IP addresses remain assigned to your accelerator for as long
#' as it exists, even if you disable the accelerator and it no longer
#' accepts or routes traffic. However, when you *delete* an accelerator,
#' you lose the static IP addresses that are assigned to it, so you can no
#' longer route traffic by using them. You can use IAM policies like
#' tag-based permissions with Global Accelerator to limit the users who
#' have permissions to delete an accelerator. For more information, see
#' [Tag-based
#' policies](https://docs.aws.amazon.com/global-accelerator/latest/dg/).
#' 
#' For standard accelerators, Global Accelerator uses the Amazon Web
#' Services global network to route traffic to the optimal regional
#' endpoint based on health, client location, and policies that you
#' configure. The service reacts instantly to changes in health or
#' configuration to ensure that internet traffic from clients is always
#' directed to healthy endpoints.
#' 
#' For more information about understanding and using Global Accelerator,
#' see the [Global Accelerator Developer
#' Guide](https://docs.aws.amazon.com/global-accelerator/latest/dg/what-is-global-accelerator.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- globalaccelerator(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- globalaccelerator()
#' svc$add_custom_routing_endpoints(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:globalaccelerator_add_custom_routing_endpoints]{add_custom_routing_endpoints} \tab Associate a virtual private cloud (VPC) subnet endpoint with your custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_add_endpoints]{add_endpoints} \tab Add endpoints to an endpoint group\cr
#'  \link[paws.networking:globalaccelerator_advertise_byoip_cidr]{advertise_byoip_cidr} \tab Advertises an IPv4 address range that is provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP)\cr
#'  \link[paws.networking:globalaccelerator_allow_custom_routing_traffic]{allow_custom_routing_traffic} \tab Specify the Amazon EC2 instance (destination) IP addresses and ports for a VPC subnet endpoint that can receive traffic for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_create_accelerator]{create_accelerator} \tab Create an accelerator\cr
#'  \link[paws.networking:globalaccelerator_create_cross_account_attachment]{create_cross_account_attachment} \tab Create a cross-account attachment in Global Accelerator\cr
#'  \link[paws.networking:globalaccelerator_create_custom_routing_accelerator]{create_custom_routing_accelerator} \tab Create a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_create_custom_routing_endpoint_group]{create_custom_routing_endpoint_group} \tab Create an endpoint group for the specified listener for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_create_custom_routing_listener]{create_custom_routing_listener} \tab Create a listener to process inbound connections from clients to a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_create_endpoint_group]{create_endpoint_group} \tab Create an endpoint group for the specified listener\cr
#'  \link[paws.networking:globalaccelerator_create_listener]{create_listener} \tab Create a listener to process inbound connections from clients to an accelerator\cr
#'  \link[paws.networking:globalaccelerator_delete_accelerator]{delete_accelerator} \tab Delete an accelerator\cr
#'  \link[paws.networking:globalaccelerator_delete_cross_account_attachment]{delete_cross_account_attachment} \tab Delete a cross-account attachment\cr
#'  \link[paws.networking:globalaccelerator_delete_custom_routing_accelerator]{delete_custom_routing_accelerator} \tab Delete a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_delete_custom_routing_endpoint_group]{delete_custom_routing_endpoint_group} \tab Delete an endpoint group from a listener for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_delete_custom_routing_listener]{delete_custom_routing_listener} \tab Delete a listener for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_delete_endpoint_group]{delete_endpoint_group} \tab Delete an endpoint group from a listener\cr
#'  \link[paws.networking:globalaccelerator_delete_listener]{delete_listener} \tab Delete a listener from an accelerator\cr
#'  \link[paws.networking:globalaccelerator_deny_custom_routing_traffic]{deny_custom_routing_traffic} \tab Specify the Amazon EC2 instance (destination) IP addresses and ports for a VPC subnet endpoint that cannot receive traffic for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_deprovision_byoip_cidr]{deprovision_byoip_cidr} \tab Releases the specified address range that you provisioned to use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and deletes the corresponding address pool\cr
#'  \link[paws.networking:globalaccelerator_describe_accelerator]{describe_accelerator} \tab Describe an accelerator\cr
#'  \link[paws.networking:globalaccelerator_describe_accelerator_attributes]{describe_accelerator_attributes} \tab Describe the attributes of an accelerator\cr
#'  \link[paws.networking:globalaccelerator_describe_cross_account_attachment]{describe_cross_account_attachment} \tab Gets configuration information about a cross-account attachment\cr
#'  \link[paws.networking:globalaccelerator_describe_custom_routing_accelerator]{describe_custom_routing_accelerator} \tab Describe a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_describe_custom_routing_accelerator_attributes]{describe_custom_routing_accelerator_attributes} \tab Describe the attributes of a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_describe_custom_routing_endpoint_group]{describe_custom_routing_endpoint_group} \tab Describe an endpoint group for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_describe_custom_routing_listener]{describe_custom_routing_listener} \tab The description of a listener for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_describe_endpoint_group]{describe_endpoint_group} \tab Describe an endpoint group\cr
#'  \link[paws.networking:globalaccelerator_describe_listener]{describe_listener} \tab Describe a listener\cr
#'  \link[paws.networking:globalaccelerator_list_accelerators]{list_accelerators} \tab List the accelerators for an Amazon Web Services account\cr
#'  \link[paws.networking:globalaccelerator_list_byoip_cidrs]{list_byoip_cidrs} \tab Lists the IP address ranges that were specified in calls to ProvisionByoipCidr, including the current state and a history of state changes\cr
#'  \link[paws.networking:globalaccelerator_list_cross_account_attachments]{list_cross_account_attachments} \tab List the cross-account attachments that have been created in Global Accelerator\cr
#'  \link[paws.networking:globalaccelerator_list_cross_account_resource_accounts]{list_cross_account_resource_accounts} \tab List the accounts that have cross-account resources\cr
#'  \link[paws.networking:globalaccelerator_list_cross_account_resources]{list_cross_account_resources} \tab List the cross-account resources available to work with\cr
#'  \link[paws.networking:globalaccelerator_list_custom_routing_accelerators]{list_custom_routing_accelerators} \tab List the custom routing accelerators for an Amazon Web Services account\cr
#'  \link[paws.networking:globalaccelerator_list_custom_routing_endpoint_groups]{list_custom_routing_endpoint_groups} \tab List the endpoint groups that are associated with a listener for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_list_custom_routing_listeners]{list_custom_routing_listeners} \tab List the listeners for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_list_custom_routing_port_mappings]{list_custom_routing_port_mappings} \tab Provides a complete mapping from the public accelerator IP address and port to destination EC2 instance IP addresses and ports in the virtual public cloud (VPC) subnet endpoint for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_list_custom_routing_port_mappings_by_destination]{list_custom_routing_port_mappings_by_destination} \tab List the port mappings for a specific EC2 instance (destination) in a VPC subnet endpoint\cr
#'  \link[paws.networking:globalaccelerator_list_endpoint_groups]{list_endpoint_groups} \tab List the endpoint groups that are associated with a listener\cr
#'  \link[paws.networking:globalaccelerator_list_listeners]{list_listeners} \tab List the listeners for an accelerator\cr
#'  \link[paws.networking:globalaccelerator_list_tags_for_resource]{list_tags_for_resource} \tab List all tags for an accelerator\cr
#'  \link[paws.networking:globalaccelerator_provision_byoip_cidr]{provision_byoip_cidr} \tab Provisions an IP address range to use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and creates a corresponding address pool\cr
#'  \link[paws.networking:globalaccelerator_remove_custom_routing_endpoints]{remove_custom_routing_endpoints} \tab Remove endpoints from a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_remove_endpoints]{remove_endpoints} \tab Remove endpoints from an endpoint group\cr
#'  \link[paws.networking:globalaccelerator_tag_resource]{tag_resource} \tab Add tags to an accelerator resource\cr
#'  \link[paws.networking:globalaccelerator_untag_resource]{untag_resource} \tab Remove tags from a Global Accelerator resource\cr
#'  \link[paws.networking:globalaccelerator_update_accelerator]{update_accelerator} \tab Update an accelerator to make changes, such as the following:\cr
#'  \link[paws.networking:globalaccelerator_update_accelerator_attributes]{update_accelerator_attributes} \tab Update the attributes for an accelerator\cr
#'  \link[paws.networking:globalaccelerator_update_cross_account_attachment]{update_cross_account_attachment} \tab Update a cross-account attachment to add or remove principals or resources\cr
#'  \link[paws.networking:globalaccelerator_update_custom_routing_accelerator]{update_custom_routing_accelerator} \tab Update a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_update_custom_routing_accelerator_attributes]{update_custom_routing_accelerator_attributes} \tab Update the attributes for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_update_custom_routing_listener]{update_custom_routing_listener} \tab Update a listener for a custom routing accelerator\cr
#'  \link[paws.networking:globalaccelerator_update_endpoint_group]{update_endpoint_group} \tab Update an endpoint group\cr
#'  \link[paws.networking:globalaccelerator_update_listener]{update_listener} \tab Update a listener\cr
#'  \link[paws.networking:globalaccelerator_withdraw_byoip_cidr]{withdraw_byoip_cidr} \tab Stops advertising an address range that is provisioned as an address pool
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname globalaccelerator
#' @export
globalaccelerator <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::globalaccelerator(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Network Firewall
#'
#' @description
#' This is the API Reference for Network Firewall. This guide is for
#' developers who need detailed information about the Network Firewall API
#' actions, data types, and errors.
#' 
#' The REST API requires you to handle connection details, such as
#' calculating signatures, handling request retries, and error handling.
#' For general information about using the Amazon Web Services REST APIs,
#' see [Amazon Web Services
#' APIs](https://docs.aws.amazon.com/general/latest/gr/).
#' 
#' To view the complete list of Amazon Web Services Regions where Network
#' Firewall is available, see [Service endpoints and
#' quotas](https://docs.aws.amazon.com/general/latest/gr/network-firewall.html)
#' in the *Amazon Web Services General Reference*.
#' 
#' To access Network Firewall using the IPv4 REST API endpoint:
#' `https://network-firewall.<region>.amazonaws.com `
#' 
#' To access Network Firewall using the Dualstack (IPv4 and IPv6) REST API
#' endpoint: `https://network-firewall.<region>.aws.api `
#' 
#' Alternatively, you can use one of the Amazon Web Services SDKs to access
#' an API that's tailored to the programming language or platform that
#' you're using. For more information, see [Amazon Web Services
#' SDKs](https://aws.amazon.com/developer/tools/#SDKs).
#' 
#' For descriptions of Network Firewall features, including and
#' step-by-step instructions on how to use them through the Network
#' Firewall console, see the [Network Firewall Developer
#' Guide](https://docs.aws.amazon.com/network-firewall/latest/developerguide/).
#' 
#' Network Firewall is a stateful, managed, network firewall and intrusion
#' detection and prevention service for Amazon Virtual Private Cloud
#' (Amazon VPC). With Network Firewall, you can filter traffic at the
#' perimeter of your VPC. This includes filtering traffic going to and
#' coming from an internet gateway, NAT gateway, or over VPN or Direct
#' Connect. Network Firewall uses rules that are compatible with Suricata,
#' a free, open source network analysis and threat detection engine.
#' Network Firewall supports Suricata version 7.0.3. For information about
#' Suricata, see the [Suricata website](https://suricata.io/) and the
#' [Suricata User Guide](https://docs.suricata.io/en/suricata-7.0.3/).
#' 
#' You can use Network Firewall to monitor and protect your VPC traffic in
#' a number of ways. The following are just a few examples:
#' 
#' -   Allow domains or IP addresses for known Amazon Web Services service
#'     endpoints, such as Amazon S3, and block all other forms of traffic.
#' 
#' -   Use custom lists of known bad domains to limit the types of domain
#'     names that your applications can access.
#' 
#' -   Perform deep packet inspection on traffic entering or leaving your
#'     VPC.
#' 
#' -   Use stateful protocol detection to filter protocols like HTTPS,
#'     regardless of the port used.
#' 
#' To enable Network Firewall for your VPCs, you perform steps in both
#' Amazon VPC and in Network Firewall. For information about using Amazon
#' VPC, see [Amazon VPC User
#' Guide](https://docs.aws.amazon.com/vpc/latest/userguide/).
#' 
#' To start using Network Firewall, do the following:
#' 
#' 1.  (Optional) If you don't already have a VPC that you want to protect,
#'     create it in Amazon VPC.
#' 
#' 2.  In Amazon VPC, in each Availability Zone where you want to have a
#'     firewall endpoint, create a subnet for the sole use of Network
#'     Firewall.
#' 
#' 3.  In Network Firewall, create stateless and stateful rule groups, to
#'     define the components of the network traffic filtering behavior that
#'     you want your firewall to have.
#' 
#' 4.  In Network Firewall, create a firewall policy that uses your rule
#'     groups and specifies additional default traffic filtering behavior.
#' 
#' 5.  In Network Firewall, create a firewall and specify your new firewall
#'     policy and VPC subnets. Network Firewall creates a firewall endpoint
#'     in each subnet that you specify, with the behavior that's defined in
#'     the firewall policy.
#' 
#' 6.  In Amazon VPC, use ingress routing enhancements to route traffic
#'     through the new firewall endpoints.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- networkfirewall(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- networkfirewall()
#' svc$associate_firewall_policy(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:networkfirewall_associate_firewall_policy]{associate_firewall_policy} \tab Associates a FirewallPolicy to a Firewall\cr
#'  \link[paws.networking:networkfirewall_associate_subnets]{associate_subnets} \tab Associates the specified subnets in the Amazon VPC to the firewall\cr
#'  \link[paws.networking:networkfirewall_create_firewall]{create_firewall} \tab Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC\cr
#'  \link[paws.networking:networkfirewall_create_firewall_policy]{create_firewall_policy} \tab Creates the firewall policy for the firewall according to the specifications\cr
#'  \link[paws.networking:networkfirewall_create_rule_group]{create_rule_group} \tab Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags\cr
#'  \link[paws.networking:networkfirewall_create_tls_inspection_configuration]{create_tls_inspection_configuration} \tab Creates an Network Firewall TLS inspection configuration\cr
#'  \link[paws.networking:networkfirewall_delete_firewall]{delete_firewall} \tab Deletes the specified Firewall and its FirewallStatus\cr
#'  \link[paws.networking:networkfirewall_delete_firewall_policy]{delete_firewall_policy} \tab Deletes the specified FirewallPolicy\cr
#'  \link[paws.networking:networkfirewall_delete_resource_policy]{delete_resource_policy} \tab Deletes a resource policy that you created in a PutResourcePolicy request\cr
#'  \link[paws.networking:networkfirewall_delete_rule_group]{delete_rule_group} \tab Deletes the specified RuleGroup\cr
#'  \link[paws.networking:networkfirewall_delete_tls_inspection_configuration]{delete_tls_inspection_configuration} \tab Deletes the specified TLSInspectionConfiguration\cr
#'  \link[paws.networking:networkfirewall_describe_firewall]{describe_firewall} \tab Returns the data objects for the specified firewall\cr
#'  \link[paws.networking:networkfirewall_describe_firewall_policy]{describe_firewall_policy} \tab Returns the data objects for the specified firewall policy\cr
#'  \link[paws.networking:networkfirewall_describe_logging_configuration]{describe_logging_configuration} \tab Returns the logging configuration for the specified firewall\cr
#'  \link[paws.networking:networkfirewall_describe_resource_policy]{describe_resource_policy} \tab Retrieves a resource policy that you created in a PutResourcePolicy request\cr
#'  \link[paws.networking:networkfirewall_describe_rule_group]{describe_rule_group} \tab Returns the data objects for the specified rule group\cr
#'  \link[paws.networking:networkfirewall_describe_rule_group_metadata]{describe_rule_group_metadata} \tab High-level information about a rule group, returned by operations like create and describe\cr
#'  \link[paws.networking:networkfirewall_describe_tls_inspection_configuration]{describe_tls_inspection_configuration} \tab Returns the data objects for the specified TLS inspection configuration\cr
#'  \link[paws.networking:networkfirewall_disassociate_subnets]{disassociate_subnets} \tab Removes the specified subnet associations from the firewall\cr
#'  \link[paws.networking:networkfirewall_get_analysis_report_results]{get_analysis_report_results} \tab The results of a COMPLETED analysis report generated with StartAnalysisReport\cr
#'  \link[paws.networking:networkfirewall_list_analysis_reports]{list_analysis_reports} \tab Returns a list of all traffic analysis reports generated within the last 30 days\cr
#'  \link[paws.networking:networkfirewall_list_firewall_policies]{list_firewall_policies} \tab Retrieves the metadata for the firewall policies that you have defined\cr
#'  \link[paws.networking:networkfirewall_list_firewalls]{list_firewalls} \tab Retrieves the metadata for the firewalls that you have defined\cr
#'  \link[paws.networking:networkfirewall_list_rule_groups]{list_rule_groups} \tab Retrieves the metadata for the rule groups that you have defined\cr
#'  \link[paws.networking:networkfirewall_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves the tags associated with the specified resource\cr
#'  \link[paws.networking:networkfirewall_list_tls_inspection_configurations]{list_tls_inspection_configurations} \tab Retrieves the metadata for the TLS inspection configurations that you have defined\cr
#'  \link[paws.networking:networkfirewall_put_resource_policy]{put_resource_policy} \tab Creates or updates an IAM policy for your rule group or firewall policy\cr
#'  \link[paws.networking:networkfirewall_start_analysis_report]{start_analysis_report} \tab Generates a traffic analysis report for the timeframe and traffic type you specify\cr
#'  \link[paws.networking:networkfirewall_tag_resource]{tag_resource} \tab Adds the specified tags to the specified resource\cr
#'  \link[paws.networking:networkfirewall_untag_resource]{untag_resource} \tab Removes the tags with the specified keys from the specified resource\cr
#'  \link[paws.networking:networkfirewall_update_firewall_analysis_settings]{update_firewall_analysis_settings} \tab Enables specific types of firewall analysis on a specific firewall you define\cr
#'  \link[paws.networking:networkfirewall_update_firewall_delete_protection]{update_firewall_delete_protection} \tab Modifies the flag, DeleteProtection, which indicates whether it is possible to delete the firewall\cr
#'  \link[paws.networking:networkfirewall_update_firewall_description]{update_firewall_description} \tab Modifies the description for the specified firewall\cr
#'  \link[paws.networking:networkfirewall_update_firewall_encryption_configuration]{update_firewall_encryption_configuration} \tab A complex type that contains settings for encryption of your firewall resources\cr
#'  \link[paws.networking:networkfirewall_update_firewall_policy]{update_firewall_policy} \tab Updates the properties of the specified firewall policy\cr
#'  \link[paws.networking:networkfirewall_update_firewall_policy_change_protection]{update_firewall_policy_change_protection} \tab Modifies the flag, ChangeProtection, which indicates whether it is possible to change the firewall\cr
#'  \link[paws.networking:networkfirewall_update_logging_configuration]{update_logging_configuration} \tab Sets the logging configuration for the specified firewall\cr
#'  \link[paws.networking:networkfirewall_update_rule_group]{update_rule_group} \tab Updates the rule settings for the specified rule group\cr
#'  \link[paws.networking:networkfirewall_update_subnet_change_protection]{update_subnet_change_protection} \tab Update subnet change protection\cr
#'  \link[paws.networking:networkfirewall_update_tls_inspection_configuration]{update_tls_inspection_configuration} \tab Updates the TLS inspection configuration settings for the specified TLS inspection configuration
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname networkfirewall
#' @export
networkfirewall <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::networkfirewall(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Network Manager
#'
#' @description
#' Amazon Web Services enables you to centrally manage your Amazon Web
#' Services Cloud WAN core network and your Transit Gateway network across
#' Amazon Web Services accounts, Regions, and on-premises locations.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- networkmanager(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- networkmanager()
#' svc$accept_attachment(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:networkmanager_accept_attachment]{accept_attachment} \tab Accepts a core network attachment request\cr
#'  \link[paws.networking:networkmanager_associate_connect_peer]{associate_connect_peer} \tab Associates a core network Connect peer with a device and optionally, with a link\cr
#'  \link[paws.networking:networkmanager_associate_customer_gateway]{associate_customer_gateway} \tab Associates a customer gateway with a device and optionally, with a link\cr
#'  \link[paws.networking:networkmanager_associate_link]{associate_link} \tab Associates a link to a device\cr
#'  \link[paws.networking:networkmanager_associate_transit_gateway_connect_peer]{associate_transit_gateway_connect_peer} \tab Associates a transit gateway Connect peer with a device, and optionally, with a link\cr
#'  \link[paws.networking:networkmanager_create_connect_attachment]{create_connect_attachment} \tab Creates a core network Connect attachment from a specified core network attachment\cr
#'  \link[paws.networking:networkmanager_create_connection]{create_connection} \tab Creates a connection between two devices\cr
#'  \link[paws.networking:networkmanager_create_connect_peer]{create_connect_peer} \tab Creates a core network Connect peer for a specified core network connect attachment between a core network and an appliance\cr
#'  \link[paws.networking:networkmanager_create_core_network]{create_core_network} \tab Creates a core network as part of your global network, and optionally, with a core network policy\cr
#'  \link[paws.networking:networkmanager_create_device]{create_device} \tab Creates a new device in a global network\cr
#'  \link[paws.networking:networkmanager_create_direct_connect_gateway_attachment]{create_direct_connect_gateway_attachment} \tab Creates an Amazon Web Services Direct Connect gateway attachment\cr
#'  \link[paws.networking:networkmanager_create_global_network]{create_global_network} \tab Creates a new, empty global network\cr
#'  \link[paws.networking:networkmanager_create_link]{create_link} \tab Creates a new link for a specified site\cr
#'  \link[paws.networking:networkmanager_create_site]{create_site} \tab Creates a new site in a global network\cr
#'  \link[paws.networking:networkmanager_create_site_to_site_vpn_attachment]{create_site_to_site_vpn_attachment} \tab Creates an Amazon Web Services site-to-site VPN attachment on an edge location of a core network\cr
#'  \link[paws.networking:networkmanager_create_transit_gateway_peering]{create_transit_gateway_peering} \tab Creates a transit gateway peering connection\cr
#'  \link[paws.networking:networkmanager_create_transit_gateway_route_table_attachment]{create_transit_gateway_route_table_attachment} \tab Creates a transit gateway route table attachment\cr
#'  \link[paws.networking:networkmanager_create_vpc_attachment]{create_vpc_attachment} \tab Creates a VPC attachment on an edge location of a core network\cr
#'  \link[paws.networking:networkmanager_delete_attachment]{delete_attachment} \tab Deletes an attachment\cr
#'  \link[paws.networking:networkmanager_delete_connection]{delete_connection} \tab Deletes the specified connection in your global network\cr
#'  \link[paws.networking:networkmanager_delete_connect_peer]{delete_connect_peer} \tab Deletes a Connect peer\cr
#'  \link[paws.networking:networkmanager_delete_core_network]{delete_core_network} \tab Deletes a core network along with all core network policies\cr
#'  \link[paws.networking:networkmanager_delete_core_network_policy_version]{delete_core_network_policy_version} \tab Deletes a policy version from a core network\cr
#'  \link[paws.networking:networkmanager_delete_device]{delete_device} \tab Deletes an existing device\cr
#'  \link[paws.networking:networkmanager_delete_global_network]{delete_global_network} \tab Deletes an existing global network\cr
#'  \link[paws.networking:networkmanager_delete_link]{delete_link} \tab Deletes an existing link\cr
#'  \link[paws.networking:networkmanager_delete_peering]{delete_peering} \tab Deletes an existing peering connection\cr
#'  \link[paws.networking:networkmanager_delete_resource_policy]{delete_resource_policy} \tab Deletes a resource policy for the specified resource\cr
#'  \link[paws.networking:networkmanager_delete_site]{delete_site} \tab Deletes an existing site\cr
#'  \link[paws.networking:networkmanager_deregister_transit_gateway]{deregister_transit_gateway} \tab Deregisters a transit gateway from your global network\cr
#'  \link[paws.networking:networkmanager_describe_global_networks]{describe_global_networks} \tab Describes one or more global networks\cr
#'  \link[paws.networking:networkmanager_disassociate_connect_peer]{disassociate_connect_peer} \tab Disassociates a core network Connect peer from a device and a link\cr
#'  \link[paws.networking:networkmanager_disassociate_customer_gateway]{disassociate_customer_gateway} \tab Disassociates a customer gateway from a device and a link\cr
#'  \link[paws.networking:networkmanager_disassociate_link]{disassociate_link} \tab Disassociates an existing device from a link\cr
#'  \link[paws.networking:networkmanager_disassociate_transit_gateway_connect_peer]{disassociate_transit_gateway_connect_peer} \tab Disassociates a transit gateway Connect peer from a device and link\cr
#'  \link[paws.networking:networkmanager_execute_core_network_change_set]{execute_core_network_change_set} \tab Executes a change set on your core network\cr
#'  \link[paws.networking:networkmanager_get_connect_attachment]{get_connect_attachment} \tab Returns information about a core network Connect attachment\cr
#'  \link[paws.networking:networkmanager_get_connections]{get_connections} \tab Gets information about one or more of your connections in a global network\cr
#'  \link[paws.networking:networkmanager_get_connect_peer]{get_connect_peer} \tab Returns information about a core network Connect peer\cr
#'  \link[paws.networking:networkmanager_get_connect_peer_associations]{get_connect_peer_associations} \tab Returns information about a core network Connect peer associations\cr
#'  \link[paws.networking:networkmanager_get_core_network]{get_core_network} \tab Returns information about the LIVE policy for a core network\cr
#'  \link[paws.networking:networkmanager_get_core_network_change_events]{get_core_network_change_events} \tab Returns information about a core network change event\cr
#'  \link[paws.networking:networkmanager_get_core_network_change_set]{get_core_network_change_set} \tab Returns a change set between the LIVE core network policy and a submitted policy\cr
#'  \link[paws.networking:networkmanager_get_core_network_policy]{get_core_network_policy} \tab Returns details about a core network policy\cr
#'  \link[paws.networking:networkmanager_get_customer_gateway_associations]{get_customer_gateway_associations} \tab Gets the association information for customer gateways that are associated with devices and links in your global network\cr
#'  \link[paws.networking:networkmanager_get_devices]{get_devices} \tab Gets information about one or more of your devices in a global network\cr
#'  \link[paws.networking:networkmanager_get_direct_connect_gateway_attachment]{get_direct_connect_gateway_attachment} \tab Returns information about a specific Amazon Web Services Direct Connect gateway attachment\cr
#'  \link[paws.networking:networkmanager_get_link_associations]{get_link_associations} \tab Gets the link associations for a device or a link\cr
#'  \link[paws.networking:networkmanager_get_links]{get_links} \tab Gets information about one or more links in a specified global network\cr
#'  \link[paws.networking:networkmanager_get_network_resource_counts]{get_network_resource_counts} \tab Gets the count of network resources, by resource type, for the specified global network\cr
#'  \link[paws.networking:networkmanager_get_network_resource_relationships]{get_network_resource_relationships} \tab Gets the network resource relationships for the specified global network\cr
#'  \link[paws.networking:networkmanager_get_network_resources]{get_network_resources} \tab Describes the network resources for the specified global network\cr
#'  \link[paws.networking:networkmanager_get_network_routes]{get_network_routes} \tab Gets the network routes of the specified global network\cr
#'  \link[paws.networking:networkmanager_get_network_telemetry]{get_network_telemetry} \tab Gets the network telemetry of the specified global network\cr
#'  \link[paws.networking:networkmanager_get_resource_policy]{get_resource_policy} \tab Returns information about a resource policy\cr
#'  \link[paws.networking:networkmanager_get_route_analysis]{get_route_analysis} \tab Gets information about the specified route analysis\cr
#'  \link[paws.networking:networkmanager_get_sites]{get_sites} \tab Gets information about one or more of your sites in a global network\cr
#'  \link[paws.networking:networkmanager_get_site_to_site_vpn_attachment]{get_site_to_site_vpn_attachment} \tab Returns information about a site-to-site VPN attachment\cr
#'  \link[paws.networking:networkmanager_get_transit_gateway_connect_peer_associations]{get_transit_gateway_connect_peer_associations} \tab Gets information about one or more of your transit gateway Connect peer associations in a global network\cr
#'  \link[paws.networking:networkmanager_get_transit_gateway_peering]{get_transit_gateway_peering} \tab Returns information about a transit gateway peer\cr
#'  \link[paws.networking:networkmanager_get_transit_gateway_registrations]{get_transit_gateway_registrations} \tab Gets information about the transit gateway registrations in a specified global network\cr
#'  \link[paws.networking:networkmanager_get_transit_gateway_route_table_attachment]{get_transit_gateway_route_table_attachment} \tab Returns information about a transit gateway route table attachment\cr
#'  \link[paws.networking:networkmanager_get_vpc_attachment]{get_vpc_attachment} \tab Returns information about a VPC attachment\cr
#'  \link[paws.networking:networkmanager_list_attachments]{list_attachments} \tab Returns a list of core network attachments\cr
#'  \link[paws.networking:networkmanager_list_connect_peers]{list_connect_peers} \tab Returns a list of core network Connect peers\cr
#'  \link[paws.networking:networkmanager_list_core_network_policy_versions]{list_core_network_policy_versions} \tab Returns a list of core network policy versions\cr
#'  \link[paws.networking:networkmanager_list_core_networks]{list_core_networks} \tab Returns a list of owned and shared core networks\cr
#'  \link[paws.networking:networkmanager_list_organization_service_access_status]{list_organization_service_access_status} \tab Gets the status of the Service Linked Role (SLR) deployment for the accounts in a given Amazon Web Services Organization\cr
#'  \link[paws.networking:networkmanager_list_peerings]{list_peerings} \tab Lists the peerings for a core network\cr
#'  \link[paws.networking:networkmanager_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for a specified resource\cr
#'  \link[paws.networking:networkmanager_put_core_network_policy]{put_core_network_policy} \tab Creates a new, immutable version of a core network policy\cr
#'  \link[paws.networking:networkmanager_put_resource_policy]{put_resource_policy} \tab Creates or updates a resource policy\cr
#'  \link[paws.networking:networkmanager_register_transit_gateway]{register_transit_gateway} \tab Registers a transit gateway in your global network\cr
#'  \link[paws.networking:networkmanager_reject_attachment]{reject_attachment} \tab Rejects a core network attachment request\cr
#'  \link[paws.networking:networkmanager_restore_core_network_policy_version]{restore_core_network_policy_version} \tab Restores a previous policy version as a new, immutable version of a core network policy\cr
#'  \link[paws.networking:networkmanager_start_organization_service_access_update]{start_organization_service_access_update} \tab Enables the Network Manager service for an Amazon Web Services Organization\cr
#'  \link[paws.networking:networkmanager_start_route_analysis]{start_route_analysis} \tab Starts analyzing the routing path between the specified source and destination\cr
#'  \link[paws.networking:networkmanager_tag_resource]{tag_resource} \tab Tags a specified resource\cr
#'  \link[paws.networking:networkmanager_untag_resource]{untag_resource} \tab Removes tags from a specified resource\cr
#'  \link[paws.networking:networkmanager_update_connection]{update_connection} \tab Updates the information for an existing connection\cr
#'  \link[paws.networking:networkmanager_update_core_network]{update_core_network} \tab Updates the description of a core network\cr
#'  \link[paws.networking:networkmanager_update_device]{update_device} \tab Updates the details for an existing device\cr
#'  \link[paws.networking:networkmanager_update_direct_connect_gateway_attachment]{update_direct_connect_gateway_attachment} \tab Updates the edge locations associated with an Amazon Web Services Direct Connect gateway attachment\cr
#'  \link[paws.networking:networkmanager_update_global_network]{update_global_network} \tab Updates an existing global network\cr
#'  \link[paws.networking:networkmanager_update_link]{update_link} \tab Updates the details for an existing link\cr
#'  \link[paws.networking:networkmanager_update_network_resource_metadata]{update_network_resource_metadata} \tab Updates the resource metadata for the specified global network\cr
#'  \link[paws.networking:networkmanager_update_site]{update_site} \tab Updates the information for an existing site\cr
#'  \link[paws.networking:networkmanager_update_vpc_attachment]{update_vpc_attachment} \tab Updates a VPC attachment
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname networkmanager
#' @export
networkmanager <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::networkmanager(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Route 53
#'
#' @description
#' Amazon Route 53 is a highly available and scalable Domain Name System
#' (DNS) web service.
#' 
#' You can use Route 53 to:
#' 
#' -   Register domain names.
#' 
#'     For more information, see [How domain registration
#'     works](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/welcome-domain-registration.html).
#' 
#' -   Route internet traffic to the resources for your domain
#' 
#'     For more information, see [How internet traffic is routed to your
#'     website or web
#'     application](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/welcome-dns-service.html).
#' 
#' -   Check the health of your resources.
#' 
#'     For more information, see [How Route 53 checks the health of your
#'     resources](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/welcome-health-checks.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- route53(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- route53()
#' # The following example associates the VPC with ID vpc-1a2b3c4d with the
#' # hosted zone with ID Z3M3LMPEXAMPLE.
#' svc$associate_vpc_with_hosted_zone(
#'   Comment = "",
#'   HostedZoneId = "Z3M3LMPEXAMPLE",
#'   VPC = list(
#'     VPCId = "vpc-1a2b3c4d",
#'     VPCRegion = "us-east-2"
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:route53_activate_key_signing_key]{activate_key_signing_key} \tab Activates a key-signing key (KSK) so that it can be used for signing by DNSSEC\cr
#'  \link[paws.networking:route53_associate_vpc_with_hosted_zone]{associate_vpc_with_hosted_zone} \tab Associates an Amazon VPC with a private hosted zone\cr
#'  \link[paws.networking:route53_change_cidr_collection]{change_cidr_collection} \tab Creates, changes, or deletes CIDR blocks within a collection\cr
#'  \link[paws.networking:route53_change_resource_record_sets]{change_resource_record_sets} \tab Creates, changes, or deletes a resource record set, which contains authoritative DNS information for a specified domain name or subdomain name\cr
#'  \link[paws.networking:route53_change_tags_for_resource]{change_tags_for_resource} \tab Adds, edits, or deletes tags for a health check or a hosted zone\cr
#'  \link[paws.networking:route53_create_cidr_collection]{create_cidr_collection} \tab Creates a CIDR collection in the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_create_health_check]{create_health_check} \tab Creates a new health check\cr
#'  \link[paws.networking:route53_create_hosted_zone]{create_hosted_zone} \tab Creates a new public or private hosted zone\cr
#'  \link[paws.networking:route53_create_key_signing_key]{create_key_signing_key} \tab Creates a new key-signing key (KSK) associated with a hosted zone\cr
#'  \link[paws.networking:route53_create_query_logging_config]{create_query_logging_config} \tab Creates a configuration for DNS query logging\cr
#'  \link[paws.networking:route53_create_reusable_delegation_set]{create_reusable_delegation_set} \tab Creates a delegation set (a group of four name servers) that can be reused by multiple hosted zones that were created by the same Amazon Web Services account\cr
#'  \link[paws.networking:route53_create_traffic_policy]{create_traffic_policy} \tab Creates a traffic policy, which you use to create multiple DNS resource record sets for one domain name (such as example\cr
#'  \link[paws.networking:route53_create_traffic_policy_instance]{create_traffic_policy_instance} \tab Creates resource record sets in a specified hosted zone based on the settings in a specified traffic policy version\cr
#'  \link[paws.networking:route53_create_traffic_policy_version]{create_traffic_policy_version} \tab Creates a new version of an existing traffic policy\cr
#'  \link[paws.networking:route53_create_vpc_association_authorization]{create_vpc_association_authorization} \tab Authorizes the Amazon Web Services account that created a specified VPC to submit an AssociateVPCWithHostedZone request to associate the VPC with a specified hosted zone that was created by a different account\cr
#'  \link[paws.networking:route53_deactivate_key_signing_key]{deactivate_key_signing_key} \tab Deactivates a key-signing key (KSK) so that it will not be used for signing by DNSSEC\cr
#'  \link[paws.networking:route53_delete_cidr_collection]{delete_cidr_collection} \tab Deletes a CIDR collection in the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_delete_health_check]{delete_health_check} \tab Deletes a health check\cr
#'  \link[paws.networking:route53_delete_hosted_zone]{delete_hosted_zone} \tab Deletes a hosted zone\cr
#'  \link[paws.networking:route53_delete_key_signing_key]{delete_key_signing_key} \tab Deletes a key-signing key (KSK)\cr
#'  \link[paws.networking:route53_delete_query_logging_config]{delete_query_logging_config} \tab Deletes a configuration for DNS query logging\cr
#'  \link[paws.networking:route53_delete_reusable_delegation_set]{delete_reusable_delegation_set} \tab Deletes a reusable delegation set\cr
#'  \link[paws.networking:route53_delete_traffic_policy]{delete_traffic_policy} \tab Deletes a traffic policy\cr
#'  \link[paws.networking:route53_delete_traffic_policy_instance]{delete_traffic_policy_instance} \tab Deletes a traffic policy instance and all of the resource record sets that Amazon Route 53 created when you created the instance\cr
#'  \link[paws.networking:route53_delete_vpc_association_authorization]{delete_vpc_association_authorization} \tab Removes authorization to submit an AssociateVPCWithHostedZone request to associate a specified VPC with a hosted zone that was created by a different account\cr
#'  \link[paws.networking:route53_disable_hosted_zone_dnssec]{disable_hosted_zone_dnssec} \tab Disables DNSSEC signing in a specific hosted zone\cr
#'  \link[paws.networking:route53_disassociate_vpc_from_hosted_zone]{disassociate_vpc_from_hosted_zone} \tab Disassociates an Amazon Virtual Private Cloud (Amazon VPC) from an Amazon Route 53 private hosted zone\cr
#'  \link[paws.networking:route53_enable_hosted_zone_dnssec]{enable_hosted_zone_dnssec} \tab Enables DNSSEC signing in a specific hosted zone\cr
#'  \link[paws.networking:route53_get_account_limit]{get_account_limit} \tab Gets the specified limit for the current account, for example, the maximum number of health checks that you can create using the account\cr
#'  \link[paws.networking:route53_get_change]{get_change} \tab Returns the current status of a change batch request\cr
#'  \link[paws.networking:route53_get_checker_ip_ranges]{get_checker_ip_ranges} \tab Route 53 does not perform authorization for this API because it retrieves information that is already available to the public\cr
#'  \link[paws.networking:route53_get_dnssec]{get_dnssec} \tab Returns information about DNSSEC for a specific hosted zone, including the key-signing keys (KSKs) in the hosted zone\cr
#'  \link[paws.networking:route53_get_geo_location]{get_geo_location} \tab Gets information about whether a specified geographic location is supported for Amazon Route 53 geolocation resource record sets\cr
#'  \link[paws.networking:route53_get_health_check]{get_health_check} \tab Gets information about a specified health check\cr
#'  \link[paws.networking:route53_get_health_check_count]{get_health_check_count} \tab Retrieves the number of health checks that are associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_get_health_check_last_failure_reason]{get_health_check_last_failure_reason} \tab Gets the reason that a specified health check failed most recently\cr
#'  \link[paws.networking:route53_get_health_check_status]{get_health_check_status} \tab Gets status of a specified health check\cr
#'  \link[paws.networking:route53_get_hosted_zone]{get_hosted_zone} \tab Gets information about a specified hosted zone including the four name servers assigned to the hosted zone\cr
#'  \link[paws.networking:route53_get_hosted_zone_count]{get_hosted_zone_count} \tab Retrieves the number of hosted zones that are associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_get_hosted_zone_limit]{get_hosted_zone_limit} \tab Gets the specified limit for a specified hosted zone, for example, the maximum number of records that you can create in the hosted zone\cr
#'  \link[paws.networking:route53_get_query_logging_config]{get_query_logging_config} \tab Gets information about a specified configuration for DNS query logging\cr
#'  \link[paws.networking:route53_get_reusable_delegation_set]{get_reusable_delegation_set} \tab Retrieves information about a specified reusable delegation set, including the four name servers that are assigned to the delegation set\cr
#'  \link[paws.networking:route53_get_reusable_delegation_set_limit]{get_reusable_delegation_set_limit} \tab Gets the maximum number of hosted zones that you can associate with the specified reusable delegation set\cr
#'  \link[paws.networking:route53_get_traffic_policy]{get_traffic_policy} \tab Gets information about a specific traffic policy version\cr
#'  \link[paws.networking:route53_get_traffic_policy_instance]{get_traffic_policy_instance} \tab Gets information about a specified traffic policy instance\cr
#'  \link[paws.networking:route53_get_traffic_policy_instance_count]{get_traffic_policy_instance_count} \tab Gets the number of traffic policy instances that are associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_list_cidr_blocks]{list_cidr_blocks} \tab Returns a paginated list of location objects and their CIDR blocks\cr
#'  \link[paws.networking:route53_list_cidr_collections]{list_cidr_collections} \tab Returns a paginated list of CIDR collections in the Amazon Web Services account (metadata only)\cr
#'  \link[paws.networking:route53_list_cidr_locations]{list_cidr_locations} \tab Returns a paginated list of CIDR locations for the given collection (metadata only, does not include CIDR blocks)\cr
#'  \link[paws.networking:route53_list_geo_locations]{list_geo_locations} \tab Retrieves a list of supported geographic locations\cr
#'  \link[paws.networking:route53_list_health_checks]{list_health_checks} \tab Retrieve a list of the health checks that are associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_list_hosted_zones]{list_hosted_zones} \tab Retrieves a list of the public and private hosted zones that are associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_list_hosted_zones_by_name]{list_hosted_zones_by_name} \tab Retrieves a list of your hosted zones in lexicographic order\cr
#'  \link[paws.networking:route53_list_hosted_zones_by_vpc]{list_hosted_zones_by_vpc} \tab Lists all the private hosted zones that a specified VPC is associated with, regardless of which Amazon Web Services account or Amazon Web Services service owns the hosted zones\cr
#'  \link[paws.networking:route53_list_query_logging_configs]{list_query_logging_configs} \tab Lists the configurations for DNS query logging that are associated with the current Amazon Web Services account or the configuration that is associated with a specified hosted zone\cr
#'  \link[paws.networking:route53_list_resource_record_sets]{list_resource_record_sets} \tab Lists the resource record sets in a specified hosted zone\cr
#'  \link[paws.networking:route53_list_reusable_delegation_sets]{list_reusable_delegation_sets} \tab Retrieves a list of the reusable delegation sets that are associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags for one health check or hosted zone\cr
#'  \link[paws.networking:route53_list_tags_for_resources]{list_tags_for_resources} \tab Lists tags for up to 10 health checks or hosted zones\cr
#'  \link[paws.networking:route53_list_traffic_policies]{list_traffic_policies} \tab Gets information about the latest version for every traffic policy that is associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_list_traffic_policy_instances]{list_traffic_policy_instances} \tab Gets information about the traffic policy instances that you created by using the current Amazon Web Services account\cr
#'  \link[paws.networking:route53_list_traffic_policy_instances_by_hosted_zone]{list_traffic_policy_instances_by_hosted_zone} \tab Gets information about the traffic policy instances that you created in a specified hosted zone\cr
#'  \link[paws.networking:route53_list_traffic_policy_instances_by_policy]{list_traffic_policy_instances_by_policy} \tab Gets information about the traffic policy instances that you created by using a specify traffic policy version\cr
#'  \link[paws.networking:route53_list_traffic_policy_versions]{list_traffic_policy_versions} \tab Gets information about all of the versions for a specified traffic policy\cr
#'  \link[paws.networking:route53_list_vpc_association_authorizations]{list_vpc_association_authorizations} \tab Gets a list of the VPCs that were created by other accounts and that can be associated with a specified hosted zone because you've submitted one or more CreateVPCAssociationAuthorization requests\cr
#'  \link[paws.networking:route53_test_dns_answer]{test_dns_answer} \tab Gets the value that Amazon Route 53 returns in response to a DNS request for a specified record name and type\cr
#'  \link[paws.networking:route53_update_health_check]{update_health_check} \tab Updates an existing health check\cr
#'  \link[paws.networking:route53_update_hosted_zone_comment]{update_hosted_zone_comment} \tab Updates the comment for a specified hosted zone\cr
#'  \link[paws.networking:route53_update_traffic_policy_comment]{update_traffic_policy_comment} \tab Updates the comment for a specified traffic policy version\cr
#'  \link[paws.networking:route53_update_traffic_policy_instance]{update_traffic_policy_instance} \tab After you submit a UpdateTrafficPolicyInstance request, there's a brief delay while Route 53 creates the resource record sets that are specified in the traffic policy definition
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname route53
#' @export
route53 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::route53(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Route 53 Domains
#'
#' @description
#' Amazon Route 53 API actions let you register domain names and perform
#' related operations.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- route53domains(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- route53domains()
#' svc$accept_domain_transfer_from_another_aws_account(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:route53domains_accept_domain_transfer_from_another_aws_account]{accept_domain_transfer_from_another_aws_account} \tab Accepts the transfer of a domain from another Amazon Web Services account to the currentAmazon Web Services account\cr
#'  \link[paws.networking:route53domains_associate_delegation_signer_to_domain]{associate_delegation_signer_to_domain} \tab Creates a delegation signer (DS) record in the registry zone for this domain name\cr
#'  \link[paws.networking:route53domains_cancel_domain_transfer_to_another_aws_account]{cancel_domain_transfer_to_another_aws_account} \tab Cancels the transfer of a domain from the current Amazon Web Services account to another Amazon Web Services account\cr
#'  \link[paws.networking:route53domains_check_domain_availability]{check_domain_availability} \tab This operation checks the availability of one domain name\cr
#'  \link[paws.networking:route53domains_check_domain_transferability]{check_domain_transferability} \tab Checks whether a domain name can be transferred to Amazon Route 53\cr
#'  \link[paws.networking:route53domains_delete_domain]{delete_domain} \tab This operation deletes the specified domain\cr
#'  \link[paws.networking:route53domains_delete_tags_for_domain]{delete_tags_for_domain} \tab This operation deletes the specified tags for a domain\cr
#'  \link[paws.networking:route53domains_disable_domain_auto_renew]{disable_domain_auto_renew} \tab This operation disables automatic renewal of domain registration for the specified domain\cr
#'  \link[paws.networking:route53domains_disable_domain_transfer_lock]{disable_domain_transfer_lock} \tab This operation removes the transfer lock on the domain (specifically the clientTransferProhibited status) to allow domain transfers\cr
#'  \link[paws.networking:route53domains_disassociate_delegation_signer_from_domain]{disassociate_delegation_signer_from_domain} \tab Deletes a delegation signer (DS) record in the registry zone for this domain name\cr
#'  \link[paws.networking:route53domains_enable_domain_auto_renew]{enable_domain_auto_renew} \tab This operation configures Amazon Route 53 to automatically renew the specified domain before the domain registration expires\cr
#'  \link[paws.networking:route53domains_enable_domain_transfer_lock]{enable_domain_transfer_lock} \tab This operation sets the transfer lock on the domain (specifically the clientTransferProhibited status) to prevent domain transfers\cr
#'  \link[paws.networking:route53domains_get_contact_reachability_status]{get_contact_reachability_status} \tab For operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain, this operation returns information about whether the registrant contact has responded\cr
#'  \link[paws.networking:route53domains_get_domain_detail]{get_domain_detail} \tab This operation returns detailed information about a specified domain that is associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53domains_get_domain_suggestions]{get_domain_suggestions} \tab The GetDomainSuggestions operation returns a list of suggested domain names\cr
#'  \link[paws.networking:route53domains_get_operation_detail]{get_operation_detail} \tab This operation returns the current status of an operation that is not completed\cr
#'  \link[paws.networking:route53domains_list_domains]{list_domains} \tab This operation returns all the domain names registered with Amazon Route 53 for the current Amazon Web Services account if no filtering conditions are used\cr
#'  \link[paws.networking:route53domains_list_operations]{list_operations} \tab Returns information about all of the operations that return an operation ID and that have ever been performed on domains that were registered by the current account\cr
#'  \link[paws.networking:route53domains_list_prices]{list_prices} \tab Lists the following prices for either all the TLDs supported by Route 53, or the specified TLD:\cr
#'  \link[paws.networking:route53domains_list_tags_for_domain]{list_tags_for_domain} \tab This operation returns all of the tags that are associated with the specified domain\cr
#'  \link[paws.networking:route53domains_push_domain]{push_domain} \tab Moves a domain from Amazon Web Services to another registrar\cr
#'  \link[paws.networking:route53domains_register_domain]{register_domain} \tab This operation registers a domain\cr
#'  \link[paws.networking:route53domains_reject_domain_transfer_from_another_aws_account]{reject_domain_transfer_from_another_aws_account} \tab Rejects the transfer of a domain from another Amazon Web Services account to the current Amazon Web Services account\cr
#'  \link[paws.networking:route53domains_renew_domain]{renew_domain} \tab This operation renews a domain for the specified number of years\cr
#'  \link[paws.networking:route53domains_resend_contact_reachability_email]{resend_contact_reachability_email} \tab For operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain, this operation resends the confirmation email to the current email address for the registrant contact\cr
#'  \link[paws.networking:route53domains_resend_operation_authorization]{resend_operation_authorization} \tab Resend the form of authorization email for this operation\cr
#'  \link[paws.networking:route53domains_retrieve_domain_auth_code]{retrieve_domain_auth_code} \tab This operation returns the authorization code for the domain\cr
#'  \link[paws.networking:route53domains_transfer_domain]{transfer_domain} \tab Transfers a domain from another registrar to Amazon Route 53\cr
#'  \link[paws.networking:route53domains_transfer_domain_to_another_aws_account]{transfer_domain_to_another_aws_account} \tab Transfers a domain from the current Amazon Web Services account to another Amazon Web Services account\cr
#'  \link[paws.networking:route53domains_update_domain_contact]{update_domain_contact} \tab This operation updates the contact information for a particular domain\cr
#'  \link[paws.networking:route53domains_update_domain_contact_privacy]{update_domain_contact_privacy} \tab This operation updates the specified domain contact's privacy setting\cr
#'  \link[paws.networking:route53domains_update_domain_nameservers]{update_domain_nameservers} \tab This operation replaces the current set of name servers for the domain with the specified set of name servers\cr
#'  \link[paws.networking:route53domains_update_tags_for_domain]{update_tags_for_domain} \tab This operation adds or updates tags for a specified domain\cr
#'  \link[paws.networking:route53domains_view_billing]{view_billing} \tab Returns all the domain-related billing records for the current Amazon Web Services account for a specified period
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname route53domains
#' @export
route53domains <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::route53domains(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Route 53 Profiles
#'
#' @description
#' With Amazon Route 53 Profiles you can share Route 53 configurations with
#' VPCs and AWS accounts
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- route53profiles(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- route53profiles()
#' svc$associate_profile(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:route53profiles_associate_profile]{associate_profile} \tab Associates a Route 53 Profiles profile with a VPC\cr
#'  \link[paws.networking:route53profiles_associate_resource_to_profile]{associate_resource_to_profile} \tab Associates a DNS reource configuration to a Route 53 Profile\cr
#'  \link[paws.networking:route53profiles_create_profile]{create_profile} \tab Creates an empty Route 53 Profile\cr
#'  \link[paws.networking:route53profiles_delete_profile]{delete_profile} \tab Deletes the specified Route 53 Profile\cr
#'  \link[paws.networking:route53profiles_disassociate_profile]{disassociate_profile} \tab Dissociates a specified Route 53 Profile from the specified VPC\cr
#'  \link[paws.networking:route53profiles_disassociate_resource_from_profile]{disassociate_resource_from_profile} \tab Dissoaciated a specified resource, from the Route 53 Profile\cr
#'  \link[paws.networking:route53profiles_get_profile]{get_profile} \tab Returns information about a specified Route 53 Profile, such as whether whether the Profile is shared, and the current status of the Profile\cr
#'  \link[paws.networking:route53profiles_get_profile_association]{get_profile_association} \tab Retrieves a Route 53 Profile association for a VPC\cr
#'  \link[paws.networking:route53profiles_get_profile_resource_association]{get_profile_resource_association} \tab Returns information about a specified Route 53 Profile resource association\cr
#'  \link[paws.networking:route53profiles_list_profile_associations]{list_profile_associations} \tab Lists all the VPCs that the specified Route 53 Profile is associated with\cr
#'  \link[paws.networking:route53profiles_list_profile_resource_associations]{list_profile_resource_associations} \tab Lists all the resource associations for the specified Route 53 Profile\cr
#'  \link[paws.networking:route53profiles_list_profiles]{list_profiles} \tab Lists all the Route 53 Profiles associated with your Amazon Web Services account\cr
#'  \link[paws.networking:route53profiles_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that you associated with the specified resource\cr
#'  \link[paws.networking:route53profiles_tag_resource]{tag_resource} \tab Adds one or more tags to a specified resource\cr
#'  \link[paws.networking:route53profiles_untag_resource]{untag_resource} \tab Removes one or more tags from a specified resource\cr
#'  \link[paws.networking:route53profiles_update_profile_resource_association]{update_profile_resource_association} \tab Updates the specified Route 53 Profile resourse association
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname route53profiles
#' @export
route53profiles <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::route53profiles(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Route53 Recovery Cluster
#'
#' @description
#' Welcome to the Routing Control (Recovery Cluster) API Reference Guide
#' for Amazon Route 53 Application Recovery Controller.
#' 
#' With Route 53 ARC, you can use routing control with extreme reliability
#' to recover applications by rerouting traffic across Availability Zones
#' or Amazon Web Services Regions. Routing controls are simple on/off
#' switches hosted on a highly available cluster in Route 53 ARC. A cluster
#' provides a set of five redundant Regional endpoints against which you
#' can run API calls to get or update the state of routing controls. To
#' implement failover, you set one routing control to ON and another one to
#' OFF, to reroute traffic from one Availability Zone or Amazon Web
#' Services Region to another.
#' 
#' *Be aware that you must specify a Regional endpoint for a cluster when
#' you work with API cluster operations to get or update routing control
#' states in Route 53 ARC.* In addition, you must specify the US West
#' (Oregon) Region for Route 53 ARC API calls. For example, use the
#' parameter `--region us-west-2` with AWS CLI commands. For more
#' information, see [Get and update routing control states using the
#' API](https://docs.aws.amazon.com/r53recovery/latest/dg/routing-control.update.api.html)
#' in the Amazon Route 53 Application Recovery Controller Developer Guide.
#' 
#' This API guide includes information about the API operations for how to
#' get and update routing control states in Route 53 ARC. To work with
#' routing control in Route 53 ARC, you must first create the required
#' components (clusters, control panels, and routing controls) using the
#' recovery cluster configuration API.
#' 
#' For more information about working with routing control in Route 53 ARC,
#' see the following:
#' 
#' -   Create clusters, control panels, and routing controls by using API
#'     operations. For more information, see the [Recovery Control
#'     Configuration API Reference Guide for Amazon Route 53 Application
#'     Recovery
#'     Controller](https://docs.aws.amazon.com/recovery-cluster/latest/api/).
#' 
#' -   Learn about the components in recovery control, including clusters,
#'     routing controls, and control panels, and how to work with Route 53
#'     ARC in the Amazon Web Services console. For more information, see
#'     [Recovery control
#'     components](https://docs.aws.amazon.com/r53recovery/latest/dg/introduction-components-zonal.html#introduction-components-routing)
#'     in the Amazon Route 53 Application Recovery Controller Developer
#'     Guide.
#' 
#' -   Route 53 ARC also provides readiness checks that continually audit
#'     resources to help make sure that your applications are scaled and
#'     ready to handle failover traffic. For more information about the
#'     related API operations, see the [Recovery Readiness API Reference
#'     Guide for Amazon Route 53 Application Recovery
#'     Controller](https://docs.aws.amazon.com/recovery-readiness/latest/api/).
#' 
#' -   For more information about creating resilient applications and
#'     preparing for recovery readiness with Route 53 ARC, see the [Amazon
#'     Route 53 Application Recovery Controller Developer
#'     Guide](https://docs.aws.amazon.com/r53recovery/latest/dg/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- route53recoverycluster(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- route53recoverycluster()
#' svc$get_routing_control_state(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:route53recoverycluster_get_routing_control_state]{get_routing_control_state} \tab Get the state for a routing control\cr
#'  \link[paws.networking:route53recoverycluster_list_routing_controls]{list_routing_controls} \tab List routing control names and Amazon Resource Names (ARNs), as well as the routing control state for each routing control, along with the control panel name and control panel ARN for the routing controls\cr
#'  \link[paws.networking:route53recoverycluster_update_routing_control_state]{update_routing_control_state} \tab Set the state of the routing control to reroute traffic\cr
#'  \link[paws.networking:route53recoverycluster_update_routing_control_states]{update_routing_control_states} \tab Set multiple routing control states
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname route53recoverycluster
#' @export
route53recoverycluster <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::route53recoverycluster(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Route53 Recovery Control Config
#'
#' @description
#' Recovery Control Configuration API Reference for Amazon Route 53
#' Application Recovery Controller
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- route53recoverycontrolconfig(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- route53recoverycontrolconfig()
#' svc$create_cluster(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:route53recoverycontrolconfig_create_cluster]{create_cluster} \tab Create a new cluster\cr
#'  \link[paws.networking:route53recoverycontrolconfig_create_control_panel]{create_control_panel} \tab Creates a new control panel\cr
#'  \link[paws.networking:route53recoverycontrolconfig_create_routing_control]{create_routing_control} \tab Creates a new routing control\cr
#'  \link[paws.networking:route53recoverycontrolconfig_create_safety_rule]{create_safety_rule} \tab Creates a safety rule in a control panel\cr
#'  \link[paws.networking:route53recoverycontrolconfig_delete_cluster]{delete_cluster} \tab Delete a cluster\cr
#'  \link[paws.networking:route53recoverycontrolconfig_delete_control_panel]{delete_control_panel} \tab Deletes a control panel\cr
#'  \link[paws.networking:route53recoverycontrolconfig_delete_routing_control]{delete_routing_control} \tab Deletes a routing control\cr
#'  \link[paws.networking:route53recoverycontrolconfig_delete_safety_rule]{delete_safety_rule} \tab Deletes a safety rule\cr
#'  \link[paws.networking:route53recoverycontrolconfig_describe_cluster]{describe_cluster} \tab Display the details about a cluster\cr
#'  \link[paws.networking:route53recoverycontrolconfig_describe_control_panel]{describe_control_panel} \tab Displays details about a control panel\cr
#'  \link[paws.networking:route53recoverycontrolconfig_describe_routing_control]{describe_routing_control} \tab Displays details about a routing control\cr
#'  \link[paws.networking:route53recoverycontrolconfig_describe_safety_rule]{describe_safety_rule} \tab Returns information about a safety rule\cr
#'  \link[paws.networking:route53recoverycontrolconfig_get_resource_policy]{get_resource_policy} \tab Get information about the resource policy for a cluster\cr
#'  \link[paws.networking:route53recoverycontrolconfig_list_associated_route_53_health_checks]{list_associated_route_53_health_checks} \tab Returns an array of all Amazon Route 53 health checks associated with a specific routing control\cr
#'  \link[paws.networking:route53recoverycontrolconfig_list_clusters]{list_clusters} \tab Returns an array of all the clusters in an account\cr
#'  \link[paws.networking:route53recoverycontrolconfig_list_control_panels]{list_control_panels} \tab Returns an array of control panels in an account or in a cluster\cr
#'  \link[paws.networking:route53recoverycontrolconfig_list_routing_controls]{list_routing_controls} \tab Returns an array of routing controls for a control panel\cr
#'  \link[paws.networking:route53recoverycontrolconfig_list_safety_rules]{list_safety_rules} \tab List the safety rules (the assertion rules and gating rules) that you've defined for the routing controls in a control panel\cr
#'  \link[paws.networking:route53recoverycontrolconfig_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for a resource\cr
#'  \link[paws.networking:route53recoverycontrolconfig_tag_resource]{tag_resource} \tab Adds a tag to a resource\cr
#'  \link[paws.networking:route53recoverycontrolconfig_untag_resource]{untag_resource} \tab Removes a tag from a resource\cr
#'  \link[paws.networking:route53recoverycontrolconfig_update_control_panel]{update_control_panel} \tab Updates a control panel\cr
#'  \link[paws.networking:route53recoverycontrolconfig_update_routing_control]{update_routing_control} \tab Updates a routing control\cr
#'  \link[paws.networking:route53recoverycontrolconfig_update_safety_rule]{update_safety_rule} \tab Update a safety rule (an assertion rule or gating rule)
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname route53recoverycontrolconfig
#' @export
route53recoverycontrolconfig <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::route53recoverycontrolconfig(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Route53 Recovery Readiness
#'
#' @description
#' Recovery readiness
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- route53recoveryreadiness(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- route53recoveryreadiness()
#' svc$create_cell(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:route53recoveryreadiness_create_cell]{create_cell} \tab Creates a cell in an account\cr
#'  \link[paws.networking:route53recoveryreadiness_create_cross_account_authorization]{create_cross_account_authorization} \tab Creates a cross-account readiness authorization\cr
#'  \link[paws.networking:route53recoveryreadiness_create_readiness_check]{create_readiness_check} \tab Creates a readiness check in an account\cr
#'  \link[paws.networking:route53recoveryreadiness_create_recovery_group]{create_recovery_group} \tab Creates a recovery group in an account\cr
#'  \link[paws.networking:route53recoveryreadiness_create_resource_set]{create_resource_set} \tab Creates a resource set\cr
#'  \link[paws.networking:route53recoveryreadiness_delete_cell]{delete_cell} \tab Delete a cell\cr
#'  \link[paws.networking:route53recoveryreadiness_delete_cross_account_authorization]{delete_cross_account_authorization} \tab Deletes cross account readiness authorization\cr
#'  \link[paws.networking:route53recoveryreadiness_delete_readiness_check]{delete_readiness_check} \tab Deletes a readiness check\cr
#'  \link[paws.networking:route53recoveryreadiness_delete_recovery_group]{delete_recovery_group} \tab Deletes a recovery group\cr
#'  \link[paws.networking:route53recoveryreadiness_delete_resource_set]{delete_resource_set} \tab Deletes a resource set\cr
#'  \link[paws.networking:route53recoveryreadiness_get_architecture_recommendations]{get_architecture_recommendations} \tab Gets recommendations about architecture designs for improving resiliency for an application, based on a recovery group\cr
#'  \link[paws.networking:route53recoveryreadiness_get_cell]{get_cell} \tab Gets information about a cell including cell name, cell Amazon Resource Name (ARN), ARNs of nested cells for this cell, and a list of those cell ARNs with their associated recovery group ARNs\cr
#'  \link[paws.networking:route53recoveryreadiness_get_cell_readiness_summary]{get_cell_readiness_summary} \tab Gets readiness for a cell\cr
#'  \link[paws.networking:route53recoveryreadiness_get_readiness_check]{get_readiness_check} \tab Gets details about a readiness check\cr
#'  \link[paws.networking:route53recoveryreadiness_get_readiness_check_resource_status]{get_readiness_check_resource_status} \tab Gets individual readiness status for a readiness check\cr
#'  \link[paws.networking:route53recoveryreadiness_get_readiness_check_status]{get_readiness_check_status} \tab Gets the readiness status for an individual readiness check\cr
#'  \link[paws.networking:route53recoveryreadiness_get_recovery_group]{get_recovery_group} \tab Gets details about a recovery group, including a list of the cells that are included in it\cr
#'  \link[paws.networking:route53recoveryreadiness_get_recovery_group_readiness_summary]{get_recovery_group_readiness_summary} \tab Displays a summary of information about a recovery group's readiness status\cr
#'  \link[paws.networking:route53recoveryreadiness_get_resource_set]{get_resource_set} \tab Displays the details about a resource set, including a list of the resources in the set\cr
#'  \link[paws.networking:route53recoveryreadiness_list_cells]{list_cells} \tab Lists the cells for an account\cr
#'  \link[paws.networking:route53recoveryreadiness_list_cross_account_authorizations]{list_cross_account_authorizations} \tab Lists the cross-account readiness authorizations that are in place for an account\cr
#'  \link[paws.networking:route53recoveryreadiness_list_readiness_checks]{list_readiness_checks} \tab Lists the readiness checks for an account\cr
#'  \link[paws.networking:route53recoveryreadiness_list_recovery_groups]{list_recovery_groups} \tab Lists the recovery groups in an account\cr
#'  \link[paws.networking:route53recoveryreadiness_list_resource_sets]{list_resource_sets} \tab Lists the resource sets in an account\cr
#'  \link[paws.networking:route53recoveryreadiness_list_rules]{list_rules} \tab Lists all readiness rules, or lists the readiness rules for a specific resource type\cr
#'  \link[paws.networking:route53recoveryreadiness_list_tags_for_resources]{list_tags_for_resources} \tab Lists the tags for a resource\cr
#'  \link[paws.networking:route53recoveryreadiness_tag_resource]{tag_resource} \tab Adds a tag to a resource\cr
#'  \link[paws.networking:route53recoveryreadiness_untag_resource]{untag_resource} \tab Removes a tag from a resource\cr
#'  \link[paws.networking:route53recoveryreadiness_update_cell]{update_cell} \tab Updates a cell to replace the list of nested cells with a new list of nested cells\cr
#'  \link[paws.networking:route53recoveryreadiness_update_readiness_check]{update_readiness_check} \tab Updates a readiness check\cr
#'  \link[paws.networking:route53recoveryreadiness_update_recovery_group]{update_recovery_group} \tab Updates a recovery group\cr
#'  \link[paws.networking:route53recoveryreadiness_update_resource_set]{update_resource_set} \tab Updates a resource set
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname route53recoveryreadiness
#' @export
route53recoveryreadiness <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::route53recoveryreadiness(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Route 53 Resolver
#'
#' @description
#' When you create a VPC using Amazon VPC, you automatically get DNS
#' resolution within the VPC from Route 53 Resolver. By default, Resolver
#' answers DNS queries for VPC domain names such as domain names for EC2
#' instances or Elastic Load Balancing load balancers. Resolver performs
#' recursive lookups against public name servers for all other domain
#' names.
#' 
#' You can also configure DNS resolution between your VPC and your network
#' over a Direct Connect or VPN connection:
#' 
#' **Forward DNS queries from resolvers on your network to Route 53
#' Resolver**
#' 
#' DNS resolvers on your network can forward DNS queries to Resolver in a
#' specified VPC. This allows your DNS resolvers to easily resolve domain
#' names for Amazon Web Services resources such as EC2 instances or records
#' in a Route 53 private hosted zone. For more information, see [How DNS
#' Resolvers on Your Network Forward DNS Queries to Route 53
#' Resolver](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/resolver.html#resolver-overview-forward-network-to-vpc)
#' in the *Amazon Route 53 Developer Guide*.
#' 
#' **Conditionally forward queries from a VPC to resolvers on your
#' network**
#' 
#' You can configure Resolver to forward queries that it receives from EC2
#' instances in your VPCs to DNS resolvers on your network. To forward
#' selected queries, you create Resolver rules that specify the domain
#' names for the DNS queries that you want to forward (such as
#' example.com), and the IP addresses of the DNS resolvers on your network
#' that you want to forward the queries to. If a query matches multiple
#' rules (example.com, acme.example.com), Resolver chooses the rule with
#' the most specific match (acme.example.com) and forwards the query to the
#' IP addresses that you specified in that rule. For more information, see
#' [How Route 53 Resolver Forwards DNS Queries from Your VPCs to Your
#' Network](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/resolver.html#resolver-overview-forward-vpc-to-network)
#' in the *Amazon Route 53 Developer Guide*.
#' 
#' Like Amazon VPC, Resolver is Regional. In each Region where you have
#' VPCs, you can choose whether to forward queries from your VPCs to your
#' network (outbound queries), from your network to your VPCs (inbound
#' queries), or both.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- route53resolver(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- route53resolver()
#' svc$associate_firewall_rule_group(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:route53resolver_associate_firewall_rule_group]{associate_firewall_rule_group} \tab Associates a FirewallRuleGroup with a VPC, to provide DNS filtering for the VPC\cr
#'  \link[paws.networking:route53resolver_associate_resolver_endpoint_ip_address]{associate_resolver_endpoint_ip_address} \tab Adds IP addresses to an inbound or an outbound Resolver endpoint\cr
#'  \link[paws.networking:route53resolver_associate_resolver_query_log_config]{associate_resolver_query_log_config} \tab Associates an Amazon VPC with a specified query logging configuration\cr
#'  \link[paws.networking:route53resolver_associate_resolver_rule]{associate_resolver_rule} \tab Associates a Resolver rule with a VPC\cr
#'  \link[paws.networking:route53resolver_create_firewall_domain_list]{create_firewall_domain_list} \tab Creates an empty firewall domain list for use in DNS Firewall rules\cr
#'  \link[paws.networking:route53resolver_create_firewall_rule]{create_firewall_rule} \tab Creates a single DNS Firewall rule in the specified rule group, using the specified domain list\cr
#'  \link[paws.networking:route53resolver_create_firewall_rule_group]{create_firewall_rule_group} \tab Creates an empty DNS Firewall rule group for filtering DNS network traffic in a VPC\cr
#'  \link[paws.networking:route53resolver_create_outpost_resolver]{create_outpost_resolver} \tab Creates a Route 53 Resolver on an Outpost\cr
#'  \link[paws.networking:route53resolver_create_resolver_endpoint]{create_resolver_endpoint} \tab Creates a Resolver endpoint\cr
#'  \link[paws.networking:route53resolver_create_resolver_query_log_config]{create_resolver_query_log_config} \tab Creates a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs\cr
#'  \link[paws.networking:route53resolver_create_resolver_rule]{create_resolver_rule} \tab For DNS queries that originate in your VPCs, specifies which Resolver endpoint the queries pass through, one domain name that you want to forward to your network, and the IP addresses of the DNS resolvers in your network\cr
#'  \link[paws.networking:route53resolver_delete_firewall_domain_list]{delete_firewall_domain_list} \tab Deletes the specified domain list\cr
#'  \link[paws.networking:route53resolver_delete_firewall_rule]{delete_firewall_rule} \tab Deletes the specified firewall rule\cr
#'  \link[paws.networking:route53resolver_delete_firewall_rule_group]{delete_firewall_rule_group} \tab Deletes the specified firewall rule group\cr
#'  \link[paws.networking:route53resolver_delete_outpost_resolver]{delete_outpost_resolver} \tab Deletes a Resolver on the Outpost\cr
#'  \link[paws.networking:route53resolver_delete_resolver_endpoint]{delete_resolver_endpoint} \tab Deletes a Resolver endpoint\cr
#'  \link[paws.networking:route53resolver_delete_resolver_query_log_config]{delete_resolver_query_log_config} \tab Deletes a query logging configuration\cr
#'  \link[paws.networking:route53resolver_delete_resolver_rule]{delete_resolver_rule} \tab Deletes a Resolver rule\cr
#'  \link[paws.networking:route53resolver_disassociate_firewall_rule_group]{disassociate_firewall_rule_group} \tab Disassociates a FirewallRuleGroup from a VPC, to remove DNS filtering from the VPC\cr
#'  \link[paws.networking:route53resolver_disassociate_resolver_endpoint_ip_address]{disassociate_resolver_endpoint_ip_address} \tab Removes IP addresses from an inbound or an outbound Resolver endpoint\cr
#'  \link[paws.networking:route53resolver_disassociate_resolver_query_log_config]{disassociate_resolver_query_log_config} \tab Disassociates a VPC from a query logging configuration\cr
#'  \link[paws.networking:route53resolver_disassociate_resolver_rule]{disassociate_resolver_rule} \tab Removes the association between a specified Resolver rule and a specified VPC\cr
#'  \link[paws.networking:route53resolver_get_firewall_config]{get_firewall_config} \tab Retrieves the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC)\cr
#'  \link[paws.networking:route53resolver_get_firewall_domain_list]{get_firewall_domain_list} \tab Retrieves the specified firewall domain list\cr
#'  \link[paws.networking:route53resolver_get_firewall_rule_group]{get_firewall_rule_group} \tab Retrieves the specified firewall rule group\cr
#'  \link[paws.networking:route53resolver_get_firewall_rule_group_association]{get_firewall_rule_group_association} \tab Retrieves a firewall rule group association, which enables DNS filtering for a VPC with one rule group\cr
#'  \link[paws.networking:route53resolver_get_firewall_rule_group_policy]{get_firewall_rule_group_policy} \tab Returns the Identity and Access Management (Amazon Web Services IAM) policy for sharing the specified rule group\cr
#'  \link[paws.networking:route53resolver_get_outpost_resolver]{get_outpost_resolver} \tab Gets information about a specified Resolver on the Outpost, such as its instance count and type, name, and the current status of the Resolver\cr
#'  \link[paws.networking:route53resolver_get_resolver_config]{get_resolver_config} \tab Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud\cr
#'  \link[paws.networking:route53resolver_get_resolver_dnssec_config]{get_resolver_dnssec_config} \tab Gets DNSSEC validation information for a specified resource\cr
#'  \link[paws.networking:route53resolver_get_resolver_endpoint]{get_resolver_endpoint} \tab Gets information about a specified Resolver endpoint, such as whether it's an inbound or an outbound Resolver endpoint, and the current status of the endpoint\cr
#'  \link[paws.networking:route53resolver_get_resolver_query_log_config]{get_resolver_query_log_config} \tab Gets information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to\cr
#'  \link[paws.networking:route53resolver_get_resolver_query_log_config_association]{get_resolver_query_log_config_association} \tab Gets information about a specified association between a Resolver query logging configuration and an Amazon VPC\cr
#'  \link[paws.networking:route53resolver_get_resolver_query_log_config_policy]{get_resolver_query_log_config_policy} \tab Gets information about a query logging policy\cr
#'  \link[paws.networking:route53resolver_get_resolver_rule]{get_resolver_rule} \tab Gets information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the ID of the outbound Resolver endpoint that the rule is associated with\cr
#'  \link[paws.networking:route53resolver_get_resolver_rule_association]{get_resolver_rule_association} \tab Gets information about an association between a specified Resolver rule and a VPC\cr
#'  \link[paws.networking:route53resolver_get_resolver_rule_policy]{get_resolver_rule_policy} \tab Gets information about the Resolver rule policy for a specified rule\cr
#'  \link[paws.networking:route53resolver_import_firewall_domains]{import_firewall_domains} \tab Imports domain names from a file into a domain list, for use in a DNS firewall rule group\cr
#'  \link[paws.networking:route53resolver_list_firewall_configs]{list_firewall_configs} \tab Retrieves the firewall configurations that you have defined\cr
#'  \link[paws.networking:route53resolver_list_firewall_domain_lists]{list_firewall_domain_lists} \tab Retrieves the firewall domain lists that you have defined\cr
#'  \link[paws.networking:route53resolver_list_firewall_domains]{list_firewall_domains} \tab Retrieves the domains that you have defined for the specified firewall domain list\cr
#'  \link[paws.networking:route53resolver_list_firewall_rule_group_associations]{list_firewall_rule_group_associations} \tab Retrieves the firewall rule group associations that you have defined\cr
#'  \link[paws.networking:route53resolver_list_firewall_rule_groups]{list_firewall_rule_groups} \tab Retrieves the minimal high-level information for the rule groups that you have defined\cr
#'  \link[paws.networking:route53resolver_list_firewall_rules]{list_firewall_rules} \tab Retrieves the firewall rules that you have defined for the specified firewall rule group\cr
#'  \link[paws.networking:route53resolver_list_outpost_resolvers]{list_outpost_resolvers} \tab Lists all the Resolvers on Outposts that were created using the current Amazon Web Services account\cr
#'  \link[paws.networking:route53resolver_list_resolver_configs]{list_resolver_configs} \tab Retrieves the Resolver configurations that you have defined\cr
#'  \link[paws.networking:route53resolver_list_resolver_dnssec_configs]{list_resolver_dnssec_configs} \tab Lists the configurations for DNSSEC validation that are associated with the current Amazon Web Services account\cr
#'  \link[paws.networking:route53resolver_list_resolver_endpoint_ip_addresses]{list_resolver_endpoint_ip_addresses} \tab Gets the IP addresses for a specified Resolver endpoint\cr
#'  \link[paws.networking:route53resolver_list_resolver_endpoints]{list_resolver_endpoints} \tab Lists all the Resolver endpoints that were created using the current Amazon Web Services account\cr
#'  \link[paws.networking:route53resolver_list_resolver_query_log_config_associations]{list_resolver_query_log_config_associations} \tab Lists information about associations between Amazon VPCs and query logging configurations\cr
#'  \link[paws.networking:route53resolver_list_resolver_query_log_configs]{list_resolver_query_log_configs} \tab Lists information about the specified query logging configurations\cr
#'  \link[paws.networking:route53resolver_list_resolver_rule_associations]{list_resolver_rule_associations} \tab Lists the associations that were created between Resolver rules and VPCs using the current Amazon Web Services account\cr
#'  \link[paws.networking:route53resolver_list_resolver_rules]{list_resolver_rules} \tab Lists the Resolver rules that were created using the current Amazon Web Services account\cr
#'  \link[paws.networking:route53resolver_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that you associated with the specified resource\cr
#'  \link[paws.networking:route53resolver_put_firewall_rule_group_policy]{put_firewall_rule_group_policy} \tab Attaches an Identity and Access Management (Amazon Web Services IAM) policy for sharing the rule group\cr
#'  \link[paws.networking:route53resolver_put_resolver_query_log_config_policy]{put_resolver_query_log_config_policy} \tab Specifies an Amazon Web Services account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration\cr
#'  \link[paws.networking:route53resolver_put_resolver_rule_policy]{put_resolver_rule_policy} \tab Specifies an Amazon Web Services rule that you want to share with another account, the account that you want to share the rule with, and the operations that you want the account to be able to perform on the rule\cr
#'  \link[paws.networking:route53resolver_tag_resource]{tag_resource} \tab Adds one or more tags to a specified resource\cr
#'  \link[paws.networking:route53resolver_untag_resource]{untag_resource} \tab Removes one or more tags from a specified resource\cr
#'  \link[paws.networking:route53resolver_update_firewall_config]{update_firewall_config} \tab Updates the configuration of the firewall behavior provided by DNS Firewall for a single VPC from Amazon Virtual Private Cloud (Amazon VPC)\cr
#'  \link[paws.networking:route53resolver_update_firewall_domains]{update_firewall_domains} \tab Updates the firewall domain list from an array of domain specifications\cr
#'  \link[paws.networking:route53resolver_update_firewall_rule]{update_firewall_rule} \tab Updates the specified firewall rule\cr
#'  \link[paws.networking:route53resolver_update_firewall_rule_group_association]{update_firewall_rule_group_association} \tab Changes the association of a FirewallRuleGroup with a VPC\cr
#'  \link[paws.networking:route53resolver_update_outpost_resolver]{update_outpost_resolver} \tab You can use UpdateOutpostResolver to update the instance count, type, or name of a Resolver on an Outpost\cr
#'  \link[paws.networking:route53resolver_update_resolver_config]{update_resolver_config} \tab Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from Amazon Virtual Private Cloud\cr
#'  \link[paws.networking:route53resolver_update_resolver_dnssec_config]{update_resolver_dnssec_config} \tab Updates an existing DNSSEC validation configuration\cr
#'  \link[paws.networking:route53resolver_update_resolver_endpoint]{update_resolver_endpoint} \tab Updates the name, or endpoint type for an inbound or an outbound Resolver endpoint\cr
#'  \link[paws.networking:route53resolver_update_resolver_rule]{update_resolver_rule} \tab Updates settings for a specified Resolver rule
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname route53resolver
#' @export
route53resolver <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::route53resolver(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Cloud Map
#'
#' @description
#' Cloud Map
#' 
#' With Cloud Map, you can configure public DNS, private DNS, or HTTP
#' namespaces that your microservice applications run in. When an instance
#' becomes available, you can call the Cloud Map API to register the
#' instance with Cloud Map. For public or private DNS namespaces, Cloud Map
#' automatically creates DNS records and an optional health check. Clients
#' that submit public or private DNS queries, or HTTP requests, for the
#' service receive an answer that contains up to eight healthy records.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- servicediscovery(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- servicediscovery()
#' # This example creates an HTTP namespace.
#' svc$create_http_namespace(
#'   CreatorRequestId = "example-creator-request-id-0001",
#'   Description = "Example.com AWS Cloud Map HTTP Namespace",
#'   Name = "example-http.com"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:servicediscovery_create_http_namespace]{create_http_namespace} \tab Creates an HTTP namespace\cr
#'  \link[paws.networking:servicediscovery_create_private_dns_namespace]{create_private_dns_namespace} \tab Creates a private namespace based on DNS, which is visible only inside a specified Amazon VPC\cr
#'  \link[paws.networking:servicediscovery_create_public_dns_namespace]{create_public_dns_namespace} \tab Creates a public namespace based on DNS, which is visible on the internet\cr
#'  \link[paws.networking:servicediscovery_create_service]{create_service} \tab Creates a service\cr
#'  \link[paws.networking:servicediscovery_delete_namespace]{delete_namespace} \tab Deletes a namespace from the current account\cr
#'  \link[paws.networking:servicediscovery_delete_service]{delete_service} \tab Deletes a specified service and all associated service attributes\cr
#'  \link[paws.networking:servicediscovery_delete_service_attributes]{delete_service_attributes} \tab Deletes specific attributes associated with a service\cr
#'  \link[paws.networking:servicediscovery_deregister_instance]{deregister_instance} \tab Deletes the Amazon Route 53 DNS records and health check, if any, that Cloud Map created for the specified instance\cr
#'  \link[paws.networking:servicediscovery_discover_instances]{discover_instances} \tab Discovers registered instances for a specified namespace and service\cr
#'  \link[paws.networking:servicediscovery_discover_instances_revision]{discover_instances_revision} \tab Discovers the increasing revision associated with an instance\cr
#'  \link[paws.networking:servicediscovery_get_instance]{get_instance} \tab Gets information about a specified instance\cr
#'  \link[paws.networking:servicediscovery_get_instances_health_status]{get_instances_health_status} \tab Gets the current health status (Healthy, Unhealthy, or Unknown) of one or more instances that are associated with a specified service\cr
#'  \link[paws.networking:servicediscovery_get_namespace]{get_namespace} \tab Gets information about a namespace\cr
#'  \link[paws.networking:servicediscovery_get_operation]{get_operation} \tab Gets information about any operation that returns an operation ID in the response, such as a CreateHttpNamespace request\cr
#'  \link[paws.networking:servicediscovery_get_service]{get_service} \tab Gets the settings for a specified service\cr
#'  \link[paws.networking:servicediscovery_get_service_attributes]{get_service_attributes} \tab Returns the attributes associated with a specified service\cr
#'  \link[paws.networking:servicediscovery_list_instances]{list_instances} \tab Lists summary information about the instances that you registered by using a specified service\cr
#'  \link[paws.networking:servicediscovery_list_namespaces]{list_namespaces} \tab Lists summary information about the namespaces that were created by the current Amazon Web Services account\cr
#'  \link[paws.networking:servicediscovery_list_operations]{list_operations} \tab Lists operations that match the criteria that you specify\cr
#'  \link[paws.networking:servicediscovery_list_services]{list_services} \tab Lists summary information for all the services that are associated with one or more namespaces\cr
#'  \link[paws.networking:servicediscovery_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags for the specified resource\cr
#'  \link[paws.networking:servicediscovery_register_instance]{register_instance} \tab Creates or updates one or more records and, optionally, creates a health check based on the settings in a specified service\cr
#'  \link[paws.networking:servicediscovery_tag_resource]{tag_resource} \tab Adds one or more tags to the specified resource\cr
#'  \link[paws.networking:servicediscovery_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.networking:servicediscovery_update_http_namespace]{update_http_namespace} \tab Updates an HTTP namespace\cr
#'  \link[paws.networking:servicediscovery_update_instance_custom_health_status]{update_instance_custom_health_status} \tab Submits a request to change the health status of a custom health check to healthy or unhealthy\cr
#'  \link[paws.networking:servicediscovery_update_private_dns_namespace]{update_private_dns_namespace} \tab Updates a private DNS namespace\cr
#'  \link[paws.networking:servicediscovery_update_public_dns_namespace]{update_public_dns_namespace} \tab Updates a public DNS namespace\cr
#'  \link[paws.networking:servicediscovery_update_service]{update_service} \tab Submits a request to perform the following operations:\cr
#'  \link[paws.networking:servicediscovery_update_service_attributes]{update_service_attributes} \tab Submits a request to update a specified service to add service-level attributes
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname servicediscovery
#' @export
servicediscovery <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::servicediscovery(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Telco Network Builder
#'
#' @description
#' Amazon Web Services Telco Network Builder (TNB) is a network automation
#' service that helps you deploy and manage telecom networks. AWS TNB helps
#' you with the lifecycle management of your telecommunication network
#' functions throughout planning, deployment, and post-deployment
#' activities.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- telconetworkbuilder(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- telconetworkbuilder()
#' svc$cancel_sol_network_operation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:telconetworkbuilder_cancel_sol_network_operation]{cancel_sol_network_operation} \tab Cancels a network operation\cr
#'  \link[paws.networking:telconetworkbuilder_create_sol_function_package]{create_sol_function_package} \tab Creates a function package\cr
#'  \link[paws.networking:telconetworkbuilder_create_sol_network_instance]{create_sol_network_instance} \tab Creates a network instance\cr
#'  \link[paws.networking:telconetworkbuilder_create_sol_network_package]{create_sol_network_package} \tab Creates a network package\cr
#'  \link[paws.networking:telconetworkbuilder_delete_sol_function_package]{delete_sol_function_package} \tab Deletes a function package\cr
#'  \link[paws.networking:telconetworkbuilder_delete_sol_network_instance]{delete_sol_network_instance} \tab Deletes a network instance\cr
#'  \link[paws.networking:telconetworkbuilder_delete_sol_network_package]{delete_sol_network_package} \tab Deletes network package\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_function_instance]{get_sol_function_instance} \tab Gets the details of a network function instance, including the instantiation state and metadata from the function package descriptor in the network function package\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_function_package]{get_sol_function_package} \tab Gets the details of an individual function package, such as the operational state and whether the package is in use\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_function_package_content]{get_sol_function_package_content} \tab Gets the contents of a function package\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_function_package_descriptor]{get_sol_function_package_descriptor} \tab Gets a function package descriptor in a function package\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_network_instance]{get_sol_network_instance} \tab Gets the details of the network instance\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_network_operation]{get_sol_network_operation} \tab Gets the details of a network operation, including the tasks involved in the network operation and the status of the tasks\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_network_package]{get_sol_network_package} \tab Gets the details of a network package\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_network_package_content]{get_sol_network_package_content} \tab Gets the contents of a network package\cr
#'  \link[paws.networking:telconetworkbuilder_get_sol_network_package_descriptor]{get_sol_network_package_descriptor} \tab Gets the content of the network service descriptor\cr
#'  \link[paws.networking:telconetworkbuilder_instantiate_sol_network_instance]{instantiate_sol_network_instance} \tab Instantiates a network instance\cr
#'  \link[paws.networking:telconetworkbuilder_list_sol_function_instances]{list_sol_function_instances} \tab Lists network function instances\cr
#'  \link[paws.networking:telconetworkbuilder_list_sol_function_packages]{list_sol_function_packages} \tab Lists information about function packages\cr
#'  \link[paws.networking:telconetworkbuilder_list_sol_network_instances]{list_sol_network_instances} \tab Lists your network instances\cr
#'  \link[paws.networking:telconetworkbuilder_list_sol_network_operations]{list_sol_network_operations} \tab Lists details for a network operation, including when the operation started and the status of the operation\cr
#'  \link[paws.networking:telconetworkbuilder_list_sol_network_packages]{list_sol_network_packages} \tab Lists network packages\cr
#'  \link[paws.networking:telconetworkbuilder_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags for AWS TNB resources\cr
#'  \link[paws.networking:telconetworkbuilder_put_sol_function_package_content]{put_sol_function_package_content} \tab Uploads the contents of a function package\cr
#'  \link[paws.networking:telconetworkbuilder_put_sol_network_package_content]{put_sol_network_package_content} \tab Uploads the contents of a network package\cr
#'  \link[paws.networking:telconetworkbuilder_tag_resource]{tag_resource} \tab Tags an AWS TNB resource\cr
#'  \link[paws.networking:telconetworkbuilder_terminate_sol_network_instance]{terminate_sol_network_instance} \tab Terminates a network instance\cr
#'  \link[paws.networking:telconetworkbuilder_untag_resource]{untag_resource} \tab Untags an AWS TNB resource\cr
#'  \link[paws.networking:telconetworkbuilder_update_sol_function_package]{update_sol_function_package} \tab Updates the operational state of function package\cr
#'  \link[paws.networking:telconetworkbuilder_update_sol_network_instance]{update_sol_network_instance} \tab Update a network instance\cr
#'  \link[paws.networking:telconetworkbuilder_update_sol_network_package]{update_sol_network_package} \tab Updates the operational state of a network package\cr
#'  \link[paws.networking:telconetworkbuilder_validate_sol_function_package_content]{validate_sol_function_package_content} \tab Validates function package content\cr
#'  \link[paws.networking:telconetworkbuilder_validate_sol_network_package_content]{validate_sol_network_package_content} \tab Validates network package content
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname telconetworkbuilder
#' @export
telconetworkbuilder <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::telconetworkbuilder(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon VPC Lattice
#'
#' @description
#' Amazon VPC Lattice is a fully managed application networking service
#' that you use to connect, secure, and monitor all of your services across
#' multiple accounts and virtual private clouds (VPCs). Amazon VPC Lattice
#' interconnects your microservices and legacy services within a logical
#' boundary, so that you can discover and manage them more efficiently. For
#' more information, see the [Amazon VPC Lattice User
#' Guide](https://docs.aws.amazon.com/vpc-lattice/latest/ug/)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- vpclattice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- vpclattice()
#' svc$batch_update_rule(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.networking:vpclattice_batch_update_rule]{batch_update_rule} \tab Updates the listener rules in a batch\cr
#'  \link[paws.networking:vpclattice_create_access_log_subscription]{create_access_log_subscription} \tab Enables access logs to be sent to Amazon CloudWatch, Amazon S3, and Amazon Kinesis Data Firehose\cr
#'  \link[paws.networking:vpclattice_create_listener]{create_listener} \tab Creates a listener for a service\cr
#'  \link[paws.networking:vpclattice_create_resource_configuration]{create_resource_configuration} \tab Creates a resource configuration\cr
#'  \link[paws.networking:vpclattice_create_resource_gateway]{create_resource_gateway} \tab Creates a resource gateway\cr
#'  \link[paws.networking:vpclattice_create_rule]{create_rule} \tab Creates a listener rule\cr
#'  \link[paws.networking:vpclattice_create_service]{create_service} \tab Creates a service\cr
#'  \link[paws.networking:vpclattice_create_service_network]{create_service_network} \tab Creates a service network\cr
#'  \link[paws.networking:vpclattice_create_service_network_resource_association]{create_service_network_resource_association} \tab Associates the specified service network with the specified resource configuration\cr
#'  \link[paws.networking:vpclattice_create_service_network_service_association]{create_service_network_service_association} \tab Associates the specified service with the specified service network\cr
#'  \link[paws.networking:vpclattice_create_service_network_vpc_association]{create_service_network_vpc_association} \tab Associates a VPC with a service network\cr
#'  \link[paws.networking:vpclattice_create_target_group]{create_target_group} \tab Creates a target group\cr
#'  \link[paws.networking:vpclattice_delete_access_log_subscription]{delete_access_log_subscription} \tab Deletes the specified access log subscription\cr
#'  \link[paws.networking:vpclattice_delete_auth_policy]{delete_auth_policy} \tab Deletes the specified auth policy\cr
#'  \link[paws.networking:vpclattice_delete_listener]{delete_listener} \tab Deletes the specified listener\cr
#'  \link[paws.networking:vpclattice_delete_resource_configuration]{delete_resource_configuration} \tab Deletes the specified resource configuration\cr
#'  \link[paws.networking:vpclattice_delete_resource_endpoint_association]{delete_resource_endpoint_association} \tab Disassociates the resource configuration from the resource VPC endpoint\cr
#'  \link[paws.networking:vpclattice_delete_resource_gateway]{delete_resource_gateway} \tab Deletes the specified resource gateway\cr
#'  \link[paws.networking:vpclattice_delete_resource_policy]{delete_resource_policy} \tab Deletes the specified resource policy\cr
#'  \link[paws.networking:vpclattice_delete_rule]{delete_rule} \tab Deletes a listener rule\cr
#'  \link[paws.networking:vpclattice_delete_service]{delete_service} \tab Deletes a service\cr
#'  \link[paws.networking:vpclattice_delete_service_network]{delete_service_network} \tab Deletes a service network\cr
#'  \link[paws.networking:vpclattice_delete_service_network_resource_association]{delete_service_network_resource_association} \tab Deletes the association between a service network and a resource configuration\cr
#'  \link[paws.networking:vpclattice_delete_service_network_service_association]{delete_service_network_service_association} \tab Deletes the association between a service and a service network\cr
#'  \link[paws.networking:vpclattice_delete_service_network_vpc_association]{delete_service_network_vpc_association} \tab Disassociates the VPC from the service network\cr
#'  \link[paws.networking:vpclattice_delete_target_group]{delete_target_group} \tab Deletes a target group\cr
#'  \link[paws.networking:vpclattice_deregister_targets]{deregister_targets} \tab Deregisters the specified targets from the specified target group\cr
#'  \link[paws.networking:vpclattice_get_access_log_subscription]{get_access_log_subscription} \tab Retrieves information about the specified access log subscription\cr
#'  \link[paws.networking:vpclattice_get_auth_policy]{get_auth_policy} \tab Retrieves information about the auth policy for the specified service or service network\cr
#'  \link[paws.networking:vpclattice_get_listener]{get_listener} \tab Retrieves information about the specified listener for the specified service\cr
#'  \link[paws.networking:vpclattice_get_resource_configuration]{get_resource_configuration} \tab Retrieves information about the specified resource configuration\cr
#'  \link[paws.networking:vpclattice_get_resource_gateway]{get_resource_gateway} \tab Retrieves information about the specified resource gateway\cr
#'  \link[paws.networking:vpclattice_get_resource_policy]{get_resource_policy} \tab Retrieves information about the specified resource policy\cr
#'  \link[paws.networking:vpclattice_get_rule]{get_rule} \tab Retrieves information about the specified listener rules\cr
#'  \link[paws.networking:vpclattice_get_service]{get_service} \tab Retrieves information about the specified service\cr
#'  \link[paws.networking:vpclattice_get_service_network]{get_service_network} \tab Retrieves information about the specified service network\cr
#'  \link[paws.networking:vpclattice_get_service_network_resource_association]{get_service_network_resource_association} \tab Retrieves information about the specified association between a service network and a resource configuration\cr
#'  \link[paws.networking:vpclattice_get_service_network_service_association]{get_service_network_service_association} \tab Retrieves information about the specified association between a service network and a service\cr
#'  \link[paws.networking:vpclattice_get_service_network_vpc_association]{get_service_network_vpc_association} \tab Retrieves information about the specified association between a service network and a VPC\cr
#'  \link[paws.networking:vpclattice_get_target_group]{get_target_group} \tab Retrieves information about the specified target group\cr
#'  \link[paws.networking:vpclattice_list_access_log_subscriptions]{list_access_log_subscriptions} \tab Lists the access log subscriptions for the specified service network or service\cr
#'  \link[paws.networking:vpclattice_list_listeners]{list_listeners} \tab Lists the listeners for the specified service\cr
#'  \link[paws.networking:vpclattice_list_resource_configurations]{list_resource_configurations} \tab Lists the resource configurations owned by or shared with this account\cr
#'  \link[paws.networking:vpclattice_list_resource_endpoint_associations]{list_resource_endpoint_associations} \tab Lists the associations for the specified VPC endpoint\cr
#'  \link[paws.networking:vpclattice_list_resource_gateways]{list_resource_gateways} \tab Lists the resource gateways that you own or that were shared with you\cr
#'  \link[paws.networking:vpclattice_list_rules]{list_rules} \tab Lists the rules for the specified listener\cr
#'  \link[paws.networking:vpclattice_list_service_network_resource_associations]{list_service_network_resource_associations} \tab Lists the associations between a service network and a resource configuration\cr
#'  \link[paws.networking:vpclattice_list_service_networks]{list_service_networks} \tab Lists the service networks owned by or shared with this account\cr
#'  \link[paws.networking:vpclattice_list_service_network_service_associations]{list_service_network_service_associations} \tab Lists the associations between a service network and a service\cr
#'  \link[paws.networking:vpclattice_list_service_network_vpc_associations]{list_service_network_vpc_associations} \tab Lists the associations between a service network and a VPC\cr
#'  \link[paws.networking:vpclattice_list_service_network_vpc_endpoint_associations]{list_service_network_vpc_endpoint_associations} \tab Lists the associations between a service network and a VPC endpoint\cr
#'  \link[paws.networking:vpclattice_list_services]{list_services} \tab Lists the services owned by the caller account or shared with the caller account\cr
#'  \link[paws.networking:vpclattice_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for the specified resource\cr
#'  \link[paws.networking:vpclattice_list_target_groups]{list_target_groups} \tab Lists your target groups\cr
#'  \link[paws.networking:vpclattice_list_targets]{list_targets} \tab Lists the targets for the target group\cr
#'  \link[paws.networking:vpclattice_put_auth_policy]{put_auth_policy} \tab Creates or updates the auth policy\cr
#'  \link[paws.networking:vpclattice_put_resource_policy]{put_resource_policy} \tab Attaches a resource-based permission policy to a service or service network\cr
#'  \link[paws.networking:vpclattice_register_targets]{register_targets} \tab Registers the targets with the target group\cr
#'  \link[paws.networking:vpclattice_tag_resource]{tag_resource} \tab Adds the specified tags to the specified resource\cr
#'  \link[paws.networking:vpclattice_untag_resource]{untag_resource} \tab Removes the specified tags from the specified resource\cr
#'  \link[paws.networking:vpclattice_update_access_log_subscription]{update_access_log_subscription} \tab Updates the specified access log subscription\cr
#'  \link[paws.networking:vpclattice_update_listener]{update_listener} \tab Updates the specified listener for the specified service\cr
#'  \link[paws.networking:vpclattice_update_resource_configuration]{update_resource_configuration} \tab Updates the specified resource configuration\cr
#'  \link[paws.networking:vpclattice_update_resource_gateway]{update_resource_gateway} \tab Updates the specified resource gateway\cr
#'  \link[paws.networking:vpclattice_update_rule]{update_rule} \tab Updates a specified rule for the listener\cr
#'  \link[paws.networking:vpclattice_update_service]{update_service} \tab Updates the specified service\cr
#'  \link[paws.networking:vpclattice_update_service_network]{update_service_network} \tab Updates the specified service network\cr
#'  \link[paws.networking:vpclattice_update_service_network_vpc_association]{update_service_network_vpc_association} \tab Updates the service network and VPC association\cr
#'  \link[paws.networking:vpclattice_update_target_group]{update_target_group} \tab Updates the specified target group
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname vpclattice
#' @export
vpclattice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.networking::vpclattice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Cloud9
#'
#' @description
#' Cloud9
#' 
#' Cloud9 is a collection of tools that you can use to code, build, run,
#' test, debug, and release software in the cloud.
#' 
#' For more information about Cloud9, see the [Cloud9 User
#' Guide](https://docs.aws.amazon.com/cloud9/latest/user-guide/).
#' 
#' Cloud9 is no longer available to new customers. Existing customers of
#' Cloud9 can continue to use the service as normal. [Learn
#' more"](https://aws.amazon.com/blogs/devops/how-to-migrate-from-aws-cloud9-to-aws-ide-toolkits-or-aws-cloudshell/)
#' 
#' Cloud9 supports these operations:
#' 
#' -   [`create_environment_ec2`][cloud9_create_environment_ec2]: Creates
#'     an Cloud9 development environment, launches an Amazon EC2 instance,
#'     and then connects from the instance to the environment.
#' 
#' -   [`create_environment_membership`][cloud9_create_environment_membership]:
#'     Adds an environment member to an environment.
#' 
#' -   [`delete_environment`][cloud9_delete_environment]: Deletes an
#'     environment. If an Amazon EC2 instance is connected to the
#'     environment, also terminates the instance.
#' 
#' -   [`delete_environment_membership`][cloud9_delete_environment_membership]:
#'     Deletes an environment member from an environment.
#' 
#' -   [`describe_environment_memberships`][cloud9_describe_environment_memberships]:
#'     Gets information about environment members for an environment.
#' 
#' -   [`describe_environments`][cloud9_describe_environments]: Gets
#'     information about environments.
#' 
#' -   [`describe_environment_status`][cloud9_describe_environment_status]:
#'     Gets status information for an environment.
#' 
#' -   [`list_environments`][cloud9_list_environments]: Gets a list of
#'     environment identifiers.
#' 
#' -   [`list_tags_for_resource`][cloud9_list_tags_for_resource]: Gets the
#'     tags for an environment.
#' 
#' -   [`tag_resource`][cloud9_tag_resource]: Adds tags to an environment.
#' 
#' -   [`untag_resource`][cloud9_untag_resource]: Removes tags from an
#'     environment.
#' 
#' -   [`update_environment`][cloud9_update_environment]: Changes the
#'     settings of an existing environment.
#' 
#' -   [`update_environment_membership`][cloud9_update_environment_membership]:
#'     Changes the settings of an existing environment member for an
#'     environment.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloud9(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloud9()
#' # 
#' svc$create_environment_ec2(
#'   name = "my-demo-environment",
#'   automaticStopTimeMinutes = 60L,
#'   description = "This is my demonstration environment.",
#'   instanceType = "t2.micro",
#'   ownerArn = "arn:aws:iam::123456789012:user/MyDemoUser",
#'   subnetId = "subnet-6300cd1b"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:cloud9_create_environment_ec2]{create_environment_ec2} \tab Creates an Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then connects from the instance to the environment\cr
#'  \link[paws.developer.tools:cloud9_create_environment_membership]{create_environment_membership} \tab Adds an environment member to an Cloud9 development environment\cr
#'  \link[paws.developer.tools:cloud9_delete_environment]{delete_environment} \tab Deletes an Cloud9 development environment\cr
#'  \link[paws.developer.tools:cloud9_delete_environment_membership]{delete_environment_membership} \tab Deletes an environment member from a development environment\cr
#'  \link[paws.developer.tools:cloud9_describe_environment_memberships]{describe_environment_memberships} \tab Gets information about environment members for an Cloud9 development environment\cr
#'  \link[paws.developer.tools:cloud9_describe_environments]{describe_environments} \tab Gets information about Cloud9 development environments\cr
#'  \link[paws.developer.tools:cloud9_describe_environment_status]{describe_environment_status} \tab Gets status information for an Cloud9 development environment\cr
#'  \link[paws.developer.tools:cloud9_list_environments]{list_environments} \tab Gets a list of Cloud9 development environment identifiers\cr
#'  \link[paws.developer.tools:cloud9_list_tags_for_resource]{list_tags_for_resource} \tab Gets a list of the tags associated with an Cloud9 development environment\cr
#'  \link[paws.developer.tools:cloud9_tag_resource]{tag_resource} \tab Adds tags to an Cloud9 development environment\cr
#'  \link[paws.developer.tools:cloud9_untag_resource]{untag_resource} \tab Removes tags from an Cloud9 development environment\cr
#'  \link[paws.developer.tools:cloud9_update_environment]{update_environment} \tab Changes the settings of an existing Cloud9 development environment\cr
#'  \link[paws.developer.tools:cloud9_update_environment_membership]{update_environment_membership} \tab Changes the settings of an existing environment member for an Cloud9 development environment
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloud9
#' @export
cloud9 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::cloud9(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Cloud Control API
#'
#' @description
#' For more information about Amazon Web Services Cloud Control API, see
#' the [Amazon Web Services Cloud Control API User
#' Guide](https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/what-is-cloudcontrolapi.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudcontrolapi(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudcontrolapi()
#' svc$cancel_resource_request(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:cloudcontrolapi_cancel_resource_request]{cancel_resource_request} \tab Cancels the specified resource operation request\cr
#'  \link[paws.developer.tools:cloudcontrolapi_create_resource]{create_resource} \tab Creates the specified resource\cr
#'  \link[paws.developer.tools:cloudcontrolapi_delete_resource]{delete_resource} \tab Deletes the specified resource\cr
#'  \link[paws.developer.tools:cloudcontrolapi_get_resource]{get_resource} \tab Returns information about the current state of the specified resource\cr
#'  \link[paws.developer.tools:cloudcontrolapi_get_resource_request_status]{get_resource_request_status} \tab Returns the current status of a resource operation request\cr
#'  \link[paws.developer.tools:cloudcontrolapi_list_resource_requests]{list_resource_requests} \tab Returns existing resource operation requests\cr
#'  \link[paws.developer.tools:cloudcontrolapi_list_resources]{list_resources} \tab Returns information about the specified resources\cr
#'  \link[paws.developer.tools:cloudcontrolapi_update_resource]{update_resource} \tab Updates the specified property values in the resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudcontrolapi
#' @export
cloudcontrolapi <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::cloudcontrolapi(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CodeBuild
#'
#' @description
#' CodeBuild
#' 
#' CodeBuild is a fully managed build service in the cloud. CodeBuild
#' compiles your source code, runs unit tests, and produces artifacts that
#' are ready to deploy. CodeBuild eliminates the need to provision, manage,
#' and scale your own build servers. It provides prepackaged build
#' environments for the most popular programming languages and build tools,
#' such as Apache Maven, Gradle, and more. You can also fully customize
#' build environments in CodeBuild to use your own build tools. CodeBuild
#' scales automatically to meet peak build requests. You pay only for the
#' build time you consume. For more information about CodeBuild, see the
#' *\href{https://docs.aws.amazon.com/codebuild/latest/userguide/welcome.html}{CodeBuild User Guide}.*
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codebuild(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codebuild()
#' # The following example gets information about builds with the specified
#' # build IDs.
#' svc$batch_get_builds(
#'   ids = list(
#'     "codebuild-demo-project:9b0ac37f-d19e-4254-9079-f47e9a389eEX",
#'     "codebuild-demo-project:b79a46f7-1473-4636-a23f-da9c45c208EX"
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codebuild_batch_delete_builds]{batch_delete_builds} \tab Deletes one or more builds\cr
#'  \link[paws.developer.tools:codebuild_batch_get_build_batches]{batch_get_build_batches} \tab Retrieves information about one or more batch builds\cr
#'  \link[paws.developer.tools:codebuild_batch_get_builds]{batch_get_builds} \tab Gets information about one or more builds\cr
#'  \link[paws.developer.tools:codebuild_batch_get_fleets]{batch_get_fleets} \tab Gets information about one or more compute fleets\cr
#'  \link[paws.developer.tools:codebuild_batch_get_projects]{batch_get_projects} \tab Gets information about one or more build projects\cr
#'  \link[paws.developer.tools:codebuild_batch_get_report_groups]{batch_get_report_groups} \tab Returns an array of report groups\cr
#'  \link[paws.developer.tools:codebuild_batch_get_reports]{batch_get_reports} \tab Returns an array of reports\cr
#'  \link[paws.developer.tools:codebuild_create_fleet]{create_fleet} \tab Creates a compute fleet\cr
#'  \link[paws.developer.tools:codebuild_create_project]{create_project} \tab Creates a build project\cr
#'  \link[paws.developer.tools:codebuild_create_report_group]{create_report_group} \tab Creates a report group\cr
#'  \link[paws.developer.tools:codebuild_create_webhook]{create_webhook} \tab For an existing CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, enables CodeBuild to start rebuilding the source code every time a code change is pushed to the repository\cr
#'  \link[paws.developer.tools:codebuild_delete_build_batch]{delete_build_batch} \tab Deletes a batch build\cr
#'  \link[paws.developer.tools:codebuild_delete_fleet]{delete_fleet} \tab Deletes a compute fleet\cr
#'  \link[paws.developer.tools:codebuild_delete_project]{delete_project} \tab Deletes a build project\cr
#'  \link[paws.developer.tools:codebuild_delete_report]{delete_report} \tab Deletes a report\cr
#'  \link[paws.developer.tools:codebuild_delete_report_group]{delete_report_group} \tab Deletes a report group\cr
#'  \link[paws.developer.tools:codebuild_delete_resource_policy]{delete_resource_policy} \tab Deletes a resource policy that is identified by its resource ARN\cr
#'  \link[paws.developer.tools:codebuild_delete_source_credentials]{delete_source_credentials} \tab Deletes a set of GitHub, GitHub Enterprise, or Bitbucket source credentials\cr
#'  \link[paws.developer.tools:codebuild_delete_webhook]{delete_webhook} \tab For an existing CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops CodeBuild from rebuilding the source code every time a code change is pushed to the repository\cr
#'  \link[paws.developer.tools:codebuild_describe_code_coverages]{describe_code_coverages} \tab Retrieves one or more code coverage reports\cr
#'  \link[paws.developer.tools:codebuild_describe_test_cases]{describe_test_cases} \tab Returns a list of details about test cases for a report\cr
#'  \link[paws.developer.tools:codebuild_get_report_group_trend]{get_report_group_trend} \tab Analyzes and accumulates test report values for the specified test reports\cr
#'  \link[paws.developer.tools:codebuild_get_resource_policy]{get_resource_policy} \tab Gets a resource policy that is identified by its resource ARN\cr
#'  \link[paws.developer.tools:codebuild_import_source_credentials]{import_source_credentials} \tab Imports the source repository credentials for an CodeBuild project that has its source code stored in a GitHub, GitHub Enterprise, GitLab, GitLab Self Managed, or Bitbucket repository\cr
#'  \link[paws.developer.tools:codebuild_invalidate_project_cache]{invalidate_project_cache} \tab Resets the cache for a project\cr
#'  \link[paws.developer.tools:codebuild_list_build_batches]{list_build_batches} \tab Retrieves the identifiers of your build batches in the current region\cr
#'  \link[paws.developer.tools:codebuild_list_build_batches_for_project]{list_build_batches_for_project} \tab Retrieves the identifiers of the build batches for a specific project\cr
#'  \link[paws.developer.tools:codebuild_list_builds]{list_builds} \tab Gets a list of build IDs, with each build ID representing a single build\cr
#'  \link[paws.developer.tools:codebuild_list_builds_for_project]{list_builds_for_project} \tab Gets a list of build identifiers for the specified build project, with each build identifier representing a single build\cr
#'  \link[paws.developer.tools:codebuild_list_curated_environment_images]{list_curated_environment_images} \tab Gets information about Docker images that are managed by CodeBuild\cr
#'  \link[paws.developer.tools:codebuild_list_fleets]{list_fleets} \tab Gets a list of compute fleet names with each compute fleet name representing a single compute fleet\cr
#'  \link[paws.developer.tools:codebuild_list_projects]{list_projects} \tab Gets a list of build project names, with each build project name representing a single build project\cr
#'  \link[paws.developer.tools:codebuild_list_report_groups]{list_report_groups} \tab Gets a list ARNs for the report groups in the current Amazon Web Services account\cr
#'  \link[paws.developer.tools:codebuild_list_reports]{list_reports} \tab Returns a list of ARNs for the reports in the current Amazon Web Services account\cr
#'  \link[paws.developer.tools:codebuild_list_reports_for_report_group]{list_reports_for_report_group} \tab Returns a list of ARNs for the reports that belong to a ReportGroup\cr
#'  \link[paws.developer.tools:codebuild_list_shared_projects]{list_shared_projects} \tab Gets a list of projects that are shared with other Amazon Web Services accounts or users\cr
#'  \link[paws.developer.tools:codebuild_list_shared_report_groups]{list_shared_report_groups} \tab Gets a list of report groups that are shared with other Amazon Web Services accounts or users\cr
#'  \link[paws.developer.tools:codebuild_list_source_credentials]{list_source_credentials} \tab Returns a list of SourceCredentialsInfo objects\cr
#'  \link[paws.developer.tools:codebuild_put_resource_policy]{put_resource_policy} \tab Stores a resource policy for the ARN of a Project or ReportGroup object\cr
#'  \link[paws.developer.tools:codebuild_retry_build]{retry_build} \tab Restarts a build\cr
#'  \link[paws.developer.tools:codebuild_retry_build_batch]{retry_build_batch} \tab Restarts a failed batch build\cr
#'  \link[paws.developer.tools:codebuild_start_build]{start_build} \tab Starts running a build with the settings defined in the project\cr
#'  \link[paws.developer.tools:codebuild_start_build_batch]{start_build_batch} \tab Starts a batch build for a project\cr
#'  \link[paws.developer.tools:codebuild_stop_build]{stop_build} \tab Attempts to stop running a build\cr
#'  \link[paws.developer.tools:codebuild_stop_build_batch]{stop_build_batch} \tab Stops a running batch build\cr
#'  \link[paws.developer.tools:codebuild_update_fleet]{update_fleet} \tab Updates a compute fleet\cr
#'  \link[paws.developer.tools:codebuild_update_project]{update_project} \tab Changes the settings of a build project\cr
#'  \link[paws.developer.tools:codebuild_update_project_visibility]{update_project_visibility} \tab Changes the public visibility for a project\cr
#'  \link[paws.developer.tools:codebuild_update_report_group]{update_report_group} \tab Updates a report group\cr
#'  \link[paws.developer.tools:codebuild_update_webhook]{update_webhook} \tab Updates the webhook associated with an CodeBuild build project
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codebuild
#' @export
codebuild <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codebuild(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' CodeArtifact
#'
#' @description
#' CodeArtifact is a fully managed artifact repository compatible with
#' language-native package managers and build tools such as npm, Apache
#' Maven, pip, and dotnet. You can use CodeArtifact to share packages with
#' development teams and pull packages. Packages can be pulled from both
#' public and CodeArtifact repositories. You can also create an upstream
#' relationship between a CodeArtifact repository and another repository,
#' which effectively merges their contents from the point of view of a
#' package manager client.
#' 
#' **CodeArtifact concepts**
#' 
#' -   **Repository**: A CodeArtifact repository contains a set of [package
#'     versions](https://docs.aws.amazon.com/codeartifact/latest/ug/welcome.html#welcome-concepts-package-version),
#'     each of which maps to a set of assets, or files. Repositories are
#'     polyglot, so a single repository can contain packages of any
#'     supported type. Each repository exposes endpoints for fetching and
#'     publishing packages using tools such as the **`npm`** CLI or the
#'     Maven CLI ( **`mvn`** ). For a list of supported package managers,
#'     see the [CodeArtifact User
#'     Guide](https://docs.aws.amazon.com/codeartifact/latest/ug/welcome.html).
#' 
#' -   **Domain**: Repositories are aggregated into a higher-level entity
#'     known as a *domain*. All package assets and metadata are stored in
#'     the domain, but are consumed through repositories. A given package
#'     asset, such as a Maven JAR file, is stored once per domain, no
#'     matter how many repositories it's present in. All of the assets and
#'     metadata in a domain are encrypted with the same customer master key
#'     (CMK) stored in Key Management Service (KMS).
#' 
#'     Each repository is a member of a single domain and can't be moved to
#'     a different domain.
#' 
#'     The domain allows organizational policy to be applied across
#'     multiple repositories, such as which accounts can access
#'     repositories in the domain, and which public repositories can be
#'     used as sources of packages.
#' 
#'     Although an organization can have multiple domains, we recommend a
#'     single production domain that contains all published artifacts so
#'     that teams can find and share packages across their organization.
#' 
#' -   **Package**: A *package* is a bundle of software and the metadata
#'     required to resolve dependencies and install the software.
#'     CodeArtifact supports npm, PyPI, Maven, NuGet, Swift, Ruby, Cargo,
#'     and generic package formats. For more information about the
#'     supported package formats and how to use CodeArtifact with them, see
#'     the [CodeArtifact User
#'     Guide](https://docs.aws.amazon.com/codeartifact/latest/ug/welcome.html).
#' 
#'     In CodeArtifact, a package consists of:
#' 
#'     -   A *name* (for example, `webpack` is the name of a popular npm
#'         package)
#' 
#'     -   An optional namespace (for example, `@@types` in `@@types/node`)
#' 
#'     -   A set of versions (for example, `1.0.0`, `1.0.1`, `1.0.2`, etc.)
#' 
#'     -   Package-level metadata (for example, npm tags)
#' 
#' -   **Package group**: A group of packages that match a specified
#'     definition. Package groups can be used to apply configuration to
#'     multiple packages that match a defined pattern using package format,
#'     package namespace, and package name. You can use package groups to
#'     more conveniently configure package origin controls for multiple
#'     packages. Package origin controls are used to block or allow
#'     ingestion or publishing of new package versions, which protects
#'     users from malicious actions known as dependency substitution
#'     attacks.
#' 
#' -   **Package version**: A version of a package, such as
#'     `@@types/node 12.6.9`. The version number format and semantics vary
#'     for different package formats. For example, npm package versions
#'     must conform to the [Semantic Versioning
#'     specification](https://semver.org/). In CodeArtifact, a package
#'     version consists of the version identifier, metadata at the package
#'     version level, and a set of assets.
#' 
#' -   **Upstream repository**: One repository is *upstream* of another
#'     when the package versions in it can be accessed from the repository
#'     endpoint of the downstream repository, effectively merging the
#'     contents of the two repositories from the point of view of a client.
#'     CodeArtifact allows creating an upstream relationship between two
#'     repositories.
#' 
#' -   **Asset**: An individual file stored in CodeArtifact associated with
#'     a package version, such as an npm `.tgz` file or Maven POM and JAR
#'     files.
#' 
#' **CodeArtifact supported API operations**
#' 
#' -   `associate_external_connection`:
#'     Adds an existing external connection to a repository.
#' 
#' -   `copy_package_versions`:
#'     Copies package versions from one repository to another repository in
#'     the same domain.
#' 
#' -   `create_domain`: Creates a domain.
#' 
#' -   `create_package_group`: Creates
#'     a package group.
#' 
#' -   `create_repository`: Creates a
#'     CodeArtifact repository in a domain.
#' 
#' -   `delete_domain`: Deletes a domain. You
#'     cannot delete a domain that contains repositories.
#' 
#' -   `delete_domain_permissions_policy`:
#'     Deletes the resource policy that is set on a domain.
#' 
#' -   `delete_package`: Deletes a package
#'     and all associated package versions.
#' 
#' -   `delete_package_group`: Deletes
#'     a package group. Does not delete packages or package versions that
#'     are associated with a package group.
#' 
#' -   `delete_package_versions`:
#'     Deletes versions of a package. After a package has been deleted, it
#'     can be republished, but its assets and metadata cannot be restored
#'     because they have been permanently removed from storage.
#' 
#' -   `delete_repository`: Deletes a
#'     repository.
#' 
#' -   `delete_repository_permissions_policy`:
#'     Deletes the resource policy that is set on a repository.
#' 
#' -   `describe_domain`: Returns a
#'     `DomainDescription` object that contains information about the
#'     requested domain.
#' 
#' -   `describe_package`: Returns a
#'     [PackageDescription](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageDescription.html)
#'     object that contains details about a package.
#' 
#' -   `describe_package_group`:
#'     Returns a
#'     [PackageGroup](https://docs.aws.amazon.com/codeartifact/latest/APIReference/)
#'     object that contains details about a package group.
#' 
#' -   `describe_package_version`:
#'     Returns a
#'     [PackageVersionDescription](https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageVersionDescription.html)
#'     object that contains details about a package version.
#' 
#' -   `describe_repository`: Returns a
#'     `RepositoryDescription` object that contains detailed information
#'     about the requested repository.
#' 
#' -   `dispose_package_versions`:
#'     Disposes versions of a package. A package version with the status
#'     `Disposed` cannot be restored because they have been permanently
#'     removed from storage.
#' 
#' -   `disassociate_external_connection`:
#'     Removes an existing external connection from a repository.
#' 
#' -   `get_associated_package_group`:
#'     Returns the most closely associated package group to the specified
#'     package.
#' 
#' -   `get_authorization_token`:
#'     Generates a temporary authorization token for accessing repositories
#'     in the domain. The token expires the authorization period has
#'     passed. The default authorization period is 12 hours and can be
#'     customized to any length with a maximum of 12 hours.
#' 
#' -   `get_domain_permissions_policy`:
#'     Returns the policy of a resource that is attached to the specified
#'     domain.
#' 
#' -   `get_package_version_asset`:
#'     Returns the contents of an asset that is in a package version.
#' 
#' -   `get_package_version_readme`:
#'     Gets the readme file or descriptive text for a package version.
#' 
#' -   `get_repository_endpoint`:
#'     Returns the endpoint of a repository for a specific package format.
#'     A repository has one endpoint for each package format:
#' 
#'     -   `cargo`
#' 
#'     -   `generic`
#' 
#'     -   `maven`
#' 
#'     -   `npm`
#' 
#'     -   `nuget`
#' 
#'     -   `pypi`
#' 
#'     -   `ruby`
#' 
#'     -   `swift`
#' 
#' -   `get_repository_permissions_policy`:
#'     Returns the resource policy that is set on a repository.
#' 
#' -   `list_allowed_repositories_for_group`:
#'     Lists the allowed repositories for a package group that has origin
#'     configuration set to `ALLOW_SPECIFIC_REPOSITORIES`.
#' 
#' -   `list_associated_packages`:
#'     Returns a list of packages associated with the requested package
#'     group.
#' 
#' -   `list_domains`: Returns a list of
#'     `DomainSummary` objects. Each returned `DomainSummary` object
#'     contains information about a domain.
#' 
#' -   `list_packages`: Lists the packages in
#'     a repository.
#' 
#' -   `list_package_groups`: Returns a
#'     list of package groups in the requested domain.
#' 
#' -   `list_package_version_assets`:
#'     Lists the assets for a given package version.
#' 
#' -   `list_package_version_dependencies`:
#'     Returns a list of the direct dependencies for a package version.
#' 
#' -   `list_package_versions`:
#'     Returns a list of package versions for a specified package in a
#'     repository.
#' 
#' -   `list_repositories`: Returns a
#'     list of repositories owned by the Amazon Web Services account that
#'     called this method.
#' 
#' -   `list_repositories_in_domain`:
#'     Returns a list of the repositories in a domain.
#' 
#' -   `list_sub_package_groups`:
#'     Returns a list of direct children of the specified package group.
#' 
#' -   `publish_package_version`:
#'     Creates a new package version containing one or more assets.
#' 
#' -   `put_domain_permissions_policy`:
#'     Attaches a resource policy to a domain.
#' 
#' -   `put_package_origin_configuration`:
#'     Sets the package origin configuration for a package, which determine
#'     how new versions of the package can be added to a specific
#'     repository.
#' 
#' -   `put_repository_permissions_policy`:
#'     Sets the resource policy on a repository that specifies permissions
#'     to access it.
#' 
#' -   `update_package_group`: Updates
#'     a package group. This API cannot be used to update a package group's
#'     origin configuration or pattern.
#' 
#' -   `update_package_group_origin_configuration`:
#'     Updates the package origin configuration for a package group.
#' 
#' -   `update_package_versions_status`:
#'     Updates the status of one or more versions of a package.
#' 
#' -   `update_repository`: Updates the
#'     properties of a repository.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codeartifact(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codeartifact()
#' svc$associate_external_connection(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codeartifact_associate_external_connection]{associate_external_connection} \tab Adds an existing external connection to a repository\cr
#'  \link[paws.developer.tools:codeartifact_copy_package_versions]{copy_package_versions} \tab Copies package versions from one repository to another repository in the same domain\cr
#'  \link[paws.developer.tools:codeartifact_create_domain]{create_domain} \tab Creates a domain\cr
#'  \link[paws.developer.tools:codeartifact_create_package_group]{create_package_group} \tab Creates a package group\cr
#'  \link[paws.developer.tools:codeartifact_create_repository]{create_repository} \tab Creates a repository\cr
#'  \link[paws.developer.tools:codeartifact_delete_domain]{delete_domain} \tab Deletes a domain\cr
#'  \link[paws.developer.tools:codeartifact_delete_domain_permissions_policy]{delete_domain_permissions_policy} \tab Deletes the resource policy set on a domain\cr
#'  \link[paws.developer.tools:codeartifact_delete_package]{delete_package} \tab Deletes a package and all associated package versions\cr
#'  \link[paws.developer.tools:codeartifact_delete_package_group]{delete_package_group} \tab Deletes a package group\cr
#'  \link[paws.developer.tools:codeartifact_delete_package_versions]{delete_package_versions} \tab Deletes one or more versions of a package\cr
#'  \link[paws.developer.tools:codeartifact_delete_repository]{delete_repository} \tab Deletes a repository\cr
#'  \link[paws.developer.tools:codeartifact_delete_repository_permissions_policy]{delete_repository_permissions_policy} \tab Deletes the resource policy that is set on a repository\cr
#'  \link[paws.developer.tools:codeartifact_describe_domain]{describe_domain} \tab Returns a DomainDescription object that contains information about the requested domain\cr
#'  \link[paws.developer.tools:codeartifact_describe_package]{describe_package} \tab Returns a PackageDescription object that contains information about the requested package\cr
#'  \link[paws.developer.tools:codeartifact_describe_package_group]{describe_package_group} \tab Returns a PackageGroupDescription object that contains information about the requested package group\cr
#'  \link[paws.developer.tools:codeartifact_describe_package_version]{describe_package_version} \tab Returns a PackageVersionDescription object that contains information about the requested package version\cr
#'  \link[paws.developer.tools:codeartifact_describe_repository]{describe_repository} \tab Returns a RepositoryDescription object that contains detailed information about the requested repository\cr
#'  \link[paws.developer.tools:codeartifact_disassociate_external_connection]{disassociate_external_connection} \tab Removes an existing external connection from a repository\cr
#'  \link[paws.developer.tools:codeartifact_dispose_package_versions]{dispose_package_versions} \tab Deletes the assets in package versions and sets the package versions' status to Disposed\cr
#'  \link[paws.developer.tools:codeartifact_get_associated_package_group]{get_associated_package_group} \tab Returns the most closely associated package group to the specified package\cr
#'  \link[paws.developer.tools:codeartifact_get_authorization_token]{get_authorization_token} \tab Generates a temporary authorization token for accessing repositories in the domain\cr
#'  \link[paws.developer.tools:codeartifact_get_domain_permissions_policy]{get_domain_permissions_policy} \tab Returns the resource policy attached to the specified domain\cr
#'  \link[paws.developer.tools:codeartifact_get_package_version_asset]{get_package_version_asset} \tab Returns an asset (or file) that is in a package\cr
#'  \link[paws.developer.tools:codeartifact_get_package_version_readme]{get_package_version_readme} \tab Gets the readme file or descriptive text for a package version\cr
#'  \link[paws.developer.tools:codeartifact_get_repository_endpoint]{get_repository_endpoint} \tab Returns the endpoint of a repository for a specific package format\cr
#'  \link[paws.developer.tools:codeartifact_get_repository_permissions_policy]{get_repository_permissions_policy} \tab Returns the resource policy that is set on a repository\cr
#'  \link[paws.developer.tools:codeartifact_list_allowed_repositories_for_group]{list_allowed_repositories_for_group} \tab Lists the repositories in the added repositories list of the specified restriction type for a package group\cr
#'  \link[paws.developer.tools:codeartifact_list_associated_packages]{list_associated_packages} \tab Returns a list of packages associated with the requested package group\cr
#'  \link[paws.developer.tools:codeartifact_list_domains]{list_domains} \tab Returns a list of DomainSummary objects for all domains owned by the Amazon Web Services account that makes this call\cr
#'  \link[paws.developer.tools:codeartifact_list_package_groups]{list_package_groups} \tab Returns a list of package groups in the requested domain\cr
#'  \link[paws.developer.tools:codeartifact_list_packages]{list_packages} \tab Returns a list of PackageSummary objects for packages in a repository that match the request parameters\cr
#'  \link[paws.developer.tools:codeartifact_list_package_version_assets]{list_package_version_assets} \tab Returns a list of AssetSummary objects for assets in a package version\cr
#'  \link[paws.developer.tools:codeartifact_list_package_version_dependencies]{list_package_version_dependencies} \tab Returns the direct dependencies for a package version\cr
#'  \link[paws.developer.tools:codeartifact_list_package_versions]{list_package_versions} \tab Returns a list of PackageVersionSummary objects for package versions in a repository that match the request parameters\cr
#'  \link[paws.developer.tools:codeartifact_list_repositories]{list_repositories} \tab Returns a list of RepositorySummary objects\cr
#'  \link[paws.developer.tools:codeartifact_list_repositories_in_domain]{list_repositories_in_domain} \tab Returns a list of RepositorySummary objects\cr
#'  \link[paws.developer.tools:codeartifact_list_sub_package_groups]{list_sub_package_groups} \tab Returns a list of direct children of the specified package group\cr
#'  \link[paws.developer.tools:codeartifact_list_tags_for_resource]{list_tags_for_resource} \tab Gets information about Amazon Web Services tags for a specified Amazon Resource Name (ARN) in CodeArtifact\cr
#'  \link[paws.developer.tools:codeartifact_publish_package_version]{publish_package_version} \tab Creates a new package version containing one or more assets (or files)\cr
#'  \link[paws.developer.tools:codeartifact_put_domain_permissions_policy]{put_domain_permissions_policy} \tab Sets a resource policy on a domain that specifies permissions to access it\cr
#'  \link[paws.developer.tools:codeartifact_put_package_origin_configuration]{put_package_origin_configuration} \tab Sets the package origin configuration for a package\cr
#'  \link[paws.developer.tools:codeartifact_put_repository_permissions_policy]{put_repository_permissions_policy} \tab Sets the resource policy on a repository that specifies permissions to access it\cr
#'  \link[paws.developer.tools:codeartifact_tag_resource]{tag_resource} \tab Adds or updates tags for a resource in CodeArtifact\cr
#'  \link[paws.developer.tools:codeartifact_untag_resource]{untag_resource} \tab Removes tags from a resource in CodeArtifact\cr
#'  \link[paws.developer.tools:codeartifact_update_package_group]{update_package_group} \tab Updates a package group\cr
#'  \link[paws.developer.tools:codeartifact_update_package_group_origin_configuration]{update_package_group_origin_configuration} \tab Updates the package origin configuration for a package group\cr
#'  \link[paws.developer.tools:codeartifact_update_package_versions_status]{update_package_versions_status} \tab Updates the status of one or more versions of a package\cr
#'  \link[paws.developer.tools:codeartifact_update_repository]{update_repository} \tab Update the properties of a repository
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codeartifact
#' @export
codeartifact <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codeartifact(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CodeCommit
#'
#' @description
#' CodeCommit
#' 
#' This is the *CodeCommit API Reference*. This reference provides
#' descriptions of the operations and data types for CodeCommit API along
#' with usage examples.
#' 
#' You can use the CodeCommit API to work with the following objects:
#' 
#' Repositories, by calling the following:
#' 
#' -   `batch_get_repositories`, which
#'     returns information about one or more repositories associated with
#'     your Amazon Web Services account.
#' 
#' -   `create_repository`, which creates
#'     an CodeCommit repository.
#' 
#' -   `delete_repository`, which deletes
#'     an CodeCommit repository.
#' 
#' -   `get_repository`, which returns
#'     information about a specified repository.
#' 
#' -   `list_repositories`, which lists all
#'     CodeCommit repositories associated with your Amazon Web Services
#'     account.
#' 
#' -   `update_repository_description`,
#'     which sets or updates the description of the repository.
#' 
#' -   `update_repository_encryption_key`,
#'     which updates the Key Management Service encryption key used to
#'     encrypt and decrypt a repository.
#' 
#' -   `update_repository_name`, which
#'     changes the name of the repository. If you change the name of a
#'     repository, no other users of that repository can access it until
#'     you send them the new HTTPS or SSH URL to use.
#' 
#' Branches, by calling the following:
#' 
#' -   `create_branch`, which creates a branch
#'     in a specified repository.
#' 
#' -   `delete_branch`, which deletes the
#'     specified branch in a repository unless it is the default branch.
#' 
#' -   `get_branch`, which returns information
#'     about a specified branch.
#' 
#' -   `list_branches`, which lists all
#'     branches for a specified repository.
#' 
#' -   `update_default_branch`, which
#'     changes the default branch for a repository.
#' 
#' Files, by calling the following:
#' 
#' -   `delete_file`, which deletes the content
#'     of a specified file from a specified branch.
#' 
#' -   `get_blob`, which returns the base-64 encoded
#'     content of an individual Git blob object in a repository.
#' 
#' -   `get_file`, which returns the base-64 encoded
#'     content of a specified file.
#' 
#' -   `get_folder`, which returns the contents of
#'     a specified folder or directory.
#' 
#' -   `list_file_commit_history`,
#'     which retrieves a list of commits and changes to a specified file.
#' 
#' -   `put_file`, which adds or modifies a single
#'     file in a specified repository and branch.
#' 
#' Commits, by calling the following:
#' 
#' -   `batch_get_commits`, which returns
#'     information about one or more commits in a repository.
#' 
#' -   `create_commit`, which creates a commit
#'     for changes to a repository.
#' 
#' -   `get_commit`, which returns information
#'     about a commit, including commit messages and author and committer
#'     information.
#' 
#' -   `get_differences`, which returns
#'     information about the differences in a valid commit specifier (such
#'     as a branch, tag, HEAD, commit ID, or other fully qualified
#'     reference).
#' 
#' Merges, by calling the following:
#' 
#' -   `batch_describe_merge_conflicts`,
#'     which returns information about conflicts in a merge between commits
#'     in a repository.
#' 
#' -   `create_unreferenced_merge_commit`,
#'     which creates an unreferenced commit between two branches or commits
#'     for the purpose of comparing them and identifying any potential
#'     conflicts.
#' 
#' -   `describe_merge_conflicts`,
#'     which returns information about merge conflicts between the base,
#'     source, and destination versions of a file in a potential merge.
#' 
#' -   `get_merge_commit`, which returns
#'     information about the merge between a source and destination commit.
#' 
#' -   `get_merge_conflicts`, which
#'     returns information about merge conflicts between the source and
#'     destination branch in a pull request.
#' 
#' -   `get_merge_options`, which returns
#'     information about the available merge options between two branches
#'     or commit specifiers.
#' 
#' -   `merge_branches_by_fast_forward`,
#'     which merges two branches using the fast-forward merge option.
#' 
#' -   `merge_branches_by_squash`,
#'     which merges two branches using the squash merge option.
#' 
#' -   `merge_branches_by_three_way`,
#'     which merges two branches using the three-way merge option.
#' 
#' Pull requests, by calling the following:
#' 
#' -   `create_pull_request`, which
#'     creates a pull request in a specified repository.
#' 
#' -   `create_pull_request_approval_rule`,
#'     which creates an approval rule for a specified pull request.
#' 
#' -   `delete_pull_request_approval_rule`,
#'     which deletes an approval rule for a specified pull request.
#' 
#' -   `describe_pull_request_events`,
#'     which returns information about one or more pull request events.
#' 
#' -   `evaluate_pull_request_approval_rules`,
#'     which evaluates whether a pull request has met all the conditions
#'     specified in its associated approval rules.
#' 
#' -   `get_comments_for_pull_request`,
#'     which returns information about comments on a specified pull
#'     request.
#' 
#' -   `get_pull_request`, which returns
#'     information about a specified pull request.
#' 
#' -   `get_pull_request_approval_states`,
#'     which returns information about the approval states for a specified
#'     pull request.
#' 
#' -   `get_pull_request_override_state`,
#'     which returns information about whether approval rules have been set
#'     aside (overriden) for a pull request, and if so, the Amazon Resource
#'     Name (ARN) of the user or identity that overrode the rules and their
#'     requirements for the pull request.
#' 
#' -   `list_pull_requests`, which lists
#'     all pull requests for a repository.
#' 
#' -   `merge_pull_request_by_fast_forward`,
#'     which merges the source destination branch of a pull request into
#'     the specified destination branch for that pull request using the
#'     fast-forward merge option.
#' 
#' -   `merge_pull_request_by_squash`,
#'     which merges the source destination branch of a pull request into
#'     the specified destination branch for that pull request using the
#'     squash merge option.
#' 
#' -   `merge_pull_request_by_three_way`,
#'     which merges the source destination branch of a pull request into
#'     the specified destination branch for that pull request using the
#'     three-way merge option.
#' 
#' -   `override_pull_request_approval_rules`,
#'     which sets aside all approval rule requirements for a pull request.
#' 
#' -   `post_comment_for_pull_request`,
#'     which posts a comment to a pull request at the specified line, file,
#'     or request.
#' 
#' -   `update_pull_request_approval_rule_content`,
#'     which updates the structure of an approval rule for a pull request.
#' 
#' -   `update_pull_request_approval_state`,
#'     which updates the state of an approval on a pull request.
#' 
#' -   `update_pull_request_description`,
#'     which updates the description of a pull request.
#' 
#' -   `update_pull_request_status`,
#'     which updates the status of a pull request.
#' 
#' -   `update_pull_request_title`,
#'     which updates the title of a pull request.
#' 
#' Approval rule templates, by calling the following:
#' 
#' -   `associate_approval_rule_template_with_repository`,
#'     which associates a template with a specified repository. After the
#'     template is associated with a repository, CodeCommit creates
#'     approval rules that match the template conditions on every pull
#'     request created in the specified repository.
#' 
#' -   `batch_associate_approval_rule_template_with_repositories`,
#'     which associates a template with one or more specified repositories.
#'     After the template is associated with a repository, CodeCommit
#'     creates approval rules that match the template conditions on every
#'     pull request created in the specified repositories.
#' 
#' -   `batch_disassociate_approval_rule_template_from_repositories`,
#'     which removes the association between a template and specified
#'     repositories so that approval rules based on the template are not
#'     automatically created when pull requests are created in those
#'     repositories.
#' 
#' -   `create_approval_rule_template`,
#'     which creates a template for approval rules that can then be
#'     associated with one or more repositories in your Amazon Web Services
#'     account.
#' 
#' -   `delete_approval_rule_template`,
#'     which deletes the specified template. It does not remove approval
#'     rules on pull requests already created with the template.
#' 
#' -   `disassociate_approval_rule_template_from_repository`,
#'     which removes the association between a template and a repository so
#'     that approval rules based on the template are not automatically
#'     created when pull requests are created in the specified repository.
#' 
#' -   `get_approval_rule_template`,
#'     which returns information about an approval rule template.
#' 
#' -   `list_approval_rule_templates`,
#'     which lists all approval rule templates in the Amazon Web Services
#'     Region in your Amazon Web Services account.
#' 
#' -   `list_associated_approval_rule_templates_for_repository`,
#'     which lists all approval rule templates that are associated with a
#'     specified repository.
#' 
#' -   `list_repositories_for_approval_rule_template`,
#'     which lists all repositories associated with the specified approval
#'     rule template.
#' 
#' -   `update_approval_rule_template_description`,
#'     which updates the description of an approval rule template.
#' 
#' -   `update_approval_rule_template_name`,
#'     which updates the name of an approval rule template.
#' 
#' -   `update_approval_rule_template_content`,
#'     which updates the content of an approval rule template.
#' 
#' Comments in a repository, by calling the following:
#' 
#' -   `delete_comment_content`, which
#'     deletes the content of a comment on a commit in a repository.
#' 
#' -   `get_comment`, which returns information
#'     about a comment on a commit.
#' 
#' -   `get_comment_reactions`, which
#'     returns information about emoji reactions to comments.
#' 
#' -   `get_comments_for_compared_commit`,
#'     which returns information about comments on the comparison between
#'     two commit specifiers in a repository.
#' 
#' -   `post_comment_for_compared_commit`,
#'     which creates a comment on the comparison between two commit
#'     specifiers in a repository.
#' 
#' -   `post_comment_reply`, which creates
#'     a reply to a comment.
#' 
#' -   `put_comment_reaction`, which
#'     creates or updates an emoji reaction to a comment.
#' 
#' -   `update_comment`, which updates the
#'     content of a comment on a commit in a repository.
#' 
#' Tags used to tag resources in CodeCommit (not Git tags), by calling the
#' following:
#' 
#' -   `list_tags_for_resource`, which
#'     gets information about Amazon Web Servicestags for a specified
#'     Amazon Resource Name (ARN) in CodeCommit.
#' 
#' -   `tag_resource`, which adds or updates
#'     tags for a resource in CodeCommit.
#' 
#' -   `untag_resource`, which removes tags
#'     for a resource in CodeCommit.
#' 
#' Triggers, by calling the following:
#' 
#' -   `get_repository_triggers`,
#'     which returns information about triggers configured for a
#'     repository.
#' 
#' -   `put_repository_triggers`,
#'     which replaces all triggers for a repository and can be used to
#'     create or delete triggers.
#' 
#' -   `test_repository_triggers`,
#'     which tests the functionality of a repository trigger by sending
#'     data to the trigger target.
#' 
#' For information about how to use CodeCommit, see the [CodeCommit User
#' Guide](https://docs.aws.amazon.com/codecommit/latest/userguide/welcome.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codecommit(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codecommit()
#' svc$associate_approval_rule_template_with_repository(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codecommit_associate_approval_rule_template_with_repository]{associate_approval_rule_template_with_repository} \tab Creates an association between an approval rule template and a specified repository\cr
#'  \link[paws.developer.tools:codecommit_batch_associate_approval_rule_template_with_repositories]{batch_associate_approval_rule_template_with_repositories} \tab Creates an association between an approval rule template and one or more specified repositories\cr
#'  \link[paws.developer.tools:codecommit_batch_describe_merge_conflicts]{batch_describe_merge_conflicts} \tab Returns information about one or more merge conflicts in the attempted merge of two commit specifiers using the squash or three-way merge strategy\cr
#'  \link[paws.developer.tools:codecommit_batch_disassociate_approval_rule_template_from_repositories]{batch_disassociate_approval_rule_template_from_repositories} \tab Removes the association between an approval rule template and one or more specified repositories\cr
#'  \link[paws.developer.tools:codecommit_batch_get_commits]{batch_get_commits} \tab Returns information about the contents of one or more commits in a repository\cr
#'  \link[paws.developer.tools:codecommit_batch_get_repositories]{batch_get_repositories} \tab Returns information about one or more repositories\cr
#'  \link[paws.developer.tools:codecommit_create_approval_rule_template]{create_approval_rule_template} \tab Creates a template for approval rules that can then be associated with one or more repositories in your Amazon Web Services account\cr
#'  \link[paws.developer.tools:codecommit_create_branch]{create_branch} \tab Creates a branch in a repository and points the branch to a commit\cr
#'  \link[paws.developer.tools:codecommit_create_commit]{create_commit} \tab Creates a commit for a repository on the tip of a specified branch\cr
#'  \link[paws.developer.tools:codecommit_create_pull_request]{create_pull_request} \tab Creates a pull request in the specified repository\cr
#'  \link[paws.developer.tools:codecommit_create_pull_request_approval_rule]{create_pull_request_approval_rule} \tab Creates an approval rule for a pull request\cr
#'  \link[paws.developer.tools:codecommit_create_repository]{create_repository} \tab Creates a new, empty repository\cr
#'  \link[paws.developer.tools:codecommit_create_unreferenced_merge_commit]{create_unreferenced_merge_commit} \tab Creates an unreferenced commit that represents the result of merging two branches using a specified merge strategy\cr
#'  \link[paws.developer.tools:codecommit_delete_approval_rule_template]{delete_approval_rule_template} \tab Deletes a specified approval rule template\cr
#'  \link[paws.developer.tools:codecommit_delete_branch]{delete_branch} \tab Deletes a branch from a repository, unless that branch is the default branch for the repository\cr
#'  \link[paws.developer.tools:codecommit_delete_comment_content]{delete_comment_content} \tab Deletes the content of a comment made on a change, file, or commit in a repository\cr
#'  \link[paws.developer.tools:codecommit_delete_file]{delete_file} \tab Deletes a specified file from a specified branch\cr
#'  \link[paws.developer.tools:codecommit_delete_pull_request_approval_rule]{delete_pull_request_approval_rule} \tab Deletes an approval rule from a specified pull request\cr
#'  \link[paws.developer.tools:codecommit_delete_repository]{delete_repository} \tab Deletes a repository\cr
#'  \link[paws.developer.tools:codecommit_describe_merge_conflicts]{describe_merge_conflicts} \tab Returns information about one or more merge conflicts in the attempted merge of two commit specifiers using the squash or three-way merge strategy\cr
#'  \link[paws.developer.tools:codecommit_describe_pull_request_events]{describe_pull_request_events} \tab Returns information about one or more pull request events\cr
#'  \link[paws.developer.tools:codecommit_disassociate_approval_rule_template_from_repository]{disassociate_approval_rule_template_from_repository} \tab Removes the association between a template and a repository so that approval rules based on the template are not automatically created when pull requests are created in the specified repository\cr
#'  \link[paws.developer.tools:codecommit_evaluate_pull_request_approval_rules]{evaluate_pull_request_approval_rules} \tab Evaluates whether a pull request has met all the conditions specified in its associated approval rules\cr
#'  \link[paws.developer.tools:codecommit_get_approval_rule_template]{get_approval_rule_template} \tab Returns information about a specified approval rule template\cr
#'  \link[paws.developer.tools:codecommit_get_blob]{get_blob} \tab Returns the base-64 encoded content of an individual blob in a repository\cr
#'  \link[paws.developer.tools:codecommit_get_branch]{get_branch} \tab Returns information about a repository branch, including its name and the last commit ID\cr
#'  \link[paws.developer.tools:codecommit_get_comment]{get_comment} \tab Returns the content of a comment made on a change, file, or commit in a repository\cr
#'  \link[paws.developer.tools:codecommit_get_comment_reactions]{get_comment_reactions} \tab Returns information about reactions to a specified comment ID\cr
#'  \link[paws.developer.tools:codecommit_get_comments_for_compared_commit]{get_comments_for_compared_commit} \tab Returns information about comments made on the comparison between two commits\cr
#'  \link[paws.developer.tools:codecommit_get_comments_for_pull_request]{get_comments_for_pull_request} \tab Returns comments made on a pull request\cr
#'  \link[paws.developer.tools:codecommit_get_commit]{get_commit} \tab Returns information about a commit, including commit message and committer information\cr
#'  \link[paws.developer.tools:codecommit_get_differences]{get_differences} \tab Returns information about the differences in a valid commit specifier (such as a branch, tag, HEAD, commit ID, or other fully qualified reference)\cr
#'  \link[paws.developer.tools:codecommit_get_file]{get_file} \tab Returns the base-64 encoded contents of a specified file and its metadata\cr
#'  \link[paws.developer.tools:codecommit_get_folder]{get_folder} \tab Returns the contents of a specified folder in a repository\cr
#'  \link[paws.developer.tools:codecommit_get_merge_commit]{get_merge_commit} \tab Returns information about a specified merge commit\cr
#'  \link[paws.developer.tools:codecommit_get_merge_conflicts]{get_merge_conflicts} \tab Returns information about merge conflicts between the before and after commit IDs for a pull request in a repository\cr
#'  \link[paws.developer.tools:codecommit_get_merge_options]{get_merge_options} \tab Returns information about the merge options available for merging two specified branches\cr
#'  \link[paws.developer.tools:codecommit_get_pull_request]{get_pull_request} \tab Gets information about a pull request in a specified repository\cr
#'  \link[paws.developer.tools:codecommit_get_pull_request_approval_states]{get_pull_request_approval_states} \tab Gets information about the approval states for a specified pull request\cr
#'  \link[paws.developer.tools:codecommit_get_pull_request_override_state]{get_pull_request_override_state} \tab Returns information about whether approval rules have been set aside (overridden) for a pull request, and if so, the Amazon Resource Name (ARN) of the user or identity that overrode the rules and their requirements for the pull request\cr
#'  \link[paws.developer.tools:codecommit_get_repository]{get_repository} \tab Returns information about a repository\cr
#'  \link[paws.developer.tools:codecommit_get_repository_triggers]{get_repository_triggers} \tab Gets information about triggers configured for a repository\cr
#'  \link[paws.developer.tools:codecommit_list_approval_rule_templates]{list_approval_rule_templates} \tab Lists all approval rule templates in the specified Amazon Web Services Region in your Amazon Web Services account\cr
#'  \link[paws.developer.tools:codecommit_list_associated_approval_rule_templates_for_repository]{list_associated_approval_rule_templates_for_repository} \tab Lists all approval rule templates that are associated with a specified repository\cr
#'  \link[paws.developer.tools:codecommit_list_branches]{list_branches} \tab Gets information about one or more branches in a repository\cr
#'  \link[paws.developer.tools:codecommit_list_file_commit_history]{list_file_commit_history} \tab Retrieves a list of commits and changes to a specified file\cr
#'  \link[paws.developer.tools:codecommit_list_pull_requests]{list_pull_requests} \tab Returns a list of pull requests for a specified repository\cr
#'  \link[paws.developer.tools:codecommit_list_repositories]{list_repositories} \tab Gets information about one or more repositories\cr
#'  \link[paws.developer.tools:codecommit_list_repositories_for_approval_rule_template]{list_repositories_for_approval_rule_template} \tab Lists all repositories associated with the specified approval rule template\cr
#'  \link[paws.developer.tools:codecommit_list_tags_for_resource]{list_tags_for_resource} \tab Gets information about Amazon Web Servicestags for a specified Amazon Resource Name (ARN) in CodeCommit\cr
#'  \link[paws.developer.tools:codecommit_merge_branches_by_fast_forward]{merge_branches_by_fast_forward} \tab Merges two branches using the fast-forward merge strategy\cr
#'  \link[paws.developer.tools:codecommit_merge_branches_by_squash]{merge_branches_by_squash} \tab Merges two branches using the squash merge strategy\cr
#'  \link[paws.developer.tools:codecommit_merge_branches_by_three_way]{merge_branches_by_three_way} \tab Merges two specified branches using the three-way merge strategy\cr
#'  \link[paws.developer.tools:codecommit_merge_pull_request_by_fast_forward]{merge_pull_request_by_fast_forward} \tab Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the fast-forward merge strategy\cr
#'  \link[paws.developer.tools:codecommit_merge_pull_request_by_squash]{merge_pull_request_by_squash} \tab Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the squash merge strategy\cr
#'  \link[paws.developer.tools:codecommit_merge_pull_request_by_three_way]{merge_pull_request_by_three_way} \tab Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the three-way merge strategy\cr
#'  \link[paws.developer.tools:codecommit_override_pull_request_approval_rules]{override_pull_request_approval_rules} \tab Sets aside (overrides) all approval rule requirements for a specified pull request\cr
#'  \link[paws.developer.tools:codecommit_post_comment_for_compared_commit]{post_comment_for_compared_commit} \tab Posts a comment on the comparison between two commits\cr
#'  \link[paws.developer.tools:codecommit_post_comment_for_pull_request]{post_comment_for_pull_request} \tab Posts a comment on a pull request\cr
#'  \link[paws.developer.tools:codecommit_post_comment_reply]{post_comment_reply} \tab Posts a comment in reply to an existing comment on a comparison between commits or a pull request\cr
#'  \link[paws.developer.tools:codecommit_put_comment_reaction]{put_comment_reaction} \tab Adds or updates a reaction to a specified comment for the user whose identity is used to make the request\cr
#'  \link[paws.developer.tools:codecommit_put_file]{put_file} \tab Adds or updates a file in a branch in an CodeCommit repository, and generates a commit for the addition in the specified branch\cr
#'  \link[paws.developer.tools:codecommit_put_repository_triggers]{put_repository_triggers} \tab Replaces all triggers for a repository\cr
#'  \link[paws.developer.tools:codecommit_tag_resource]{tag_resource} \tab Adds or updates tags for a resource in CodeCommit\cr
#'  \link[paws.developer.tools:codecommit_test_repository_triggers]{test_repository_triggers} \tab Tests the functionality of repository triggers by sending information to the trigger target\cr
#'  \link[paws.developer.tools:codecommit_untag_resource]{untag_resource} \tab Removes tags for a resource in CodeCommit\cr
#'  \link[paws.developer.tools:codecommit_update_approval_rule_template_content]{update_approval_rule_template_content} \tab Updates the content of an approval rule template\cr
#'  \link[paws.developer.tools:codecommit_update_approval_rule_template_description]{update_approval_rule_template_description} \tab Updates the description for a specified approval rule template\cr
#'  \link[paws.developer.tools:codecommit_update_approval_rule_template_name]{update_approval_rule_template_name} \tab Updates the name of a specified approval rule template\cr
#'  \link[paws.developer.tools:codecommit_update_comment]{update_comment} \tab Replaces the contents of a comment\cr
#'  \link[paws.developer.tools:codecommit_update_default_branch]{update_default_branch} \tab Sets or changes the default branch name for the specified repository\cr
#'  \link[paws.developer.tools:codecommit_update_pull_request_approval_rule_content]{update_pull_request_approval_rule_content} \tab Updates the structure of an approval rule created specifically for a pull request\cr
#'  \link[paws.developer.tools:codecommit_update_pull_request_approval_state]{update_pull_request_approval_state} \tab Updates the state of a user's approval on a pull request\cr
#'  \link[paws.developer.tools:codecommit_update_pull_request_description]{update_pull_request_description} \tab Replaces the contents of the description of a pull request\cr
#'  \link[paws.developer.tools:codecommit_update_pull_request_status]{update_pull_request_status} \tab Updates the status of a pull request\cr
#'  \link[paws.developer.tools:codecommit_update_pull_request_title]{update_pull_request_title} \tab Replaces the title of a pull request\cr
#'  \link[paws.developer.tools:codecommit_update_repository_description]{update_repository_description} \tab Sets or changes the comment or description for a repository\cr
#'  \link[paws.developer.tools:codecommit_update_repository_encryption_key]{update_repository_encryption_key} \tab Updates the Key Management Service encryption key used to encrypt and decrypt a CodeCommit repository\cr
#'  \link[paws.developer.tools:codecommit_update_repository_name]{update_repository_name} \tab Renames a repository
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codecommit
#' @export
codecommit <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codecommit(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CodeCatalyst
#'
#' @description
#' Welcome to the Amazon CodeCatalyst API reference. This reference
#' provides descriptions of operations and data types for Amazon
#' CodeCatalyst. You can use the Amazon CodeCatalyst API to work with the
#' following objects.
#' 
#' Spaces, by calling the following:
#' 
#' -   `delete_space`, which deletes a space.
#' 
#' -   `get_space`, which returns information
#'     about a space.
#' 
#' -   `get_subscription`, which returns
#'     information about the Amazon Web Services account used for billing
#'     purposes and the billing plan for the space.
#' 
#' -   `list_spaces`, which retrieves a list of
#'     spaces.
#' 
#' -   `update_space`, which changes one or
#'     more values for a space.
#' 
#' Projects, by calling the following:
#' 
#' -   `create_project` which creates a
#'     project in a specified space.
#' 
#' -   `get_project`, which returns information
#'     about a project.
#' 
#' -   `list_projects`, which retrieves a
#'     list of projects in a space.
#' 
#' Users, by calling the following:
#' 
#' -   `get_user_details`, which returns
#'     information about a user in Amazon CodeCatalyst.
#' 
#' Source repositories, by calling the following:
#' 
#' -   `create_source_repository`,
#'     which creates an empty Git-based source repository in a specified
#'     project.
#' 
#' -   `create_source_repository_branch`,
#'     which creates a branch in a specified repository where you can work
#'     on code.
#' 
#' -   `delete_source_repository`,
#'     which deletes a source repository.
#' 
#' -   `get_source_repository`, which
#'     returns information about a source repository.
#' 
#' -   `get_source_repository_clone_urls`,
#'     which returns information about the URLs that can be used with a Git
#'     client to clone a source repository.
#' 
#' -   `list_source_repositories`,
#'     which retrieves a list of source repositories in a project.
#' 
#' -   `list_source_repository_branches`,
#'     which retrieves a list of branches in a source repository.
#' 
#' Dev Environments and the Amazon Web Services Toolkits, by calling the
#' following:
#' 
#' -   `create_dev_environment`,
#'     which creates a Dev Environment, where you can quickly work on the
#'     code stored in the source repositories of your project.
#' 
#' -   `delete_dev_environment`,
#'     which deletes a Dev Environment.
#' 
#' -   `get_dev_environment`, which
#'     returns information about a Dev Environment.
#' 
#' -   `list_dev_environments`, which
#'     retrieves a list of Dev Environments in a project.
#' 
#' -   `list_dev_environment_sessions`,
#'     which retrieves a list of active Dev Environment sessions in a
#'     project.
#' 
#' -   `start_dev_environment`, which
#'     starts a specified Dev Environment and puts it into an active state.
#' 
#' -   `start_dev_environment_session`,
#'     which starts a session to a specified Dev Environment.
#' 
#' -   `stop_dev_environment`, which
#'     stops a specified Dev Environment and puts it into an stopped state.
#' 
#' -   `stop_dev_environment_session`,
#'     which stops a session for a specified Dev Environment.
#' 
#' -   `update_dev_environment`,
#'     which changes one or more values for a Dev Environment.
#' 
#' Workflows, by calling the following:
#' 
#' -   `get_workflow`, which returns
#'     information about a workflow.
#' 
#' -   `get_workflow_run`, which returns
#'     information about a specified run of a workflow.
#' 
#' -   `list_workflow_runs`, which
#'     retrieves a list of runs of a specified workflow.
#' 
#' -   `list_workflows`, which retrieves a
#'     list of workflows in a specified project.
#' 
#' -   `start_workflow_run`, which
#'     starts a run of a specified workflow.
#' 
#' Security, activity, and resource management in Amazon CodeCatalyst, by
#' calling the following:
#' 
#' -   `create_access_token`, which
#'     creates a personal access token (PAT) for the current user.
#' 
#' -   `delete_access_token`, which
#'     deletes a specified personal access token (PAT).
#' 
#' -   `list_access_tokens`, which lists
#'     all personal access tokens (PATs) associated with a user.
#' 
#' -   `list_event_logs`, which retrieves a
#'     list of events that occurred during a specified time period in a
#'     space.
#' 
#' -   `verify_session`, which verifies
#'     whether the calling user has a valid Amazon CodeCatalyst login and
#'     session.
#' 
#' If you are using the Amazon CodeCatalyst APIs with an SDK or the CLI,
#' you must configure your computer to work with Amazon CodeCatalyst and
#' single sign-on (SSO). For more information, see [Setting up to use the
#' CLI with Amazon
#' CodeCatalyst](https://docs.aws.amazon.com/codecatalyst/latest/userguide/set-up-cli.html)
#' and the SSO documentation for your SDK.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codecatalyst(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codecatalyst()
#' svc$create_access_token(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codecatalyst_create_access_token]{create_access_token} \tab Creates a personal access token (PAT) for the current user\cr
#'  \link[paws.developer.tools:codecatalyst_create_dev_environment]{create_dev_environment} \tab Creates a Dev Environment in Amazon CodeCatalyst, a cloud-based development environment that you can use to quickly work on the code stored in the source repositories of your project\cr
#'  \link[paws.developer.tools:codecatalyst_create_project]{create_project} \tab Creates a project in a specified space\cr
#'  \link[paws.developer.tools:codecatalyst_create_source_repository]{create_source_repository} \tab Creates an empty Git-based source repository in a specified project\cr
#'  \link[paws.developer.tools:codecatalyst_create_source_repository_branch]{create_source_repository_branch} \tab Creates a branch in a specified source repository in Amazon CodeCatalyst\cr
#'  \link[paws.developer.tools:codecatalyst_delete_access_token]{delete_access_token} \tab Deletes a specified personal access token (PAT)\cr
#'  \link[paws.developer.tools:codecatalyst_delete_dev_environment]{delete_dev_environment} \tab Deletes a Dev Environment\cr
#'  \link[paws.developer.tools:codecatalyst_delete_project]{delete_project} \tab Deletes a project in a space\cr
#'  \link[paws.developer.tools:codecatalyst_delete_source_repository]{delete_source_repository} \tab Deletes a source repository in Amazon CodeCatalyst\cr
#'  \link[paws.developer.tools:codecatalyst_delete_space]{delete_space} \tab Deletes a space\cr
#'  \link[paws.developer.tools:codecatalyst_get_dev_environment]{get_dev_environment} \tab Returns information about a Dev Environment for a source repository in a project\cr
#'  \link[paws.developer.tools:codecatalyst_get_project]{get_project} \tab Returns information about a project\cr
#'  \link[paws.developer.tools:codecatalyst_get_source_repository]{get_source_repository} \tab Returns information about a source repository\cr
#'  \link[paws.developer.tools:codecatalyst_get_source_repository_clone_urls]{get_source_repository_clone_urls} \tab Returns information about the URLs that can be used with a Git client to clone a source repository\cr
#'  \link[paws.developer.tools:codecatalyst_get_space]{get_space} \tab Returns information about an space\cr
#'  \link[paws.developer.tools:codecatalyst_get_subscription]{get_subscription} \tab Returns information about the Amazon Web Services account used for billing purposes and the billing plan for the space\cr
#'  \link[paws.developer.tools:codecatalyst_get_user_details]{get_user_details} \tab Returns information about a user\cr
#'  \link[paws.developer.tools:codecatalyst_get_workflow]{get_workflow} \tab Returns information about a workflow\cr
#'  \link[paws.developer.tools:codecatalyst_get_workflow_run]{get_workflow_run} \tab Returns information about a specified run of a workflow\cr
#'  \link[paws.developer.tools:codecatalyst_list_access_tokens]{list_access_tokens} \tab Lists all personal access tokens (PATs) associated with the user who calls the API\cr
#'  \link[paws.developer.tools:codecatalyst_list_dev_environments]{list_dev_environments} \tab Retrieves a list of Dev Environments in a project\cr
#'  \link[paws.developer.tools:codecatalyst_list_dev_environment_sessions]{list_dev_environment_sessions} \tab Retrieves a list of active sessions for a Dev Environment in a project\cr
#'  \link[paws.developer.tools:codecatalyst_list_event_logs]{list_event_logs} \tab Retrieves a list of events that occurred during a specific time in a space\cr
#'  \link[paws.developer.tools:codecatalyst_list_projects]{list_projects} \tab Retrieves a list of projects\cr
#'  \link[paws.developer.tools:codecatalyst_list_source_repositories]{list_source_repositories} \tab Retrieves a list of source repositories in a project\cr
#'  \link[paws.developer.tools:codecatalyst_list_source_repository_branches]{list_source_repository_branches} \tab Retrieves a list of branches in a specified source repository\cr
#'  \link[paws.developer.tools:codecatalyst_list_spaces]{list_spaces} \tab Retrieves a list of spaces\cr
#'  \link[paws.developer.tools:codecatalyst_list_workflow_runs]{list_workflow_runs} \tab Retrieves a list of workflow runs of a specified workflow\cr
#'  \link[paws.developer.tools:codecatalyst_list_workflows]{list_workflows} \tab Retrieves a list of workflows in a specified project\cr
#'  \link[paws.developer.tools:codecatalyst_start_dev_environment]{start_dev_environment} \tab Starts a specified Dev Environment and puts it into an active state\cr
#'  \link[paws.developer.tools:codecatalyst_start_dev_environment_session]{start_dev_environment_session} \tab Starts a session for a specified Dev Environment\cr
#'  \link[paws.developer.tools:codecatalyst_start_workflow_run]{start_workflow_run} \tab Begins a run of a specified workflow\cr
#'  \link[paws.developer.tools:codecatalyst_stop_dev_environment]{stop_dev_environment} \tab Pauses a specified Dev Environment and places it in a non-running state\cr
#'  \link[paws.developer.tools:codecatalyst_stop_dev_environment_session]{stop_dev_environment_session} \tab Stops a session for a specified Dev Environment\cr
#'  \link[paws.developer.tools:codecatalyst_update_dev_environment]{update_dev_environment} \tab Changes one or more values for a Dev Environment\cr
#'  \link[paws.developer.tools:codecatalyst_update_project]{update_project} \tab Changes one or more values for a project\cr
#'  \link[paws.developer.tools:codecatalyst_update_space]{update_space} \tab Changes one or more values for a space\cr
#'  \link[paws.developer.tools:codecatalyst_verify_session]{verify_session} \tab Verifies whether the calling user has a valid Amazon CodeCatalyst login and session
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codecatalyst
#' @export
codecatalyst <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codecatalyst(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CodeDeploy
#'
#' @description
#' CodeDeploy is a deployment service that automates application
#' deployments to Amazon EC2 instances, on-premises instances running in
#' your own facility, serverless Lambda functions, or applications in an
#' Amazon ECS service.
#' 
#' You can deploy a nearly unlimited variety of application content, such
#' as an updated Lambda function, updated applications in an Amazon ECS
#' service, code, web and configuration files, executables, packages,
#' scripts, multimedia files, and so on. CodeDeploy can deploy application
#' content stored in Amazon S3 buckets, GitHub repositories, or Bitbucket
#' repositories. You do not need to make changes to your existing code
#' before you can use CodeDeploy.
#' 
#' CodeDeploy makes it easier for you to rapidly release new features,
#' helps you avoid downtime during application deployment, and handles the
#' complexity of updating your applications, without many of the risks
#' associated with error-prone manual deployments.
#' 
#' **CodeDeploy Components**
#' 
#' Use the information in this guide to help you work with the following
#' CodeDeploy components:
#' 
#' -   **Application**: A name that uniquely identifies the application you
#'     want to deploy. CodeDeploy uses this name, which functions as a
#'     container, to ensure the correct combination of revision, deployment
#'     configuration, and deployment group are referenced during a
#'     deployment.
#' 
#' -   **Deployment group**: A set of individual instances, CodeDeploy
#'     Lambda deployment configuration settings, or an Amazon ECS service
#'     and network details. A Lambda deployment group specifies how to
#'     route traffic to a new version of a Lambda function. An Amazon ECS
#'     deployment group specifies the service created in Amazon ECS to
#'     deploy, a load balancer, and a listener to reroute production
#'     traffic to an updated containerized application. An Amazon
#'     EC2/On-premises deployment group contains individually tagged
#'     instances, Amazon EC2 instances in Amazon EC2 Auto Scaling groups,
#'     or both. All deployment groups can specify optional trigger, alarm,
#'     and rollback settings.
#' 
#' -   **Deployment configuration**: A set of deployment rules and
#'     deployment success and failure conditions used by CodeDeploy during
#'     a deployment.
#' 
#' -   **Deployment**: The process and the components used when updating a
#'     Lambda function, a containerized application in an Amazon ECS
#'     service, or of installing content on one or more instances.
#' 
#' -   **Application revisions**: For an Lambda deployment, this is an
#'     AppSpec file that specifies the Lambda function to be updated and
#'     one or more functions to validate deployment lifecycle events. For
#'     an Amazon ECS deployment, this is an AppSpec file that specifies the
#'     Amazon ECS task definition, container, and port where production
#'     traffic is rerouted. For an EC2/On-premises deployment, this is an
#'     archive file that contains source content—source code, webpages,
#'     executable files, and deployment scripts—along with an AppSpec file.
#'     Revisions are stored in Amazon S3 buckets or GitHub repositories.
#'     For Amazon S3, a revision is uniquely identified by its Amazon S3
#'     object key and its ETag, version, or both. For GitHub, a revision is
#'     uniquely identified by its commit ID.
#' 
#' This guide also contains information to help you get details about the
#' instances in your deployments, to make on-premises instances available
#' for CodeDeploy deployments, to get details about a Lambda function
#' deployment, and to get details about Amazon ECS service deployments.
#' 
#' **CodeDeploy Information Resources**
#' 
#' -   [CodeDeploy User
#'     Guide](https://docs.aws.amazon.com/codedeploy/latest/userguide/)
#' 
#' -   [CodeDeploy API Reference
#'     Guide](https://docs.aws.amazon.com/codedeploy/latest/APIReference/)
#' 
#' -   [CLI Reference for
#'     CodeDeploy](https://docs.aws.amazon.com/cli/latest/reference/deploy/)
#' 
#' -   CodeDeploy Developer Forum
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codedeploy(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codedeploy()
#' svc$add_tags_to_on_premises_instances(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codedeploy_add_tags_to_on_premises_instances]{add_tags_to_on_premises_instances} \tab Adds tags to on-premises instances\cr
#'  \link[paws.developer.tools:codedeploy_batch_get_application_revisions]{batch_get_application_revisions} \tab Gets information about one or more application revisions\cr
#'  \link[paws.developer.tools:codedeploy_batch_get_applications]{batch_get_applications} \tab Gets information about one or more applications\cr
#'  \link[paws.developer.tools:codedeploy_batch_get_deployment_groups]{batch_get_deployment_groups} \tab Gets information about one or more deployment groups\cr
#'  \link[paws.developer.tools:codedeploy_batch_get_deployment_instances]{batch_get_deployment_instances} \tab This method works, but is deprecated\cr
#'  \link[paws.developer.tools:codedeploy_batch_get_deployments]{batch_get_deployments} \tab Gets information about one or more deployments\cr
#'  \link[paws.developer.tools:codedeploy_batch_get_deployment_targets]{batch_get_deployment_targets} \tab Returns an array of one or more targets associated with a deployment\cr
#'  \link[paws.developer.tools:codedeploy_batch_get_on_premises_instances]{batch_get_on_premises_instances} \tab Gets information about one or more on-premises instances\cr
#'  \link[paws.developer.tools:codedeploy_continue_deployment]{continue_deployment} \tab For a blue/green deployment, starts the process of rerouting traffic from instances in the original environment to instances in the replacement environment without waiting for a specified wait time to elapse\cr
#'  \link[paws.developer.tools:codedeploy_create_application]{create_application} \tab Creates an application\cr
#'  \link[paws.developer.tools:codedeploy_create_deployment]{create_deployment} \tab Deploys an application revision through the specified deployment group\cr
#'  \link[paws.developer.tools:codedeploy_create_deployment_config]{create_deployment_config} \tab Creates a deployment configuration\cr
#'  \link[paws.developer.tools:codedeploy_create_deployment_group]{create_deployment_group} \tab Creates a deployment group to which application revisions are deployed\cr
#'  \link[paws.developer.tools:codedeploy_delete_application]{delete_application} \tab Deletes an application\cr
#'  \link[paws.developer.tools:codedeploy_delete_deployment_config]{delete_deployment_config} \tab Deletes a deployment configuration\cr
#'  \link[paws.developer.tools:codedeploy_delete_deployment_group]{delete_deployment_group} \tab Deletes a deployment group\cr
#'  \link[paws.developer.tools:codedeploy_delete_git_hub_account_token]{delete_git_hub_account_token} \tab Deletes a GitHub account connection\cr
#'  \link[paws.developer.tools:codedeploy_delete_resources_by_external_id]{delete_resources_by_external_id} \tab Deletes resources linked to an external ID\cr
#'  \link[paws.developer.tools:codedeploy_deregister_on_premises_instance]{deregister_on_premises_instance} \tab Deregisters an on-premises instance\cr
#'  \link[paws.developer.tools:codedeploy_get_application]{get_application} \tab Gets information about an application\cr
#'  \link[paws.developer.tools:codedeploy_get_application_revision]{get_application_revision} \tab Gets information about an application revision\cr
#'  \link[paws.developer.tools:codedeploy_get_deployment]{get_deployment} \tab Gets information about a deployment\cr
#'  \link[paws.developer.tools:codedeploy_get_deployment_config]{get_deployment_config} \tab Gets information about a deployment configuration\cr
#'  \link[paws.developer.tools:codedeploy_get_deployment_group]{get_deployment_group} \tab Gets information about a deployment group\cr
#'  \link[paws.developer.tools:codedeploy_get_deployment_instance]{get_deployment_instance} \tab Gets information about an instance as part of a deployment\cr
#'  \link[paws.developer.tools:codedeploy_get_deployment_target]{get_deployment_target} \tab Returns information about a deployment target\cr
#'  \link[paws.developer.tools:codedeploy_get_on_premises_instance]{get_on_premises_instance} \tab Gets information about an on-premises instance\cr
#'  \link[paws.developer.tools:codedeploy_list_application_revisions]{list_application_revisions} \tab Lists information about revisions for an application\cr
#'  \link[paws.developer.tools:codedeploy_list_applications]{list_applications} \tab Lists the applications registered with the user or Amazon Web Services account\cr
#'  \link[paws.developer.tools:codedeploy_list_deployment_configs]{list_deployment_configs} \tab Lists the deployment configurations with the user or Amazon Web Services account\cr
#'  \link[paws.developer.tools:codedeploy_list_deployment_groups]{list_deployment_groups} \tab Lists the deployment groups for an application registered with the Amazon Web Services user or Amazon Web Services account\cr
#'  \link[paws.developer.tools:codedeploy_list_deployment_instances]{list_deployment_instances} \tab The newer BatchGetDeploymentTargets should be used instead because it works with all compute types\cr
#'  \link[paws.developer.tools:codedeploy_list_deployments]{list_deployments} \tab Lists the deployments in a deployment group for an application registered with the user or Amazon Web Services account\cr
#'  \link[paws.developer.tools:codedeploy_list_deployment_targets]{list_deployment_targets} \tab Returns an array of target IDs that are associated a deployment\cr
#'  \link[paws.developer.tools:codedeploy_list_git_hub_account_token_names]{list_git_hub_account_token_names} \tab Lists the names of stored connections to GitHub accounts\cr
#'  \link[paws.developer.tools:codedeploy_list_on_premises_instances]{list_on_premises_instances} \tab Gets a list of names for one or more on-premises instances\cr
#'  \link[paws.developer.tools:codedeploy_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags for the resource identified by a specified Amazon Resource Name (ARN)\cr
#'  \link[paws.developer.tools:codedeploy_put_lifecycle_event_hook_execution_status]{put_lifecycle_event_hook_execution_status} \tab Sets the result of a Lambda validation function\cr
#'  \link[paws.developer.tools:codedeploy_register_application_revision]{register_application_revision} \tab Registers with CodeDeploy a revision for the specified application\cr
#'  \link[paws.developer.tools:codedeploy_register_on_premises_instance]{register_on_premises_instance} \tab Registers an on-premises instance\cr
#'  \link[paws.developer.tools:codedeploy_remove_tags_from_on_premises_instances]{remove_tags_from_on_premises_instances} \tab Removes one or more tags from one or more on-premises instances\cr
#'  \link[paws.developer.tools:codedeploy_skip_wait_time_for_instance_termination]{skip_wait_time_for_instance_termination} \tab In a blue/green deployment, overrides any specified wait time and starts terminating instances immediately after the traffic routing is complete\cr
#'  \link[paws.developer.tools:codedeploy_stop_deployment]{stop_deployment} \tab Attempts to stop an ongoing deployment\cr
#'  \link[paws.developer.tools:codedeploy_tag_resource]{tag_resource} \tab Associates the list of tags in the input Tags parameter with the resource identified by the ResourceArn input parameter\cr
#'  \link[paws.developer.tools:codedeploy_untag_resource]{untag_resource} \tab Disassociates a resource from a list of tags\cr
#'  \link[paws.developer.tools:codedeploy_update_application]{update_application} \tab Changes the name of an application\cr
#'  \link[paws.developer.tools:codedeploy_update_deployment_group]{update_deployment_group} \tab Changes information about a deployment group
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codedeploy
#' @export
codedeploy <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codedeploy(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CodeGuru Profiler
#'
#' @description
#' This section provides documentation for the Amazon CodeGuru Profiler API
#' operations.
#' 
#' Amazon CodeGuru Profiler collects runtime performance data from your
#' live applications, and provides recommendations that can help you
#' fine-tune your application performance. Using machine learning
#' algorithms, CodeGuru Profiler can help you find your most expensive
#' lines of code and suggest ways you can improve efficiency and remove CPU
#' bottlenecks.
#' 
#' Amazon CodeGuru Profiler provides different visualizations of profiling
#' data to help you identify what code is running on the CPU, see how much
#' time is consumed, and suggest ways to reduce CPU utilization.
#' 
#' Amazon CodeGuru Profiler currently supports applications written in all
#' Java virtual machine (JVM) languages and Python. While CodeGuru Profiler
#' supports both visualizations and recommendations for applications
#' written in Java, it can also generate visualizations and a subset of
#' recommendations for applications written in other JVM languages and
#' Python.
#' 
#' For more information, see [What is Amazon CodeGuru
#' Profiler](https://docs.aws.amazon.com/codeguru/latest/profiler-ug/what-is-codeguru-profiler.html)
#' in the *Amazon CodeGuru Profiler User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codeguruprofiler(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codeguruprofiler()
#' svc$add_notification_channels(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codeguruprofiler_add_notification_channels]{add_notification_channels} \tab Add up to 2 anomaly notifications channels for a profiling group\cr
#'  \link[paws.developer.tools:codeguruprofiler_batch_get_frame_metric_data]{batch_get_frame_metric_data} \tab Returns the time series of values for a requested list of frame metrics from a time period\cr
#'  \link[paws.developer.tools:codeguruprofiler_configure_agent]{configure_agent} \tab Used by profiler agents to report their current state and to receive remote configuration updates\cr
#'  \link[paws.developer.tools:codeguruprofiler_create_profiling_group]{create_profiling_group} \tab Creates a profiling group\cr
#'  \link[paws.developer.tools:codeguruprofiler_delete_profiling_group]{delete_profiling_group} \tab Deletes a profiling group\cr
#'  \link[paws.developer.tools:codeguruprofiler_describe_profiling_group]{describe_profiling_group} \tab Returns a ProfilingGroupDescription object that contains information about the requested profiling group\cr
#'  \link[paws.developer.tools:codeguruprofiler_get_findings_report_account_summary]{get_findings_report_account_summary} \tab Returns a list of FindingsReportSummary objects that contain analysis results for all profiling groups in your AWS account\cr
#'  \link[paws.developer.tools:codeguruprofiler_get_notification_configuration]{get_notification_configuration} \tab Get the current configuration for anomaly notifications for a profiling group\cr
#'  \link[paws.developer.tools:codeguruprofiler_get_policy]{get_policy} \tab Returns the JSON-formatted resource-based policy on a profiling group\cr
#'  \link[paws.developer.tools:codeguruprofiler_get_profile]{get_profile} \tab Gets the aggregated profile of a profiling group for a specified time range\cr
#'  \link[paws.developer.tools:codeguruprofiler_get_recommendations]{get_recommendations} \tab Returns a list of Recommendation objects that contain recommendations for a profiling group for a given time period\cr
#'  \link[paws.developer.tools:codeguruprofiler_list_findings_reports]{list_findings_reports} \tab List the available reports for a given profiling group and time range\cr
#'  \link[paws.developer.tools:codeguruprofiler_list_profile_times]{list_profile_times} \tab Lists the start times of the available aggregated profiles of a profiling group for an aggregation period within the specified time range\cr
#'  \link[paws.developer.tools:codeguruprofiler_list_profiling_groups]{list_profiling_groups} \tab Returns a list of profiling groups\cr
#'  \link[paws.developer.tools:codeguruprofiler_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of the tags that are assigned to a specified resource\cr
#'  \link[paws.developer.tools:codeguruprofiler_post_agent_profile]{post_agent_profile} \tab Submits profiling data to an aggregated profile of a profiling group\cr
#'  \link[paws.developer.tools:codeguruprofiler_put_permission]{put_permission} \tab Adds permissions to a profiling group's resource-based policy that are provided using an action group\cr
#'  \link[paws.developer.tools:codeguruprofiler_remove_notification_channel]{remove_notification_channel} \tab Remove one anomaly notifications channel for a profiling group\cr
#'  \link[paws.developer.tools:codeguruprofiler_remove_permission]{remove_permission} \tab Removes permissions from a profiling group's resource-based policy that are provided using an action group\cr
#'  \link[paws.developer.tools:codeguruprofiler_submit_feedback]{submit_feedback} \tab Sends feedback to CodeGuru Profiler about whether the anomaly detected by the analysis is useful or not\cr
#'  \link[paws.developer.tools:codeguruprofiler_tag_resource]{tag_resource} \tab Use to assign one or more tags to a resource\cr
#'  \link[paws.developer.tools:codeguruprofiler_untag_resource]{untag_resource} \tab Use to remove one or more tags from a resource\cr
#'  \link[paws.developer.tools:codeguruprofiler_update_profiling_group]{update_profiling_group} \tab Updates a profiling group
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codeguruprofiler
#' @export
codeguruprofiler <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codeguruprofiler(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CodeGuru Reviewer
#'
#' @description
#' This section provides documentation for the Amazon CodeGuru Reviewer API
#' operations. CodeGuru Reviewer is a service that uses program analysis
#' and machine learning to detect potential defects that are difficult for
#' developers to find and recommends fixes in your Java and Python code.
#' 
#' By proactively detecting and providing recommendations for addressing
#' code defects and implementing best practices, CodeGuru Reviewer improves
#' the overall quality and maintainability of your code base during the
#' code review stage. For more information about CodeGuru Reviewer, see the
#' *\href{https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/welcome.html}{Amazon CodeGuru Reviewer User Guide}.*
#' 
#' To improve the security of your CodeGuru Reviewer API calls, you can
#' establish a private connection between your VPC and CodeGuru Reviewer by
#' creating an *interface VPC endpoint*. For more information, see
#' [CodeGuru Reviewer and interface VPC endpoints (Amazon Web Services
#' PrivateLink)](https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/vpc-interface-endpoints.html)
#' in the *Amazon CodeGuru Reviewer User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codegurureviewer(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codegurureviewer()
#' svc$associate_repository(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codegurureviewer_associate_repository]{associate_repository} \tab Use to associate an Amazon Web Services CodeCommit repository or a repository managed by Amazon Web Services CodeStar Connections with Amazon CodeGuru Reviewer\cr
#'  \link[paws.developer.tools:codegurureviewer_create_code_review]{create_code_review} \tab Use to create a code review with a CodeReviewType of RepositoryAnalysis\cr
#'  \link[paws.developer.tools:codegurureviewer_describe_code_review]{describe_code_review} \tab Returns the metadata associated with the code review along with its status\cr
#'  \link[paws.developer.tools:codegurureviewer_describe_recommendation_feedback]{describe_recommendation_feedback} \tab Describes the customer feedback for a CodeGuru Reviewer recommendation\cr
#'  \link[paws.developer.tools:codegurureviewer_describe_repository_association]{describe_repository_association} \tab Returns a RepositoryAssociation object that contains information about the requested repository association\cr
#'  \link[paws.developer.tools:codegurureviewer_disassociate_repository]{disassociate_repository} \tab Removes the association between Amazon CodeGuru Reviewer and a repository\cr
#'  \link[paws.developer.tools:codegurureviewer_list_code_reviews]{list_code_reviews} \tab Lists all the code reviews that the customer has created in the past 90 days\cr
#'  \link[paws.developer.tools:codegurureviewer_list_recommendation_feedback]{list_recommendation_feedback} \tab Returns a list of RecommendationFeedbackSummary objects that contain customer recommendation feedback for all CodeGuru Reviewer users\cr
#'  \link[paws.developer.tools:codegurureviewer_list_recommendations]{list_recommendations} \tab Returns the list of all recommendations for a completed code review\cr
#'  \link[paws.developer.tools:codegurureviewer_list_repository_associations]{list_repository_associations} \tab Returns a list of RepositoryAssociationSummary objects that contain summary information about a repository association\cr
#'  \link[paws.developer.tools:codegurureviewer_list_tags_for_resource]{list_tags_for_resource} \tab Returns the list of tags associated with an associated repository resource\cr
#'  \link[paws.developer.tools:codegurureviewer_put_recommendation_feedback]{put_recommendation_feedback} \tab Stores customer feedback for a CodeGuru Reviewer recommendation\cr
#'  \link[paws.developer.tools:codegurureviewer_tag_resource]{tag_resource} \tab Adds one or more tags to an associated repository\cr
#'  \link[paws.developer.tools:codegurureviewer_untag_resource]{untag_resource} \tab Removes a tag from an associated repository
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codegurureviewer
#' @export
codegurureviewer <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codegurureviewer(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CodeGuru Security
#'
#' @description
#' Amazon CodeGuru Security is in preview release and is subject to change.
#' 
#' This section provides documentation for the Amazon CodeGuru Security API
#' operations. CodeGuru Security is a service that uses program analysis
#' and machine learning to detect security policy violations and
#' vulnerabilities, and recommends ways to address these security risks.
#' 
#' By proactively detecting and providing recommendations for addressing
#' security risks, CodeGuru Security improves the overall security of your
#' application code. For more information about CodeGuru Security, see the
#' [Amazon CodeGuru Security User
#' Guide](https://docs.aws.amazon.com/codeguru/latest/security-ug/what-is-codeguru-security.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codegurusecurity(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codegurusecurity()
#' svc$batch_get_findings(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codegurusecurity_batch_get_findings]{batch_get_findings} \tab Returns a list of requested findings from standard scans\cr
#'  \link[paws.developer.tools:codegurusecurity_create_scan]{create_scan} \tab Use to create a scan using code uploaded to an Amazon S3 bucket\cr
#'  \link[paws.developer.tools:codegurusecurity_create_upload_url]{create_upload_url} \tab Generates a pre-signed URL, request headers used to upload a code resource, and code artifact identifier for the uploaded resource\cr
#'  \link[paws.developer.tools:codegurusecurity_get_account_configuration]{get_account_configuration} \tab Use to get the encryption configuration for an account\cr
#'  \link[paws.developer.tools:codegurusecurity_get_findings]{get_findings} \tab Returns a list of all findings generated by a particular scan\cr
#'  \link[paws.developer.tools:codegurusecurity_get_metrics_summary]{get_metrics_summary} \tab Returns a summary of metrics for an account from a specified date, including number of open findings, the categories with most findings, the scans with most open findings, and scans with most open critical findings\cr
#'  \link[paws.developer.tools:codegurusecurity_get_scan]{get_scan} \tab Returns details about a scan, including whether or not a scan has completed\cr
#'  \link[paws.developer.tools:codegurusecurity_list_findings_metrics]{list_findings_metrics} \tab Returns metrics about all findings in an account within a specified time range\cr
#'  \link[paws.developer.tools:codegurusecurity_list_scans]{list_scans} \tab Returns a list of all scans in an account\cr
#'  \link[paws.developer.tools:codegurusecurity_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of all tags associated with a scan\cr
#'  \link[paws.developer.tools:codegurusecurity_tag_resource]{tag_resource} \tab Use to add one or more tags to an existing scan\cr
#'  \link[paws.developer.tools:codegurusecurity_untag_resource]{untag_resource} \tab Use to remove one or more tags from an existing scan\cr
#'  \link[paws.developer.tools:codegurusecurity_update_account_configuration]{update_account_configuration} \tab Use to update the encryption configuration for an account
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codegurusecurity
#' @export
codegurusecurity <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codegurusecurity(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CodePipeline
#'
#' @description
#' CodePipeline
#' 
#' **Overview**
#' 
#' This is the CodePipeline API Reference. This guide provides descriptions
#' of the actions and data types for CodePipeline. Some functionality for
#' your pipeline can only be configured through the API. For more
#' information, see the [CodePipeline User
#' Guide](https://docs.aws.amazon.com/codepipeline/latest/userguide/welcome.html).
#' 
#' You can use the CodePipeline API to work with pipelines, stages,
#' actions, and transitions.
#' 
#' *Pipelines* are models of automated release processes. Each pipeline is
#' uniquely named, and consists of stages, actions, and transitions.
#' 
#' You can work with pipelines by calling:
#' 
#' -   `create_pipeline`, which creates a
#'     uniquely named pipeline.
#' 
#' -   `delete_pipeline`, which deletes the
#'     specified pipeline.
#' 
#' -   `get_pipeline`, which returns
#'     information about the pipeline structure and pipeline metadata,
#'     including the pipeline Amazon Resource Name (ARN).
#' 
#' -   `get_pipeline_execution`,
#'     which returns information about a specific execution of a pipeline.
#' 
#' -   `get_pipeline_state`, which
#'     returns information about the current state of the stages and
#'     actions of a pipeline.
#' 
#' -   `list_action_executions`,
#'     which returns action-level details for past executions. The details
#'     include full stage and action-level details, including individual
#'     action duration, status, any errors that occurred during the
#'     execution, and input and output artifact location details.
#' 
#' -   `list_pipelines`, which gets a
#'     summary of all of the pipelines associated with your account.
#' 
#' -   `list_pipeline_executions`,
#'     which gets a summary of the most recent executions for a pipeline.
#' 
#' -   `start_pipeline_execution`,
#'     which runs the most recent revision of an artifact through the
#'     pipeline.
#' 
#' -   `stop_pipeline_execution`,
#'     which stops the specified pipeline execution from continuing through
#'     the pipeline.
#' 
#' -   `update_pipeline`, which updates a
#'     pipeline with edits or changes to the structure of the pipeline.
#' 
#' Pipelines include *stages*. Each stage contains one or more actions that
#' must complete before the next stage begins. A stage results in success
#' or failure. If a stage fails, the pipeline stops at that stage and
#' remains stopped until either a new version of an artifact appears in the
#' source location, or a user takes action to rerun the most recent
#' artifact through the pipeline. You can call
#' `get_pipeline_state`, which displays
#' the status of a pipeline, including the status of stages in the
#' pipeline, or `get_pipeline`, which returns
#' the entire structure of the pipeline, including the stages of that
#' pipeline. For more information about the structure of stages and
#' actions, see [CodePipeline Pipeline Structure
#' Reference](https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html).
#' 
#' Pipeline stages include *actions* that are categorized into categories
#' such as source or build actions performed in a stage of a pipeline. For
#' example, you can use a source action to import artifacts into a pipeline
#' from a source such as Amazon S3. Like stages, you do not work with
#' actions directly in most cases, but you do define and interact with
#' actions when working with pipeline operations such as
#' `create_pipeline` and
#' `get_pipeline_state`. Valid action
#' categories are:
#' 
#' -   Source
#' 
#' -   Build
#' 
#' -   Test
#' 
#' -   Deploy
#' 
#' -   Approval
#' 
#' -   Invoke
#' 
#' -   Compute
#' 
#' Pipelines also include *transitions*, which allow the transition of
#' artifacts from one stage to the next in a pipeline after the actions in
#' one stage complete.
#' 
#' You can work with transitions by calling:
#' 
#' -   `disable_stage_transition`,
#'     which prevents artifacts from transitioning to the next stage in a
#'     pipeline.
#' 
#' -   `enable_stage_transition`,
#'     which enables transition of artifacts between stages in a pipeline.
#' 
#' **Using the API to integrate with CodePipeline**
#' 
#' For third-party integrators or developers who want to create their own
#' integrations with CodePipeline, the expected sequence varies from the
#' standard API user. To integrate with CodePipeline, developers need to
#' work with the following items:
#' 
#' **Jobs**, which are instances of an action. For example, a job for a
#' source action might import a revision of an artifact from a source.
#' 
#' You can work with jobs by calling:
#' 
#' -   `acknowledge_job`, which confirms
#'     whether a job worker has received the specified job.
#' 
#' -   `get_job_details`, which returns the
#'     details of a job.
#' 
#' -   `poll_for_jobs`, which determines
#'     whether there are any jobs to act on.
#' 
#' -   `put_job_failure_result`,
#'     which provides details of a job failure.
#' 
#' -   `put_job_success_result`,
#'     which provides details of a job success.
#' 
#' **Third party jobs**, which are instances of an action created by a
#' partner action and integrated into CodePipeline. Partner actions are
#' created by members of the Amazon Web Services Partner Network.
#' 
#' You can work with third party jobs by calling:
#' 
#' -   `acknowledge_third_party_job`,
#'     which confirms whether a job worker has received the specified job.
#' 
#' -   `get_third_party_job_details`,
#'     which requests the details of a job for a partner action.
#' 
#' -   `poll_for_third_party_jobs`,
#'     which determines whether there are any jobs to act on.
#' 
#' -   `put_third_party_job_failure_result`,
#'     which provides details of a job failure.
#' 
#' -   `put_third_party_job_success_result`,
#'     which provides details of a job success.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codepipeline(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codepipeline()
#' svc$acknowledge_job(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codepipeline_acknowledge_job]{acknowledge_job} \tab Returns information about a specified job and whether that job has been received by the job worker\cr
#'  \link[paws.developer.tools:codepipeline_acknowledge_third_party_job]{acknowledge_third_party_job} \tab Confirms a job worker has received the specified job\cr
#'  \link[paws.developer.tools:codepipeline_create_custom_action_type]{create_custom_action_type} \tab Creates a new custom action that can be used in all pipelines associated with the Amazon Web Services account\cr
#'  \link[paws.developer.tools:codepipeline_create_pipeline]{create_pipeline} \tab Creates a pipeline\cr
#'  \link[paws.developer.tools:codepipeline_delete_custom_action_type]{delete_custom_action_type} \tab Marks a custom action as deleted\cr
#'  \link[paws.developer.tools:codepipeline_delete_pipeline]{delete_pipeline} \tab Deletes the specified pipeline\cr
#'  \link[paws.developer.tools:codepipeline_delete_webhook]{delete_webhook} \tab Deletes a previously created webhook by name\cr
#'  \link[paws.developer.tools:codepipeline_deregister_webhook_with_third_party]{deregister_webhook_with_third_party} \tab Removes the connection between the webhook that was created by CodePipeline and the external tool with events to be detected\cr
#'  \link[paws.developer.tools:codepipeline_disable_stage_transition]{disable_stage_transition} \tab Prevents artifacts in a pipeline from transitioning to the next stage in the pipeline\cr
#'  \link[paws.developer.tools:codepipeline_enable_stage_transition]{enable_stage_transition} \tab Enables artifacts in a pipeline to transition to a stage in a pipeline\cr
#'  \link[paws.developer.tools:codepipeline_get_action_type]{get_action_type} \tab Returns information about an action type created for an external provider, where the action is to be used by customers of the external provider\cr
#'  \link[paws.developer.tools:codepipeline_get_job_details]{get_job_details} \tab Returns information about a job\cr
#'  \link[paws.developer.tools:codepipeline_get_pipeline]{get_pipeline} \tab Returns the metadata, structure, stages, and actions of a pipeline\cr
#'  \link[paws.developer.tools:codepipeline_get_pipeline_execution]{get_pipeline_execution} \tab Returns information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline\cr
#'  \link[paws.developer.tools:codepipeline_get_pipeline_state]{get_pipeline_state} \tab Returns information about the state of a pipeline, including the stages and actions\cr
#'  \link[paws.developer.tools:codepipeline_get_third_party_job_details]{get_third_party_job_details} \tab Requests the details of a job for a third party action\cr
#'  \link[paws.developer.tools:codepipeline_list_action_executions]{list_action_executions} \tab Lists the action executions that have occurred in a pipeline\cr
#'  \link[paws.developer.tools:codepipeline_list_action_types]{list_action_types} \tab Gets a summary of all CodePipeline action types associated with your account\cr
#'  \link[paws.developer.tools:codepipeline_list_pipeline_executions]{list_pipeline_executions} \tab Gets a summary of the most recent executions for a pipeline\cr
#'  \link[paws.developer.tools:codepipeline_list_pipelines]{list_pipelines} \tab Gets a summary of all of the pipelines associated with your account\cr
#'  \link[paws.developer.tools:codepipeline_list_rule_executions]{list_rule_executions} \tab Lists the rule executions that have occurred in a pipeline configured for conditions with rules\cr
#'  \link[paws.developer.tools:codepipeline_list_rule_types]{list_rule_types} \tab Lists the rules for the condition\cr
#'  \link[paws.developer.tools:codepipeline_list_tags_for_resource]{list_tags_for_resource} \tab Gets the set of key-value pairs (metadata) that are used to manage the resource\cr
#'  \link[paws.developer.tools:codepipeline_list_webhooks]{list_webhooks} \tab Gets a listing of all the webhooks in this Amazon Web Services Region for this account\cr
#'  \link[paws.developer.tools:codepipeline_override_stage_condition]{override_stage_condition} \tab Used to override a stage condition\cr
#'  \link[paws.developer.tools:codepipeline_poll_for_jobs]{poll_for_jobs} \tab Returns information about any jobs for CodePipeline to act on\cr
#'  \link[paws.developer.tools:codepipeline_poll_for_third_party_jobs]{poll_for_third_party_jobs} \tab Determines whether there are any third party jobs for a job worker to act on\cr
#'  \link[paws.developer.tools:codepipeline_put_action_revision]{put_action_revision} \tab Provides information to CodePipeline about new revisions to a source\cr
#'  \link[paws.developer.tools:codepipeline_put_approval_result]{put_approval_result} \tab Provides the response to a manual approval request to CodePipeline\cr
#'  \link[paws.developer.tools:codepipeline_put_job_failure_result]{put_job_failure_result} \tab Represents the failure of a job as returned to the pipeline by a job worker\cr
#'  \link[paws.developer.tools:codepipeline_put_job_success_result]{put_job_success_result} \tab Represents the success of a job as returned to the pipeline by a job worker\cr
#'  \link[paws.developer.tools:codepipeline_put_third_party_job_failure_result]{put_third_party_job_failure_result} \tab Represents the failure of a third party job as returned to the pipeline by a job worker\cr
#'  \link[paws.developer.tools:codepipeline_put_third_party_job_success_result]{put_third_party_job_success_result} \tab Represents the success of a third party job as returned to the pipeline by a job worker\cr
#'  \link[paws.developer.tools:codepipeline_put_webhook]{put_webhook} \tab Defines a webhook and returns a unique webhook URL generated by CodePipeline\cr
#'  \link[paws.developer.tools:codepipeline_register_webhook_with_third_party]{register_webhook_with_third_party} \tab Configures a connection between the webhook that was created and the external tool with events to be detected\cr
#'  \link[paws.developer.tools:codepipeline_retry_stage_execution]{retry_stage_execution} \tab You can retry a stage that has failed without having to run a pipeline again from the beginning\cr
#'  \link[paws.developer.tools:codepipeline_rollback_stage]{rollback_stage} \tab Rolls back a stage execution\cr
#'  \link[paws.developer.tools:codepipeline_start_pipeline_execution]{start_pipeline_execution} \tab Starts the specified pipeline\cr
#'  \link[paws.developer.tools:codepipeline_stop_pipeline_execution]{stop_pipeline_execution} \tab Stops the specified pipeline execution\cr
#'  \link[paws.developer.tools:codepipeline_tag_resource]{tag_resource} \tab Adds to or modifies the tags of the given resource\cr
#'  \link[paws.developer.tools:codepipeline_untag_resource]{untag_resource} \tab Removes tags from an Amazon Web Services resource\cr
#'  \link[paws.developer.tools:codepipeline_update_action_type]{update_action_type} \tab Updates an action type that was created with any supported integration model, where the action type is to be used by customers of the action type provider\cr
#'  \link[paws.developer.tools:codepipeline_update_pipeline]{update_pipeline} \tab Updates a specified pipeline with edits or changes to its structure
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codepipeline
#' @export
codepipeline <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codepipeline(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CodeConnections
#'
#' @description
#' This Amazon Web Services CodeConnections API Reference provides
#' descriptions and usage examples of the operations and data types for the
#' Amazon Web Services CodeConnections API. You can use the connections API
#' to work with connections and installations.
#' 
#' *Connections* are configurations that you use to connect Amazon Web
#' Services resources to external code repositories. Each connection is a
#' resource that can be given to services such as CodePipeline to connect
#' to a third-party repository such as Bitbucket. For example, you can add
#' the connection in CodePipeline so that it triggers your pipeline when a
#' code change is made to your third-party code repository. Each connection
#' is named and associated with a unique ARN that is used to reference the
#' connection.
#' 
#' When you create a connection, the console initiates a third-party
#' connection handshake. *Installations* are the apps that are used to
#' conduct this handshake. For example, the installation for the Bitbucket
#' provider type is the Bitbucket app. When you create a connection, you
#' can choose an existing installation or create one.
#' 
#' When you want to create a connection to an installed provider type such
#' as GitHub Enterprise Server, you create a *host* for your connections.
#' 
#' You can work with connections by calling:
#' 
#' -   `create_connection`, which
#'     creates a uniquely named connection that can be referenced by
#'     services such as CodePipeline.
#' 
#' -   `delete_connection`, which
#'     deletes the specified connection.
#' 
#' -   `get_connection`, which returns
#'     information about the connection, including the connection status.
#' 
#' -   `list_connections`, which lists
#'     the connections associated with your account.
#' 
#' You can work with hosts by calling:
#' 
#' -   `create_host`, which creates a host
#'     that represents the infrastructure where your provider is installed.
#' 
#' -   `delete_host`, which deletes the
#'     specified host.
#' 
#' -   `get_host`, which returns information
#'     about the host, including the setup status.
#' 
#' -   `list_hosts`, which lists the hosts
#'     associated with your account.
#' 
#' You can work with tags in Amazon Web Services CodeConnections by calling
#' the following:
#' 
#' -   `list_tags_for_resource`,
#'     which gets information about Amazon Web Services tags for a
#'     specified Amazon Resource Name (ARN) in Amazon Web Services
#'     CodeConnections.
#' 
#' -   `tag_resource`, which adds or
#'     updates tags for a resource in Amazon Web Services CodeConnections.
#' 
#' -   `untag_resource`, which removes
#'     tags for a resource in Amazon Web Services CodeConnections.
#' 
#' For information about how to use Amazon Web Services CodeConnections,
#' see the [Developer Tools User
#' Guide](https://docs.aws.amazon.com/dtconsole/latest/userguide/welcome-connections.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codeconnections(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codeconnections()
#' svc$create_connection(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codeconnections_create_connection]{create_connection} \tab Creates a connection that can then be given to other Amazon Web Services services like CodePipeline so that it can access third-party code repositories\cr
#'  \link[paws.developer.tools:codeconnections_create_host]{create_host} \tab Creates a resource that represents the infrastructure where a third-party provider is installed\cr
#'  \link[paws.developer.tools:codeconnections_create_repository_link]{create_repository_link} \tab Creates a link to a specified external Git repository\cr
#'  \link[paws.developer.tools:codeconnections_create_sync_configuration]{create_sync_configuration} \tab Creates a sync configuration which allows Amazon Web Services to sync content from a Git repository to update a specified Amazon Web Services resource\cr
#'  \link[paws.developer.tools:codeconnections_delete_connection]{delete_connection} \tab The connection to be deleted\cr
#'  \link[paws.developer.tools:codeconnections_delete_host]{delete_host} \tab The host to be deleted\cr
#'  \link[paws.developer.tools:codeconnections_delete_repository_link]{delete_repository_link} \tab Deletes the association between your connection and a specified external Git repository\cr
#'  \link[paws.developer.tools:codeconnections_delete_sync_configuration]{delete_sync_configuration} \tab Deletes the sync configuration for a specified repository and connection\cr
#'  \link[paws.developer.tools:codeconnections_get_connection]{get_connection} \tab Returns the connection ARN and details such as status, owner, and provider type\cr
#'  \link[paws.developer.tools:codeconnections_get_host]{get_host} \tab Returns the host ARN and details such as status, provider type, endpoint, and, if applicable, the VPC configuration\cr
#'  \link[paws.developer.tools:codeconnections_get_repository_link]{get_repository_link} \tab Returns details about a repository link\cr
#'  \link[paws.developer.tools:codeconnections_get_repository_sync_status]{get_repository_sync_status} \tab Returns details about the sync status for a repository\cr
#'  \link[paws.developer.tools:codeconnections_get_resource_sync_status]{get_resource_sync_status} \tab Returns the status of the sync with the Git repository for a specific Amazon Web Services resource\cr
#'  \link[paws.developer.tools:codeconnections_get_sync_blocker_summary]{get_sync_blocker_summary} \tab Returns a list of the most recent sync blockers\cr
#'  \link[paws.developer.tools:codeconnections_get_sync_configuration]{get_sync_configuration} \tab Returns details about a sync configuration, including the sync type and resource name\cr
#'  \link[paws.developer.tools:codeconnections_list_connections]{list_connections} \tab Lists the connections associated with your account\cr
#'  \link[paws.developer.tools:codeconnections_list_hosts]{list_hosts} \tab Lists the hosts associated with your account\cr
#'  \link[paws.developer.tools:codeconnections_list_repository_links]{list_repository_links} \tab Lists the repository links created for connections in your account\cr
#'  \link[paws.developer.tools:codeconnections_list_repository_sync_definitions]{list_repository_sync_definitions} \tab Lists the repository sync definitions for repository links in your account\cr
#'  \link[paws.developer.tools:codeconnections_list_sync_configurations]{list_sync_configurations} \tab Returns a list of sync configurations for a specified repository\cr
#'  \link[paws.developer.tools:codeconnections_list_tags_for_resource]{list_tags_for_resource} \tab Gets the set of key-value pairs (metadata) that are used to manage the resource\cr
#'  \link[paws.developer.tools:codeconnections_tag_resource]{tag_resource} \tab Adds to or modifies the tags of the given resource\cr
#'  \link[paws.developer.tools:codeconnections_untag_resource]{untag_resource} \tab Removes tags from an Amazon Web Services resource\cr
#'  \link[paws.developer.tools:codeconnections_update_host]{update_host} \tab Updates a specified host with the provided configurations\cr
#'  \link[paws.developer.tools:codeconnections_update_repository_link]{update_repository_link} \tab Updates the association between your connection and a specified external Git repository\cr
#'  \link[paws.developer.tools:codeconnections_update_sync_blocker]{update_sync_blocker} \tab Allows you to update the status of a sync blocker, resolving the blocker and allowing syncing to continue\cr
#'  \link[paws.developer.tools:codeconnections_update_sync_configuration]{update_sync_configuration} \tab Updates the sync configuration for your connection and a specified external Git repository
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codeconnections
#' @export
codeconnections <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codeconnections(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CodeStar connections
#'
#' @description
#' AWS CodeStar Connections
#' 
#' This Amazon Web Services CodeStar Connections API Reference provides
#' descriptions and usage examples of the operations and data types for the
#' Amazon Web Services CodeStar Connections API. You can use the
#' connections API to work with connections and installations.
#' 
#' *Connections* are configurations that you use to connect Amazon Web
#' Services resources to external code repositories. Each connection is a
#' resource that can be given to services such as CodePipeline to connect
#' to a third-party repository such as Bitbucket. For example, you can add
#' the connection in CodePipeline so that it triggers your pipeline when a
#' code change is made to your third-party code repository. Each connection
#' is named and associated with a unique ARN that is used to reference the
#' connection.
#' 
#' When you create a connection, the console initiates a third-party
#' connection handshake. *Installations* are the apps that are used to
#' conduct this handshake. For example, the installation for the Bitbucket
#' provider type is the Bitbucket app. When you create a connection, you
#' can choose an existing installation or create one.
#' 
#' When you want to create a connection to an installed provider type such
#' as GitHub Enterprise Server, you create a *host* for your connections.
#' 
#' You can work with connections by calling:
#' 
#' -   `create_connection`, which
#'     creates a uniquely named connection that can be referenced by
#'     services such as CodePipeline.
#' 
#' -   `delete_connection`, which
#'     deletes the specified connection.
#' 
#' -   `get_connection`, which
#'     returns information about the connection, including the connection
#'     status.
#' 
#' -   `list_connections`, which
#'     lists the connections associated with your account.
#' 
#' You can work with hosts by calling:
#' 
#' -   `create_host`, which creates a
#'     host that represents the infrastructure where your provider is
#'     installed.
#' 
#' -   `delete_host`, which deletes the
#'     specified host.
#' 
#' -   `get_host`, which returns
#'     information about the host, including the setup status.
#' 
#' -   `list_hosts`, which lists the
#'     hosts associated with your account.
#' 
#' You can work with tags in Amazon Web Services CodeStar Connections by
#' calling the following:
#' 
#' -   `list_tags_for_resource`,
#'     which gets information about Amazon Web Services tags for a
#'     specified Amazon Resource Name (ARN) in Amazon Web Services CodeStar
#'     Connections.
#' 
#' -   `tag_resource`, which adds or
#'     updates tags for a resource in Amazon Web Services CodeStar
#'     Connections.
#' 
#' -   `untag_resource`, which
#'     removes tags for a resource in Amazon Web Services CodeStar
#'     Connections.
#' 
#' For information about how to use Amazon Web Services CodeStar
#' Connections, see the [Developer Tools User
#' Guide](https://docs.aws.amazon.com/dtconsole/latest/userguide/welcome-connections.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codestarconnections(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codestarconnections()
#' svc$create_connection(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codestarconnections_create_connection]{create_connection} \tab Creates a connection that can then be given to other Amazon Web Services services like CodePipeline so that it can access third-party code repositories\cr
#'  \link[paws.developer.tools:codestarconnections_create_host]{create_host} \tab Creates a resource that represents the infrastructure where a third-party provider is installed\cr
#'  \link[paws.developer.tools:codestarconnections_create_repository_link]{create_repository_link} \tab Creates a link to a specified external Git repository\cr
#'  \link[paws.developer.tools:codestarconnections_create_sync_configuration]{create_sync_configuration} \tab Creates a sync configuration which allows Amazon Web Services to sync content from a Git repository to update a specified Amazon Web Services resource\cr
#'  \link[paws.developer.tools:codestarconnections_delete_connection]{delete_connection} \tab The connection to be deleted\cr
#'  \link[paws.developer.tools:codestarconnections_delete_host]{delete_host} \tab The host to be deleted\cr
#'  \link[paws.developer.tools:codestarconnections_delete_repository_link]{delete_repository_link} \tab Deletes the association between your connection and a specified external Git repository\cr
#'  \link[paws.developer.tools:codestarconnections_delete_sync_configuration]{delete_sync_configuration} \tab Deletes the sync configuration for a specified repository and connection\cr
#'  \link[paws.developer.tools:codestarconnections_get_connection]{get_connection} \tab Returns the connection ARN and details such as status, owner, and provider type\cr
#'  \link[paws.developer.tools:codestarconnections_get_host]{get_host} \tab Returns the host ARN and details such as status, provider type, endpoint, and, if applicable, the VPC configuration\cr
#'  \link[paws.developer.tools:codestarconnections_get_repository_link]{get_repository_link} \tab Returns details about a repository link\cr
#'  \link[paws.developer.tools:codestarconnections_get_repository_sync_status]{get_repository_sync_status} \tab Returns details about the sync status for a repository\cr
#'  \link[paws.developer.tools:codestarconnections_get_resource_sync_status]{get_resource_sync_status} \tab Returns the status of the sync with the Git repository for a specific Amazon Web Services resource\cr
#'  \link[paws.developer.tools:codestarconnections_get_sync_blocker_summary]{get_sync_blocker_summary} \tab Returns a list of the most recent sync blockers\cr
#'  \link[paws.developer.tools:codestarconnections_get_sync_configuration]{get_sync_configuration} \tab Returns details about a sync configuration, including the sync type and resource name\cr
#'  \link[paws.developer.tools:codestarconnections_list_connections]{list_connections} \tab Lists the connections associated with your account\cr
#'  \link[paws.developer.tools:codestarconnections_list_hosts]{list_hosts} \tab Lists the hosts associated with your account\cr
#'  \link[paws.developer.tools:codestarconnections_list_repository_links]{list_repository_links} \tab Lists the repository links created for connections in your account\cr
#'  \link[paws.developer.tools:codestarconnections_list_repository_sync_definitions]{list_repository_sync_definitions} \tab Lists the repository sync definitions for repository links in your account\cr
#'  \link[paws.developer.tools:codestarconnections_list_sync_configurations]{list_sync_configurations} \tab Returns a list of sync configurations for a specified repository\cr
#'  \link[paws.developer.tools:codestarconnections_list_tags_for_resource]{list_tags_for_resource} \tab Gets the set of key-value pairs (metadata) that are used to manage the resource\cr
#'  \link[paws.developer.tools:codestarconnections_tag_resource]{tag_resource} \tab Adds to or modifies the tags of the given resource\cr
#'  \link[paws.developer.tools:codestarconnections_untag_resource]{untag_resource} \tab Removes tags from an Amazon Web Services resource\cr
#'  \link[paws.developer.tools:codestarconnections_update_host]{update_host} \tab Updates a specified host with the provided configurations\cr
#'  \link[paws.developer.tools:codestarconnections_update_repository_link]{update_repository_link} \tab Updates the association between your connection and a specified external Git repository\cr
#'  \link[paws.developer.tools:codestarconnections_update_sync_blocker]{update_sync_blocker} \tab Allows you to update the status of a sync blocker, resolving the blocker and allowing syncing to continue\cr
#'  \link[paws.developer.tools:codestarconnections_update_sync_configuration]{update_sync_configuration} \tab Updates the sync configuration for your connection and a specified external Git repository
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codestarconnections
#' @export
codestarconnections <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codestarconnections(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CodeStar Notifications
#'
#' @description
#' This AWS CodeStar Notifications API Reference provides descriptions and
#' usage examples of the operations and data types for the AWS CodeStar
#' Notifications API. You can use the AWS CodeStar Notifications API to
#' work with the following objects:
#' 
#' Notification rules, by calling the following:
#' 
#' -   `create_notification_rule`,
#'     which creates a notification rule for a resource in your account.
#' 
#' -   `delete_notification_rule`,
#'     which deletes a notification rule.
#' 
#' -   `describe_notification_rule`,
#'     which provides information about a notification rule.
#' 
#' -   `list_notification_rules`,
#'     which lists the notification rules associated with your account.
#' 
#' -   `update_notification_rule`,
#'     which changes the name, events, or targets associated with a
#'     notification rule.
#' 
#' -   `subscribe`, which subscribes a
#'     target to a notification rule.
#' 
#' -   `unsubscribe`, which removes a
#'     target from a notification rule.
#' 
#' Targets, by calling the following:
#' 
#' -   `delete_target`, which
#'     removes a notification rule target from a notification rule.
#' 
#' -   `list_targets`, which lists
#'     the targets associated with a notification rule.
#' 
#' Events, by calling the following:
#' 
#' -   `list_event_types`, which
#'     lists the event types you can include in a notification rule.
#' 
#' Tags, by calling the following:
#' 
#' -   `list_tags_for_resource`,
#'     which lists the tags already associated with a notification rule in
#'     your account.
#' 
#' -   `tag_resource`, which
#'     associates a tag you provide with a notification rule in your
#'     account.
#' 
#' -   `untag_resource`, which
#'     removes a tag from a notification rule in your account.
#' 
#' For information about how to use AWS CodeStar Notifications, see the
#' [Amazon Web Services Developer Tools Console User
#' Guide](https://docs.aws.amazon.com/dtconsole/latest/userguide/what-is-dtconsole.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- codestarnotifications(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- codestarnotifications()
#' svc$create_notification_rule(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:codestarnotifications_create_notification_rule]{create_notification_rule} \tab Creates a notification rule for a resource\cr
#'  \link[paws.developer.tools:codestarnotifications_delete_notification_rule]{delete_notification_rule} \tab Deletes a notification rule for a resource\cr
#'  \link[paws.developer.tools:codestarnotifications_delete_target]{delete_target} \tab Deletes a specified target for notifications\cr
#'  \link[paws.developer.tools:codestarnotifications_describe_notification_rule]{describe_notification_rule} \tab Returns information about a specified notification rule\cr
#'  \link[paws.developer.tools:codestarnotifications_list_event_types]{list_event_types} \tab Returns information about the event types available for configuring notifications\cr
#'  \link[paws.developer.tools:codestarnotifications_list_notification_rules]{list_notification_rules} \tab Returns a list of the notification rules for an Amazon Web Services account\cr
#'  \link[paws.developer.tools:codestarnotifications_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of the tags associated with a notification rule\cr
#'  \link[paws.developer.tools:codestarnotifications_list_targets]{list_targets} \tab Returns a list of the notification rule targets for an Amazon Web Services account\cr
#'  \link[paws.developer.tools:codestarnotifications_subscribe]{subscribe} \tab Creates an association between a notification rule and an Chatbot topic or Chatbot client so that the associated target can receive notifications when the events described in the rule are triggered\cr
#'  \link[paws.developer.tools:codestarnotifications_tag_resource]{tag_resource} \tab Associates a set of provided tags with a notification rule\cr
#'  \link[paws.developer.tools:codestarnotifications_unsubscribe]{unsubscribe} \tab Removes an association between a notification rule and an Chatbot topic so that subscribers to that topic stop receiving notifications when the events described in the rule are triggered\cr
#'  \link[paws.developer.tools:codestarnotifications_untag_resource]{untag_resource} \tab Removes the association between one or more provided tags and a notification rule\cr
#'  \link[paws.developer.tools:codestarnotifications_update_notification_rule]{update_notification_rule} \tab Updates a notification rule for a resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname codestarnotifications
#' @export
codestarnotifications <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::codestarnotifications(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Elastic Disaster Recovery Service
#'
#' @description
#' AWS Elastic Disaster Recovery Service.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- drs(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- drs()
#' svc$associate_source_network_stack(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:drs_associate_source_network_stack]{associate_source_network_stack} \tab Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network\cr
#'  \link[paws.developer.tools:drs_create_extended_source_server]{create_extended_source_server} \tab Create an extended source server in the target Account based on the source server in staging account\cr
#'  \link[paws.developer.tools:drs_create_launch_configuration_template]{create_launch_configuration_template} \tab Creates a new Launch Configuration Template\cr
#'  \link[paws.developer.tools:drs_create_replication_configuration_template]{create_replication_configuration_template} \tab Creates a new ReplicationConfigurationTemplate\cr
#'  \link[paws.developer.tools:drs_create_source_network]{create_source_network} \tab Create a new Source Network resource for a provided VPC ID\cr
#'  \link[paws.developer.tools:drs_delete_job]{delete_job} \tab Deletes a single Job by ID\cr
#'  \link[paws.developer.tools:drs_delete_launch_action]{delete_launch_action} \tab Deletes a resource launch action\cr
#'  \link[paws.developer.tools:drs_delete_launch_configuration_template]{delete_launch_configuration_template} \tab Deletes a single Launch Configuration Template by ID\cr
#'  \link[paws.developer.tools:drs_delete_recovery_instance]{delete_recovery_instance} \tab Deletes a single Recovery Instance by ID\cr
#'  \link[paws.developer.tools:drs_delete_replication_configuration_template]{delete_replication_configuration_template} \tab Deletes a single Replication Configuration Template by ID\cr
#'  \link[paws.developer.tools:drs_delete_source_network]{delete_source_network} \tab Delete Source Network resource\cr
#'  \link[paws.developer.tools:drs_delete_source_server]{delete_source_server} \tab Deletes a single Source Server by ID\cr
#'  \link[paws.developer.tools:drs_describe_job_log_items]{describe_job_log_items} \tab Retrieves a detailed Job log with pagination\cr
#'  \link[paws.developer.tools:drs_describe_jobs]{describe_jobs} \tab Returns a list of Jobs\cr
#'  \link[paws.developer.tools:drs_describe_launch_configuration_templates]{describe_launch_configuration_templates} \tab Lists all Launch Configuration Templates, filtered by Launch Configuration Template IDs\cr
#'  \link[paws.developer.tools:drs_describe_recovery_instances]{describe_recovery_instances} \tab Lists all Recovery Instances or multiple Recovery Instances by ID\cr
#'  \link[paws.developer.tools:drs_describe_recovery_snapshots]{describe_recovery_snapshots} \tab Lists all Recovery Snapshots for a single Source Server\cr
#'  \link[paws.developer.tools:drs_describe_replication_configuration_templates]{describe_replication_configuration_templates} \tab Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs\cr
#'  \link[paws.developer.tools:drs_describe_source_networks]{describe_source_networks} \tab Lists all Source Networks or multiple Source Networks filtered by ID\cr
#'  \link[paws.developer.tools:drs_describe_source_servers]{describe_source_servers} \tab Lists all Source Servers or multiple Source Servers filtered by ID\cr
#'  \link[paws.developer.tools:drs_disconnect_recovery_instance]{disconnect_recovery_instance} \tab Disconnect a Recovery Instance from Elastic Disaster Recovery\cr
#'  \link[paws.developer.tools:drs_disconnect_source_server]{disconnect_source_server} \tab Disconnects a specific Source Server from Elastic Disaster Recovery\cr
#'  \link[paws.developer.tools:drs_export_source_network_cfn_template]{export_source_network_cfn_template} \tab Export the Source Network CloudFormation template to an S3 bucket\cr
#'  \link[paws.developer.tools:drs_get_failback_replication_configuration]{get_failback_replication_configuration} \tab Lists all Failback ReplicationConfigurations, filtered by Recovery Instance ID\cr
#'  \link[paws.developer.tools:drs_get_launch_configuration]{get_launch_configuration} \tab Gets a LaunchConfiguration, filtered by Source Server IDs\cr
#'  \link[paws.developer.tools:drs_get_replication_configuration]{get_replication_configuration} \tab Gets a ReplicationConfiguration, filtered by Source Server ID\cr
#'  \link[paws.developer.tools:drs_initialize_service]{initialize_service} \tab Initialize Elastic Disaster Recovery\cr
#'  \link[paws.developer.tools:drs_list_extensible_source_servers]{list_extensible_source_servers} \tab Returns a list of source servers on a staging account that are extensible, which means that: a\cr
#'  \link[paws.developer.tools:drs_list_launch_actions]{list_launch_actions} \tab Lists resource launch actions\cr
#'  \link[paws.developer.tools:drs_list_staging_accounts]{list_staging_accounts} \tab Returns an array of staging accounts for existing extended source servers\cr
#'  \link[paws.developer.tools:drs_list_tags_for_resource]{list_tags_for_resource} \tab List all tags for your Elastic Disaster Recovery resources\cr
#'  \link[paws.developer.tools:drs_put_launch_action]{put_launch_action} \tab Puts a resource launch action\cr
#'  \link[paws.developer.tools:drs_retry_data_replication]{retry_data_replication} \tab WARNING: RetryDataReplication is deprecated\cr
#'  \link[paws.developer.tools:drs_reverse_replication]{reverse_replication} \tab Start replication to origin / target region - applies only to protected instances that originated in EC2\cr
#'  \link[paws.developer.tools:drs_start_failback_launch]{start_failback_launch} \tab Initiates a Job for launching the machine that is being failed back to from the specified Recovery Instance\cr
#'  \link[paws.developer.tools:drs_start_recovery]{start_recovery} \tab Launches Recovery Instances for the specified Source Servers\cr
#'  \link[paws.developer.tools:drs_start_replication]{start_replication} \tab Starts replication for a stopped Source Server\cr
#'  \link[paws.developer.tools:drs_start_source_network_recovery]{start_source_network_recovery} \tab Deploy VPC for the specified Source Network and modify launch templates to use this network\cr
#'  \link[paws.developer.tools:drs_start_source_network_replication]{start_source_network_replication} \tab Starts replication for a Source Network\cr
#'  \link[paws.developer.tools:drs_stop_failback]{stop_failback} \tab Stops the failback process for a specified Recovery Instance\cr
#'  \link[paws.developer.tools:drs_stop_replication]{stop_replication} \tab Stops replication for a Source Server\cr
#'  \link[paws.developer.tools:drs_stop_source_network_replication]{stop_source_network_replication} \tab Stops replication for a Source Network\cr
#'  \link[paws.developer.tools:drs_tag_resource]{tag_resource} \tab Adds or overwrites only the specified tags for the specified Elastic Disaster Recovery resource or resources\cr
#'  \link[paws.developer.tools:drs_terminate_recovery_instances]{terminate_recovery_instances} \tab Initiates a Job for terminating the EC2 resources associated with the specified Recovery Instances, and then will delete the Recovery Instances from the Elastic Disaster Recovery service\cr
#'  \link[paws.developer.tools:drs_untag_resource]{untag_resource} \tab Deletes the specified set of tags from the specified set of Elastic Disaster Recovery resources\cr
#'  \link[paws.developer.tools:drs_update_failback_replication_configuration]{update_failback_replication_configuration} \tab Allows you to update the failback replication configuration of a Recovery Instance by ID\cr
#'  \link[paws.developer.tools:drs_update_launch_configuration]{update_launch_configuration} \tab Updates a LaunchConfiguration by Source Server ID\cr
#'  \link[paws.developer.tools:drs_update_launch_configuration_template]{update_launch_configuration_template} \tab Updates an existing Launch Configuration Template by ID\cr
#'  \link[paws.developer.tools:drs_update_replication_configuration]{update_replication_configuration} \tab Allows you to update a ReplicationConfiguration by Source Server ID\cr
#'  \link[paws.developer.tools:drs_update_replication_configuration_template]{update_replication_configuration_template} \tab Updates a ReplicationConfigurationTemplate by ID
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname drs
#' @export
drs <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::drs(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon DevOps Guru
#'
#' @description
#' Amazon DevOps Guru is a fully managed service that helps you identify
#' anomalous behavior in business critical operational applications. You
#' specify the Amazon Web Services resources that you want DevOps Guru to
#' cover, then the Amazon CloudWatch metrics and Amazon Web Services
#' CloudTrail events related to those resources are analyzed. When
#' anomalous behavior is detected, DevOps Guru creates an *insight* that
#' includes recommendations, related events, and related metrics that can
#' help you improve your operational applications. For more information,
#' see [What is Amazon DevOps
#' Guru](https://docs.aws.amazon.com/devops-guru/latest/userguide/welcome.html).
#' 
#' You can specify 1 or 2 Amazon Simple Notification Service topics so you
#' are notified every time a new insight is created. You can also enable
#' DevOps Guru to generate an OpsItem in Amazon Web Services Systems
#' Manager for each insight to help you manage and track your work
#' addressing insights.
#' 
#' To learn about the DevOps Guru workflow, see [How DevOps Guru
#' works](https://docs.aws.amazon.com/devops-guru/latest/userguide/welcome.html#how-it-works).
#' To learn about DevOps Guru concepts, see [Concepts in DevOps
#' Guru](https://docs.aws.amazon.com/devops-guru/latest/userguide/concepts.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- devopsguru(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- devopsguru()
#' svc$add_notification_channel(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:devopsguru_add_notification_channel]{add_notification_channel} \tab Adds a notification channel to DevOps Guru\cr
#'  \link[paws.developer.tools:devopsguru_delete_insight]{delete_insight} \tab Deletes the insight along with the associated anomalies, events and recommendations\cr
#'  \link[paws.developer.tools:devopsguru_describe_account_health]{describe_account_health} \tab Returns the number of open reactive insights, the number of open proactive insights, and the number of metrics analyzed in your Amazon Web Services account\cr
#'  \link[paws.developer.tools:devopsguru_describe_account_overview]{describe_account_overview} \tab For the time range passed in, returns the number of open reactive insight that were created, the number of open proactive insights that were created, and the Mean Time to Recover (MTTR) for all closed reactive insights\cr
#'  \link[paws.developer.tools:devopsguru_describe_anomaly]{describe_anomaly} \tab Returns details about an anomaly that you specify using its ID\cr
#'  \link[paws.developer.tools:devopsguru_describe_event_sources_config]{describe_event_sources_config} \tab Returns the integration status of services that are integrated with DevOps Guru as Consumer via EventBridge\cr
#'  \link[paws.developer.tools:devopsguru_describe_feedback]{describe_feedback} \tab Returns the most recent feedback submitted in the current Amazon Web Services account and Region\cr
#'  \link[paws.developer.tools:devopsguru_describe_insight]{describe_insight} \tab Returns details about an insight that you specify using its ID\cr
#'  \link[paws.developer.tools:devopsguru_describe_organization_health]{describe_organization_health} \tab Returns active insights, predictive insights, and resource hours analyzed in last hour\cr
#'  \link[paws.developer.tools:devopsguru_describe_organization_overview]{describe_organization_overview} \tab Returns an overview of your organization's history based on the specified time range\cr
#'  \link[paws.developer.tools:devopsguru_describe_organization_resource_collection_health]{describe_organization_resource_collection_health} \tab Provides an overview of your system's health\cr
#'  \link[paws.developer.tools:devopsguru_describe_resource_collection_health]{describe_resource_collection_health} \tab Returns the number of open proactive insights, open reactive insights, and the Mean Time to Recover (MTTR) for all closed insights in resource collections in your account\cr
#'  \link[paws.developer.tools:devopsguru_describe_service_integration]{describe_service_integration} \tab Returns the integration status of services that are integrated with DevOps Guru\cr
#'  \link[paws.developer.tools:devopsguru_get_cost_estimation]{get_cost_estimation} \tab Returns an estimate of the monthly cost for DevOps Guru to analyze your Amazon Web Services resources\cr
#'  \link[paws.developer.tools:devopsguru_get_resource_collection]{get_resource_collection} \tab Returns lists Amazon Web Services resources that are of the specified resource collection type\cr
#'  \link[paws.developer.tools:devopsguru_list_anomalies_for_insight]{list_anomalies_for_insight} \tab Returns a list of the anomalies that belong to an insight that you specify using its ID\cr
#'  \link[paws.developer.tools:devopsguru_list_anomalous_log_groups]{list_anomalous_log_groups} \tab Returns the list of log groups that contain log anomalies\cr
#'  \link[paws.developer.tools:devopsguru_list_events]{list_events} \tab Returns a list of the events emitted by the resources that are evaluated by DevOps Guru\cr
#'  \link[paws.developer.tools:devopsguru_list_insights]{list_insights} \tab Returns a list of insights in your Amazon Web Services account\cr
#'  \link[paws.developer.tools:devopsguru_list_monitored_resources]{list_monitored_resources} \tab Returns the list of all log groups that are being monitored and tagged by DevOps Guru\cr
#'  \link[paws.developer.tools:devopsguru_list_notification_channels]{list_notification_channels} \tab Returns a list of notification channels configured for DevOps Guru\cr
#'  \link[paws.developer.tools:devopsguru_list_organization_insights]{list_organization_insights} \tab Returns a list of insights associated with the account or OU Id\cr
#'  \link[paws.developer.tools:devopsguru_list_recommendations]{list_recommendations} \tab Returns a list of a specified insight's recommendations\cr
#'  \link[paws.developer.tools:devopsguru_put_feedback]{put_feedback} \tab Collects customer feedback about the specified insight\cr
#'  \link[paws.developer.tools:devopsguru_remove_notification_channel]{remove_notification_channel} \tab Removes a notification channel from DevOps Guru\cr
#'  \link[paws.developer.tools:devopsguru_search_insights]{search_insights} \tab Returns a list of insights in your Amazon Web Services account\cr
#'  \link[paws.developer.tools:devopsguru_search_organization_insights]{search_organization_insights} \tab Returns a list of insights in your organization\cr
#'  \link[paws.developer.tools:devopsguru_start_cost_estimation]{start_cost_estimation} \tab Starts the creation of an estimate of the monthly cost to analyze your Amazon Web Services resources\cr
#'  \link[paws.developer.tools:devopsguru_update_event_sources_config]{update_event_sources_config} \tab Enables or disables integration with a service that can be integrated with DevOps Guru\cr
#'  \link[paws.developer.tools:devopsguru_update_resource_collection]{update_resource_collection} \tab Updates the collection of resources that DevOps Guru analyzes\cr
#'  \link[paws.developer.tools:devopsguru_update_service_integration]{update_service_integration} \tab Enables or disables integration with a service that can be integrated with DevOps Guru
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname devopsguru
#' @export
devopsguru <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::devopsguru(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Fault Injection Simulator
#'
#' @description
#' Amazon Web Services Fault Injection Service is a managed service that
#' enables you to perform fault injection experiments on your Amazon Web
#' Services workloads. For more information, see the [Fault Injection
#' Service User Guide](https://docs.aws.amazon.com/fis/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- fis(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- fis()
#' svc$create_experiment_template(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:fis_create_experiment_template]{create_experiment_template} \tab Creates an experiment template\cr
#'  \link[paws.developer.tools:fis_create_target_account_configuration]{create_target_account_configuration} \tab Creates a target account configuration for the experiment template\cr
#'  \link[paws.developer.tools:fis_delete_experiment_template]{delete_experiment_template} \tab Deletes the specified experiment template\cr
#'  \link[paws.developer.tools:fis_delete_target_account_configuration]{delete_target_account_configuration} \tab Deletes the specified target account configuration of the experiment template\cr
#'  \link[paws.developer.tools:fis_get_action]{get_action} \tab Gets information about the specified FIS action\cr
#'  \link[paws.developer.tools:fis_get_experiment]{get_experiment} \tab Gets information about the specified experiment\cr
#'  \link[paws.developer.tools:fis_get_experiment_target_account_configuration]{get_experiment_target_account_configuration} \tab Gets information about the specified target account configuration of the experiment\cr
#'  \link[paws.developer.tools:fis_get_experiment_template]{get_experiment_template} \tab Gets information about the specified experiment template\cr
#'  \link[paws.developer.tools:fis_get_safety_lever]{get_safety_lever} \tab Gets information about the specified safety lever\cr
#'  \link[paws.developer.tools:fis_get_target_account_configuration]{get_target_account_configuration} \tab Gets information about the specified target account configuration of the experiment template\cr
#'  \link[paws.developer.tools:fis_get_target_resource_type]{get_target_resource_type} \tab Gets information about the specified resource type\cr
#'  \link[paws.developer.tools:fis_list_actions]{list_actions} \tab Lists the available FIS actions\cr
#'  \link[paws.developer.tools:fis_list_experiment_resolved_targets]{list_experiment_resolved_targets} \tab Lists the resolved targets information of the specified experiment\cr
#'  \link[paws.developer.tools:fis_list_experiments]{list_experiments} \tab Lists your experiments\cr
#'  \link[paws.developer.tools:fis_list_experiment_target_account_configurations]{list_experiment_target_account_configurations} \tab Lists the target account configurations of the specified experiment\cr
#'  \link[paws.developer.tools:fis_list_experiment_templates]{list_experiment_templates} \tab Lists your experiment templates\cr
#'  \link[paws.developer.tools:fis_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for the specified resource\cr
#'  \link[paws.developer.tools:fis_list_target_account_configurations]{list_target_account_configurations} \tab Lists the target account configurations of the specified experiment template\cr
#'  \link[paws.developer.tools:fis_list_target_resource_types]{list_target_resource_types} \tab Lists the target resource types\cr
#'  \link[paws.developer.tools:fis_start_experiment]{start_experiment} \tab Starts running an experiment from the specified experiment template\cr
#'  \link[paws.developer.tools:fis_stop_experiment]{stop_experiment} \tab Stops the specified experiment\cr
#'  \link[paws.developer.tools:fis_tag_resource]{tag_resource} \tab Applies the specified tags to the specified resource\cr
#'  \link[paws.developer.tools:fis_untag_resource]{untag_resource} \tab Removes the specified tags from the specified resource\cr
#'  \link[paws.developer.tools:fis_update_experiment_template]{update_experiment_template} \tab Updates the specified experiment template\cr
#'  \link[paws.developer.tools:fis_update_safety_lever_state]{update_safety_lever_state} \tab Updates the specified safety lever state\cr
#'  \link[paws.developer.tools:fis_update_target_account_configuration]{update_target_account_configuration} \tab Updates the target account configuration for the specified experiment template
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname fis
#' @export
fis <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::fis(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Well-Architected Tool
#'
#' @description
#' Well-Architected Tool
#' 
#' This is the *Well-Architected Tool API Reference*. The WA Tool API
#' provides programmatic access to the [Well-Architected
#' Tool](https://aws.amazon.com/well-architected-tool/) in the Amazon Web
#' Services Management Console. For information about the Well-Architected
#' Tool, see the [Well-Architected Tool User
#' Guide](https://docs.aws.amazon.com/wellarchitected/latest/userguide/intro.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- wellarchitected(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- wellarchitected()
#' svc$associate_lenses(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:wellarchitected_associate_lenses]{associate_lenses} \tab Associate a lens to a workload\cr
#'  \link[paws.developer.tools:wellarchitected_associate_profiles]{associate_profiles} \tab Associate a profile with a workload\cr
#'  \link[paws.developer.tools:wellarchitected_create_lens_share]{create_lens_share} \tab Create a lens share\cr
#'  \link[paws.developer.tools:wellarchitected_create_lens_version]{create_lens_version} \tab Create a new lens version\cr
#'  \link[paws.developer.tools:wellarchitected_create_milestone]{create_milestone} \tab Create a milestone for an existing workload\cr
#'  \link[paws.developer.tools:wellarchitected_create_profile]{create_profile} \tab Create a profile\cr
#'  \link[paws.developer.tools:wellarchitected_create_profile_share]{create_profile_share} \tab Create a profile share\cr
#'  \link[paws.developer.tools:wellarchitected_create_review_template]{create_review_template} \tab Create a review template\cr
#'  \link[paws.developer.tools:wellarchitected_create_template_share]{create_template_share} \tab Create a review template share\cr
#'  \link[paws.developer.tools:wellarchitected_create_workload]{create_workload} \tab Create a new workload\cr
#'  \link[paws.developer.tools:wellarchitected_create_workload_share]{create_workload_share} \tab Create a workload share\cr
#'  \link[paws.developer.tools:wellarchitected_delete_lens]{delete_lens} \tab Delete an existing lens\cr
#'  \link[paws.developer.tools:wellarchitected_delete_lens_share]{delete_lens_share} \tab Delete a lens share\cr
#'  \link[paws.developer.tools:wellarchitected_delete_profile]{delete_profile} \tab Delete a profile\cr
#'  \link[paws.developer.tools:wellarchitected_delete_profile_share]{delete_profile_share} \tab Delete a profile share\cr
#'  \link[paws.developer.tools:wellarchitected_delete_review_template]{delete_review_template} \tab Delete a review template\cr
#'  \link[paws.developer.tools:wellarchitected_delete_template_share]{delete_template_share} \tab Delete a review template share\cr
#'  \link[paws.developer.tools:wellarchitected_delete_workload]{delete_workload} \tab Delete an existing workload\cr
#'  \link[paws.developer.tools:wellarchitected_delete_workload_share]{delete_workload_share} \tab Delete a workload share\cr
#'  \link[paws.developer.tools:wellarchitected_disassociate_lenses]{disassociate_lenses} \tab Disassociate a lens from a workload\cr
#'  \link[paws.developer.tools:wellarchitected_disassociate_profiles]{disassociate_profiles} \tab Disassociate a profile from a workload\cr
#'  \link[paws.developer.tools:wellarchitected_export_lens]{export_lens} \tab Export an existing lens\cr
#'  \link[paws.developer.tools:wellarchitected_get_answer]{get_answer} \tab Get the answer to a specific question in a workload review\cr
#'  \link[paws.developer.tools:wellarchitected_get_consolidated_report]{get_consolidated_report} \tab Get a consolidated report of your workloads\cr
#'  \link[paws.developer.tools:wellarchitected_get_global_settings]{get_global_settings} \tab Global settings for all workloads\cr
#'  \link[paws.developer.tools:wellarchitected_get_lens]{get_lens} \tab Get an existing lens\cr
#'  \link[paws.developer.tools:wellarchitected_get_lens_review]{get_lens_review} \tab Get lens review\cr
#'  \link[paws.developer.tools:wellarchitected_get_lens_review_report]{get_lens_review_report} \tab Get lens review report\cr
#'  \link[paws.developer.tools:wellarchitected_get_lens_version_difference]{get_lens_version_difference} \tab Get lens version differences\cr
#'  \link[paws.developer.tools:wellarchitected_get_milestone]{get_milestone} \tab Get a milestone for an existing workload\cr
#'  \link[paws.developer.tools:wellarchitected_get_profile]{get_profile} \tab Get profile information\cr
#'  \link[paws.developer.tools:wellarchitected_get_profile_template]{get_profile_template} \tab Get profile template\cr
#'  \link[paws.developer.tools:wellarchitected_get_review_template]{get_review_template} \tab Get review template\cr
#'  \link[paws.developer.tools:wellarchitected_get_review_template_answer]{get_review_template_answer} \tab Get review template answer\cr
#'  \link[paws.developer.tools:wellarchitected_get_review_template_lens_review]{get_review_template_lens_review} \tab Get a lens review associated with a review template\cr
#'  \link[paws.developer.tools:wellarchitected_get_workload]{get_workload} \tab Get an existing workload\cr
#'  \link[paws.developer.tools:wellarchitected_import_lens]{import_lens} \tab Import a new custom lens or update an existing custom lens\cr
#'  \link[paws.developer.tools:wellarchitected_list_answers]{list_answers} \tab List of answers for a particular workload and lens\cr
#'  \link[paws.developer.tools:wellarchitected_list_check_details]{list_check_details} \tab List of Trusted Advisor check details by account related to the workload\cr
#'  \link[paws.developer.tools:wellarchitected_list_check_summaries]{list_check_summaries} \tab List of Trusted Advisor checks summarized for all accounts related to the workload\cr
#'  \link[paws.developer.tools:wellarchitected_list_lenses]{list_lenses} \tab List the available lenses\cr
#'  \link[paws.developer.tools:wellarchitected_list_lens_review_improvements]{list_lens_review_improvements} \tab List the improvements of a particular lens review\cr
#'  \link[paws.developer.tools:wellarchitected_list_lens_reviews]{list_lens_reviews} \tab List lens reviews for a particular workload\cr
#'  \link[paws.developer.tools:wellarchitected_list_lens_shares]{list_lens_shares} \tab List the lens shares associated with the lens\cr
#'  \link[paws.developer.tools:wellarchitected_list_milestones]{list_milestones} \tab List all milestones for an existing workload\cr
#'  \link[paws.developer.tools:wellarchitected_list_notifications]{list_notifications} \tab List lens notifications\cr
#'  \link[paws.developer.tools:wellarchitected_list_profile_notifications]{list_profile_notifications} \tab List profile notifications\cr
#'  \link[paws.developer.tools:wellarchitected_list_profiles]{list_profiles} \tab List profiles\cr
#'  \link[paws.developer.tools:wellarchitected_list_profile_shares]{list_profile_shares} \tab List profile shares\cr
#'  \link[paws.developer.tools:wellarchitected_list_review_template_answers]{list_review_template_answers} \tab List the answers of a review template\cr
#'  \link[paws.developer.tools:wellarchitected_list_review_templates]{list_review_templates} \tab List review templates\cr
#'  \link[paws.developer.tools:wellarchitected_list_share_invitations]{list_share_invitations} \tab List the share invitations\cr
#'  \link[paws.developer.tools:wellarchitected_list_tags_for_resource]{list_tags_for_resource} \tab List the tags for a resource\cr
#'  \link[paws.developer.tools:wellarchitected_list_template_shares]{list_template_shares} \tab List review template shares\cr
#'  \link[paws.developer.tools:wellarchitected_list_workloads]{list_workloads} \tab Paginated list of workloads\cr
#'  \link[paws.developer.tools:wellarchitected_list_workload_shares]{list_workload_shares} \tab List the workload shares associated with the workload\cr
#'  \link[paws.developer.tools:wellarchitected_tag_resource]{tag_resource} \tab Adds one or more tags to the specified resource\cr
#'  \link[paws.developer.tools:wellarchitected_untag_resource]{untag_resource} \tab Deletes specified tags from a resource\cr
#'  \link[paws.developer.tools:wellarchitected_update_answer]{update_answer} \tab Update the answer to a specific question in a workload review\cr
#'  \link[paws.developer.tools:wellarchitected_update_global_settings]{update_global_settings} \tab Update whether the Amazon Web Services account is opted into organization sharing and discovery integration features\cr
#'  \link[paws.developer.tools:wellarchitected_update_integration]{update_integration} \tab Update integration features\cr
#'  \link[paws.developer.tools:wellarchitected_update_lens_review]{update_lens_review} \tab Update lens review for a particular workload\cr
#'  \link[paws.developer.tools:wellarchitected_update_profile]{update_profile} \tab Update a profile\cr
#'  \link[paws.developer.tools:wellarchitected_update_review_template]{update_review_template} \tab Update a review template\cr
#'  \link[paws.developer.tools:wellarchitected_update_review_template_answer]{update_review_template_answer} \tab Update a review template answer\cr
#'  \link[paws.developer.tools:wellarchitected_update_review_template_lens_review]{update_review_template_lens_review} \tab Update a lens review associated with a review template\cr
#'  \link[paws.developer.tools:wellarchitected_update_share_invitation]{update_share_invitation} \tab Update a workload or custom lens share invitation\cr
#'  \link[paws.developer.tools:wellarchitected_update_workload]{update_workload} \tab Update an existing workload\cr
#'  \link[paws.developer.tools:wellarchitected_update_workload_share]{update_workload_share} \tab Update a workload share\cr
#'  \link[paws.developer.tools:wellarchitected_upgrade_lens_review]{upgrade_lens_review} \tab Upgrade lens review for a particular workload\cr
#'  \link[paws.developer.tools:wellarchitected_upgrade_profile_version]{upgrade_profile_version} \tab Upgrade a profile\cr
#'  \link[paws.developer.tools:wellarchitected_upgrade_review_template_lens_review]{upgrade_review_template_lens_review} \tab Upgrade the lens review of a review template
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname wellarchitected
#' @export
wellarchitected <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::wellarchitected(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS X-Ray
#'
#' @description
#' Amazon Web Services X-Ray provides APIs for managing debug traces and
#' retrieving service maps and other data created by processing those
#' traces.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- xray(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- xray()
#' svc$batch_get_traces(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.developer.tools:xray_batch_get_traces]{batch_get_traces} \tab You cannot find traces through this API if Transaction Search is enabled since trace is not indexed in X-Ray\cr
#'  \link[paws.developer.tools:xray_cancel_trace_retrieval]{cancel_trace_retrieval} \tab Cancels an ongoing trace retrieval job initiated by StartTraceRetrieval using the provided RetrievalToken\cr
#'  \link[paws.developer.tools:xray_create_group]{create_group} \tab Creates a group resource with a name and a filter expression\cr
#'  \link[paws.developer.tools:xray_create_sampling_rule]{create_sampling_rule} \tab Creates a rule to control sampling behavior for instrumented applications\cr
#'  \link[paws.developer.tools:xray_delete_group]{delete_group} \tab Deletes a group resource\cr
#'  \link[paws.developer.tools:xray_delete_resource_policy]{delete_resource_policy} \tab Deletes a resource policy from the target Amazon Web Services account\cr
#'  \link[paws.developer.tools:xray_delete_sampling_rule]{delete_sampling_rule} \tab Deletes a sampling rule\cr
#'  \link[paws.developer.tools:xray_get_encryption_config]{get_encryption_config} \tab Retrieves the current encryption configuration for X-Ray data\cr
#'  \link[paws.developer.tools:xray_get_group]{get_group} \tab Retrieves group resource details\cr
#'  \link[paws.developer.tools:xray_get_groups]{get_groups} \tab Retrieves all active group details\cr
#'  \link[paws.developer.tools:xray_get_indexing_rules]{get_indexing_rules} \tab Retrieves all indexing rules\cr
#'  \link[paws.developer.tools:xray_get_insight]{get_insight} \tab Retrieves the summary information of an insight\cr
#'  \link[paws.developer.tools:xray_get_insight_events]{get_insight_events} \tab X-Ray reevaluates insights periodically until they're resolved, and records each intermediate state as an event\cr
#'  \link[paws.developer.tools:xray_get_insight_impact_graph]{get_insight_impact_graph} \tab Retrieves a service graph structure filtered by the specified insight\cr
#'  \link[paws.developer.tools:xray_get_insight_summaries]{get_insight_summaries} \tab Retrieves the summaries of all insights in the specified group matching the provided filter values\cr
#'  \link[paws.developer.tools:xray_get_retrieved_traces_graph]{get_retrieved_traces_graph} \tab Retrieves a service graph for traces based on the specified RetrievalToken from the CloudWatch log group generated by Transaction Search\cr
#'  \link[paws.developer.tools:xray_get_sampling_rules]{get_sampling_rules} \tab Retrieves all sampling rules\cr
#'  \link[paws.developer.tools:xray_get_sampling_statistic_summaries]{get_sampling_statistic_summaries} \tab Retrieves information about recent sampling results for all sampling rules\cr
#'  \link[paws.developer.tools:xray_get_sampling_targets]{get_sampling_targets} \tab Requests a sampling quota for rules that the service is using to sample requests\cr
#'  \link[paws.developer.tools:xray_get_service_graph]{get_service_graph} \tab Retrieves a document that describes services that process incoming requests, and downstream services that they call as a result\cr
#'  \link[paws.developer.tools:xray_get_time_series_service_statistics]{get_time_series_service_statistics} \tab Get an aggregation of service statistics defined by a specific time range\cr
#'  \link[paws.developer.tools:xray_get_trace_graph]{get_trace_graph} \tab Retrieves a service graph for one or more specific trace IDs\cr
#'  \link[paws.developer.tools:xray_get_trace_segment_destination]{get_trace_segment_destination} \tab Retrieves the current destination of data sent to PutTraceSegments and OpenTelemetry API\cr
#'  \link[paws.developer.tools:xray_get_trace_summaries]{get_trace_summaries} \tab Retrieves IDs and annotations for traces available for a specified time frame using an optional filter\cr
#'  \link[paws.developer.tools:xray_list_resource_policies]{list_resource_policies} \tab Returns the list of resource policies in the target Amazon Web Services account\cr
#'  \link[paws.developer.tools:xray_list_retrieved_traces]{list_retrieved_traces} \tab Retrieves a list of traces for a given RetrievalToken from the CloudWatch log group generated by Transaction Search\cr
#'  \link[paws.developer.tools:xray_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags that are applied to the specified Amazon Web Services X-Ray group or sampling rule\cr
#'  \link[paws.developer.tools:xray_put_encryption_config]{put_encryption_config} \tab Updates the encryption configuration for X-Ray data\cr
#'  \link[paws.developer.tools:xray_put_resource_policy]{put_resource_policy} \tab Sets the resource policy to grant one or more Amazon Web Services services and accounts permissions to access X-Ray\cr
#'  \link[paws.developer.tools:xray_put_telemetry_records]{put_telemetry_records} \tab Used by the Amazon Web Services X-Ray daemon to upload telemetry\cr
#'  \link[paws.developer.tools:xray_put_trace_segments]{put_trace_segments} \tab Uploads segment documents to Amazon Web Services X-Ray\cr
#'  \link[paws.developer.tools:xray_start_trace_retrieval]{start_trace_retrieval} \tab Initiates a trace retrieval process using the specified time range and for the give trace IDs on Transaction Search generated by the CloudWatch log group\cr
#'  \link[paws.developer.tools:xray_tag_resource]{tag_resource} \tab Applies tags to an existing Amazon Web Services X-Ray group or sampling rule\cr
#'  \link[paws.developer.tools:xray_untag_resource]{untag_resource} \tab Removes tags from an Amazon Web Services X-Ray group or sampling rule\cr
#'  \link[paws.developer.tools:xray_update_group]{update_group} \tab Updates a group resource\cr
#'  \link[paws.developer.tools:xray_update_indexing_rule]{update_indexing_rule} \tab Modifies an indexing rule’s configuration\cr
#'  \link[paws.developer.tools:xray_update_sampling_rule]{update_sampling_rule} \tab Modifies a sampling rule's configuration\cr
#'  \link[paws.developer.tools:xray_update_trace_segment_destination]{update_trace_segment_destination} \tab Modifies the destination of data sent to PutTraceSegments
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname xray
#' @export
xray <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.developer.tools::xray(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Prometheus Service
#'
#' @description
#' Amazon Managed Service for Prometheus is a serverless,
#' Prometheus-compatible monitoring service for container metrics that
#' makes it easier to securely monitor container environments at scale.
#' With Amazon Managed Service for Prometheus, you can use the same
#' open-source Prometheus data model and query language that you use today
#' to monitor the performance of your containerized workloads, and also
#' enjoy improved scalability, availability, and security without having to
#' manage the underlying infrastructure.
#' 
#' For more information about Amazon Managed Service for Prometheus, see
#' the [Amazon Managed Service for
#' Prometheus](https://docs.aws.amazon.com/prometheus/latest/userguide/what-is-Amazon-Managed-Service-Prometheus.html)
#' User Guide.
#' 
#' Amazon Managed Service for Prometheus includes two APIs.
#' 
#' -   Use the Amazon Web Services API described in this guide to manage
#'     Amazon Managed Service for Prometheus resources, such as workspaces,
#'     rule groups, and alert managers.
#' 
#' -   Use the [Prometheus-compatible
#'     API](https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-APIReference.html#AMP-APIReference-Prometheus-Compatible-Apis)
#'     to work within your Prometheus workspace.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- prometheusservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- prometheusservice()
#' svc$create_alert_manager_definition(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:prometheusservice_create_alert_manager_definition]{create_alert_manager_definition} \tab The CreateAlertManagerDefinition operation creates the alert manager definition in a workspace\cr
#'  \link[paws.management:prometheusservice_create_logging_configuration]{create_logging_configuration} \tab The CreateLoggingConfiguration operation creates a logging configuration for the workspace\cr
#'  \link[paws.management:prometheusservice_create_rule_groups_namespace]{create_rule_groups_namespace} \tab The CreateRuleGroupsNamespace operation creates a rule groups namespace within a workspace\cr
#'  \link[paws.management:prometheusservice_create_scraper]{create_scraper} \tab The CreateScraper operation creates a scraper to collect metrics\cr
#'  \link[paws.management:prometheusservice_create_workspace]{create_workspace} \tab Creates a Prometheus workspace\cr
#'  \link[paws.management:prometheusservice_delete_alert_manager_definition]{delete_alert_manager_definition} \tab Deletes the alert manager definition from a workspace\cr
#'  \link[paws.management:prometheusservice_delete_logging_configuration]{delete_logging_configuration} \tab Deletes the logging configuration for a workspace\cr
#'  \link[paws.management:prometheusservice_delete_rule_groups_namespace]{delete_rule_groups_namespace} \tab Deletes one rule groups namespace and its associated rule groups definition\cr
#'  \link[paws.management:prometheusservice_delete_scraper]{delete_scraper} \tab The DeleteScraper operation deletes one scraper, and stops any metrics collection that the scraper performs\cr
#'  \link[paws.management:prometheusservice_delete_workspace]{delete_workspace} \tab Deletes an existing workspace\cr
#'  \link[paws.management:prometheusservice_describe_alert_manager_definition]{describe_alert_manager_definition} \tab Retrieves the full information about the alert manager definition for a workspace\cr
#'  \link[paws.management:prometheusservice_describe_logging_configuration]{describe_logging_configuration} \tab Returns complete information about the current logging configuration of the workspace\cr
#'  \link[paws.management:prometheusservice_describe_rule_groups_namespace]{describe_rule_groups_namespace} \tab Returns complete information about one rule groups namespace\cr
#'  \link[paws.management:prometheusservice_describe_scraper]{describe_scraper} \tab The DescribeScraper operation displays information about an existing scraper\cr
#'  \link[paws.management:prometheusservice_describe_workspace]{describe_workspace} \tab Returns information about an existing workspace\cr
#'  \link[paws.management:prometheusservice_get_default_scraper_configuration]{get_default_scraper_configuration} \tab The GetDefaultScraperConfiguration operation returns the default scraper configuration used when Amazon EKS creates a scraper for you\cr
#'  \link[paws.management:prometheusservice_list_rule_groups_namespaces]{list_rule_groups_namespaces} \tab Returns a list of rule groups namespaces in a workspace\cr
#'  \link[paws.management:prometheusservice_list_scrapers]{list_scrapers} \tab The ListScrapers operation lists all of the scrapers in your account\cr
#'  \link[paws.management:prometheusservice_list_tags_for_resource]{list_tags_for_resource} \tab The ListTagsForResource operation returns the tags that are associated with an Amazon Managed Service for Prometheus resource\cr
#'  \link[paws.management:prometheusservice_list_workspaces]{list_workspaces} \tab Lists all of the Amazon Managed Service for Prometheus workspaces in your account\cr
#'  \link[paws.management:prometheusservice_put_alert_manager_definition]{put_alert_manager_definition} \tab Updates an existing alert manager definition in a workspace\cr
#'  \link[paws.management:prometheusservice_put_rule_groups_namespace]{put_rule_groups_namespace} \tab Updates an existing rule groups namespace within a workspace\cr
#'  \link[paws.management:prometheusservice_tag_resource]{tag_resource} \tab The TagResource operation associates tags with an Amazon Managed Service for Prometheus resource\cr
#'  \link[paws.management:prometheusservice_untag_resource]{untag_resource} \tab Removes the specified tags from an Amazon Managed Service for Prometheus resource\cr
#'  \link[paws.management:prometheusservice_update_logging_configuration]{update_logging_configuration} \tab Updates the log group ARN or the workspace ID of the current logging configuration\cr
#'  \link[paws.management:prometheusservice_update_scraper]{update_scraper} \tab Updates an existing scraper\cr
#'  \link[paws.management:prometheusservice_update_workspace_alias]{update_workspace_alias} \tab Updates the alias of an existing workspace
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname prometheusservice
#' @export
prometheusservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::prometheusservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Application Auto Scaling
#'
#' @description
#' With Application Auto Scaling, you can configure automatic scaling for
#' the following resources:
#' 
#' -   Amazon AppStream 2.0 fleets
#' 
#' -   Amazon Aurora Replicas
#' 
#' -   Amazon Comprehend document classification and entity recognizer
#'     endpoints
#' 
#' -   Amazon DynamoDB tables and global secondary indexes throughput
#'     capacity
#' 
#' -   Amazon ECS services
#' 
#' -   Amazon ElastiCache for Redis clusters (replication groups)
#' 
#' -   Amazon EMR clusters
#' 
#' -   Amazon Keyspaces (for Apache Cassandra) tables
#' 
#' -   Lambda function provisioned concurrency
#' 
#' -   Amazon Managed Streaming for Apache Kafka broker storage
#' 
#' -   Amazon Neptune clusters
#' 
#' -   Amazon SageMaker endpoint variants
#' 
#' -   Amazon SageMaker inference components
#' 
#' -   Amazon SageMaker serverless endpoint provisioned concurrency
#' 
#' -   Spot Fleets (Amazon EC2)
#' 
#' -   Pool of WorkSpaces
#' 
#' -   Custom resources provided by your own applications or services
#' 
#' To learn more about Application Auto Scaling, see the [Application Auto
#' Scaling User
#' Guide](https://docs.aws.amazon.com/autoscaling/application/userguide/what-is-application-auto-scaling.html).
#' 
#' **API Summary**
#' 
#' The Application Auto Scaling service API includes three key sets of
#' actions:
#' 
#' -   Register and manage scalable targets - Register Amazon Web Services
#'     or custom resources as scalable targets (a resource that Application
#'     Auto Scaling can scale), set minimum and maximum capacity limits,
#'     and retrieve information on existing scalable targets.
#' 
#' -   Configure and manage automatic scaling - Define scaling policies to
#'     dynamically scale your resources in response to CloudWatch alarms,
#'     schedule one-time or recurring scaling actions, and retrieve your
#'     recent scaling activity history.
#' 
#' -   Suspend and resume scaling - Temporarily suspend and later resume
#'     automatic scaling by calling the
#'     `register_scalable_target`
#'     API action for any Application Auto Scaling scalable target. You can
#'     suspend and resume (individually or in combination) scale-out
#'     activities that are triggered by a scaling policy, scale-in
#'     activities that are triggered by a scaling policy, and scheduled
#'     scaling.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- applicationautoscaling(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- applicationautoscaling()
#' # This example deletes a scaling policy for the Amazon ECS service called
#' # web-app, which is running in the default cluster.
#' svc$delete_scaling_policy(
#'   PolicyName = "web-app-cpu-lt-25",
#'   ResourceId = "service/default/web-app",
#'   ScalableDimension = "ecs:service:DesiredCount",
#'   ServiceNamespace = "ecs"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:applicationautoscaling_delete_scaling_policy]{delete_scaling_policy} \tab Deletes the specified scaling policy for an Application Auto Scaling scalable target\cr
#'  \link[paws.management:applicationautoscaling_delete_scheduled_action]{delete_scheduled_action} \tab Deletes the specified scheduled action for an Application Auto Scaling scalable target\cr
#'  \link[paws.management:applicationautoscaling_deregister_scalable_target]{deregister_scalable_target} \tab Deregisters an Application Auto Scaling scalable target when you have finished using it\cr
#'  \link[paws.management:applicationautoscaling_describe_scalable_targets]{describe_scalable_targets} \tab Gets information about the scalable targets in the specified namespace\cr
#'  \link[paws.management:applicationautoscaling_describe_scaling_activities]{describe_scaling_activities} \tab Provides descriptive information about the scaling activities in the specified namespace from the previous six weeks\cr
#'  \link[paws.management:applicationautoscaling_describe_scaling_policies]{describe_scaling_policies} \tab Describes the Application Auto Scaling scaling policies for the specified service namespace\cr
#'  \link[paws.management:applicationautoscaling_describe_scheduled_actions]{describe_scheduled_actions} \tab Describes the Application Auto Scaling scheduled actions for the specified service namespace\cr
#'  \link[paws.management:applicationautoscaling_get_predictive_scaling_forecast]{get_predictive_scaling_forecast} \tab Retrieves the forecast data for a predictive scaling policy\cr
#'  \link[paws.management:applicationautoscaling_list_tags_for_resource]{list_tags_for_resource} \tab Returns all the tags on the specified Application Auto Scaling scalable target\cr
#'  \link[paws.management:applicationautoscaling_put_scaling_policy]{put_scaling_policy} \tab Creates or updates a scaling policy for an Application Auto Scaling scalable target\cr
#'  \link[paws.management:applicationautoscaling_put_scheduled_action]{put_scheduled_action} \tab Creates or updates a scheduled action for an Application Auto Scaling scalable target\cr
#'  \link[paws.management:applicationautoscaling_register_scalable_target]{register_scalable_target} \tab Registers or updates a scalable target, which is the resource that you want to scale\cr
#'  \link[paws.management:applicationautoscaling_tag_resource]{tag_resource} \tab Adds or edits tags on an Application Auto Scaling scalable target\cr
#'  \link[paws.management:applicationautoscaling_untag_resource]{untag_resource} \tab Deletes tags from an Application Auto Scaling scalable target
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname applicationautoscaling
#' @export
applicationautoscaling <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::applicationautoscaling(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudWatch Application Insights
#'
#' @description
#' Amazon CloudWatch Application Insights is a service that helps you
#' detect common problems with your applications. It enables you to
#' pinpoint the source of issues in your applications (built with
#' technologies such as Microsoft IIS, .NET, and Microsoft SQL Server), by
#' providing key insights into detected problems.
#' 
#' After you onboard your application, CloudWatch Application Insights
#' identifies, recommends, and sets up metrics and logs. It continuously
#' analyzes and correlates your metrics and logs for unusual behavior to
#' surface actionable problems with your application. For example, if your
#' application is slow and unresponsive and leading to HTTP 500 errors in
#' your Application Load Balancer (ALB), Application Insights informs you
#' that a memory pressure problem with your SQL Server database is
#' occurring. It bases this analysis on impactful metrics and log errors.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- applicationinsights(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- applicationinsights()
#' svc$add_workload(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:applicationinsights_add_workload]{add_workload} \tab Adds a workload to a component\cr
#'  \link[paws.management:applicationinsights_create_application]{create_application} \tab Adds an application that is created from a resource group\cr
#'  \link[paws.management:applicationinsights_create_component]{create_component} \tab Creates a custom component by grouping similar standalone instances to monitor\cr
#'  \link[paws.management:applicationinsights_create_log_pattern]{create_log_pattern} \tab Adds an log pattern to a LogPatternSet\cr
#'  \link[paws.management:applicationinsights_delete_application]{delete_application} \tab Removes the specified application from monitoring\cr
#'  \link[paws.management:applicationinsights_delete_component]{delete_component} \tab Ungroups a custom component\cr
#'  \link[paws.management:applicationinsights_delete_log_pattern]{delete_log_pattern} \tab Removes the specified log pattern from a LogPatternSet\cr
#'  \link[paws.management:applicationinsights_describe_application]{describe_application} \tab Describes the application\cr
#'  \link[paws.management:applicationinsights_describe_component]{describe_component} \tab Describes a component and lists the resources that are grouped together in a component\cr
#'  \link[paws.management:applicationinsights_describe_component_configuration]{describe_component_configuration} \tab Describes the monitoring configuration of the component\cr
#'  \link[paws.management:applicationinsights_describe_component_configuration_recommendation]{describe_component_configuration_recommendation} \tab Describes the recommended monitoring configuration of the component\cr
#'  \link[paws.management:applicationinsights_describe_log_pattern]{describe_log_pattern} \tab Describe a specific log pattern from a LogPatternSet\cr
#'  \link[paws.management:applicationinsights_describe_observation]{describe_observation} \tab Describes an anomaly or error with the application\cr
#'  \link[paws.management:applicationinsights_describe_problem]{describe_problem} \tab Describes an application problem\cr
#'  \link[paws.management:applicationinsights_describe_problem_observations]{describe_problem_observations} \tab Describes the anomalies or errors associated with the problem\cr
#'  \link[paws.management:applicationinsights_describe_workload]{describe_workload} \tab Describes a workload and its configuration\cr
#'  \link[paws.management:applicationinsights_list_applications]{list_applications} \tab Lists the IDs of the applications that you are monitoring\cr
#'  \link[paws.management:applicationinsights_list_components]{list_components} \tab Lists the auto-grouped, standalone, and custom components of the application\cr
#'  \link[paws.management:applicationinsights_list_configuration_history]{list_configuration_history} \tab Lists the INFO, WARN, and ERROR events for periodic configuration updates performed by Application Insights\cr
#'  \link[paws.management:applicationinsights_list_log_patterns]{list_log_patterns} \tab Lists the log patterns in the specific log LogPatternSet\cr
#'  \link[paws.management:applicationinsights_list_log_pattern_sets]{list_log_pattern_sets} \tab Lists the log pattern sets in the specific application\cr
#'  \link[paws.management:applicationinsights_list_problems]{list_problems} \tab Lists the problems with your application\cr
#'  \link[paws.management:applicationinsights_list_tags_for_resource]{list_tags_for_resource} \tab Retrieve a list of the tags (keys and values) that are associated with a specified application\cr
#'  \link[paws.management:applicationinsights_list_workloads]{list_workloads} \tab Lists the workloads that are configured on a given component\cr
#'  \link[paws.management:applicationinsights_remove_workload]{remove_workload} \tab Remove workload from a component\cr
#'  \link[paws.management:applicationinsights_tag_resource]{tag_resource} \tab Add one or more tags (keys and values) to a specified application\cr
#'  \link[paws.management:applicationinsights_untag_resource]{untag_resource} \tab Remove one or more tags (keys and values) from a specified application\cr
#'  \link[paws.management:applicationinsights_update_application]{update_application} \tab Updates the application\cr
#'  \link[paws.management:applicationinsights_update_component]{update_component} \tab Updates the custom component name and/or the list of resources that make up the component\cr
#'  \link[paws.management:applicationinsights_update_component_configuration]{update_component_configuration} \tab Updates the monitoring configurations for the component\cr
#'  \link[paws.management:applicationinsights_update_log_pattern]{update_log_pattern} \tab Adds a log pattern to a LogPatternSet\cr
#'  \link[paws.management:applicationinsights_update_problem]{update_problem} \tab Updates the visibility of the problem or specifies the problem as RESOLVED\cr
#'  \link[paws.management:applicationinsights_update_workload]{update_workload} \tab Adds a workload to a component
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname applicationinsights
#' @export
applicationinsights <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::applicationinsights(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudWatch Application Signals
#'
#' @description
#' Use CloudWatch Application Signals for comprehensive observability of
#' your cloud-based applications. It enables real-time service health
#' dashboards and helps you track long-term performance trends against your
#' business goals. The application-centric view provides you with unified
#' visibility across your applications, services, and dependencies, so you
#' can proactively monitor and efficiently triage any issues that may
#' arise, ensuring optimal customer experience.
#' 
#' Application Signals provides the following benefits:
#' 
#' -   Automatically collect metrics and traces from your applications, and
#'     display key metrics such as call volume, availability, latency,
#'     faults, and errors.
#' 
#' -   Create and monitor service level objectives (SLOs).
#' 
#' -   See a map of your application topology that Application Signals
#'     automatically discovers, that gives you a visual representation of
#'     your applications, dependencies, and their connectivity.
#' 
#' Application Signals works with CloudWatch RUM, CloudWatch Synthetics
#' canaries, and Amazon Web Services Service Catalog AppRegistry, to
#' display your client pages, Synthetics canaries, and application names
#' within dashboards and maps.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudwatchapplicationsignals(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudwatchapplicationsignals()
#' svc$batch_get_service_level_objective_budget_report(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudwatchapplicationsignals_batch_get_service_level_objective_budget_report]{batch_get_service_level_objective_budget_report} \tab Use this operation to retrieve one or more service level objective (SLO) budget reports\cr
#'  \link[paws.management:cloudwatchapplicationsignals_create_service_level_objective]{create_service_level_objective} \tab Creates a service level objective (SLO), which can help you ensure that your critical business operations are meeting customer expectations\cr
#'  \link[paws.management:cloudwatchapplicationsignals_delete_service_level_objective]{delete_service_level_objective} \tab Deletes the specified service level objective\cr
#'  \link[paws.management:cloudwatchapplicationsignals_get_service]{get_service} \tab Returns information about a service discovered by Application Signals\cr
#'  \link[paws.management:cloudwatchapplicationsignals_get_service_level_objective]{get_service_level_objective} \tab Returns information about one SLO created in the account\cr
#'  \link[paws.management:cloudwatchapplicationsignals_list_service_dependencies]{list_service_dependencies} \tab Returns a list of service dependencies of the service that you specify\cr
#'  \link[paws.management:cloudwatchapplicationsignals_list_service_dependents]{list_service_dependents} \tab Returns the list of dependents that invoked the specified service during the provided time range\cr
#'  \link[paws.management:cloudwatchapplicationsignals_list_service_level_objectives]{list_service_level_objectives} \tab Returns a list of SLOs created in this account\cr
#'  \link[paws.management:cloudwatchapplicationsignals_list_service_operations]{list_service_operations} \tab Returns a list of the operations of this service that have been discovered by Application Signals\cr
#'  \link[paws.management:cloudwatchapplicationsignals_list_services]{list_services} \tab Returns a list of services that have been discovered by Application Signals\cr
#'  \link[paws.management:cloudwatchapplicationsignals_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with a CloudWatch resource\cr
#'  \link[paws.management:cloudwatchapplicationsignals_start_discovery]{start_discovery} \tab Enables this Amazon Web Services account to be able to use CloudWatch Application Signals by creating the AWSServiceRoleForCloudWatchApplicationSignals service-linked role\cr
#'  \link[paws.management:cloudwatchapplicationsignals_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified CloudWatch resource, such as a service level objective\cr
#'  \link[paws.management:cloudwatchapplicationsignals_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.management:cloudwatchapplicationsignals_update_service_level_objective]{update_service_level_objective} \tab Updates an existing service level objective (SLO)
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudwatchapplicationsignals
#' @export
cloudwatchapplicationsignals <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudwatchapplicationsignals(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Application Cost Profiler
#'
#' @description
#' This reference provides descriptions of the AWS Application Cost
#' Profiler API.
#' 
#' The AWS Application Cost Profiler API provides programmatic access to
#' view, create, update, and delete application cost report definitions, as
#' well as to import your usage data into the Application Cost Profiler
#' service.
#' 
#' For more information about using this service, see the AWS Application
#' Cost Profiler User Guide.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- applicationcostprofiler(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- applicationcostprofiler()
#' svc$delete_report_definition(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:applicationcostprofiler_delete_report_definition]{delete_report_definition} \tab Deletes the specified report definition in AWS Application Cost Profiler\cr
#'  \link[paws.management:applicationcostprofiler_get_report_definition]{get_report_definition} \tab Retrieves the definition of a report already configured in AWS Application Cost Profiler\cr
#'  \link[paws.management:applicationcostprofiler_import_application_usage]{import_application_usage} \tab Ingests application usage data from Amazon Simple Storage Service (Amazon S3)\cr
#'  \link[paws.management:applicationcostprofiler_list_report_definitions]{list_report_definitions} \tab Retrieves a list of all reports and their configurations for your AWS account\cr
#'  \link[paws.management:applicationcostprofiler_put_report_definition]{put_report_definition} \tab Creates the report definition for a report in Application Cost Profiler\cr
#'  \link[paws.management:applicationcostprofiler_update_report_definition]{update_report_definition} \tab Updates existing report in AWS Application Cost Profiler
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname applicationcostprofiler
#' @export
applicationcostprofiler <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::applicationcostprofiler(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Audit Manager
#'
#' @description
#' Welcome to the Audit Manager API reference. This guide is for developers
#' who need detailed information about the Audit Manager API operations,
#' data types, and errors.
#' 
#' Audit Manager is a service that provides automated evidence collection
#' so that you can continually audit your Amazon Web Services usage. You
#' can use it to assess the effectiveness of your controls, manage risk,
#' and simplify compliance.
#' 
#' Audit Manager provides prebuilt frameworks that structure and automate
#' assessments for a given compliance standard. Frameworks include a
#' prebuilt collection of controls with descriptions and testing
#' procedures. These controls are grouped according to the requirements of
#' the specified compliance standard or regulation. You can also customize
#' frameworks and controls to support internal audits with specific
#' requirements.
#' 
#' Use the following links to get started with the Audit Manager API:
#' 
#' -   [Actions](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_Operations.html):
#'     An alphabetical list of all Audit Manager API operations.
#' 
#' -   [Data
#'     types](https://docs.aws.amazon.com/audit-manager/latest/APIReference/API_Types.html):
#'     An alphabetical list of all Audit Manager data types.
#' 
#' -   [Common
#'     parameters](https://docs.aws.amazon.com/audit-manager/latest/APIReference/CommonParameters.html):
#'     Parameters that all operations can use.
#' 
#' -   [Common
#'     errors](https://docs.aws.amazon.com/audit-manager/latest/APIReference/CommonErrors.html):
#'     Client and server errors that all operations can return.
#' 
#' If you're new to Audit Manager, we recommend that you review the [Audit
#' Manager User
#' Guide](https://docs.aws.amazon.com/audit-manager/latest/userguide/what-is.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- auditmanager(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- auditmanager()
#' svc$associate_assessment_report_evidence_folder(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:auditmanager_associate_assessment_report_evidence_folder]{associate_assessment_report_evidence_folder} \tab Associates an evidence folder to an assessment report in an Audit Manager assessment\cr
#'  \link[paws.management:auditmanager_batch_associate_assessment_report_evidence]{batch_associate_assessment_report_evidence} \tab Associates a list of evidence to an assessment report in an Audit Manager assessment\cr
#'  \link[paws.management:auditmanager_batch_create_delegation_by_assessment]{batch_create_delegation_by_assessment} \tab Creates a batch of delegations for an assessment in Audit Manager\cr
#'  \link[paws.management:auditmanager_batch_delete_delegation_by_assessment]{batch_delete_delegation_by_assessment} \tab Deletes a batch of delegations for an assessment in Audit Manager\cr
#'  \link[paws.management:auditmanager_batch_disassociate_assessment_report_evidence]{batch_disassociate_assessment_report_evidence} \tab Disassociates a list of evidence from an assessment report in Audit Manager\cr
#'  \link[paws.management:auditmanager_batch_import_evidence_to_assessment_control]{batch_import_evidence_to_assessment_control} \tab Adds one or more pieces of evidence to a control in an Audit Manager assessment\cr
#'  \link[paws.management:auditmanager_create_assessment]{create_assessment} \tab Creates an assessment in Audit Manager\cr
#'  \link[paws.management:auditmanager_create_assessment_framework]{create_assessment_framework} \tab Creates a custom framework in Audit Manager\cr
#'  \link[paws.management:auditmanager_create_assessment_report]{create_assessment_report} \tab Creates an assessment report for the specified assessment\cr
#'  \link[paws.management:auditmanager_create_control]{create_control} \tab Creates a new custom control in Audit Manager\cr
#'  \link[paws.management:auditmanager_delete_assessment]{delete_assessment} \tab Deletes an assessment in Audit Manager\cr
#'  \link[paws.management:auditmanager_delete_assessment_framework]{delete_assessment_framework} \tab Deletes a custom framework in Audit Manager\cr
#'  \link[paws.management:auditmanager_delete_assessment_framework_share]{delete_assessment_framework_share} \tab Deletes a share request for a custom framework in Audit Manager\cr
#'  \link[paws.management:auditmanager_delete_assessment_report]{delete_assessment_report} \tab Deletes an assessment report in Audit Manager\cr
#'  \link[paws.management:auditmanager_delete_control]{delete_control} \tab Deletes a custom control in Audit Manager\cr
#'  \link[paws.management:auditmanager_deregister_account]{deregister_account} \tab Deregisters an account in Audit Manager\cr
#'  \link[paws.management:auditmanager_deregister_organization_admin_account]{deregister_organization_admin_account} \tab Removes the specified Amazon Web Services account as a delegated administrator for Audit Manager\cr
#'  \link[paws.management:auditmanager_disassociate_assessment_report_evidence_folder]{disassociate_assessment_report_evidence_folder} \tab Disassociates an evidence folder from the specified assessment report in Audit Manager\cr
#'  \link[paws.management:auditmanager_get_account_status]{get_account_status} \tab Gets the registration status of an account in Audit Manager\cr
#'  \link[paws.management:auditmanager_get_assessment]{get_assessment} \tab Gets information about a specified assessment\cr
#'  \link[paws.management:auditmanager_get_assessment_framework]{get_assessment_framework} \tab Gets information about a specified framework\cr
#'  \link[paws.management:auditmanager_get_assessment_report_url]{get_assessment_report_url} \tab Gets the URL of an assessment report in Audit Manager\cr
#'  \link[paws.management:auditmanager_get_change_logs]{get_change_logs} \tab Gets a list of changelogs from Audit Manager\cr
#'  \link[paws.management:auditmanager_get_control]{get_control} \tab Gets information about a specified control\cr
#'  \link[paws.management:auditmanager_get_delegations]{get_delegations} \tab Gets a list of delegations from an audit owner to a delegate\cr
#'  \link[paws.management:auditmanager_get_evidence]{get_evidence} \tab Gets information about a specified evidence item\cr
#'  \link[paws.management:auditmanager_get_evidence_by_evidence_folder]{get_evidence_by_evidence_folder} \tab Gets all evidence from a specified evidence folder in Audit Manager\cr
#'  \link[paws.management:auditmanager_get_evidence_file_upload_url]{get_evidence_file_upload_url} \tab Creates a presigned Amazon S3 URL that can be used to upload a file as manual evidence\cr
#'  \link[paws.management:auditmanager_get_evidence_folder]{get_evidence_folder} \tab Gets an evidence folder from a specified assessment in Audit Manager\cr
#'  \link[paws.management:auditmanager_get_evidence_folders_by_assessment]{get_evidence_folders_by_assessment} \tab Gets the evidence folders from a specified assessment in Audit Manager\cr
#'  \link[paws.management:auditmanager_get_evidence_folders_by_assessment_control]{get_evidence_folders_by_assessment_control} \tab Gets a list of evidence folders that are associated with a specified control in an Audit Manager assessment\cr
#'  \link[paws.management:auditmanager_get_insights]{get_insights} \tab Gets the latest analytics data for all your current active assessments\cr
#'  \link[paws.management:auditmanager_get_insights_by_assessment]{get_insights_by_assessment} \tab Gets the latest analytics data for a specific active assessment\cr
#'  \link[paws.management:auditmanager_get_organization_admin_account]{get_organization_admin_account} \tab Gets the name of the delegated Amazon Web Services administrator account for a specified organization\cr
#'  \link[paws.management:auditmanager_get_services_in_scope]{get_services_in_scope} \tab Gets a list of the Amazon Web Services from which Audit Manager can collect evidence\cr
#'  \link[paws.management:auditmanager_get_settings]{get_settings} \tab Gets the settings for a specified Amazon Web Services account\cr
#'  \link[paws.management:auditmanager_list_assessment_control_insights_by_control_domain]{list_assessment_control_insights_by_control_domain} \tab Lists the latest analytics data for controls within a specific control domain and a specific active assessment\cr
#'  \link[paws.management:auditmanager_list_assessment_frameworks]{list_assessment_frameworks} \tab Returns a list of the frameworks that are available in the Audit Manager framework library\cr
#'  \link[paws.management:auditmanager_list_assessment_framework_share_requests]{list_assessment_framework_share_requests} \tab Returns a list of sent or received share requests for custom frameworks in Audit Manager\cr
#'  \link[paws.management:auditmanager_list_assessment_reports]{list_assessment_reports} \tab Returns a list of assessment reports created in Audit Manager\cr
#'  \link[paws.management:auditmanager_list_assessments]{list_assessments} \tab Returns a list of current and past assessments from Audit Manager\cr
#'  \link[paws.management:auditmanager_list_control_domain_insights]{list_control_domain_insights} \tab Lists the latest analytics data for control domains across all of your active assessments\cr
#'  \link[paws.management:auditmanager_list_control_domain_insights_by_assessment]{list_control_domain_insights_by_assessment} \tab Lists analytics data for control domains within a specified active assessment\cr
#'  \link[paws.management:auditmanager_list_control_insights_by_control_domain]{list_control_insights_by_control_domain} \tab Lists the latest analytics data for controls within a specific control domain across all active assessments\cr
#'  \link[paws.management:auditmanager_list_controls]{list_controls} \tab Returns a list of controls from Audit Manager\cr
#'  \link[paws.management:auditmanager_list_keywords_for_data_source]{list_keywords_for_data_source} \tab Returns a list of keywords that are pre-mapped to the specified control data source\cr
#'  \link[paws.management:auditmanager_list_notifications]{list_notifications} \tab Returns a list of all Audit Manager notifications\cr
#'  \link[paws.management:auditmanager_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags for the specified resource in Audit Manager\cr
#'  \link[paws.management:auditmanager_register_account]{register_account} \tab Enables Audit Manager for the specified Amazon Web Services account\cr
#'  \link[paws.management:auditmanager_register_organization_admin_account]{register_organization_admin_account} \tab Enables an Amazon Web Services account within the organization as the delegated administrator for Audit Manager\cr
#'  \link[paws.management:auditmanager_start_assessment_framework_share]{start_assessment_framework_share} \tab Creates a share request for a custom framework in Audit Manager\cr
#'  \link[paws.management:auditmanager_tag_resource]{tag_resource} \tab Tags the specified resource in Audit Manager\cr
#'  \link[paws.management:auditmanager_untag_resource]{untag_resource} \tab Removes a tag from a resource in Audit Manager\cr
#'  \link[paws.management:auditmanager_update_assessment]{update_assessment} \tab Edits an Audit Manager assessment\cr
#'  \link[paws.management:auditmanager_update_assessment_control]{update_assessment_control} \tab Updates a control within an assessment in Audit Manager\cr
#'  \link[paws.management:auditmanager_update_assessment_control_set_status]{update_assessment_control_set_status} \tab Updates the status of a control set in an Audit Manager assessment\cr
#'  \link[paws.management:auditmanager_update_assessment_framework]{update_assessment_framework} \tab Updates a custom framework in Audit Manager\cr
#'  \link[paws.management:auditmanager_update_assessment_framework_share]{update_assessment_framework_share} \tab Updates a share request for a custom framework in Audit Manager\cr
#'  \link[paws.management:auditmanager_update_assessment_status]{update_assessment_status} \tab Updates the status of an assessment in Audit Manager\cr
#'  \link[paws.management:auditmanager_update_control]{update_control} \tab Updates a custom control in Audit Manager\cr
#'  \link[paws.management:auditmanager_update_settings]{update_settings} \tab Updates Audit Manager settings for the current account\cr
#'  \link[paws.management:auditmanager_validate_assessment_report_integrity]{validate_assessment_report_integrity} \tab Validates the integrity of an assessment report in Audit Manager
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname auditmanager
#' @export
auditmanager <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::auditmanager(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Auto Scaling
#'
#' @description
#' Amazon EC2 Auto Scaling
#' 
#' Amazon EC2 Auto Scaling is designed to automatically launch and
#' terminate EC2 instances based on user-defined scaling policies,
#' scheduled actions, and health checks.
#' 
#' For more information, see the [Amazon EC2 Auto Scaling User
#' Guide](https://docs.aws.amazon.com/autoscaling/ec2/userguide/what-is-amazon-ec2-auto-scaling.html)
#' and the [Amazon EC2 Auto Scaling API
#' Reference](https://docs.aws.amazon.com/autoscaling/ec2/APIReference/Welcome.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- autoscaling(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- autoscaling()
#' # This example attaches the specified instance to the specified Auto
#' # Scaling group.
#' svc$attach_instances(
#'   AutoScalingGroupName = "my-auto-scaling-group",
#'   InstanceIds = list(
#'     "i-93633f9b"
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:autoscaling_attach_instances]{attach_instances} \tab Attaches one or more EC2 instances to the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_attach_load_balancers]{attach_load_balancers} \tab This API operation is superseded by https://docs\cr
#'  \link[paws.management:autoscaling_attach_load_balancer_target_groups]{attach_load_balancer_target_groups} \tab This API operation is superseded by AttachTrafficSources, which can attach multiple traffic sources types\cr
#'  \link[paws.management:autoscaling_attach_traffic_sources]{attach_traffic_sources} \tab Attaches one or more traffic sources to the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_batch_delete_scheduled_action]{batch_delete_scheduled_action} \tab Deletes one or more scheduled actions for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_batch_put_scheduled_update_group_action]{batch_put_scheduled_update_group_action} \tab Creates or updates one or more scheduled scaling actions for an Auto Scaling group\cr
#'  \link[paws.management:autoscaling_cancel_instance_refresh]{cancel_instance_refresh} \tab Cancels an instance refresh or rollback that is in progress\cr
#'  \link[paws.management:autoscaling_complete_lifecycle_action]{complete_lifecycle_action} \tab Completes the lifecycle action for the specified token or instance with the specified result\cr
#'  \link[paws.management:autoscaling_create_auto_scaling_group]{create_auto_scaling_group} \tab We strongly recommend using a launch template when calling this operation to ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2\cr
#'  \link[paws.management:autoscaling_create_launch_configuration]{create_launch_configuration} \tab Creates a launch configuration\cr
#'  \link[paws.management:autoscaling_create_or_update_tags]{create_or_update_tags} \tab Creates or updates tags for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_delete_auto_scaling_group]{delete_auto_scaling_group} \tab Deletes the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_delete_launch_configuration]{delete_launch_configuration} \tab Deletes the specified launch configuration\cr
#'  \link[paws.management:autoscaling_delete_lifecycle_hook]{delete_lifecycle_hook} \tab Deletes the specified lifecycle hook\cr
#'  \link[paws.management:autoscaling_delete_notification_configuration]{delete_notification_configuration} \tab Deletes the specified notification\cr
#'  \link[paws.management:autoscaling_delete_policy]{delete_policy} \tab Deletes the specified scaling policy\cr
#'  \link[paws.management:autoscaling_delete_scheduled_action]{delete_scheduled_action} \tab Deletes the specified scheduled action\cr
#'  \link[paws.management:autoscaling_delete_tags]{delete_tags} \tab Deletes the specified tags\cr
#'  \link[paws.management:autoscaling_delete_warm_pool]{delete_warm_pool} \tab Deletes the warm pool for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_describe_account_limits]{describe_account_limits} \tab Describes the current Amazon EC2 Auto Scaling resource quotas for your account\cr
#'  \link[paws.management:autoscaling_describe_adjustment_types]{describe_adjustment_types} \tab Describes the available adjustment types for step scaling and simple scaling policies\cr
#'  \link[paws.management:autoscaling_describe_auto_scaling_groups]{describe_auto_scaling_groups} \tab Gets information about the Auto Scaling groups in the account and Region\cr
#'  \link[paws.management:autoscaling_describe_auto_scaling_instances]{describe_auto_scaling_instances} \tab Gets information about the Auto Scaling instances in the account and Region\cr
#'  \link[paws.management:autoscaling_describe_auto_scaling_notification_types]{describe_auto_scaling_notification_types} \tab Describes the notification types that are supported by Amazon EC2 Auto Scaling\cr
#'  \link[paws.management:autoscaling_describe_instance_refreshes]{describe_instance_refreshes} \tab Gets information about the instance refreshes for the specified Auto Scaling group from the previous six weeks\cr
#'  \link[paws.management:autoscaling_describe_launch_configurations]{describe_launch_configurations} \tab Gets information about the launch configurations in the account and Region\cr
#'  \link[paws.management:autoscaling_describe_lifecycle_hooks]{describe_lifecycle_hooks} \tab Gets information about the lifecycle hooks for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_describe_lifecycle_hook_types]{describe_lifecycle_hook_types} \tab Describes the available types of lifecycle hooks\cr
#'  \link[paws.management:autoscaling_describe_load_balancers]{describe_load_balancers} \tab This API operation is superseded by DescribeTrafficSources, which can describe multiple traffic sources types\cr
#'  \link[paws.management:autoscaling_describe_load_balancer_target_groups]{describe_load_balancer_target_groups} \tab This API operation is superseded by DescribeTrafficSources, which can describe multiple traffic sources types\cr
#'  \link[paws.management:autoscaling_describe_metric_collection_types]{describe_metric_collection_types} \tab Describes the available CloudWatch metrics for Amazon EC2 Auto Scaling\cr
#'  \link[paws.management:autoscaling_describe_notification_configurations]{describe_notification_configurations} \tab Gets information about the Amazon SNS notifications that are configured for one or more Auto Scaling groups\cr
#'  \link[paws.management:autoscaling_describe_policies]{describe_policies} \tab Gets information about the scaling policies in the account and Region\cr
#'  \link[paws.management:autoscaling_describe_scaling_activities]{describe_scaling_activities} \tab Gets information about the scaling activities in the account and Region\cr
#'  \link[paws.management:autoscaling_describe_scaling_process_types]{describe_scaling_process_types} \tab Describes the scaling process types for use with the ResumeProcesses and SuspendProcesses APIs\cr
#'  \link[paws.management:autoscaling_describe_scheduled_actions]{describe_scheduled_actions} \tab Gets information about the scheduled actions that haven't run or that have not reached their end time\cr
#'  \link[paws.management:autoscaling_describe_tags]{describe_tags} \tab Describes the specified tags\cr
#'  \link[paws.management:autoscaling_describe_termination_policy_types]{describe_termination_policy_types} \tab Describes the termination policies supported by Amazon EC2 Auto Scaling\cr
#'  \link[paws.management:autoscaling_describe_traffic_sources]{describe_traffic_sources} \tab Gets information about the traffic sources for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_describe_warm_pool]{describe_warm_pool} \tab Gets information about a warm pool and its instances\cr
#'  \link[paws.management:autoscaling_detach_instances]{detach_instances} \tab Removes one or more instances from the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_detach_load_balancers]{detach_load_balancers} \tab This API operation is superseded by DetachTrafficSources, which can detach multiple traffic sources types\cr
#'  \link[paws.management:autoscaling_detach_load_balancer_target_groups]{detach_load_balancer_target_groups} \tab This API operation is superseded by DetachTrafficSources, which can detach multiple traffic sources types\cr
#'  \link[paws.management:autoscaling_detach_traffic_sources]{detach_traffic_sources} \tab Detaches one or more traffic sources from the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_disable_metrics_collection]{disable_metrics_collection} \tab Disables group metrics collection for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_enable_metrics_collection]{enable_metrics_collection} \tab Enables group metrics collection for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_enter_standby]{enter_standby} \tab Moves the specified instances into the standby state\cr
#'  \link[paws.management:autoscaling_execute_policy]{execute_policy} \tab Executes the specified policy\cr
#'  \link[paws.management:autoscaling_exit_standby]{exit_standby} \tab Moves the specified instances out of the standby state\cr
#'  \link[paws.management:autoscaling_get_predictive_scaling_forecast]{get_predictive_scaling_forecast} \tab Retrieves the forecast data for a predictive scaling policy\cr
#'  \link[paws.management:autoscaling_put_lifecycle_hook]{put_lifecycle_hook} \tab Creates or updates a lifecycle hook for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_put_notification_configuration]{put_notification_configuration} \tab Configures an Auto Scaling group to send notifications when specified events take place\cr
#'  \link[paws.management:autoscaling_put_scaling_policy]{put_scaling_policy} \tab Creates or updates a scaling policy for an Auto Scaling group\cr
#'  \link[paws.management:autoscaling_put_scheduled_update_group_action]{put_scheduled_update_group_action} \tab Creates or updates a scheduled scaling action for an Auto Scaling group\cr
#'  \link[paws.management:autoscaling_put_warm_pool]{put_warm_pool} \tab Creates or updates a warm pool for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_record_lifecycle_action_heartbeat]{record_lifecycle_action_heartbeat} \tab Records a heartbeat for the lifecycle action associated with the specified token or instance\cr
#'  \link[paws.management:autoscaling_resume_processes]{resume_processes} \tab Resumes the specified suspended auto scaling processes, or all suspended process, for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_rollback_instance_refresh]{rollback_instance_refresh} \tab Cancels an instance refresh that is in progress and rolls back any changes that it made\cr
#'  \link[paws.management:autoscaling_set_desired_capacity]{set_desired_capacity} \tab Sets the size of the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_set_instance_health]{set_instance_health} \tab Sets the health status of the specified instance\cr
#'  \link[paws.management:autoscaling_set_instance_protection]{set_instance_protection} \tab Updates the instance protection settings of the specified instances\cr
#'  \link[paws.management:autoscaling_start_instance_refresh]{start_instance_refresh} \tab Starts an instance refresh\cr
#'  \link[paws.management:autoscaling_suspend_processes]{suspend_processes} \tab Suspends the specified auto scaling processes, or all processes, for the specified Auto Scaling group\cr
#'  \link[paws.management:autoscaling_terminate_instance_in_auto_scaling_group]{terminate_instance_in_auto_scaling_group} \tab Terminates the specified instance and optionally adjusts the desired group size\cr
#'  \link[paws.management:autoscaling_update_auto_scaling_group]{update_auto_scaling_group} \tab We strongly recommend that all Auto Scaling groups use launch templates to ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname autoscaling
#' @export
autoscaling <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::autoscaling(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Auto Scaling Plans
#'
#' @description
#' AWS Auto Scaling
#' 
#' Use AWS Auto Scaling to create scaling plans for your applications to
#' automatically scale your scalable AWS resources.
#' 
#' **API Summary**
#' 
#' You can use the AWS Auto Scaling service API to accomplish the following
#' tasks:
#' 
#' -   Create and manage scaling plans
#' 
#' -   Define target tracking scaling policies to dynamically scale your
#'     resources based on utilization
#' 
#' -   Scale Amazon EC2 Auto Scaling groups using predictive scaling and
#'     dynamic scaling to scale your Amazon EC2 capacity faster
#' 
#' -   Set minimum and maximum capacity limits
#' 
#' -   Retrieve information on existing scaling plans
#' 
#' -   Access current forecast data and historical forecast data for up to
#'     56 days previous
#' 
#' To learn more about AWS Auto Scaling, including information about
#' granting IAM users required permissions for AWS Auto Scaling actions,
#' see the [AWS Auto Scaling User
#' Guide](https://docs.aws.amazon.com/autoscaling/plans/userguide/migrate-scaling-plan.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- autoscalingplans(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- autoscalingplans()
#' svc$create_scaling_plan(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:autoscalingplans_create_scaling_plan]{create_scaling_plan} \tab Creates a scaling plan\cr
#'  \link[paws.management:autoscalingplans_delete_scaling_plan]{delete_scaling_plan} \tab Deletes the specified scaling plan\cr
#'  \link[paws.management:autoscalingplans_describe_scaling_plan_resources]{describe_scaling_plan_resources} \tab Describes the scalable resources in the specified scaling plan\cr
#'  \link[paws.management:autoscalingplans_describe_scaling_plans]{describe_scaling_plans} \tab Describes one or more of your scaling plans\cr
#'  \link[paws.management:autoscalingplans_get_scaling_plan_resource_forecast_data]{get_scaling_plan_resource_forecast_data} \tab Retrieves the forecast data for a scalable resource\cr
#'  \link[paws.management:autoscalingplans_update_scaling_plan]{update_scaling_plan} \tab Updates the specified scaling plan
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname autoscalingplans
#' @export
autoscalingplans <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::autoscalingplans(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CloudFormation
#'
#' @description
#' CloudFormation
#' 
#' CloudFormation allows you to create and manage Amazon Web Services
#' infrastructure deployments predictably and repeatedly. You can use
#' CloudFormation to leverage Amazon Web Services products, such as Amazon
#' Elastic Compute Cloud, Amazon Elastic Block Store, Amazon Simple
#' Notification Service, Elastic Load Balancing, and Amazon EC2 Auto
#' Scaling to build highly reliable, highly scalable, cost-effective
#' applications without creating or configuring the underlying Amazon Web
#' Services infrastructure.
#' 
#' With CloudFormation, you declare all your resources and dependencies in
#' a template file. The template defines a collection of resources as a
#' single unit called a stack. CloudFormation creates and deletes all
#' member resources of the stack together and manages all dependencies
#' between the resources for you.
#' 
#' For more information about CloudFormation, see the [CloudFormation
#' product page](https://aws.amazon.com/cloudformation/).
#' 
#' CloudFormation makes use of other Amazon Web Services products. If you
#' need additional technical information about a specific Amazon Web
#' Services product, you can find the product's technical documentation at
#' [docs.aws.amazon.com](https://docs.aws.amazon.com/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudformation(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudformation()
#' svc$activate_organizations_access(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudformation_activate_organizations_access]{activate_organizations_access} \tab Activate trusted access with Organizations\cr
#'  \link[paws.management:cloudformation_activate_type]{activate_type} \tab Activates a public third-party extension, making it available for use in stack templates\cr
#'  \link[paws.management:cloudformation_batch_describe_type_configurations]{batch_describe_type_configurations} \tab Returns configuration data for the specified CloudFormation extensions, from the CloudFormation registry for the account and Region\cr
#'  \link[paws.management:cloudformation_cancel_update_stack]{cancel_update_stack} \tab Cancels an update on the specified stack\cr
#'  \link[paws.management:cloudformation_continue_update_rollback]{continue_update_rollback} \tab For a specified stack that's in the UPDATE_ROLLBACK_FAILED state, continues rolling it back to the UPDATE_ROLLBACK_COMPLETE state\cr
#'  \link[paws.management:cloudformation_create_change_set]{create_change_set} \tab Creates a list of changes that will be applied to a stack so that you can review the changes before executing them\cr
#'  \link[paws.management:cloudformation_create_generated_template]{create_generated_template} \tab Creates a template from existing resources that are not already managed with CloudFormation\cr
#'  \link[paws.management:cloudformation_create_stack]{create_stack} \tab Creates a stack as specified in the template\cr
#'  \link[paws.management:cloudformation_create_stack_instances]{create_stack_instances} \tab Creates stack instances for the specified accounts, within the specified Amazon Web Services Regions\cr
#'  \link[paws.management:cloudformation_create_stack_refactor]{create_stack_refactor} \tab Creates a refactor across multiple stacks, with the list of stacks and resources that are affected\cr
#'  \link[paws.management:cloudformation_create_stack_set]{create_stack_set} \tab Creates a stack set\cr
#'  \link[paws.management:cloudformation_deactivate_organizations_access]{deactivate_organizations_access} \tab Deactivates trusted access with Organizations\cr
#'  \link[paws.management:cloudformation_deactivate_type]{deactivate_type} \tab Deactivates a public extension that was previously activated in this account and Region\cr
#'  \link[paws.management:cloudformation_delete_change_set]{delete_change_set} \tab Deletes the specified change set\cr
#'  \link[paws.management:cloudformation_delete_generated_template]{delete_generated_template} \tab Deleted a generated template\cr
#'  \link[paws.management:cloudformation_delete_stack]{delete_stack} \tab Deletes a specified stack\cr
#'  \link[paws.management:cloudformation_delete_stack_instances]{delete_stack_instances} \tab Deletes stack instances for the specified accounts, in the specified Amazon Web Services Regions\cr
#'  \link[paws.management:cloudformation_delete_stack_set]{delete_stack_set} \tab Deletes a stack set\cr
#'  \link[paws.management:cloudformation_deregister_type]{deregister_type} \tab Marks an extension or extension version as DEPRECATED in the CloudFormation registry, removing it from active use\cr
#'  \link[paws.management:cloudformation_describe_account_limits]{describe_account_limits} \tab Retrieves your account's CloudFormation limits, such as the maximum number of stacks that you can create in your account\cr
#'  \link[paws.management:cloudformation_describe_change_set]{describe_change_set} \tab Returns the inputs for the change set and a list of changes that CloudFormation will make if you execute the change set\cr
#'  \link[paws.management:cloudformation_describe_change_set_hooks]{describe_change_set_hooks} \tab Returns hook-related information for the change set and a list of changes that CloudFormation makes when you run the change set\cr
#'  \link[paws.management:cloudformation_describe_generated_template]{describe_generated_template} \tab Describes a generated template\cr
#'  \link[paws.management:cloudformation_describe_organizations_access]{describe_organizations_access} \tab Retrieves information about the account's OrganizationAccess status\cr
#'  \link[paws.management:cloudformation_describe_publisher]{describe_publisher} \tab Returns information about a CloudFormation extension publisher\cr
#'  \link[paws.management:cloudformation_describe_resource_scan]{describe_resource_scan} \tab Describes details of a resource scan\cr
#'  \link[paws.management:cloudformation_describe_stack_drift_detection_status]{describe_stack_drift_detection_status} \tab Returns information about a stack drift detection operation\cr
#'  \link[paws.management:cloudformation_describe_stack_events]{describe_stack_events} \tab Returns all stack related events for a specified stack in reverse chronological order\cr
#'  \link[paws.management:cloudformation_describe_stack_instance]{describe_stack_instance} \tab Returns the stack instance that's associated with the specified StackSet, Amazon Web Services account, and Amazon Web Services Region\cr
#'  \link[paws.management:cloudformation_describe_stack_refactor]{describe_stack_refactor} \tab Describes the stack refactor status\cr
#'  \link[paws.management:cloudformation_describe_stack_resource]{describe_stack_resource} \tab Returns a description of the specified resource in the specified stack\cr
#'  \link[paws.management:cloudformation_describe_stack_resource_drifts]{describe_stack_resource_drifts} \tab Returns drift information for the resources that have been checked for drift in the specified stack\cr
#'  \link[paws.management:cloudformation_describe_stack_resources]{describe_stack_resources} \tab Returns Amazon Web Services resource descriptions for running and deleted stacks\cr
#'  \link[paws.management:cloudformation_describe_stacks]{describe_stacks} \tab Returns the description for the specified stack; if no stack name was specified, then it returns the description for all the stacks created\cr
#'  \link[paws.management:cloudformation_describe_stack_set]{describe_stack_set} \tab Returns the description of the specified StackSet\cr
#'  \link[paws.management:cloudformation_describe_stack_set_operation]{describe_stack_set_operation} \tab Returns the description of the specified StackSet operation\cr
#'  \link[paws.management:cloudformation_describe_type]{describe_type} \tab Returns detailed information about an extension that has been registered\cr
#'  \link[paws.management:cloudformation_describe_type_registration]{describe_type_registration} \tab Returns information about an extension's registration, including its current status and type and version identifiers\cr
#'  \link[paws.management:cloudformation_detect_stack_drift]{detect_stack_drift} \tab Detects whether a stack's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters\cr
#'  \link[paws.management:cloudformation_detect_stack_resource_drift]{detect_stack_resource_drift} \tab Returns information about whether a resource's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters\cr
#'  \link[paws.management:cloudformation_detect_stack_set_drift]{detect_stack_set_drift} \tab Detect drift on a stack set\cr
#'  \link[paws.management:cloudformation_estimate_template_cost]{estimate_template_cost} \tab Returns the estimated monthly cost of a template\cr
#'  \link[paws.management:cloudformation_execute_change_set]{execute_change_set} \tab Updates a stack using the input information that was provided when the specified change set was created\cr
#'  \link[paws.management:cloudformation_execute_stack_refactor]{execute_stack_refactor} \tab Executes the stack refactor operation\cr
#'  \link[paws.management:cloudformation_get_generated_template]{get_generated_template} \tab Retrieves a generated template\cr
#'  \link[paws.management:cloudformation_get_stack_policy]{get_stack_policy} \tab Returns the stack policy for a specified stack\cr
#'  \link[paws.management:cloudformation_get_template]{get_template} \tab Returns the template body for a specified stack\cr
#'  \link[paws.management:cloudformation_get_template_summary]{get_template_summary} \tab Returns information about a new or existing template\cr
#'  \link[paws.management:cloudformation_import_stacks_to_stack_set]{import_stacks_to_stack_set} \tab Import existing stacks into a new stack sets\cr
#'  \link[paws.management:cloudformation_list_change_sets]{list_change_sets} \tab Returns the ID and status of each active change set for a stack\cr
#'  \link[paws.management:cloudformation_list_exports]{list_exports} \tab Lists all exported output values in the account and Region in which you call this action\cr
#'  \link[paws.management:cloudformation_list_generated_templates]{list_generated_templates} \tab Lists your generated templates in this Region\cr
#'  \link[paws.management:cloudformation_list_hook_results]{list_hook_results} \tab Returns summaries of invoked Hooks when a change set or Cloud Control API operation target is provided\cr
#'  \link[paws.management:cloudformation_list_imports]{list_imports} \tab Lists all stacks that are importing an exported output value\cr
#'  \link[paws.management:cloudformation_list_resource_scan_related_resources]{list_resource_scan_related_resources} \tab Lists the related resources for a list of resources from a resource scan\cr
#'  \link[paws.management:cloudformation_list_resource_scan_resources]{list_resource_scan_resources} \tab Lists the resources from a resource scan\cr
#'  \link[paws.management:cloudformation_list_resource_scans]{list_resource_scans} \tab List the resource scans from newest to oldest\cr
#'  \link[paws.management:cloudformation_list_stack_instance_resource_drifts]{list_stack_instance_resource_drifts} \tab Returns drift information for resources in a stack instance\cr
#'  \link[paws.management:cloudformation_list_stack_instances]{list_stack_instances} \tab Returns summary information about stack instances that are associated with the specified stack set\cr
#'  \link[paws.management:cloudformation_list_stack_refactor_actions]{list_stack_refactor_actions} \tab Lists the stack refactor actions that will be taken after calling the ExecuteStackRefactor action\cr
#'  \link[paws.management:cloudformation_list_stack_refactors]{list_stack_refactors} \tab Lists all account stack refactor operations and their statuses\cr
#'  \link[paws.management:cloudformation_list_stack_resources]{list_stack_resources} \tab Returns descriptions of all resources of the specified stack\cr
#'  \link[paws.management:cloudformation_list_stacks]{list_stacks} \tab Returns the summary information for stacks whose status matches the specified StackStatusFilter\cr
#'  \link[paws.management:cloudformation_list_stack_set_auto_deployment_targets]{list_stack_set_auto_deployment_targets} \tab Returns summary information about deployment targets for a stack set\cr
#'  \link[paws.management:cloudformation_list_stack_set_operation_results]{list_stack_set_operation_results} \tab Returns summary information about the results of a stack set operation\cr
#'  \link[paws.management:cloudformation_list_stack_set_operations]{list_stack_set_operations} \tab Returns summary information about operations performed on a stack set\cr
#'  \link[paws.management:cloudformation_list_stack_sets]{list_stack_sets} \tab Returns summary information about stack sets that are associated with the user\cr
#'  \link[paws.management:cloudformation_list_type_registrations]{list_type_registrations} \tab Returns a list of registration tokens for the specified extension(s)\cr
#'  \link[paws.management:cloudformation_list_types]{list_types} \tab Returns summary information about extension that have been registered with CloudFormation\cr
#'  \link[paws.management:cloudformation_list_type_versions]{list_type_versions} \tab Returns summary information about the versions of an extension\cr
#'  \link[paws.management:cloudformation_publish_type]{publish_type} \tab Publishes the specified extension to the CloudFormation registry as a public extension in this Region\cr
#'  \link[paws.management:cloudformation_record_handler_progress]{record_handler_progress} \tab Reports progress of a resource handler to CloudFormation\cr
#'  \link[paws.management:cloudformation_register_publisher]{register_publisher} \tab Registers your account as a publisher of public extensions in the CloudFormation registry\cr
#'  \link[paws.management:cloudformation_register_type]{register_type} \tab Registers an extension with the CloudFormation service\cr
#'  \link[paws.management:cloudformation_rollback_stack]{rollback_stack} \tab When specifying RollbackStack, you preserve the state of previously provisioned resources when an operation fails\cr
#'  \link[paws.management:cloudformation_set_stack_policy]{set_stack_policy} \tab Sets a stack policy for a specified stack\cr
#'  \link[paws.management:cloudformation_set_type_configuration]{set_type_configuration} \tab Specifies the configuration data for a registered CloudFormation extension, in the given account and Region\cr
#'  \link[paws.management:cloudformation_set_type_default_version]{set_type_default_version} \tab Specify the default version of an extension\cr
#'  \link[paws.management:cloudformation_signal_resource]{signal_resource} \tab Sends a signal to the specified resource with a success or failure status\cr
#'  \link[paws.management:cloudformation_start_resource_scan]{start_resource_scan} \tab Starts a scan of the resources in this account in this Region\cr
#'  \link[paws.management:cloudformation_stop_stack_set_operation]{stop_stack_set_operation} \tab Stops an in-progress operation on a stack set and its associated stack instances\cr
#'  \link[paws.management:cloudformation_test_type]{test_type} \tab Tests a registered extension to make sure it meets all necessary requirements for being published in the CloudFormation registry\cr
#'  \link[paws.management:cloudformation_update_generated_template]{update_generated_template} \tab Updates a generated template\cr
#'  \link[paws.management:cloudformation_update_stack]{update_stack} \tab Updates a stack as specified in the template\cr
#'  \link[paws.management:cloudformation_update_stack_instances]{update_stack_instances} \tab Updates the parameter values for stack instances for the specified accounts, within the specified Amazon Web Services Regions\cr
#'  \link[paws.management:cloudformation_update_stack_set]{update_stack_set} \tab Updates the stack set, and associated stack instances in the specified accounts and Amazon Web Services Regions\cr
#'  \link[paws.management:cloudformation_update_termination_protection]{update_termination_protection} \tab Updates termination protection for the specified stack\cr
#'  \link[paws.management:cloudformation_validate_template]{validate_template} \tab Validates a specified template
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudformation
#' @export
cloudformation <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudformation(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CloudTrail
#'
#' @description
#' CloudTrail
#' 
#' This is the CloudTrail API Reference. It provides descriptions of
#' actions, data types, common parameters, and common errors for
#' CloudTrail.
#' 
#' CloudTrail is a web service that records Amazon Web Services API calls
#' for your Amazon Web Services account and delivers log files to an Amazon
#' S3 bucket. The recorded information includes the identity of the user,
#' the start time of the Amazon Web Services API call, the source IP
#' address, the request parameters, and the response elements returned by
#' the service.
#' 
#' As an alternative to the API, you can use one of the Amazon Web Services
#' SDKs, which consist of libraries and sample code for various programming
#' languages and platforms (Java, Ruby, .NET, iOS, Android, etc.). The SDKs
#' provide programmatic access to CloudTrail. For example, the SDKs handle
#' cryptographically signing requests, managing errors, and retrying
#' requests automatically. For more information about the Amazon Web
#' Services SDKs, including how to download and install them, see [Tools to
#' Build on Amazon Web Services](https://aws.amazon.com/developer/tools/).
#' 
#' See the [CloudTrail User
#' Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-user-guide.html)
#' for information about the data that is included with each Amazon Web
#' Services API call listed in the log files.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudtrail(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudtrail()
#' svc$add_tags(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudtrail_add_tags]{add_tags} \tab Adds one or more tags to a trail, event data store, dashboard, or channel, up to a limit of 50\cr
#'  \link[paws.management:cloudtrail_cancel_query]{cancel_query} \tab Cancels a query if the query is not in a terminated state, such as CANCELLED, FAILED, TIMED_OUT, or FINISHED\cr
#'  \link[paws.management:cloudtrail_create_channel]{create_channel} \tab Creates a channel for CloudTrail to ingest events from a partner or external source\cr
#'  \link[paws.management:cloudtrail_create_dashboard]{create_dashboard} \tab Creates a custom dashboard or the Highlights dashboard\cr
#'  \link[paws.management:cloudtrail_create_event_data_store]{create_event_data_store} \tab Creates a new event data store\cr
#'  \link[paws.management:cloudtrail_create_trail]{create_trail} \tab Creates a trail that specifies the settings for delivery of log data to an Amazon S3 bucket\cr
#'  \link[paws.management:cloudtrail_delete_channel]{delete_channel} \tab Deletes a channel\cr
#'  \link[paws.management:cloudtrail_delete_dashboard]{delete_dashboard} \tab Deletes the specified dashboard\cr
#'  \link[paws.management:cloudtrail_delete_event_data_store]{delete_event_data_store} \tab Disables the event data store specified by EventDataStore, which accepts an event data store ARN\cr
#'  \link[paws.management:cloudtrail_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource-based policy attached to the CloudTrail event data store, dashboard, or channel\cr
#'  \link[paws.management:cloudtrail_delete_trail]{delete_trail} \tab Deletes a trail\cr
#'  \link[paws.management:cloudtrail_deregister_organization_delegated_admin]{deregister_organization_delegated_admin} \tab Removes CloudTrail delegated administrator permissions from a member account in an organization\cr
#'  \link[paws.management:cloudtrail_describe_query]{describe_query} \tab Returns metadata about a query, including query run time in milliseconds, number of events scanned and matched, and query status\cr
#'  \link[paws.management:cloudtrail_describe_trails]{describe_trails} \tab Retrieves settings for one or more trails associated with the current Region for your account\cr
#'  \link[paws.management:cloudtrail_disable_federation]{disable_federation} \tab Disables Lake query federation on the specified event data store\cr
#'  \link[paws.management:cloudtrail_enable_federation]{enable_federation} \tab Enables Lake query federation on the specified event data store\cr
#'  \link[paws.management:cloudtrail_generate_query]{generate_query} \tab Generates a query from a natural language prompt\cr
#'  \link[paws.management:cloudtrail_get_channel]{get_channel} \tab Returns information about a specific channel\cr
#'  \link[paws.management:cloudtrail_get_dashboard]{get_dashboard} \tab Returns the specified dashboard\cr
#'  \link[paws.management:cloudtrail_get_event_data_store]{get_event_data_store} \tab Returns information about an event data store specified as either an ARN or the ID portion of the ARN\cr
#'  \link[paws.management:cloudtrail_get_event_selectors]{get_event_selectors} \tab Describes the settings for the event selectors that you configured for your trail\cr
#'  \link[paws.management:cloudtrail_get_import]{get_import} \tab Returns information about a specific import\cr
#'  \link[paws.management:cloudtrail_get_insight_selectors]{get_insight_selectors} \tab Describes the settings for the Insights event selectors that you configured for your trail or event data store\cr
#'  \link[paws.management:cloudtrail_get_query_results]{get_query_results} \tab Gets event data results of a query\cr
#'  \link[paws.management:cloudtrail_get_resource_policy]{get_resource_policy} \tab Retrieves the JSON text of the resource-based policy document attached to the CloudTrail event data store, dashboard, or channel\cr
#'  \link[paws.management:cloudtrail_get_trail]{get_trail} \tab Returns settings information for a specified trail\cr
#'  \link[paws.management:cloudtrail_get_trail_status]{get_trail_status} \tab Returns a JSON-formatted list of information about the specified trail\cr
#'  \link[paws.management:cloudtrail_list_channels]{list_channels} \tab Lists the channels in the current account, and their source names\cr
#'  \link[paws.management:cloudtrail_list_dashboards]{list_dashboards} \tab Returns information about all dashboards in the account, in the current Region\cr
#'  \link[paws.management:cloudtrail_list_event_data_stores]{list_event_data_stores} \tab Returns information about all event data stores in the account, in the current Region\cr
#'  \link[paws.management:cloudtrail_list_import_failures]{list_import_failures} \tab Returns a list of failures for the specified import\cr
#'  \link[paws.management:cloudtrail_list_imports]{list_imports} \tab Returns information on all imports, or a select set of imports by ImportStatus or Destination\cr
#'  \link[paws.management:cloudtrail_list_insights_metric_data]{list_insights_metric_data} \tab Returns Insights metrics data for trails that have enabled Insights\cr
#'  \link[paws.management:cloudtrail_list_public_keys]{list_public_keys} \tab Returns all public keys whose private keys were used to sign the digest files within the specified time range\cr
#'  \link[paws.management:cloudtrail_list_queries]{list_queries} \tab Returns a list of queries and query statuses for the past seven days\cr
#'  \link[paws.management:cloudtrail_list_tags]{list_tags} \tab Lists the tags for the specified trails, event data stores, dashboards, or channels in the current Region\cr
#'  \link[paws.management:cloudtrail_list_trails]{list_trails} \tab Lists trails that are in the current account\cr
#'  \link[paws.management:cloudtrail_lookup_events]{lookup_events} \tab Looks up management events or CloudTrail Insights events that are captured by CloudTrail\cr
#'  \link[paws.management:cloudtrail_put_event_selectors]{put_event_selectors} \tab Configures event selectors (also referred to as basic event selectors) or advanced event selectors for your trail\cr
#'  \link[paws.management:cloudtrail_put_insight_selectors]{put_insight_selectors} \tab Lets you enable Insights event logging by specifying the Insights selectors that you want to enable on an existing trail or event data store\cr
#'  \link[paws.management:cloudtrail_put_resource_policy]{put_resource_policy} \tab Attaches a resource-based permission policy to a CloudTrail event data store, dashboard, or channel\cr
#'  \link[paws.management:cloudtrail_register_organization_delegated_admin]{register_organization_delegated_admin} \tab Registers an organization’s member account as the CloudTrail delegated administrator\cr
#'  \link[paws.management:cloudtrail_remove_tags]{remove_tags} \tab Removes the specified tags from a trail, event data store, dashboard, or channel\cr
#'  \link[paws.management:cloudtrail_restore_event_data_store]{restore_event_data_store} \tab Restores a deleted event data store specified by EventDataStore, which accepts an event data store ARN\cr
#'  \link[paws.management:cloudtrail_search_sample_queries]{search_sample_queries} \tab Searches sample queries and returns a list of sample queries that are sorted by relevance\cr
#'  \link[paws.management:cloudtrail_start_dashboard_refresh]{start_dashboard_refresh} \tab Starts a refresh of the specified dashboard\cr
#'  \link[paws.management:cloudtrail_start_event_data_store_ingestion]{start_event_data_store_ingestion} \tab Starts the ingestion of live events on an event data store specified as either an ARN or the ID portion of the ARN\cr
#'  \link[paws.management:cloudtrail_start_import]{start_import} \tab Starts an import of logged trail events from a source S3 bucket to a destination event data store\cr
#'  \link[paws.management:cloudtrail_start_logging]{start_logging} \tab Starts the recording of Amazon Web Services API calls and log file delivery for a trail\cr
#'  \link[paws.management:cloudtrail_start_query]{start_query} \tab Starts a CloudTrail Lake query\cr
#'  \link[paws.management:cloudtrail_stop_event_data_store_ingestion]{stop_event_data_store_ingestion} \tab Stops the ingestion of live events on an event data store specified as either an ARN or the ID portion of the ARN\cr
#'  \link[paws.management:cloudtrail_stop_import]{stop_import} \tab Stops a specified import\cr
#'  \link[paws.management:cloudtrail_stop_logging]{stop_logging} \tab Suspends the recording of Amazon Web Services API calls and log file delivery for the specified trail\cr
#'  \link[paws.management:cloudtrail_update_channel]{update_channel} \tab Updates a channel specified by a required channel ARN or UUID\cr
#'  \link[paws.management:cloudtrail_update_dashboard]{update_dashboard} \tab Updates the specified dashboard\cr
#'  \link[paws.management:cloudtrail_update_event_data_store]{update_event_data_store} \tab Updates an event data store\cr
#'  \link[paws.management:cloudtrail_update_trail]{update_trail} \tab Updates trail settings that control what events you are logging, and how to handle log files
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudtrail
#' @export
cloudtrail <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudtrail(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CloudTrail Data Service
#'
#' @description
#' The CloudTrail Data Service lets you ingest events into CloudTrail from
#' any source in your hybrid environments, such as in-house or SaaS
#' applications hosted on-premises or in the cloud, virtual machines, or
#' containers. You can store, access, analyze, troubleshoot and take action
#' on this data without maintaining multiple log aggregators and reporting
#' tools. After you run
#' `put_audit_events` to ingest
#' your application activity into CloudTrail, you can use CloudTrail Lake
#' to search, query, and analyze the data that is logged from your
#' applications.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudtraildataservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudtraildataservice()
#' svc$put_audit_events(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudtraildataservice_put_audit_events]{put_audit_events} \tab Ingests your application events into CloudTrail Lake
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudtraildataservice
#' @export
cloudtraildataservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudtraildataservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Config
#'
#' @description
#' Config
#' 
#' Config provides a way to keep track of the configurations of all the
#' Amazon Web Services resources associated with your Amazon Web Services
#' account. You can use Config to get the current and historical
#' configurations of each Amazon Web Services resource and also to get
#' information about the relationship between the resources. An Amazon Web
#' Services resource can be an Amazon Compute Cloud (Amazon EC2) instance,
#' an Elastic Block Store (EBS) volume, an elastic network Interface (ENI),
#' or a security group. For a complete list of resources currently
#' supported by Config, see [Supported Amazon Web Services
#' resources](https://docs.aws.amazon.com/config/latest/developerguide/resource-config-reference.html#supported-resources).
#' 
#' You can access and manage Config through the Amazon Web Services
#' Management Console, the Amazon Web Services Command Line Interface
#' (Amazon Web Services CLI), the Config API, or the Amazon Web Services
#' SDKs for Config. This reference guide contains documentation for the
#' Config API and the Amazon Web Services CLI commands that you can use to
#' manage Config. The Config API uses the Signature Version 4 protocol for
#' signing requests. For more information about how to sign a request with
#' this protocol, see [Signature Version 4 Signing
#' Process](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html).
#' For detailed information about Config features and their associated
#' actions or commands, as well as how to work with Amazon Web Services
#' Management Console, see [What Is
#' Config](https://docs.aws.amazon.com/config/latest/developerguide/WhatIsConfig.html)
#' in the *Config Developer Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- configservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- configservice()
#' svc$associate_resource_types(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:configservice_associate_resource_types]{associate_resource_types} \tab Adds all resource types specified in the ResourceTypes list to the RecordingGroup of specified configuration recorder and includes those resource types when recording\cr
#'  \link[paws.management:configservice_batch_get_aggregate_resource_config]{batch_get_aggregate_resource_config} \tab Returns the current configuration items for resources that are present in your Config aggregator\cr
#'  \link[paws.management:configservice_batch_get_resource_config]{batch_get_resource_config} \tab Returns the BaseConfigurationItem for one or more requested resources\cr
#'  \link[paws.management:configservice_delete_aggregation_authorization]{delete_aggregation_authorization} \tab Deletes the authorization granted to the specified configuration aggregator account in a specified region\cr
#'  \link[paws.management:configservice_delete_config_rule]{delete_config_rule} \tab Deletes the specified Config rule and all of its evaluation results\cr
#'  \link[paws.management:configservice_delete_configuration_aggregator]{delete_configuration_aggregator} \tab Deletes the specified configuration aggregator and the aggregated data associated with the aggregator\cr
#'  \link[paws.management:configservice_delete_configuration_recorder]{delete_configuration_recorder} \tab Deletes the customer managed configuration recorder\cr
#'  \link[paws.management:configservice_delete_conformance_pack]{delete_conformance_pack} \tab Deletes the specified conformance pack and all the Config rules, remediation actions, and all evaluation results within that conformance pack\cr
#'  \link[paws.management:configservice_delete_delivery_channel]{delete_delivery_channel} \tab Deletes the delivery channel\cr
#'  \link[paws.management:configservice_delete_evaluation_results]{delete_evaluation_results} \tab Deletes the evaluation results for the specified Config rule\cr
#'  \link[paws.management:configservice_delete_organization_config_rule]{delete_organization_config_rule} \tab Deletes the specified organization Config rule and all of its evaluation results from all member accounts in that organization\cr
#'  \link[paws.management:configservice_delete_organization_conformance_pack]{delete_organization_conformance_pack} \tab Deletes the specified organization conformance pack and all of the Config rules and remediation actions from all member accounts in that organization\cr
#'  \link[paws.management:configservice_delete_pending_aggregation_request]{delete_pending_aggregation_request} \tab Deletes pending authorization requests for a specified aggregator account in a specified region\cr
#'  \link[paws.management:configservice_delete_remediation_configuration]{delete_remediation_configuration} \tab Deletes the remediation configuration\cr
#'  \link[paws.management:configservice_delete_remediation_exceptions]{delete_remediation_exceptions} \tab Deletes one or more remediation exceptions mentioned in the resource keys\cr
#'  \link[paws.management:configservice_delete_resource_config]{delete_resource_config} \tab Records the configuration state for a custom resource that has been deleted\cr
#'  \link[paws.management:configservice_delete_retention_configuration]{delete_retention_configuration} \tab Deletes the retention configuration\cr
#'  \link[paws.management:configservice_delete_service_linked_configuration_recorder]{delete_service_linked_configuration_recorder} \tab Deletes an existing service-linked configuration recorder\cr
#'  \link[paws.management:configservice_delete_stored_query]{delete_stored_query} \tab Deletes the stored query for a single Amazon Web Services account and a single Amazon Web Services Region\cr
#'  \link[paws.management:configservice_deliver_config_snapshot]{deliver_config_snapshot} \tab Schedules delivery of a configuration snapshot to the Amazon S3 bucket in the specified delivery channel\cr
#'  \link[paws.management:configservice_describe_aggregate_compliance_by_config_rules]{describe_aggregate_compliance_by_config_rules} \tab Returns a list of compliant and noncompliant rules with the number of resources for compliant and noncompliant rules\cr
#'  \link[paws.management:configservice_describe_aggregate_compliance_by_conformance_packs]{describe_aggregate_compliance_by_conformance_packs} \tab Returns a list of the existing and deleted conformance packs and their associated compliance status with the count of compliant and noncompliant Config rules within each conformance pack\cr
#'  \link[paws.management:configservice_describe_aggregation_authorizations]{describe_aggregation_authorizations} \tab Returns a list of authorizations granted to various aggregator accounts and regions\cr
#'  \link[paws.management:configservice_describe_compliance_by_config_rule]{describe_compliance_by_config_rule} \tab Indicates whether the specified Config rules are compliant\cr
#'  \link[paws.management:configservice_describe_compliance_by_resource]{describe_compliance_by_resource} \tab Indicates whether the specified Amazon Web Services resources are compliant\cr
#'  \link[paws.management:configservice_describe_config_rule_evaluation_status]{describe_config_rule_evaluation_status} \tab Returns status information for each of your Config managed rules\cr
#'  \link[paws.management:configservice_describe_config_rules]{describe_config_rules} \tab Returns details about your Config rules\cr
#'  \link[paws.management:configservice_describe_configuration_aggregators]{describe_configuration_aggregators} \tab Returns the details of one or more configuration aggregators\cr
#'  \link[paws.management:configservice_describe_configuration_aggregator_sources_status]{describe_configuration_aggregator_sources_status} \tab Returns status information for sources within an aggregator\cr
#'  \link[paws.management:configservice_describe_configuration_recorders]{describe_configuration_recorders} \tab Returns details for the configuration recorder you specify\cr
#'  \link[paws.management:configservice_describe_configuration_recorder_status]{describe_configuration_recorder_status} \tab Returns the current status of the configuration recorder you specify as well as the status of the last recording event for the configuration recorders\cr
#'  \link[paws.management:configservice_describe_conformance_pack_compliance]{describe_conformance_pack_compliance} \tab Returns compliance details for each rule in that conformance pack\cr
#'  \link[paws.management:configservice_describe_conformance_packs]{describe_conformance_packs} \tab Returns a list of one or more conformance packs\cr
#'  \link[paws.management:configservice_describe_conformance_pack_status]{describe_conformance_pack_status} \tab Provides one or more conformance packs deployment status\cr
#'  \link[paws.management:configservice_describe_delivery_channels]{describe_delivery_channels} \tab Returns details about the specified delivery channel\cr
#'  \link[paws.management:configservice_describe_delivery_channel_status]{describe_delivery_channel_status} \tab Returns the current status of the specified delivery channel\cr
#'  \link[paws.management:configservice_describe_organization_config_rules]{describe_organization_config_rules} \tab Returns a list of organization Config rules\cr
#'  \link[paws.management:configservice_describe_organization_config_rule_statuses]{describe_organization_config_rule_statuses} \tab Provides organization Config rule deployment status for an organization\cr
#'  \link[paws.management:configservice_describe_organization_conformance_packs]{describe_organization_conformance_packs} \tab Returns a list of organization conformance packs\cr
#'  \link[paws.management:configservice_describe_organization_conformance_pack_statuses]{describe_organization_conformance_pack_statuses} \tab Provides organization conformance pack deployment status for an organization\cr
#'  \link[paws.management:configservice_describe_pending_aggregation_requests]{describe_pending_aggregation_requests} \tab Returns a list of all pending aggregation requests\cr
#'  \link[paws.management:configservice_describe_remediation_configurations]{describe_remediation_configurations} \tab Returns the details of one or more remediation configurations\cr
#'  \link[paws.management:configservice_describe_remediation_exceptions]{describe_remediation_exceptions} \tab Returns the details of one or more remediation exceptions\cr
#'  \link[paws.management:configservice_describe_remediation_execution_status]{describe_remediation_execution_status} \tab Provides a detailed view of a Remediation Execution for a set of resources including state, timestamps for when steps for the remediation execution occur, and any error messages for steps that have failed\cr
#'  \link[paws.management:configservice_describe_retention_configurations]{describe_retention_configurations} \tab Returns the details of one or more retention configurations\cr
#'  \link[paws.management:configservice_disassociate_resource_types]{disassociate_resource_types} \tab Removes all resource types specified in the ResourceTypes list from the RecordingGroup of configuration recorder and excludes these resource types when recording\cr
#'  \link[paws.management:configservice_get_aggregate_compliance_details_by_config_rule]{get_aggregate_compliance_details_by_config_rule} \tab Returns the evaluation results for the specified Config rule for a specific resource in a rule\cr
#'  \link[paws.management:configservice_get_aggregate_config_rule_compliance_summary]{get_aggregate_config_rule_compliance_summary} \tab Returns the number of compliant and noncompliant rules for one or more accounts and regions in an aggregator\cr
#'  \link[paws.management:configservice_get_aggregate_conformance_pack_compliance_summary]{get_aggregate_conformance_pack_compliance_summary} \tab Returns the count of compliant and noncompliant conformance packs across all Amazon Web Services accounts and Amazon Web Services Regions in an aggregator\cr
#'  \link[paws.management:configservice_get_aggregate_discovered_resource_counts]{get_aggregate_discovered_resource_counts} \tab Returns the resource counts across accounts and regions that are present in your Config aggregator\cr
#'  \link[paws.management:configservice_get_aggregate_resource_config]{get_aggregate_resource_config} \tab Returns configuration item that is aggregated for your specific resource in a specific source account and region\cr
#'  \link[paws.management:configservice_get_compliance_details_by_config_rule]{get_compliance_details_by_config_rule} \tab Returns the evaluation results for the specified Config rule\cr
#'  \link[paws.management:configservice_get_compliance_details_by_resource]{get_compliance_details_by_resource} \tab Returns the evaluation results for the specified Amazon Web Services resource\cr
#'  \link[paws.management:configservice_get_compliance_summary_by_config_rule]{get_compliance_summary_by_config_rule} \tab Returns the number of Config rules that are compliant and noncompliant, up to a maximum of 25 for each\cr
#'  \link[paws.management:configservice_get_compliance_summary_by_resource_type]{get_compliance_summary_by_resource_type} \tab Returns the number of resources that are compliant and the number that are noncompliant\cr
#'  \link[paws.management:configservice_get_conformance_pack_compliance_details]{get_conformance_pack_compliance_details} \tab Returns compliance details of a conformance pack for all Amazon Web Services resources that are monitered by conformance pack\cr
#'  \link[paws.management:configservice_get_conformance_pack_compliance_summary]{get_conformance_pack_compliance_summary} \tab Returns compliance details for the conformance pack based on the cumulative compliance results of all the rules in that conformance pack\cr
#'  \link[paws.management:configservice_get_custom_rule_policy]{get_custom_rule_policy} \tab Returns the policy definition containing the logic for your Config Custom Policy rule\cr
#'  \link[paws.management:configservice_get_discovered_resource_counts]{get_discovered_resource_counts} \tab Returns the resource types, the number of each resource type, and the total number of resources that Config is recording in this region for your Amazon Web Services account\cr
#'  \link[paws.management:configservice_get_organization_config_rule_detailed_status]{get_organization_config_rule_detailed_status} \tab Returns detailed status for each member account within an organization for a given organization Config rule\cr
#'  \link[paws.management:configservice_get_organization_conformance_pack_detailed_status]{get_organization_conformance_pack_detailed_status} \tab Returns detailed status for each member account within an organization for a given organization conformance pack\cr
#'  \link[paws.management:configservice_get_organization_custom_rule_policy]{get_organization_custom_rule_policy} \tab Returns the policy definition containing the logic for your organization Config Custom Policy rule\cr
#'  \link[paws.management:configservice_get_resource_config_history]{get_resource_config_history} \tab For accurate reporting on the compliance status, you must record the AWS::Config::ResourceCompliance resource type\cr
#'  \link[paws.management:configservice_get_resource_evaluation_summary]{get_resource_evaluation_summary} \tab Returns a summary of resource evaluation for the specified resource evaluation ID from the proactive rules that were run\cr
#'  \link[paws.management:configservice_get_stored_query]{get_stored_query} \tab Returns the details of a specific stored query\cr
#'  \link[paws.management:configservice_list_aggregate_discovered_resources]{list_aggregate_discovered_resources} \tab Accepts a resource type and returns a list of resource identifiers that are aggregated for a specific resource type across accounts and regions\cr
#'  \link[paws.management:configservice_list_configuration_recorders]{list_configuration_recorders} \tab Returns a list of configuration recorders depending on the filters you specify\cr
#'  \link[paws.management:configservice_list_conformance_pack_compliance_scores]{list_conformance_pack_compliance_scores} \tab Returns a list of conformance pack compliance scores\cr
#'  \link[paws.management:configservice_list_discovered_resources]{list_discovered_resources} \tab Accepts a resource type and returns a list of resource identifiers for the resources of that type\cr
#'  \link[paws.management:configservice_list_resource_evaluations]{list_resource_evaluations} \tab Returns a list of proactive resource evaluations\cr
#'  \link[paws.management:configservice_list_stored_queries]{list_stored_queries} \tab Lists the stored queries for a single Amazon Web Services account and a single Amazon Web Services Region\cr
#'  \link[paws.management:configservice_list_tags_for_resource]{list_tags_for_resource} \tab List the tags for Config resource\cr
#'  \link[paws.management:configservice_put_aggregation_authorization]{put_aggregation_authorization} \tab Authorizes the aggregator account and region to collect data from the source account and region\cr
#'  \link[paws.management:configservice_put_config_rule]{put_config_rule} \tab Adds or updates an Config rule to evaluate if your Amazon Web Services resources comply with your desired configurations\cr
#'  \link[paws.management:configservice_put_configuration_aggregator]{put_configuration_aggregator} \tab Creates and updates the configuration aggregator with the selected source accounts and regions\cr
#'  \link[paws.management:configservice_put_configuration_recorder]{put_configuration_recorder} \tab Creates or updates the customer managed configuration recorder\cr
#'  \link[paws.management:configservice_put_conformance_pack]{put_conformance_pack} \tab Creates or updates a conformance pack\cr
#'  \link[paws.management:configservice_put_delivery_channel]{put_delivery_channel} \tab Creates or updates a delivery channel to deliver configuration information and other compliance information\cr
#'  \link[paws.management:configservice_put_evaluations]{put_evaluations} \tab Used by an Lambda function to deliver evaluation results to Config\cr
#'  \link[paws.management:configservice_put_external_evaluation]{put_external_evaluation} \tab Add or updates the evaluations for process checks\cr
#'  \link[paws.management:configservice_put_organization_config_rule]{put_organization_config_rule} \tab Adds or updates an Config rule for your entire organization to evaluate if your Amazon Web Services resources comply with your desired configurations\cr
#'  \link[paws.management:configservice_put_organization_conformance_pack]{put_organization_conformance_pack} \tab Deploys conformance packs across member accounts in an Amazon Web Services Organization\cr
#'  \link[paws.management:configservice_put_remediation_configurations]{put_remediation_configurations} \tab Adds or updates the remediation configuration with a specific Config rule with the selected target or action\cr
#'  \link[paws.management:configservice_put_remediation_exceptions]{put_remediation_exceptions} \tab A remediation exception is when a specified resource is no longer considered for auto-remediation\cr
#'  \link[paws.management:configservice_put_resource_config]{put_resource_config} \tab Records the configuration state for the resource provided in the request\cr
#'  \link[paws.management:configservice_put_retention_configuration]{put_retention_configuration} \tab Creates and updates the retention configuration with details about retention period (number of days) that Config stores your historical information\cr
#'  \link[paws.management:configservice_put_service_linked_configuration_recorder]{put_service_linked_configuration_recorder} \tab Creates a service-linked configuration recorder that is linked to a specific Amazon Web Services service based on the ServicePrincipal you specify\cr
#'  \link[paws.management:configservice_put_stored_query]{put_stored_query} \tab Saves a new query or updates an existing saved query\cr
#'  \link[paws.management:configservice_select_aggregate_resource_config]{select_aggregate_resource_config} \tab Accepts a structured query language (SQL) SELECT command and an aggregator to query configuration state of Amazon Web Services resources across multiple accounts and regions, performs the corresponding search, and returns resource configurations matching the properties\cr
#'  \link[paws.management:configservice_select_resource_config]{select_resource_config} \tab Accepts a structured query language (SQL) SELECT command, performs the corresponding search, and returns resource configurations matching the properties\cr
#'  \link[paws.management:configservice_start_config_rules_evaluation]{start_config_rules_evaluation} \tab Runs an on-demand evaluation for the specified Config rules against the last known configuration state of the resources\cr
#'  \link[paws.management:configservice_start_configuration_recorder]{start_configuration_recorder} \tab Starts the customer managed configuration recorder\cr
#'  \link[paws.management:configservice_start_remediation_execution]{start_remediation_execution} \tab Runs an on-demand remediation for the specified Config rules against the last known remediation configuration\cr
#'  \link[paws.management:configservice_start_resource_evaluation]{start_resource_evaluation} \tab Runs an on-demand evaluation for the specified resource to determine whether the resource details will comply with configured Config rules\cr
#'  \link[paws.management:configservice_stop_configuration_recorder]{stop_configuration_recorder} \tab Stops the customer managed configuration recorder\cr
#'  \link[paws.management:configservice_tag_resource]{tag_resource} \tab Associates the specified tags to a resource with the specified ResourceArn\cr
#'  \link[paws.management:configservice_untag_resource]{untag_resource} \tab Deletes specified tags from a resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname configservice
#' @export
configservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::configservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Control Tower
#'
#' @description
#' Amazon Web Services Control Tower offers application programming
#' interface (API) operations that support programmatic interaction with
#' these types of resources:
#' 
#' -   [*Controls*](https://docs.aws.amazon.com/controltower/latest/controlreference/controls.html)
#' 
#'     -   `disable_control`
#' 
#'     -   `enable_control`
#' 
#'     -   `get_enabled_control`
#' 
#'     -   `list_control_operations`
#' 
#'     -   `list_enabled_controls`
#' 
#'     -   `update_enabled_control`
#' 
#' -   [*Landing
#'     zones*](https://docs.aws.amazon.com/controltower/latest/userguide/lz-api-launch.html)
#' 
#'     -   `create_landing_zone`
#' 
#'     -   `delete_landing_zone`
#' 
#'     -   `get_landing_zone`
#' 
#'     -   `get_landing_zone_operation`
#' 
#'     -   `list_landing_zones`
#' 
#'     -   `list_landing_zone_operations`
#' 
#'     -   `reset_landing_zone`
#' 
#'     -   `update_landing_zone`
#' 
#' -   [*Baselines*](https://docs.aws.amazon.com/controltower/latest/userguide/types-of-baselines.html)
#' 
#'     -   `disable_baseline`
#' 
#'     -   `enable_baseline`
#' 
#'     -   `get_baseline`
#' 
#'     -   `get_baseline_operation`
#' 
#'     -   `get_enabled_baseline`
#' 
#'     -   `list_baselines`
#' 
#'     -   `list_enabled_baselines`
#' 
#'     -   `reset_enabled_baseline`
#' 
#'     -   `update_enabled_baseline`
#' 
#' -   [*Tagging*](https://docs.aws.amazon.com/controltower/latest/controlreference/tagging.html)
#' 
#'     -   `list_tags_for_resource`
#' 
#'     -   `tag_resource`
#' 
#'     -   `untag_resource`
#' 
#' For more information about these types of resources, see the [*Amazon
#' Web Services Control Tower User
#' Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/what-is-control-tower.html)
#' .
#' 
#' **About control APIs**
#' 
#' These interfaces allow you to apply the Amazon Web Services library of
#' pre-defined *controls* to your organizational units, programmatically.
#' In Amazon Web Services Control Tower, the terms "control" and
#' "guardrail" are synonyms.
#' 
#' To call these APIs, you'll need to know:
#' 
#' -   the `controlIdentifier` for the control--or guardrail--you are
#'     targeting.
#' 
#' -   the ARN associated with the target organizational unit (OU), which
#'     we call the `targetIdentifier`.
#' 
#' -   the ARN associated with a resource that you wish to tag or untag.
#' 
#' **To get the `controlIdentifier` for your Amazon Web Services Control
#' Tower control:**
#' 
#' The `controlIdentifier` is an ARN that is specified for each control.
#' You can view the `controlIdentifier` in the console on the **Control
#' details** page, as well as in the documentation.
#' 
#' **About identifiers for Amazon Web Services Control Tower**
#' 
#' The Amazon Web Services Control Tower `controlIdentifier` is unique in
#' each Amazon Web Services Region for each control. You can find the
#' `controlIdentifier` for each Region and control in the [Tables of
#' control
#' metadata](https://docs.aws.amazon.com/controltower/latest/controlreference/control-metadata-tables.html)
#' or the [Control availability by Region
#' tables](https://docs.aws.amazon.com/controltower/latest/controlreference/control-region-tables.html)
#' in the *Amazon Web Services Control Tower Controls Reference Guide*.
#' 
#' A quick-reference list of control identifers for the Amazon Web Services
#' Control Tower legacy *Strongly recommended* and *Elective* controls is
#' given in [Resource identifiers for APIs and
#' controls](https://docs.aws.amazon.com/controltower/latest/controlreference/)
#' in the [*Amazon Web Services Control Tower Controls Reference
#' Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-identifiers.html)
#' . Remember that *Mandatory* controls cannot be added or removed.
#' 
#' **Some controls have two identifiers**
#' 
#' -   **ARN format for Amazon Web Services Control Tower:**
#'     `arn:aws:controltower:{REGION}::control/{CONTROL_TOWER_OPAQUE_ID}`
#' 
#'     **Example:**
#' 
#'     `arn:aws:controltower:us-west-2::control/AWS-GR_AUTOSCALING_LAUNCH_CONFIG_PUBLIC_IP_DISABLED`
#' 
#' -   **ARN format for Amazon Web Services Control Catalog:**
#'     `arn:{PARTITION}:controlcatalog:::control/{CONTROL_CATALOG_OPAQUE_ID}`
#' 
#' You can find the `{CONTROL_CATALOG_OPAQUE_ID}` in the [*Amazon Web
#' Services Control Tower Controls Reference
#' Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/all-global-identifiers.html)
#' , or in the Amazon Web Services Control Tower console, on the **Control
#' details** page.
#' 
#' The Amazon Web Services Control Tower APIs for enabled controls, such as
#' `get_enabled_control` and
#' `list_enabled_controls` always
#' return an ARN of the same type given when the control was enabled.
#' 
#' **To get the `targetIdentifier`:**
#' 
#' The `targetIdentifier` is the ARN for an OU.
#' 
#' In the Amazon Web Services Organizations console, you can find the ARN
#' for the OU on the **Organizational unit details** page associated with
#' that OU.
#' 
#' **OU ARN format:**
#' 
#' `arn:${Partition}:organizations::${MasterAccountId}:ou/o-${OrganizationId}/ou-${OrganizationalUnitId}`
#' 
#' **About landing zone APIs**
#' 
#' You can configure and launch an Amazon Web Services Control Tower
#' landing zone with APIs. For an introduction and steps, see [Getting
#' started with Amazon Web Services Control Tower using
#' APIs](https://docs.aws.amazon.com/controltower/latest/userguide/getting-started-apis.html).
#' 
#' For an overview of landing zone API operations, see [Amazon Web Services
#' Control Tower supports landing zone
#' APIs](https://docs.aws.amazon.com/controltower/latest/userguide/2023-all.html#landing-zone-apis).
#' The individual API operations for landing zones are detailed in this
#' document, the [API reference
#' manual](https://docs.aws.amazon.com/controltower/latest/APIReference/API_Operations.html),
#' in the "Actions" section.
#' 
#' **About baseline APIs**
#' 
#' You can apply the `AWSControlTowerBaseline` baseline to an
#' organizational unit (OU) as a way to register the OU with Amazon Web
#' Services Control Tower, programmatically. For a general overview of this
#' capability, see [Amazon Web Services Control Tower supports APIs for OU
#' registration and configuration with
#' baselines](https://docs.aws.amazon.com/controltower/latest/userguide/2024-all.html#baseline-apis).
#' 
#' You can call the baseline API operations to view the baselines that
#' Amazon Web Services Control Tower enables for your landing zone, on your
#' behalf, when setting up the landing zone. These baselines are read-only
#' baselines.
#' 
#' The individual API operations for baselines are detailed in this
#' document, the [API reference
#' manual](https://docs.aws.amazon.com/controltower/latest/APIReference/API_Operations.html),
#' in the "Actions" section. For usage examples, see [Baseline API input
#' and output examples with
#' CLI](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html).
#' 
#' **About Amazon Web Services Control Catalog identifiers**
#' 
#' -   The `enable_control` and
#'     `disable_control` API operations can
#'     be called by specifying either the Amazon Web Services Control Tower
#'     identifer or the Amazon Web Services Control Catalog identifier. The
#'     API response returns the same type of identifier that you specified
#'     when calling the API.
#' 
#' -   If you use an Amazon Web Services Control Tower identifier to call
#'     the `enable_control` API, and then
#'     call `enable_control` again with an
#'     Amazon Web Services Control Catalog identifier, Amazon Web Services
#'     Control Tower returns an error message stating that the control is
#'     already enabled. Similar behavior applies to the
#'     `disable_control` API operation.
#' 
#' -   Mandatory controls and the landing-zone-level Region deny control
#'     have Amazon Web Services Control Tower identifiers only.
#' 
#' **Details and examples**
#' 
#' -   [Control API input and output examples with
#'     CLI](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html)
#' 
#' -   [Baseline API input and output examples with
#'     CLI](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html)
#' 
#' -   [Enable controls with
#'     CloudFormation](https://docs.aws.amazon.com/controltower/latest/controlreference/enable-controls.html)
#' 
#' -   [Launch a landing zone with
#'     CloudFormation](https://docs.aws.amazon.com/controltower/latest/userguide/lz-apis-cfn-setup.html)
#' 
#' -   [Control metadata tables (large
#'     page)](https://docs.aws.amazon.com/controltower/latest/controlreference/control-metadata-tables.html)
#' 
#' -   [Control availability by Region tables (large
#'     page)](https://docs.aws.amazon.com/controltower/latest/controlreference/control-region-tables.html)
#' 
#' -   [List of identifiers for legacy
#'     controls](https://docs.aws.amazon.com/controltower/latest/controlreference/control-identifiers.html)
#' 
#' -   [Controls reference
#'     guide](https://docs.aws.amazon.com/controltower/latest/controlreference/controls.html)
#' 
#' -   [Controls library
#'     groupings](https://docs.aws.amazon.com/controltower/latest/controlreference/controls-reference.html)
#' 
#' -   [Creating Amazon Web Services Control Tower resources with Amazon
#'     Web Services
#'     CloudFormation](https://docs.aws.amazon.com/controltower/latest/userguide/creating-resources-with-cloudformation.html)
#' 
#' To view the open source resource repository on GitHub, see
#' [aws-cloudformation/aws-cloudformation-resource-providers-controltower](https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-controltower)
#' 
#' **Recording API Requests**
#' 
#' Amazon Web Services Control Tower supports Amazon Web Services
#' CloudTrail, a service that records Amazon Web Services API calls for
#' your Amazon Web Services account and delivers log files to an Amazon S3
#' bucket. By using information collected by CloudTrail, you can determine
#' which requests the Amazon Web Services Control Tower service received,
#' who made the request and when, and so on. For more about Amazon Web
#' Services Control Tower and its support for CloudTrail, see [Logging
#' Amazon Web Services Control Tower Actions with Amazon Web Services
#' CloudTrail](https://docs.aws.amazon.com/controltower/latest/userguide/logging-using-cloudtrail.html)
#' in the Amazon Web Services Control Tower User Guide. To learn more about
#' CloudTrail, including how to turn it on and find your log files, see the
#' Amazon Web Services CloudTrail User Guide.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- controltower(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- controltower()
#' svc$create_landing_zone(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:controltower_create_landing_zone]{create_landing_zone} \tab Creates a new landing zone\cr
#'  \link[paws.management:controltower_delete_landing_zone]{delete_landing_zone} \tab Decommissions a landing zone\cr
#'  \link[paws.management:controltower_disable_baseline]{disable_baseline} \tab Disable an EnabledBaseline resource on the specified Target\cr
#'  \link[paws.management:controltower_disable_control]{disable_control} \tab This API call turns off a control\cr
#'  \link[paws.management:controltower_enable_baseline]{enable_baseline} \tab Enable (apply) a Baseline to a Target\cr
#'  \link[paws.management:controltower_enable_control]{enable_control} \tab This API call activates a control\cr
#'  \link[paws.management:controltower_get_baseline]{get_baseline} \tab Retrieve details about an existing Baseline resource by specifying its identifier\cr
#'  \link[paws.management:controltower_get_baseline_operation]{get_baseline_operation} \tab Returns the details of an asynchronous baseline operation, as initiated by any of these APIs: EnableBaseline, DisableBaseline, UpdateEnabledBaseline, ResetEnabledBaseline\cr
#'  \link[paws.management:controltower_get_control_operation]{get_control_operation} \tab Returns the status of a particular EnableControl or DisableControl operation\cr
#'  \link[paws.management:controltower_get_enabled_baseline]{get_enabled_baseline} \tab Retrieve details of an EnabledBaseline resource by specifying its identifier\cr
#'  \link[paws.management:controltower_get_enabled_control]{get_enabled_control} \tab Retrieves details about an enabled control\cr
#'  \link[paws.management:controltower_get_landing_zone]{get_landing_zone} \tab Returns details about the landing zone\cr
#'  \link[paws.management:controltower_get_landing_zone_operation]{get_landing_zone_operation} \tab Returns the status of the specified landing zone operation\cr
#'  \link[paws.management:controltower_list_baselines]{list_baselines} \tab Returns a summary list of all available baselines\cr
#'  \link[paws.management:controltower_list_control_operations]{list_control_operations} \tab Provides a list of operations in progress or queued\cr
#'  \link[paws.management:controltower_list_enabled_baselines]{list_enabled_baselines} \tab Returns a list of summaries describing EnabledBaseline resources\cr
#'  \link[paws.management:controltower_list_enabled_controls]{list_enabled_controls} \tab Lists the controls enabled by Amazon Web Services Control Tower on the specified organizational unit and the accounts it contains\cr
#'  \link[paws.management:controltower_list_landing_zone_operations]{list_landing_zone_operations} \tab Lists all landing zone operations from the past 90 days\cr
#'  \link[paws.management:controltower_list_landing_zones]{list_landing_zones} \tab Returns the landing zone ARN for the landing zone deployed in your managed account\cr
#'  \link[paws.management:controltower_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags associated with the resource\cr
#'  \link[paws.management:controltower_reset_enabled_baseline]{reset_enabled_baseline} \tab Re-enables an EnabledBaseline resource\cr
#'  \link[paws.management:controltower_reset_enabled_control]{reset_enabled_control} \tab Resets an enabled control\cr
#'  \link[paws.management:controltower_reset_landing_zone]{reset_landing_zone} \tab This API call resets a landing zone\cr
#'  \link[paws.management:controltower_tag_resource]{tag_resource} \tab Applies tags to a resource\cr
#'  \link[paws.management:controltower_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.management:controltower_update_enabled_baseline]{update_enabled_baseline} \tab Updates an EnabledBaseline resource's applied parameters or version\cr
#'  \link[paws.management:controltower_update_enabled_control]{update_enabled_control} \tab Updates the configuration of an already enabled control\cr
#'  \link[paws.management:controltower_update_landing_zone]{update_landing_zone} \tab This API call updates the landing zone
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname controltower
#' @export
controltower <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::controltower(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudWatch Evidently
#'
#' @description
#' You can use Amazon CloudWatch Evidently to safely validate new features
#' by serving them to a specified percentage of your users while you roll
#' out the feature. You can monitor the performance of the new feature to
#' help you decide when to ramp up traffic to your users. This helps you
#' reduce risk and identify unintended consequences before you fully launch
#' the feature.
#' 
#' You can also conduct A/B experiments to make feature design decisions
#' based on evidence and data. An experiment can test as many as five
#' variations at once. Evidently collects experiment data and analyzes it
#' using statistical methods. It also provides clear recommendations about
#' which variations perform better. You can test both user-facing features
#' and backend features.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudwatchevidently(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudwatchevidently()
#' svc$batch_evaluate_feature(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudwatchevidently_batch_evaluate_feature]{batch_evaluate_feature} \tab This operation assigns feature variation to user sessions\cr
#'  \link[paws.management:cloudwatchevidently_create_experiment]{create_experiment} \tab Creates an Evidently experiment\cr
#'  \link[paws.management:cloudwatchevidently_create_feature]{create_feature} \tab Creates an Evidently feature that you want to launch or test\cr
#'  \link[paws.management:cloudwatchevidently_create_launch]{create_launch} \tab Creates a launch of a given feature\cr
#'  \link[paws.management:cloudwatchevidently_create_project]{create_project} \tab Creates a project, which is the logical object in Evidently that can contain features, launches, and experiments\cr
#'  \link[paws.management:cloudwatchevidently_create_segment]{create_segment} \tab Use this operation to define a segment of your audience\cr
#'  \link[paws.management:cloudwatchevidently_delete_experiment]{delete_experiment} \tab Deletes an Evidently experiment\cr
#'  \link[paws.management:cloudwatchevidently_delete_feature]{delete_feature} \tab Deletes an Evidently feature\cr
#'  \link[paws.management:cloudwatchevidently_delete_launch]{delete_launch} \tab Deletes an Evidently launch\cr
#'  \link[paws.management:cloudwatchevidently_delete_project]{delete_project} \tab Deletes an Evidently project\cr
#'  \link[paws.management:cloudwatchevidently_delete_segment]{delete_segment} \tab Deletes a segment\cr
#'  \link[paws.management:cloudwatchevidently_evaluate_feature]{evaluate_feature} \tab This operation assigns a feature variation to one given user session\cr
#'  \link[paws.management:cloudwatchevidently_get_experiment]{get_experiment} \tab Returns the details about one experiment\cr
#'  \link[paws.management:cloudwatchevidently_get_experiment_results]{get_experiment_results} \tab Retrieves the results of a running or completed experiment\cr
#'  \link[paws.management:cloudwatchevidently_get_feature]{get_feature} \tab Returns the details about one feature\cr
#'  \link[paws.management:cloudwatchevidently_get_launch]{get_launch} \tab Returns the details about one launch\cr
#'  \link[paws.management:cloudwatchevidently_get_project]{get_project} \tab Returns the details about one launch\cr
#'  \link[paws.management:cloudwatchevidently_get_segment]{get_segment} \tab Returns information about the specified segment\cr
#'  \link[paws.management:cloudwatchevidently_list_experiments]{list_experiments} \tab Returns configuration details about all the experiments in the specified project\cr
#'  \link[paws.management:cloudwatchevidently_list_features]{list_features} \tab Returns configuration details about all the features in the specified project\cr
#'  \link[paws.management:cloudwatchevidently_list_launches]{list_launches} \tab Returns configuration details about all the launches in the specified project\cr
#'  \link[paws.management:cloudwatchevidently_list_projects]{list_projects} \tab Returns configuration details about all the projects in the current Region in your account\cr
#'  \link[paws.management:cloudwatchevidently_list_segment_references]{list_segment_references} \tab Use this operation to find which experiments or launches are using a specified segment\cr
#'  \link[paws.management:cloudwatchevidently_list_segments]{list_segments} \tab Returns a list of audience segments that you have created in your account in this Region\cr
#'  \link[paws.management:cloudwatchevidently_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with an Evidently resource\cr
#'  \link[paws.management:cloudwatchevidently_put_project_events]{put_project_events} \tab Sends performance events to Evidently\cr
#'  \link[paws.management:cloudwatchevidently_start_experiment]{start_experiment} \tab Starts an existing experiment\cr
#'  \link[paws.management:cloudwatchevidently_start_launch]{start_launch} \tab Starts an existing launch\cr
#'  \link[paws.management:cloudwatchevidently_stop_experiment]{stop_experiment} \tab Stops an experiment that is currently running\cr
#'  \link[paws.management:cloudwatchevidently_stop_launch]{stop_launch} \tab Stops a launch that is currently running\cr
#'  \link[paws.management:cloudwatchevidently_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified CloudWatch Evidently resource\cr
#'  \link[paws.management:cloudwatchevidently_test_segment_pattern]{test_segment_pattern} \tab Use this operation to test a rules pattern that you plan to use to create an audience segment\cr
#'  \link[paws.management:cloudwatchevidently_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.management:cloudwatchevidently_update_experiment]{update_experiment} \tab Updates an Evidently experiment\cr
#'  \link[paws.management:cloudwatchevidently_update_feature]{update_feature} \tab Updates an existing feature\cr
#'  \link[paws.management:cloudwatchevidently_update_launch]{update_launch} \tab Updates a launch of a given feature\cr
#'  \link[paws.management:cloudwatchevidently_update_project]{update_project} \tab Updates the description of an existing project\cr
#'  \link[paws.management:cloudwatchevidently_update_project_data_delivery]{update_project_data_delivery} \tab Updates the data storage options for this project
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudwatchevidently
#' @export
cloudwatchevidently <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudwatchevidently(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' FinSpace User Environment Management service
#'
#' @description
#' The FinSpace management service provides the APIs for managing FinSpace
#' environments.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- finspace(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- finspace()
#' svc$create_environment(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:finspace_create_environment]{create_environment} \tab Create a new FinSpace environment\cr
#'  \link[paws.management:finspace_create_kx_changeset]{create_kx_changeset} \tab Creates a changeset for a kdb database\cr
#'  \link[paws.management:finspace_create_kx_cluster]{create_kx_cluster} \tab Creates a new kdb cluster\cr
#'  \link[paws.management:finspace_create_kx_database]{create_kx_database} \tab Creates a new kdb database in the environment\cr
#'  \link[paws.management:finspace_create_kx_dataview]{create_kx_dataview} \tab Creates a snapshot of kdb database with tiered storage capabilities and a pre-warmed cache, ready for mounting on kdb clusters\cr
#'  \link[paws.management:finspace_create_kx_environment]{create_kx_environment} \tab Creates a managed kdb environment for the account\cr
#'  \link[paws.management:finspace_create_kx_scaling_group]{create_kx_scaling_group} \tab Creates a new scaling group\cr
#'  \link[paws.management:finspace_create_kx_user]{create_kx_user} \tab Creates a user in FinSpace kdb environment with an associated IAM role\cr
#'  \link[paws.management:finspace_create_kx_volume]{create_kx_volume} \tab Creates a new volume with a specific amount of throughput and storage capacity\cr
#'  \link[paws.management:finspace_delete_environment]{delete_environment} \tab Delete an FinSpace environment\cr
#'  \link[paws.management:finspace_delete_kx_cluster]{delete_kx_cluster} \tab Deletes a kdb cluster\cr
#'  \link[paws.management:finspace_delete_kx_cluster_node]{delete_kx_cluster_node} \tab Deletes the specified nodes from a cluster\cr
#'  \link[paws.management:finspace_delete_kx_database]{delete_kx_database} \tab Deletes the specified database and all of its associated data\cr
#'  \link[paws.management:finspace_delete_kx_dataview]{delete_kx_dataview} \tab Deletes the specified dataview\cr
#'  \link[paws.management:finspace_delete_kx_environment]{delete_kx_environment} \tab Deletes the kdb environment\cr
#'  \link[paws.management:finspace_delete_kx_scaling_group]{delete_kx_scaling_group} \tab Deletes the specified scaling group\cr
#'  \link[paws.management:finspace_delete_kx_user]{delete_kx_user} \tab Deletes a user in the specified kdb environment\cr
#'  \link[paws.management:finspace_delete_kx_volume]{delete_kx_volume} \tab Deletes a volume\cr
#'  \link[paws.management:finspace_get_environment]{get_environment} \tab Returns the FinSpace environment object\cr
#'  \link[paws.management:finspace_get_kx_changeset]{get_kx_changeset} \tab Returns information about a kdb changeset\cr
#'  \link[paws.management:finspace_get_kx_cluster]{get_kx_cluster} \tab Retrieves information about a kdb cluster\cr
#'  \link[paws.management:finspace_get_kx_connection_string]{get_kx_connection_string} \tab Retrieves a connection string for a user to connect to a kdb cluster\cr
#'  \link[paws.management:finspace_get_kx_database]{get_kx_database} \tab Returns database information for the specified environment ID\cr
#'  \link[paws.management:finspace_get_kx_dataview]{get_kx_dataview} \tab Retrieves details of the dataview\cr
#'  \link[paws.management:finspace_get_kx_environment]{get_kx_environment} \tab Retrieves all the information for the specified kdb environment\cr
#'  \link[paws.management:finspace_get_kx_scaling_group]{get_kx_scaling_group} \tab Retrieves details of a scaling group\cr
#'  \link[paws.management:finspace_get_kx_user]{get_kx_user} \tab Retrieves information about the specified kdb user\cr
#'  \link[paws.management:finspace_get_kx_volume]{get_kx_volume} \tab Retrieves the information about the volume\cr
#'  \link[paws.management:finspace_list_environments]{list_environments} \tab A list of all of your FinSpace environments\cr
#'  \link[paws.management:finspace_list_kx_changesets]{list_kx_changesets} \tab Returns a list of all the changesets for a database\cr
#'  \link[paws.management:finspace_list_kx_cluster_nodes]{list_kx_cluster_nodes} \tab Lists all the nodes in a kdb cluster\cr
#'  \link[paws.management:finspace_list_kx_clusters]{list_kx_clusters} \tab Returns a list of clusters\cr
#'  \link[paws.management:finspace_list_kx_databases]{list_kx_databases} \tab Returns a list of all the databases in the kdb environment\cr
#'  \link[paws.management:finspace_list_kx_dataviews]{list_kx_dataviews} \tab Returns a list of all the dataviews in the database\cr
#'  \link[paws.management:finspace_list_kx_environments]{list_kx_environments} \tab Returns a list of kdb environments created in an account\cr
#'  \link[paws.management:finspace_list_kx_scaling_groups]{list_kx_scaling_groups} \tab Returns a list of scaling groups in a kdb environment\cr
#'  \link[paws.management:finspace_list_kx_users]{list_kx_users} \tab Lists all the users in a kdb environment\cr
#'  \link[paws.management:finspace_list_kx_volumes]{list_kx_volumes} \tab Lists all the volumes in a kdb environment\cr
#'  \link[paws.management:finspace_list_tags_for_resource]{list_tags_for_resource} \tab A list of all tags for a resource\cr
#'  \link[paws.management:finspace_tag_resource]{tag_resource} \tab Adds metadata tags to a FinSpace resource\cr
#'  \link[paws.management:finspace_untag_resource]{untag_resource} \tab Removes metadata tags from a FinSpace resource\cr
#'  \link[paws.management:finspace_update_environment]{update_environment} \tab Update your FinSpace environment\cr
#'  \link[paws.management:finspace_update_kx_cluster_code_configuration]{update_kx_cluster_code_configuration} \tab Allows you to update code configuration on a running cluster\cr
#'  \link[paws.management:finspace_update_kx_cluster_databases]{update_kx_cluster_databases} \tab Updates the databases mounted on a kdb cluster, which includes the changesetId and all the dbPaths to be cached\cr
#'  \link[paws.management:finspace_update_kx_database]{update_kx_database} \tab Updates information for the given kdb database\cr
#'  \link[paws.management:finspace_update_kx_dataview]{update_kx_dataview} \tab Updates the specified dataview\cr
#'  \link[paws.management:finspace_update_kx_environment]{update_kx_environment} \tab Updates information for the given kdb environment\cr
#'  \link[paws.management:finspace_update_kx_environment_network]{update_kx_environment_network} \tab Updates environment network to connect to your internal network by using a transit gateway\cr
#'  \link[paws.management:finspace_update_kx_user]{update_kx_user} \tab Updates the user details\cr
#'  \link[paws.management:finspace_update_kx_volume]{update_kx_volume} \tab Updates the throughput or capacity of a volume
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname finspace
#' @export
finspace <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::finspace(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Managed Grafana
#'
#' @description
#' Amazon Managed Grafana is a fully managed and secure data visualization
#' service that you can use to instantly query, correlate, and visualize
#' operational metrics, logs, and traces from multiple sources. Amazon
#' Managed Grafana makes it easy to deploy, operate, and scale Grafana, a
#' widely deployed data visualization tool that is popular for its
#' extensible data support.
#' 
#' With Amazon Managed Grafana, you create logically isolated Grafana
#' servers called *workspaces*. In a workspace, you can create Grafana
#' dashboards and visualizations to analyze your metrics, logs, and traces
#' without having to build, package, or deploy any hardware to run Grafana
#' servers.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- managedgrafana(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- managedgrafana()
#' svc$associate_license(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:managedgrafana_associate_license]{associate_license} \tab Assigns a Grafana Enterprise license to a workspace\cr
#'  \link[paws.management:managedgrafana_create_workspace]{create_workspace} \tab Creates a workspace\cr
#'  \link[paws.management:managedgrafana_create_workspace_api_key]{create_workspace_api_key} \tab Creates a Grafana API key for the workspace\cr
#'  \link[paws.management:managedgrafana_create_workspace_service_account]{create_workspace_service_account} \tab Creates a service account for the workspace\cr
#'  \link[paws.management:managedgrafana_create_workspace_service_account_token]{create_workspace_service_account_token} \tab Creates a token that can be used to authenticate and authorize Grafana HTTP API operations for the given workspace service account\cr
#'  \link[paws.management:managedgrafana_delete_workspace]{delete_workspace} \tab Deletes an Amazon Managed Grafana workspace\cr
#'  \link[paws.management:managedgrafana_delete_workspace_api_key]{delete_workspace_api_key} \tab Deletes a Grafana API key for the workspace\cr
#'  \link[paws.management:managedgrafana_delete_workspace_service_account]{delete_workspace_service_account} \tab Deletes a workspace service account from the workspace\cr
#'  \link[paws.management:managedgrafana_delete_workspace_service_account_token]{delete_workspace_service_account_token} \tab Deletes a token for the workspace service account\cr
#'  \link[paws.management:managedgrafana_describe_workspace]{describe_workspace} \tab Displays information about one Amazon Managed Grafana workspace\cr
#'  \link[paws.management:managedgrafana_describe_workspace_authentication]{describe_workspace_authentication} \tab Displays information about the authentication methods used in one Amazon Managed Grafana workspace\cr
#'  \link[paws.management:managedgrafana_describe_workspace_configuration]{describe_workspace_configuration} \tab Gets the current configuration string for the given workspace\cr
#'  \link[paws.management:managedgrafana_disassociate_license]{disassociate_license} \tab Removes the Grafana Enterprise license from a workspace\cr
#'  \link[paws.management:managedgrafana_list_permissions]{list_permissions} \tab Lists the users and groups who have the Grafana Admin and Editor roles in this workspace\cr
#'  \link[paws.management:managedgrafana_list_tags_for_resource]{list_tags_for_resource} \tab The ListTagsForResource operation returns the tags that are associated with the Amazon Managed Service for Grafana resource specified by the resourceArn\cr
#'  \link[paws.management:managedgrafana_list_versions]{list_versions} \tab Lists available versions of Grafana\cr
#'  \link[paws.management:managedgrafana_list_workspaces]{list_workspaces} \tab Returns a list of Amazon Managed Grafana workspaces in the account, with some information about each workspace\cr
#'  \link[paws.management:managedgrafana_list_workspace_service_accounts]{list_workspace_service_accounts} \tab Returns a list of service accounts for a workspace\cr
#'  \link[paws.management:managedgrafana_list_workspace_service_account_tokens]{list_workspace_service_account_tokens} \tab Returns a list of tokens for a workspace service account\cr
#'  \link[paws.management:managedgrafana_tag_resource]{tag_resource} \tab The TagResource operation associates tags with an Amazon Managed Grafana resource\cr
#'  \link[paws.management:managedgrafana_untag_resource]{untag_resource} \tab The UntagResource operation removes the association of the tag with the Amazon Managed Grafana resource\cr
#'  \link[paws.management:managedgrafana_update_permissions]{update_permissions} \tab Updates which users in a workspace have the Grafana Admin or Editor roles\cr
#'  \link[paws.management:managedgrafana_update_workspace]{update_workspace} \tab Modifies an existing Amazon Managed Grafana workspace\cr
#'  \link[paws.management:managedgrafana_update_workspace_authentication]{update_workspace_authentication} \tab Use this operation to define the identity provider (IdP) that this workspace authenticates users from, using SAML\cr
#'  \link[paws.management:managedgrafana_update_workspace_configuration]{update_workspace_configuration} \tab Updates the configuration string for the given workspace
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname managedgrafana
#' @export
managedgrafana <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::managedgrafana(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Health APIs and Notifications
#'
#' @description
#' Health
#' 
#' The Health API provides access to the Health information that appears in
#' the Health Dashboard. You can use the API operations to get information
#' about events that might affect your Amazon Web Services services and
#' resources.
#' 
#' You must have a Business, Enterprise On-Ramp, or Enterprise Support plan
#' from [Amazon Web Services
#' Support](https://aws.amazon.com/premiumsupport/) to use the Health API.
#' If you call the Health API from an Amazon Web Services account that
#' doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan,
#' you receive a `SubscriptionRequiredException` error.
#' 
#' For API access, you need an access key ID and a secret access key. Use
#' temporary credentials instead of long-term access keys when possible.
#' Temporary credentials include an access key ID, a secret access key, and
#' a security token that indicates when the credentials expire. For more
#' information, see [Best practices for managing Amazon Web Services access
#' keys](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html#securing_access-keys)
#' in the *Amazon Web Services General Reference*.
#' 
#' You can use the Health endpoint health.us-east-1.amazonaws.com (HTTPS)
#' to call the Health API operations. Health supports a multi-Region
#' application architecture and has two regional endpoints in an
#' active-passive configuration. You can use the high availability endpoint
#' example to determine which Amazon Web Services Region is active, so that
#' you can get the latest information from the API. For more information,
#' see [Accessing the Health
#' API](https://docs.aws.amazon.com/health/latest/ug/health-api.html) in
#' the *Health User Guide*.
#' 
#' For authentication of requests, Health uses the [Signature Version 4
#' Signing
#' Process](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html).
#' 
#' If your Amazon Web Services account is part of Organizations, you can
#' use the Health organizational view feature. This feature provides a
#' centralized view of Health events across all accounts in your
#' organization. You can aggregate Health events in real time to identify
#' accounts in your organization that are affected by an operational event
#' or get notified of security vulnerabilities. Use the organizational view
#' API operations to enable this feature and return event information. For
#' more information, see [Aggregating Health
#' events](https://docs.aws.amazon.com/health/latest/ug/aggregate-events.html)
#' in the *Health User Guide*.
#' 
#' When you use the Health API operations to return Health events, see the
#' following recommendations:
#' 
#' -   Use the
#'     [eventScopeCode](https://docs.aws.amazon.com/health/latest/APIReference/API_Event.html#AWSHealth-Type-Event-eventScopeCode)
#'     parameter to specify whether to return Health events that are public
#'     or account-specific.
#' 
#' -   Use pagination to view all events from the response. For example, if
#'     you call the
#'     `describe_events_for_organization`
#'     operation to get all events in your organization, you might receive
#'     several page results. Specify the `nextToken` in the next request to
#'     return more results.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- health(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- health()
#' svc$describe_affected_accounts_for_organization(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:health_describe_affected_accounts_for_organization]{describe_affected_accounts_for_organization} \tab Returns a list of accounts in the organization from Organizations that are affected by the provided event\cr
#'  \link[paws.management:health_describe_affected_entities]{describe_affected_entities} \tab Returns a list of entities that have been affected by the specified events, based on the specified filter criteria\cr
#'  \link[paws.management:health_describe_affected_entities_for_organization]{describe_affected_entities_for_organization} \tab Returns a list of entities that have been affected by one or more events for one or more accounts in your organization in Organizations, based on the filter criteria\cr
#'  \link[paws.management:health_describe_entity_aggregates]{describe_entity_aggregates} \tab Returns the number of entities that are affected by each of the specified events\cr
#'  \link[paws.management:health_describe_entity_aggregates_for_organization]{describe_entity_aggregates_for_organization} \tab Returns a list of entity aggregates for your Organizations that are affected by each of the specified events\cr
#'  \link[paws.management:health_describe_event_aggregates]{describe_event_aggregates} \tab Returns the number of events of each event type (issue, scheduled change, and account notification)\cr
#'  \link[paws.management:health_describe_event_details]{describe_event_details} \tab Returns detailed information about one or more specified events\cr
#'  \link[paws.management:health_describe_event_details_for_organization]{describe_event_details_for_organization} \tab Returns detailed information about one or more specified events for one or more Amazon Web Services accounts in your organization\cr
#'  \link[paws.management:health_describe_events]{describe_events} \tab Returns information about events that meet the specified filter criteria\cr
#'  \link[paws.management:health_describe_events_for_organization]{describe_events_for_organization} \tab Returns information about events across your organization in Organizations\cr
#'  \link[paws.management:health_describe_event_types]{describe_event_types} \tab Returns the event types that meet the specified filter criteria\cr
#'  \link[paws.management:health_describe_health_service_status_for_organization]{describe_health_service_status_for_organization} \tab This operation provides status information on enabling or disabling Health to work with your organization\cr
#'  \link[paws.management:health_disable_health_service_access_for_organization]{disable_health_service_access_for_organization} \tab Disables Health from working with Organizations\cr
#'  \link[paws.management:health_enable_health_service_access_for_organization]{enable_health_service_access_for_organization} \tab Enables Health to work with Organizations
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname health
#' @export
health <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::health(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS License Manager
#'
#' @description
#' License Manager makes it easier to manage licenses from software vendors
#' across multiple Amazon Web Services accounts and on-premises servers.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- licensemanager(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- licensemanager()
#' svc$accept_grant(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:licensemanager_accept_grant]{accept_grant} \tab Accepts the specified grant\cr
#'  \link[paws.management:licensemanager_check_in_license]{check_in_license} \tab Checks in the specified license\cr
#'  \link[paws.management:licensemanager_checkout_borrow_license]{checkout_borrow_license} \tab Checks out the specified license for offline use\cr
#'  \link[paws.management:licensemanager_checkout_license]{checkout_license} \tab Checks out the specified license\cr
#'  \link[paws.management:licensemanager_create_grant]{create_grant} \tab Creates a grant for the specified license\cr
#'  \link[paws.management:licensemanager_create_grant_version]{create_grant_version} \tab Creates a new version of the specified grant\cr
#'  \link[paws.management:licensemanager_create_license]{create_license} \tab Creates a license\cr
#'  \link[paws.management:licensemanager_create_license_configuration]{create_license_configuration} \tab Creates a license configuration\cr
#'  \link[paws.management:licensemanager_create_license_conversion_task_for_resource]{create_license_conversion_task_for_resource} \tab Creates a new license conversion task\cr
#'  \link[paws.management:licensemanager_create_license_manager_report_generator]{create_license_manager_report_generator} \tab Creates a report generator\cr
#'  \link[paws.management:licensemanager_create_license_version]{create_license_version} \tab Creates a new version of the specified license\cr
#'  \link[paws.management:licensemanager_create_token]{create_token} \tab Creates a long-lived token\cr
#'  \link[paws.management:licensemanager_delete_grant]{delete_grant} \tab Deletes the specified grant\cr
#'  \link[paws.management:licensemanager_delete_license]{delete_license} \tab Deletes the specified license\cr
#'  \link[paws.management:licensemanager_delete_license_configuration]{delete_license_configuration} \tab Deletes the specified license configuration\cr
#'  \link[paws.management:licensemanager_delete_license_manager_report_generator]{delete_license_manager_report_generator} \tab Deletes the specified report generator\cr
#'  \link[paws.management:licensemanager_delete_token]{delete_token} \tab Deletes the specified token\cr
#'  \link[paws.management:licensemanager_extend_license_consumption]{extend_license_consumption} \tab Extends the expiration date for license consumption\cr
#'  \link[paws.management:licensemanager_get_access_token]{get_access_token} \tab Gets a temporary access token to use with AssumeRoleWithWebIdentity\cr
#'  \link[paws.management:licensemanager_get_grant]{get_grant} \tab Gets detailed information about the specified grant\cr
#'  \link[paws.management:licensemanager_get_license]{get_license} \tab Gets detailed information about the specified license\cr
#'  \link[paws.management:licensemanager_get_license_configuration]{get_license_configuration} \tab Gets detailed information about the specified license configuration\cr
#'  \link[paws.management:licensemanager_get_license_conversion_task]{get_license_conversion_task} \tab Gets information about the specified license type conversion task\cr
#'  \link[paws.management:licensemanager_get_license_manager_report_generator]{get_license_manager_report_generator} \tab Gets information about the specified report generator\cr
#'  \link[paws.management:licensemanager_get_license_usage]{get_license_usage} \tab Gets detailed information about the usage of the specified license\cr
#'  \link[paws.management:licensemanager_get_service_settings]{get_service_settings} \tab Gets the License Manager settings for the current Region\cr
#'  \link[paws.management:licensemanager_list_associations_for_license_configuration]{list_associations_for_license_configuration} \tab Lists the resource associations for the specified license configuration\cr
#'  \link[paws.management:licensemanager_list_distributed_grants]{list_distributed_grants} \tab Lists the grants distributed for the specified license\cr
#'  \link[paws.management:licensemanager_list_failures_for_license_configuration_operations]{list_failures_for_license_configuration_operations} \tab Lists the license configuration operations that failed\cr
#'  \link[paws.management:licensemanager_list_license_configurations]{list_license_configurations} \tab Lists the license configurations for your account\cr
#'  \link[paws.management:licensemanager_list_license_conversion_tasks]{list_license_conversion_tasks} \tab Lists the license type conversion tasks for your account\cr
#'  \link[paws.management:licensemanager_list_license_manager_report_generators]{list_license_manager_report_generators} \tab Lists the report generators for your account\cr
#'  \link[paws.management:licensemanager_list_licenses]{list_licenses} \tab Lists the licenses for your account\cr
#'  \link[paws.management:licensemanager_list_license_specifications_for_resource]{list_license_specifications_for_resource} \tab Describes the license configurations for the specified resource\cr
#'  \link[paws.management:licensemanager_list_license_versions]{list_license_versions} \tab Lists all versions of the specified license\cr
#'  \link[paws.management:licensemanager_list_received_grants]{list_received_grants} \tab Lists grants that are received\cr
#'  \link[paws.management:licensemanager_list_received_grants_for_organization]{list_received_grants_for_organization} \tab Lists the grants received for all accounts in the organization\cr
#'  \link[paws.management:licensemanager_list_received_licenses]{list_received_licenses} \tab Lists received licenses\cr
#'  \link[paws.management:licensemanager_list_received_licenses_for_organization]{list_received_licenses_for_organization} \tab Lists the licenses received for all accounts in the organization\cr
#'  \link[paws.management:licensemanager_list_resource_inventory]{list_resource_inventory} \tab Lists resources managed using Systems Manager inventory\cr
#'  \link[paws.management:licensemanager_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for the specified license configuration\cr
#'  \link[paws.management:licensemanager_list_tokens]{list_tokens} \tab Lists your tokens\cr
#'  \link[paws.management:licensemanager_list_usage_for_license_configuration]{list_usage_for_license_configuration} \tab Lists all license usage records for a license configuration, displaying license consumption details by resource at a selected point in time\cr
#'  \link[paws.management:licensemanager_reject_grant]{reject_grant} \tab Rejects the specified grant\cr
#'  \link[paws.management:licensemanager_tag_resource]{tag_resource} \tab Adds the specified tags to the specified license configuration\cr
#'  \link[paws.management:licensemanager_untag_resource]{untag_resource} \tab Removes the specified tags from the specified license configuration\cr
#'  \link[paws.management:licensemanager_update_license_configuration]{update_license_configuration} \tab Modifies the attributes of an existing license configuration\cr
#'  \link[paws.management:licensemanager_update_license_manager_report_generator]{update_license_manager_report_generator} \tab Updates a report generator\cr
#'  \link[paws.management:licensemanager_update_license_specifications_for_resource]{update_license_specifications_for_resource} \tab Adds or removes the specified license configurations for the specified Amazon Web Services resource\cr
#'  \link[paws.management:licensemanager_update_service_settings]{update_service_settings} \tab Updates License Manager settings for the current Region
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname licensemanager
#' @export
licensemanager <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::licensemanager(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS License Manager User Subscriptions
#'
#' @description
#' With License Manager, you can create user-based subscriptions to utilize
#' licensed software with a per user subscription fee on Amazon EC2
#' instances.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- licensemanagerusersubscriptions(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- licensemanagerusersubscriptions()
#' svc$associate_user(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:licensemanagerusersubscriptions_associate_user]{associate_user} \tab Associates the user to an EC2 instance to utilize user-based subscriptions\cr
#'  \link[paws.management:licensemanagerusersubscriptions_create_license_server_endpoint]{create_license_server_endpoint} \tab Creates a network endpoint for the Remote Desktop Services (RDS) license server\cr
#'  \link[paws.management:licensemanagerusersubscriptions_delete_license_server_endpoint]{delete_license_server_endpoint} \tab Deletes a LicenseServerEndpoint resource\cr
#'  \link[paws.management:licensemanagerusersubscriptions_deregister_identity_provider]{deregister_identity_provider} \tab Deregisters the Active Directory identity provider from License Manager user-based subscriptions\cr
#'  \link[paws.management:licensemanagerusersubscriptions_disassociate_user]{disassociate_user} \tab Disassociates the user from an EC2 instance providing user-based subscriptions\cr
#'  \link[paws.management:licensemanagerusersubscriptions_list_identity_providers]{list_identity_providers} \tab Lists the Active Directory identity providers for user-based subscriptions\cr
#'  \link[paws.management:licensemanagerusersubscriptions_list_instances]{list_instances} \tab Lists the EC2 instances providing user-based subscriptions\cr
#'  \link[paws.management:licensemanagerusersubscriptions_list_license_server_endpoints]{list_license_server_endpoints} \tab List the Remote Desktop Services (RDS) License Server endpoints\cr
#'  \link[paws.management:licensemanagerusersubscriptions_list_product_subscriptions]{list_product_subscriptions} \tab Lists the user-based subscription products available from an identity provider\cr
#'  \link[paws.management:licensemanagerusersubscriptions_list_tags_for_resource]{list_tags_for_resource} \tab Returns the list of tags for the specified resource\cr
#'  \link[paws.management:licensemanagerusersubscriptions_list_user_associations]{list_user_associations} \tab Lists user associations for an identity provider\cr
#'  \link[paws.management:licensemanagerusersubscriptions_register_identity_provider]{register_identity_provider} \tab Registers an identity provider for user-based subscriptions\cr
#'  \link[paws.management:licensemanagerusersubscriptions_start_product_subscription]{start_product_subscription} \tab Starts a product subscription for a user with the specified identity provider\cr
#'  \link[paws.management:licensemanagerusersubscriptions_stop_product_subscription]{stop_product_subscription} \tab Stops a product subscription for a user with the specified identity provider\cr
#'  \link[paws.management:licensemanagerusersubscriptions_tag_resource]{tag_resource} \tab Adds tags to a resource\cr
#'  \link[paws.management:licensemanagerusersubscriptions_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.management:licensemanagerusersubscriptions_update_identity_provider_settings]{update_identity_provider_settings} \tab Updates additional product configuration settings for the registered identity provider
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname licensemanagerusersubscriptions
#' @export
licensemanagerusersubscriptions <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::licensemanagerusersubscriptions(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS License Manager Linux Subscriptions
#'
#' @description
#' With License Manager, you can discover and track your commercial Linux
#' subscriptions on running Amazon EC2 instances.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- licensemanagerlinuxsubscriptions(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- licensemanagerlinuxsubscriptions()
#' svc$deregister_subscription_provider(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:licensemanagerlinuxsubscriptions_deregister_subscription_provider]{deregister_subscription_provider} \tab Remove a third-party subscription provider from the Bring Your Own License (BYOL) subscriptions registered to your account\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_get_registered_subscription_provider]{get_registered_subscription_provider} \tab Get details for a Bring Your Own License (BYOL) subscription that's registered to your account\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_get_service_settings]{get_service_settings} \tab Lists the Linux subscriptions service settings for your account\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_list_linux_subscription_instances]{list_linux_subscription_instances} \tab Lists the running Amazon EC2 instances that were discovered with commercial Linux subscriptions\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_list_linux_subscriptions]{list_linux_subscriptions} \tab Lists the Linux subscriptions that have been discovered\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_list_registered_subscription_providers]{list_registered_subscription_providers} \tab List Bring Your Own License (BYOL) subscription registration resources for your account\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_list_tags_for_resource]{list_tags_for_resource} \tab List the metadata tags that are assigned to the specified Amazon Web Services resource\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_register_subscription_provider]{register_subscription_provider} \tab Register the supported third-party subscription provider for your Bring Your Own License (BYOL) subscription\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_tag_resource]{tag_resource} \tab Add metadata tags to the specified Amazon Web Services resource\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_untag_resource]{untag_resource} \tab Remove one or more metadata tag from the specified Amazon Web Services resource\cr
#'  \link[paws.management:licensemanagerlinuxsubscriptions_update_service_settings]{update_service_settings} \tab Updates the service settings for Linux subscriptions
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname licensemanagerlinuxsubscriptions
#' @export
licensemanagerlinuxsubscriptions <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::licensemanagerlinuxsubscriptions(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudWatch Logs
#'
#' @description
#' You can use Amazon CloudWatch Logs to monitor, store, and access your
#' log files from EC2 instances, CloudTrail, and other sources. You can
#' then retrieve the associated log data from CloudWatch Logs using the
#' CloudWatch console. Alternatively, you can use CloudWatch Logs commands
#' in the Amazon Web Services CLI, CloudWatch Logs API, or CloudWatch Logs
#' SDK.
#' 
#' You can use CloudWatch Logs to:
#' 
#' -   **Monitor logs from EC2 instances in real time**: You can use
#'     CloudWatch Logs to monitor applications and systems using log data.
#'     For example, CloudWatch Logs can track the number of errors that
#'     occur in your application logs. Then, it can send you a notification
#'     whenever the rate of errors exceeds a threshold that you specify.
#'     CloudWatch Logs uses your log data for monitoring so no code changes
#'     are required. For example, you can monitor application logs for
#'     specific literal terms (such as "NullReferenceException"). You can
#'     also count the number of occurrences of a literal term at a
#'     particular position in log data (such as "404" status codes in an
#'     Apache access log). When the term you are searching for is found,
#'     CloudWatch Logs reports the data to a CloudWatch metric that you
#'     specify.
#' 
#' -   **Monitor CloudTrail logged events**: You can create alarms in
#'     CloudWatch and receive notifications of particular API activity as
#'     captured by CloudTrail. You can use the notification to perform
#'     troubleshooting.
#' 
#' -   **Archive log data**: You can use CloudWatch Logs to store your log
#'     data in highly durable storage. You can change the log retention
#'     setting so that any log events earlier than this setting are
#'     automatically deleted. The CloudWatch Logs agent helps to quickly
#'     send both rotated and non-rotated log data off of a host and into
#'     the log service. You can then access the raw log data when you need
#'     it.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudwatchlogs(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudwatchlogs()
#' svc$associate_kms_key(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudwatchlogs_associate_kms_key]{associate_kms_key} \tab Associates the specified KMS key with either one log group in the account, or with all stored CloudWatch Logs query insights results in the account\cr
#'  \link[paws.management:cloudwatchlogs_cancel_export_task]{cancel_export_task} \tab Cancels the specified export task\cr
#'  \link[paws.management:cloudwatchlogs_create_delivery]{create_delivery} \tab Creates a delivery\cr
#'  \link[paws.management:cloudwatchlogs_create_export_task]{create_export_task} \tab Creates an export task so that you can efficiently export data from a log group to an Amazon S3 bucket\cr
#'  \link[paws.management:cloudwatchlogs_create_log_anomaly_detector]{create_log_anomaly_detector} \tab Creates an anomaly detector that regularly scans one or more log groups and look for patterns and anomalies in the logs\cr
#'  \link[paws.management:cloudwatchlogs_create_log_group]{create_log_group} \tab Creates a log group with the specified name\cr
#'  \link[paws.management:cloudwatchlogs_create_log_stream]{create_log_stream} \tab Creates a log stream for the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_delete_account_policy]{delete_account_policy} \tab Deletes a CloudWatch Logs account policy\cr
#'  \link[paws.management:cloudwatchlogs_delete_data_protection_policy]{delete_data_protection_policy} \tab Deletes the data protection policy from the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_delete_delivery]{delete_delivery} \tab Deletes a delivery\cr
#'  \link[paws.management:cloudwatchlogs_delete_delivery_destination]{delete_delivery_destination} \tab Deletes a delivery destination\cr
#'  \link[paws.management:cloudwatchlogs_delete_delivery_destination_policy]{delete_delivery_destination_policy} \tab Deletes a delivery destination policy\cr
#'  \link[paws.management:cloudwatchlogs_delete_delivery_source]{delete_delivery_source} \tab Deletes a delivery source\cr
#'  \link[paws.management:cloudwatchlogs_delete_destination]{delete_destination} \tab Deletes the specified destination, and eventually disables all the subscription filters that publish to it\cr
#'  \link[paws.management:cloudwatchlogs_delete_index_policy]{delete_index_policy} \tab Deletes a log-group level field index policy that was applied to a single log group\cr
#'  \link[paws.management:cloudwatchlogs_delete_integration]{delete_integration} \tab Deletes the integration between CloudWatch Logs and OpenSearch Service\cr
#'  \link[paws.management:cloudwatchlogs_delete_log_anomaly_detector]{delete_log_anomaly_detector} \tab Deletes the specified CloudWatch Logs anomaly detector\cr
#'  \link[paws.management:cloudwatchlogs_delete_log_group]{delete_log_group} \tab Deletes the specified log group and permanently deletes all the archived log events associated with the log group\cr
#'  \link[paws.management:cloudwatchlogs_delete_log_stream]{delete_log_stream} \tab Deletes the specified log stream and permanently deletes all the archived log events associated with the log stream\cr
#'  \link[paws.management:cloudwatchlogs_delete_metric_filter]{delete_metric_filter} \tab Deletes the specified metric filter\cr
#'  \link[paws.management:cloudwatchlogs_delete_query_definition]{delete_query_definition} \tab Deletes a saved CloudWatch Logs Insights query definition\cr
#'  \link[paws.management:cloudwatchlogs_delete_resource_policy]{delete_resource_policy} \tab Deletes a resource policy from this account\cr
#'  \link[paws.management:cloudwatchlogs_delete_retention_policy]{delete_retention_policy} \tab Deletes the specified retention policy\cr
#'  \link[paws.management:cloudwatchlogs_delete_subscription_filter]{delete_subscription_filter} \tab Deletes the specified subscription filter\cr
#'  \link[paws.management:cloudwatchlogs_delete_transformer]{delete_transformer} \tab Deletes the log transformer for the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_describe_account_policies]{describe_account_policies} \tab Returns a list of all CloudWatch Logs account policies in the account\cr
#'  \link[paws.management:cloudwatchlogs_describe_configuration_templates]{describe_configuration_templates} \tab Use this operation to return the valid and default values that are used when creating delivery sources, delivery destinations, and deliveries\cr
#'  \link[paws.management:cloudwatchlogs_describe_deliveries]{describe_deliveries} \tab Retrieves a list of the deliveries that have been created in the account\cr
#'  \link[paws.management:cloudwatchlogs_describe_delivery_destinations]{describe_delivery_destinations} \tab Retrieves a list of the delivery destinations that have been created in the account\cr
#'  \link[paws.management:cloudwatchlogs_describe_delivery_sources]{describe_delivery_sources} \tab Retrieves a list of the delivery sources that have been created in the account\cr
#'  \link[paws.management:cloudwatchlogs_describe_destinations]{describe_destinations} \tab Lists all your destinations\cr
#'  \link[paws.management:cloudwatchlogs_describe_export_tasks]{describe_export_tasks} \tab Lists the specified export tasks\cr
#'  \link[paws.management:cloudwatchlogs_describe_field_indexes]{describe_field_indexes} \tab Returns a list of field indexes listed in the field index policies of one or more log groups\cr
#'  \link[paws.management:cloudwatchlogs_describe_index_policies]{describe_index_policies} \tab Returns the field index policies of one or more log groups\cr
#'  \link[paws.management:cloudwatchlogs_describe_log_groups]{describe_log_groups} \tab Lists the specified log groups\cr
#'  \link[paws.management:cloudwatchlogs_describe_log_streams]{describe_log_streams} \tab Lists the log streams for the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_describe_metric_filters]{describe_metric_filters} \tab Lists the specified metric filters\cr
#'  \link[paws.management:cloudwatchlogs_describe_queries]{describe_queries} \tab Returns a list of CloudWatch Logs Insights queries that are scheduled, running, or have been run recently in this account\cr
#'  \link[paws.management:cloudwatchlogs_describe_query_definitions]{describe_query_definitions} \tab This operation returns a paginated list of your saved CloudWatch Logs Insights query definitions\cr
#'  \link[paws.management:cloudwatchlogs_describe_resource_policies]{describe_resource_policies} \tab Lists the resource policies in this account\cr
#'  \link[paws.management:cloudwatchlogs_describe_subscription_filters]{describe_subscription_filters} \tab Lists the subscription filters for the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_disassociate_kms_key]{disassociate_kms_key} \tab Disassociates the specified KMS key from the specified log group or from all CloudWatch Logs Insights query results in the account\cr
#'  \link[paws.management:cloudwatchlogs_filter_log_events]{filter_log_events} \tab Lists log events from the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_get_data_protection_policy]{get_data_protection_policy} \tab Returns information about a log group data protection policy\cr
#'  \link[paws.management:cloudwatchlogs_get_delivery]{get_delivery} \tab Returns complete information about one logical delivery\cr
#'  \link[paws.management:cloudwatchlogs_get_delivery_destination]{get_delivery_destination} \tab Retrieves complete information about one delivery destination\cr
#'  \link[paws.management:cloudwatchlogs_get_delivery_destination_policy]{get_delivery_destination_policy} \tab Retrieves the delivery destination policy assigned to the delivery destination that you specify\cr
#'  \link[paws.management:cloudwatchlogs_get_delivery_source]{get_delivery_source} \tab Retrieves complete information about one delivery source\cr
#'  \link[paws.management:cloudwatchlogs_get_integration]{get_integration} \tab Returns information about one integration between CloudWatch Logs and OpenSearch Service\cr
#'  \link[paws.management:cloudwatchlogs_get_log_anomaly_detector]{get_log_anomaly_detector} \tab Retrieves information about the log anomaly detector that you specify\cr
#'  \link[paws.management:cloudwatchlogs_get_log_events]{get_log_events} \tab Lists log events from the specified log stream\cr
#'  \link[paws.management:cloudwatchlogs_get_log_group_fields]{get_log_group_fields} \tab Returns a list of the fields that are included in log events in the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_get_log_record]{get_log_record} \tab Retrieves all of the fields and values of a single log event\cr
#'  \link[paws.management:cloudwatchlogs_get_query_results]{get_query_results} \tab Returns the results from the specified query\cr
#'  \link[paws.management:cloudwatchlogs_get_transformer]{get_transformer} \tab Returns the information about the log transformer associated with this log group\cr
#'  \link[paws.management:cloudwatchlogs_list_anomalies]{list_anomalies} \tab Returns a list of anomalies that log anomaly detectors have found\cr
#'  \link[paws.management:cloudwatchlogs_list_integrations]{list_integrations} \tab Returns a list of integrations between CloudWatch Logs and other services in this account\cr
#'  \link[paws.management:cloudwatchlogs_list_log_anomaly_detectors]{list_log_anomaly_detectors} \tab Retrieves a list of the log anomaly detectors in the account\cr
#'  \link[paws.management:cloudwatchlogs_list_log_groups_for_query]{list_log_groups_for_query} \tab Returns a list of the log groups that were analyzed during a single CloudWatch Logs Insights query\cr
#'  \link[paws.management:cloudwatchlogs_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with a CloudWatch Logs resource\cr
#'  \link[paws.management:cloudwatchlogs_list_tags_log_group]{list_tags_log_group} \tab The ListTagsLogGroup operation is on the path to deprecation\cr
#'  \link[paws.management:cloudwatchlogs_put_account_policy]{put_account_policy} \tab Creates an account-level data protection policy, subscription filter policy, or field index policy that applies to all log groups or a subset of log groups in the account\cr
#'  \link[paws.management:cloudwatchlogs_put_data_protection_policy]{put_data_protection_policy} \tab Creates a data protection policy for the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_put_delivery_destination]{put_delivery_destination} \tab Creates or updates a logical delivery destination\cr
#'  \link[paws.management:cloudwatchlogs_put_delivery_destination_policy]{put_delivery_destination_policy} \tab Creates and assigns an IAM policy that grants permissions to CloudWatch Logs to deliver logs cross-account to a specified destination in this account\cr
#'  \link[paws.management:cloudwatchlogs_put_delivery_source]{put_delivery_source} \tab Creates or updates a logical delivery source\cr
#'  \link[paws.management:cloudwatchlogs_put_destination]{put_destination} \tab Creates or updates a destination\cr
#'  \link[paws.management:cloudwatchlogs_put_destination_policy]{put_destination_policy} \tab Creates or updates an access policy associated with an existing destination\cr
#'  \link[paws.management:cloudwatchlogs_put_index_policy]{put_index_policy} \tab Creates or updates a field index policy for the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_put_integration]{put_integration} \tab Creates an integration between CloudWatch Logs and another service in this account\cr
#'  \link[paws.management:cloudwatchlogs_put_log_events]{put_log_events} \tab Uploads a batch of log events to the specified log stream\cr
#'  \link[paws.management:cloudwatchlogs_put_metric_filter]{put_metric_filter} \tab Creates or updates a metric filter and associates it with the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_put_query_definition]{put_query_definition} \tab Creates or updates a query definition for CloudWatch Logs Insights\cr
#'  \link[paws.management:cloudwatchlogs_put_resource_policy]{put_resource_policy} \tab Creates or updates a resource policy allowing other Amazon Web Services services to put log events to this account, such as Amazon Route 53\cr
#'  \link[paws.management:cloudwatchlogs_put_retention_policy]{put_retention_policy} \tab Sets the retention of the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_put_subscription_filter]{put_subscription_filter} \tab Creates or updates a subscription filter and associates it with the specified log group\cr
#'  \link[paws.management:cloudwatchlogs_put_transformer]{put_transformer} \tab Creates or updates a log transformer for a single log group\cr
#'  \link[paws.management:cloudwatchlogs_start_live_tail]{start_live_tail} \tab Starts a Live Tail streaming session for one or more log groups\cr
#'  \link[paws.management:cloudwatchlogs_start_query]{start_query} \tab Starts a query of one or more log groups using CloudWatch Logs Insights\cr
#'  \link[paws.management:cloudwatchlogs_stop_query]{stop_query} \tab Stops a CloudWatch Logs Insights query that is in progress\cr
#'  \link[paws.management:cloudwatchlogs_tag_log_group]{tag_log_group} \tab The TagLogGroup operation is on the path to deprecation\cr
#'  \link[paws.management:cloudwatchlogs_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified CloudWatch Logs resource\cr
#'  \link[paws.management:cloudwatchlogs_test_metric_filter]{test_metric_filter} \tab Tests the filter pattern of a metric filter against a sample of log event messages\cr
#'  \link[paws.management:cloudwatchlogs_test_transformer]{test_transformer} \tab Use this operation to test a log transformer\cr
#'  \link[paws.management:cloudwatchlogs_untag_log_group]{untag_log_group} \tab The UntagLogGroup operation is on the path to deprecation\cr
#'  \link[paws.management:cloudwatchlogs_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.management:cloudwatchlogs_update_anomaly]{update_anomaly} \tab Use this operation to suppress anomaly detection for a specified anomaly or pattern\cr
#'  \link[paws.management:cloudwatchlogs_update_delivery_configuration]{update_delivery_configuration} \tab Use this operation to update the configuration of a delivery to change either the S3 path pattern or the format of the delivered logs\cr
#'  \link[paws.management:cloudwatchlogs_update_log_anomaly_detector]{update_log_anomaly_detector} \tab Updates an existing log anomaly detector
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudwatchlogs
#' @export
cloudwatchlogs <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudwatchlogs(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudWatch Internet Monitor
#'
#' @description
#' Amazon CloudWatch Internet Monitor provides visibility into how internet
#' issues impact the performance and availability between your applications
#' hosted on Amazon Web Services and your end users. It can reduce the time
#' it takes for you to diagnose internet issues from days to minutes.
#' Internet Monitor uses the connectivity data that Amazon Web Services
#' captures from its global networking footprint to calculate a baseline of
#' performance and availability for internet traffic. This is the same data
#' that Amazon Web Services uses to monitor internet uptime and
#' availability. With those measurements as a baseline, Internet Monitor
#' raises awareness for you when there are significant problems for your
#' end users in the different geographic locations where your application
#' runs.
#' 
#' Internet Monitor publishes internet measurements to CloudWatch Logs and
#' CloudWatch Metrics, to easily support using CloudWatch tools with health
#' information for geographies and networks specific to your application.
#' Internet Monitor sends health events to Amazon EventBridge so that you
#' can set up notifications. If an issue is caused by the Amazon Web
#' Services network, you also automatically receive an Amazon Web Services
#' Health Dashboard notification with the steps that Amazon Web Services is
#' taking to mitigate the problem.
#' 
#' To use Internet Monitor, you create a *monitor* and associate your
#' application's resources with it - VPCs, NLBs, CloudFront distributions,
#' or WorkSpaces directories - so Internet Monitor can determine where your
#' application's internet traffic is. Internet Monitor then provides
#' internet measurements from Amazon Web Services that are specific to the
#' locations and ASNs (typically, internet service providers or ISPs) that
#' communicate with your application.
#' 
#' For more information, see [Using Amazon CloudWatch Internet
#' Monitor](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-InternetMonitor.html)
#' in the *Amazon CloudWatch User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudwatchinternetmonitor(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudwatchinternetmonitor()
#' svc$create_monitor(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudwatchinternetmonitor_create_monitor]{create_monitor} \tab Creates a monitor in Amazon CloudWatch Internet Monitor\cr
#'  \link[paws.management:cloudwatchinternetmonitor_delete_monitor]{delete_monitor} \tab Deletes a monitor in Amazon CloudWatch Internet Monitor\cr
#'  \link[paws.management:cloudwatchinternetmonitor_get_health_event]{get_health_event} \tab Gets information that Amazon CloudWatch Internet Monitor has created and stored about a health event for a specified monitor\cr
#'  \link[paws.management:cloudwatchinternetmonitor_get_internet_event]{get_internet_event} \tab Gets information that Amazon CloudWatch Internet Monitor has generated about an internet event\cr
#'  \link[paws.management:cloudwatchinternetmonitor_get_monitor]{get_monitor} \tab Gets information about a monitor in Amazon CloudWatch Internet Monitor based on a monitor name\cr
#'  \link[paws.management:cloudwatchinternetmonitor_get_query_results]{get_query_results} \tab Return the data for a query with the Amazon CloudWatch Internet Monitor query interface\cr
#'  \link[paws.management:cloudwatchinternetmonitor_get_query_status]{get_query_status} \tab Returns the current status of a query for the Amazon CloudWatch Internet Monitor query interface, for a specified query ID and monitor\cr
#'  \link[paws.management:cloudwatchinternetmonitor_list_health_events]{list_health_events} \tab Lists all health events for a monitor in Amazon CloudWatch Internet Monitor\cr
#'  \link[paws.management:cloudwatchinternetmonitor_list_internet_events]{list_internet_events} \tab Lists internet events that cause performance or availability issues for client locations\cr
#'  \link[paws.management:cloudwatchinternetmonitor_list_monitors]{list_monitors} \tab Lists all of your monitors for Amazon CloudWatch Internet Monitor and their statuses, along with the Amazon Resource Name (ARN) and name of each monitor\cr
#'  \link[paws.management:cloudwatchinternetmonitor_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for a resource\cr
#'  \link[paws.management:cloudwatchinternetmonitor_start_query]{start_query} \tab Start a query to return data for a specific query type for the Amazon CloudWatch Internet Monitor query interface\cr
#'  \link[paws.management:cloudwatchinternetmonitor_stop_query]{stop_query} \tab Stop a query that is progress for a specific monitor\cr
#'  \link[paws.management:cloudwatchinternetmonitor_tag_resource]{tag_resource} \tab Adds a tag to a resource\cr
#'  \link[paws.management:cloudwatchinternetmonitor_untag_resource]{untag_resource} \tab Removes a tag from a resource\cr
#'  \link[paws.management:cloudwatchinternetmonitor_update_monitor]{update_monitor} \tab Updates a monitor
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudwatchinternetmonitor
#' @export
cloudwatchinternetmonitor <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudwatchinternetmonitor(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudWatch
#'
#' @description
#' Amazon CloudWatch monitors your Amazon Web Services (Amazon Web
#' Services) resources and the applications you run on Amazon Web Services
#' in real time. You can use CloudWatch to collect and track metrics, which
#' are the variables you want to measure for your resources and
#' applications.
#' 
#' CloudWatch alarms send notifications or automatically change the
#' resources you are monitoring based on rules that you define. For
#' example, you can monitor the CPU usage and disk reads and writes of your
#' Amazon EC2 instances. Then, use this data to determine whether you
#' should launch additional instances to handle increased load. You can
#' also use this data to stop under-used instances to save money.
#' 
#' In addition to monitoring the built-in metrics that come with Amazon Web
#' Services, you can monitor your own custom metrics. With CloudWatch, you
#' gain system-wide visibility into resource utilization, application
#' performance, and operational health.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudwatch(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudwatch()
#' svc$delete_alarms(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudwatch_delete_alarms]{delete_alarms} \tab Deletes the specified alarms\cr
#'  \link[paws.management:cloudwatch_delete_anomaly_detector]{delete_anomaly_detector} \tab Deletes the specified anomaly detection model from your account\cr
#'  \link[paws.management:cloudwatch_delete_dashboards]{delete_dashboards} \tab Deletes all dashboards that you specify\cr
#'  \link[paws.management:cloudwatch_delete_insight_rules]{delete_insight_rules} \tab Permanently deletes the specified Contributor Insights rules\cr
#'  \link[paws.management:cloudwatch_delete_metric_stream]{delete_metric_stream} \tab Permanently deletes the metric stream that you specify\cr
#'  \link[paws.management:cloudwatch_describe_alarm_history]{describe_alarm_history} \tab Retrieves the history for the specified alarm\cr
#'  \link[paws.management:cloudwatch_describe_alarms]{describe_alarms} \tab Retrieves the specified alarms\cr
#'  \link[paws.management:cloudwatch_describe_alarms_for_metric]{describe_alarms_for_metric} \tab Retrieves the alarms for the specified metric\cr
#'  \link[paws.management:cloudwatch_describe_anomaly_detectors]{describe_anomaly_detectors} \tab Lists the anomaly detection models that you have created in your account\cr
#'  \link[paws.management:cloudwatch_describe_insight_rules]{describe_insight_rules} \tab Returns a list of all the Contributor Insights rules in your account\cr
#'  \link[paws.management:cloudwatch_disable_alarm_actions]{disable_alarm_actions} \tab Disables the actions for the specified alarms\cr
#'  \link[paws.management:cloudwatch_disable_insight_rules]{disable_insight_rules} \tab Disables the specified Contributor Insights rules\cr
#'  \link[paws.management:cloudwatch_enable_alarm_actions]{enable_alarm_actions} \tab Enables the actions for the specified alarms\cr
#'  \link[paws.management:cloudwatch_enable_insight_rules]{enable_insight_rules} \tab Enables the specified Contributor Insights rules\cr
#'  \link[paws.management:cloudwatch_get_dashboard]{get_dashboard} \tab Displays the details of the dashboard that you specify\cr
#'  \link[paws.management:cloudwatch_get_insight_rule_report]{get_insight_rule_report} \tab This operation returns the time series data collected by a Contributor Insights rule\cr
#'  \link[paws.management:cloudwatch_get_metric_data]{get_metric_data} \tab You can use the GetMetricData API to retrieve CloudWatch metric values\cr
#'  \link[paws.management:cloudwatch_get_metric_statistics]{get_metric_statistics} \tab Gets statistics for the specified metric\cr
#'  \link[paws.management:cloudwatch_get_metric_stream]{get_metric_stream} \tab Returns information about the metric stream that you specify\cr
#'  \link[paws.management:cloudwatch_get_metric_widget_image]{get_metric_widget_image} \tab You can use the GetMetricWidgetImage API to retrieve a snapshot graph of one or more Amazon CloudWatch metrics as a bitmap image\cr
#'  \link[paws.management:cloudwatch_list_dashboards]{list_dashboards} \tab Returns a list of the dashboards for your account\cr
#'  \link[paws.management:cloudwatch_list_managed_insight_rules]{list_managed_insight_rules} \tab Returns a list that contains the number of managed Contributor Insights rules in your account\cr
#'  \link[paws.management:cloudwatch_list_metrics]{list_metrics} \tab List the specified metrics\cr
#'  \link[paws.management:cloudwatch_list_metric_streams]{list_metric_streams} \tab Returns a list of metric streams in this account\cr
#'  \link[paws.management:cloudwatch_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with a CloudWatch resource\cr
#'  \link[paws.management:cloudwatch_put_anomaly_detector]{put_anomaly_detector} \tab Creates an anomaly detection model for a CloudWatch metric\cr
#'  \link[paws.management:cloudwatch_put_composite_alarm]{put_composite_alarm} \tab Creates or updates a composite alarm\cr
#'  \link[paws.management:cloudwatch_put_dashboard]{put_dashboard} \tab Creates a dashboard if it does not already exist, or updates an existing dashboard\cr
#'  \link[paws.management:cloudwatch_put_insight_rule]{put_insight_rule} \tab Creates a Contributor Insights rule\cr
#'  \link[paws.management:cloudwatch_put_managed_insight_rules]{put_managed_insight_rules} \tab Creates a managed Contributor Insights rule for a specified Amazon Web Services resource\cr
#'  \link[paws.management:cloudwatch_put_metric_alarm]{put_metric_alarm} \tab Creates or updates an alarm and associates it with the specified metric, metric math expression, anomaly detection model, or Metrics Insights query\cr
#'  \link[paws.management:cloudwatch_put_metric_data]{put_metric_data} \tab Publishes metric data to Amazon CloudWatch\cr
#'  \link[paws.management:cloudwatch_put_metric_stream]{put_metric_stream} \tab Creates or updates a metric stream\cr
#'  \link[paws.management:cloudwatch_set_alarm_state]{set_alarm_state} \tab Temporarily sets the state of an alarm for testing purposes\cr
#'  \link[paws.management:cloudwatch_start_metric_streams]{start_metric_streams} \tab Starts the streaming of metrics for one or more of your metric streams\cr
#'  \link[paws.management:cloudwatch_stop_metric_streams]{stop_metric_streams} \tab Stops the streaming of metrics for one or more of your metric streams\cr
#'  \link[paws.management:cloudwatch_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified CloudWatch resource\cr
#'  \link[paws.management:cloudwatch_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudwatch
#' @export
cloudwatch <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudwatch(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' CloudWatch Observability Access Manager
#'
#' @description
#' Use Amazon CloudWatch Observability Access Manager to create and manage
#' links between source accounts and monitoring accounts by using
#' *CloudWatch cross-account observability*. With CloudWatch cross-account
#' observability, you can monitor and troubleshoot applications that span
#' multiple accounts within a Region. Seamlessly search, visualize, and
#' analyze your metrics, logs, traces, and Application Insights
#' applications in any of the linked accounts without account boundaries.
#' 
#' Set up one or more Amazon Web Services accounts as *monitoring accounts*
#' and link them with multiple *source accounts*. A monitoring account is a
#' central Amazon Web Services account that can view and interact with
#' observability data generated from source accounts. A source account is
#' an individual Amazon Web Services account that generates observability
#' data for the resources that reside in it. Source accounts share their
#' observability data with the monitoring account. The shared observability
#' data can include metrics in Amazon CloudWatch, logs in Amazon CloudWatch
#' Logs, traces in X-Ray, and applications in Amazon CloudWatch Application
#' Insights.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudwatchobservabilityaccessmanager(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudwatchobservabilityaccessmanager()
#' svc$create_link(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_create_link]{create_link} \tab Creates a link between a source account and a sink that you have created in a monitoring account\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_create_sink]{create_sink} \tab Use this to create a sink in the current account, so that it can be used as a monitoring account in CloudWatch cross-account observability\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_delete_link]{delete_link} \tab Deletes a link between a monitoring account sink and a source account\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_delete_sink]{delete_sink} \tab Deletes a sink\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_get_link]{get_link} \tab Returns complete information about one link\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_get_sink]{get_sink} \tab Returns complete information about one monitoring account sink\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_get_sink_policy]{get_sink_policy} \tab Returns the current sink policy attached to this sink\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_list_attached_links]{list_attached_links} \tab Returns a list of source account links that are linked to this monitoring account sink\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_list_links]{list_links} \tab Use this operation in a source account to return a list of links to monitoring account sinks that this source account has\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_list_sinks]{list_sinks} \tab Use this operation in a monitoring account to return the list of sinks created in that account\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with a resource\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_put_sink_policy]{put_sink_policy} \tab Creates or updates the resource policy that grants permissions to source accounts to link to the monitoring account sink\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified resource\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.management:cloudwatchobservabilityaccessmanager_update_link]{update_link} \tab Use this operation to change what types of data are shared from a source account to its linked monitoring account sink
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudwatchobservabilityaccessmanager
#' @export
cloudwatchobservabilityaccessmanager <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudwatchobservabilityaccessmanager(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS OpsWorks
#'
#' @description
#' OpsWorks
#' 
#' Welcome to the *OpsWorks Stacks API Reference*. This guide provides
#' descriptions, syntax, and usage examples for OpsWorks Stacks actions and
#' data types, including common parameters and error codes.
#' 
#' OpsWorks Stacks is an application management service that provides an
#' integrated experience for managing the complete application lifecycle.
#' For information about OpsWorks, see the
#' [OpsWorks](https://aws.amazon.com/) information page.
#' 
#' **SDKs and CLI**
#' 
#' Use the OpsWorks Stacks API by using the Command Line Interface (CLI) or
#' by using one of the Amazon Web Services SDKs to implement applications
#' in your preferred language. For more information, see:
#' 
#' -   [CLI](https://docs.aws.amazon.com/cli/latest/userguide/cli-chap-welcome.html)
#' 
#' -   [SDK for
#'     Java](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/opsworks/AWSOpsWorksClient.html)
#' 
#' -   [SDK for
#'     .NET](https://docs.aws.amazon.com/sdkfornet/v3/apidocs/items/OpsWorks/NOpsWorks.html)
#' 
#' -   [SDK for
#'     PHP](https://docs.aws.amazon.com/aws-sdk-php/v3/api/class-Aws.OpsWorks.OpsWorksClient.html)
#' 
#' -   [SDK for Ruby](https://docs.aws.amazon.com/sdk-for-ruby/v2/api/)
#' 
#' -   [Amazon Web Services SDK for
#'     Node.js](https://docs.aws.amazon.com/sdk-for-javascript/)
#' 
#' -   [SDK for Python
#'     (Boto)](https://docs.pythonboto.org/en/latest/ref/opsworks.html)
#' 
#' **Endpoints**
#' 
#' OpsWorks Stacks supports the following endpoints, all HTTPS. You must
#' connect to one of the following endpoints. Stacks can only be accessed
#' or managed within the endpoint in which they are created.
#' 
#' -   opsworks.us-east-1.amazonaws.com
#' 
#' -   opsworks.us-east-2.amazonaws.com
#' 
#' -   opsworks.us-west-1.amazonaws.com
#' 
#' -   opsworks.us-west-2.amazonaws.com
#' 
#' -   opsworks.ca-central-1.amazonaws.com (API only; not available in the
#'     Amazon Web Services Management Console)
#' 
#' -   opsworks.eu-west-1.amazonaws.com
#' 
#' -   opsworks.eu-west-2.amazonaws.com
#' 
#' -   opsworks.eu-west-3.amazonaws.com
#' 
#' -   opsworks.eu-central-1.amazonaws.com
#' 
#' -   opsworks.ap-northeast-1.amazonaws.com
#' 
#' -   opsworks.ap-northeast-2.amazonaws.com
#' 
#' -   opsworks.ap-south-1.amazonaws.com
#' 
#' -   opsworks.ap-southeast-1.amazonaws.com
#' 
#' -   opsworks.ap-southeast-2.amazonaws.com
#' 
#' -   opsworks.sa-east-1.amazonaws.com
#' 
#' **Chef Versions**
#' 
#' When you call `create_stack`,
#' `clone_stack`, or
#' `update_stack` we recommend you use the
#' `ConfigurationManager` parameter to specify the Chef version. The
#' recommended and default value for Linux stacks is currently 12. Windows
#' stacks use Chef 12.2. For more information, see [Chef
#' Versions](https://docs.aws.amazon.com/opsworks/latest/userguide/workingcookbook-chef11.html).
#' 
#' You can specify Chef 12, 11.10, or 11.4 for your Linux stack. We
#' recommend migrating your existing Linux stacks to Chef 12 as soon as
#' possible.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- opsworks(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- opsworks()
#' svc$assign_instance(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:opsworks_assign_instance]{assign_instance} \tab Assign a registered instance to a layer\cr
#'  \link[paws.management:opsworks_assign_volume]{assign_volume} \tab Assigns one of the stack's registered Amazon EBS volumes to a specified instance\cr
#'  \link[paws.management:opsworks_associate_elastic_ip]{associate_elastic_ip} \tab Associates one of the stack's registered Elastic IP addresses with a specified instance\cr
#'  \link[paws.management:opsworks_attach_elastic_load_balancer]{attach_elastic_load_balancer} \tab Attaches an Elastic Load Balancing load balancer to a specified layer\cr
#'  \link[paws.management:opsworks_clone_stack]{clone_stack} \tab Creates a clone of a specified stack\cr
#'  \link[paws.management:opsworks_create_app]{create_app} \tab Creates an app for a specified stack\cr
#'  \link[paws.management:opsworks_create_deployment]{create_deployment} \tab Runs deployment or stack commands\cr
#'  \link[paws.management:opsworks_create_instance]{create_instance} \tab Creates an instance in a specified stack\cr
#'  \link[paws.management:opsworks_create_layer]{create_layer} \tab Creates a layer\cr
#'  \link[paws.management:opsworks_create_stack]{create_stack} \tab Creates a new stack\cr
#'  \link[paws.management:opsworks_create_user_profile]{create_user_profile} \tab Creates a new user profile\cr
#'  \link[paws.management:opsworks_delete_app]{delete_app} \tab Deletes a specified app\cr
#'  \link[paws.management:opsworks_delete_instance]{delete_instance} \tab Deletes a specified instance, which terminates the associated Amazon EC2 instance\cr
#'  \link[paws.management:opsworks_delete_layer]{delete_layer} \tab Deletes a specified layer\cr
#'  \link[paws.management:opsworks_delete_stack]{delete_stack} \tab Deletes a specified stack\cr
#'  \link[paws.management:opsworks_delete_user_profile]{delete_user_profile} \tab Deletes a user profile\cr
#'  \link[paws.management:opsworks_deregister_ecs_cluster]{deregister_ecs_cluster} \tab Deregisters a specified Amazon ECS cluster from a stack\cr
#'  \link[paws.management:opsworks_deregister_elastic_ip]{deregister_elastic_ip} \tab Deregisters a specified Elastic IP address\cr
#'  \link[paws.management:opsworks_deregister_instance]{deregister_instance} \tab Deregister an instance from OpsWorks Stacks\cr
#'  \link[paws.management:opsworks_deregister_rds_db_instance]{deregister_rds_db_instance} \tab Deregisters an Amazon RDS instance\cr
#'  \link[paws.management:opsworks_deregister_volume]{deregister_volume} \tab Deregisters an Amazon EBS volume\cr
#'  \link[paws.management:opsworks_describe_agent_versions]{describe_agent_versions} \tab Describes the available OpsWorks Stacks agent versions\cr
#'  \link[paws.management:opsworks_describe_apps]{describe_apps} \tab Requests a description of a specified set of apps\cr
#'  \link[paws.management:opsworks_describe_commands]{describe_commands} \tab Describes the results of specified commands\cr
#'  \link[paws.management:opsworks_describe_deployments]{describe_deployments} \tab Requests a description of a specified set of deployments\cr
#'  \link[paws.management:opsworks_describe_ecs_clusters]{describe_ecs_clusters} \tab Describes Amazon ECS clusters that are registered with a stack\cr
#'  \link[paws.management:opsworks_describe_elastic_ips]{describe_elastic_ips} \tab Describes Elastic IP addresses\cr
#'  \link[paws.management:opsworks_describe_elastic_load_balancers]{describe_elastic_load_balancers} \tab Describes a stack's Elastic Load Balancing instances\cr
#'  \link[paws.management:opsworks_describe_instances]{describe_instances} \tab Requests a description of a set of instances\cr
#'  \link[paws.management:opsworks_describe_layers]{describe_layers} \tab Requests a description of one or more layers in a specified stack\cr
#'  \link[paws.management:opsworks_describe_load_based_auto_scaling]{describe_load_based_auto_scaling} \tab Describes load-based auto scaling configurations for specified layers\cr
#'  \link[paws.management:opsworks_describe_my_user_profile]{describe_my_user_profile} \tab Describes a user's SSH information\cr
#'  \link[paws.management:opsworks_describe_operating_systems]{describe_operating_systems} \tab Describes the operating systems that are supported by OpsWorks Stacks\cr
#'  \link[paws.management:opsworks_describe_permissions]{describe_permissions} \tab Describes the permissions for a specified stack\cr
#'  \link[paws.management:opsworks_describe_raid_arrays]{describe_raid_arrays} \tab Describe an instance's RAID arrays\cr
#'  \link[paws.management:opsworks_describe_rds_db_instances]{describe_rds_db_instances} \tab Describes Amazon RDS instances\cr
#'  \link[paws.management:opsworks_describe_service_errors]{describe_service_errors} \tab Describes OpsWorks Stacks service errors\cr
#'  \link[paws.management:opsworks_describe_stack_provisioning_parameters]{describe_stack_provisioning_parameters} \tab Requests a description of a stack's provisioning parameters\cr
#'  \link[paws.management:opsworks_describe_stacks]{describe_stacks} \tab Requests a description of one or more stacks\cr
#'  \link[paws.management:opsworks_describe_stack_summary]{describe_stack_summary} \tab Describes the number of layers and apps in a specified stack, and the number of instances in each state, such as running_setup or online\cr
#'  \link[paws.management:opsworks_describe_time_based_auto_scaling]{describe_time_based_auto_scaling} \tab Describes time-based auto scaling configurations for specified instances\cr
#'  \link[paws.management:opsworks_describe_user_profiles]{describe_user_profiles} \tab Describe specified users\cr
#'  \link[paws.management:opsworks_describe_volumes]{describe_volumes} \tab Describes an instance's Amazon EBS volumes\cr
#'  \link[paws.management:opsworks_detach_elastic_load_balancer]{detach_elastic_load_balancer} \tab Detaches a specified Elastic Load Balancing instance from its layer\cr
#'  \link[paws.management:opsworks_disassociate_elastic_ip]{disassociate_elastic_ip} \tab Disassociates an Elastic IP address from its instance\cr
#'  \link[paws.management:opsworks_get_hostname_suggestion]{get_hostname_suggestion} \tab Gets a generated host name for the specified layer, based on the current host name theme\cr
#'  \link[paws.management:opsworks_grant_access]{grant_access} \tab This action can be used only with Windows stacks\cr
#'  \link[paws.management:opsworks_list_tags]{list_tags} \tab Returns a list of tags that are applied to the specified stack or layer\cr
#'  \link[paws.management:opsworks_reboot_instance]{reboot_instance} \tab Reboots a specified instance\cr
#'  \link[paws.management:opsworks_register_ecs_cluster]{register_ecs_cluster} \tab Registers a specified Amazon ECS cluster with a stack\cr
#'  \link[paws.management:opsworks_register_elastic_ip]{register_elastic_ip} \tab Registers an Elastic IP address with a specified stack\cr
#'  \link[paws.management:opsworks_register_instance]{register_instance} \tab Registers instances that were created outside of OpsWorks Stacks with a specified stack\cr
#'  \link[paws.management:opsworks_register_rds_db_instance]{register_rds_db_instance} \tab Registers an Amazon RDS instance with a stack\cr
#'  \link[paws.management:opsworks_register_volume]{register_volume} \tab Registers an Amazon EBS volume with a specified stack\cr
#'  \link[paws.management:opsworks_set_load_based_auto_scaling]{set_load_based_auto_scaling} \tab Specify the load-based auto scaling configuration for a specified layer\cr
#'  \link[paws.management:opsworks_set_permission]{set_permission} \tab Specifies a user's permissions\cr
#'  \link[paws.management:opsworks_set_time_based_auto_scaling]{set_time_based_auto_scaling} \tab Specify the time-based auto scaling configuration for a specified instance\cr
#'  \link[paws.management:opsworks_start_instance]{start_instance} \tab Starts a specified instance\cr
#'  \link[paws.management:opsworks_start_stack]{start_stack} \tab Starts a stack's instances\cr
#'  \link[paws.management:opsworks_stop_instance]{stop_instance} \tab Stops a specified instance\cr
#'  \link[paws.management:opsworks_stop_stack]{stop_stack} \tab Stops a specified stack\cr
#'  \link[paws.management:opsworks_tag_resource]{tag_resource} \tab Apply cost-allocation tags to a specified stack or layer in OpsWorks Stacks\cr
#'  \link[paws.management:opsworks_unassign_instance]{unassign_instance} \tab Unassigns a registered instance from all layers that are using the instance\cr
#'  \link[paws.management:opsworks_unassign_volume]{unassign_volume} \tab Unassigns an assigned Amazon EBS volume\cr
#'  \link[paws.management:opsworks_untag_resource]{untag_resource} \tab Removes tags from a specified stack or layer\cr
#'  \link[paws.management:opsworks_update_app]{update_app} \tab Updates a specified app\cr
#'  \link[paws.management:opsworks_update_elastic_ip]{update_elastic_ip} \tab Updates a registered Elastic IP address's name\cr
#'  \link[paws.management:opsworks_update_instance]{update_instance} \tab Updates a specified instance\cr
#'  \link[paws.management:opsworks_update_layer]{update_layer} \tab Updates a specified layer\cr
#'  \link[paws.management:opsworks_update_my_user_profile]{update_my_user_profile} \tab Updates a user's SSH public key\cr
#'  \link[paws.management:opsworks_update_rds_db_instance]{update_rds_db_instance} \tab Updates an Amazon RDS instance\cr
#'  \link[paws.management:opsworks_update_stack]{update_stack} \tab Updates a specified stack\cr
#'  \link[paws.management:opsworks_update_user_profile]{update_user_profile} \tab Updates a specified user profile\cr
#'  \link[paws.management:opsworks_update_volume]{update_volume} \tab Updates an Amazon EBS volume's name or mount point
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname opsworks
#' @export
opsworks <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::opsworks(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS OpsWorks CM
#'
#' @description
#' AWS OpsWorks for configuration management (CM) is a service that runs
#' and manages configuration management servers. You can use AWS OpsWorks
#' CM to create and manage AWS OpsWorks for Chef Automate and AWS OpsWorks
#' for Puppet Enterprise servers, and add or remove nodes for the servers
#' to manage.
#' 
#' **Glossary of terms**
#' 
#' -   **Server**: A configuration management server that can be
#'     highly-available. The configuration management server runs on an
#'     Amazon Elastic Compute Cloud (EC2) instance, and may use various
#'     other AWS services, such as Amazon Relational Database Service (RDS)
#'     and Elastic Load Balancing. A server is a generic abstraction over
#'     the configuration manager that you want to use, much like Amazon
#'     RDS. In AWS OpsWorks CM, you do not start or stop servers. After you
#'     create servers, they continue to run until they are deleted.
#' 
#' -   **Engine**: The engine is the specific configuration manager that
#'     you want to use. Valid values in this release include `ChefAutomate`
#'     and `Puppet`.
#' 
#' -   **Backup**: This is an application-level backup of the data that the
#'     configuration manager stores. AWS OpsWorks CM creates an S3 bucket
#'     for backups when you launch the first server. A backup maintains a
#'     snapshot of a server's configuration-related attributes at the time
#'     the backup starts.
#' 
#' -   **Events**: Events are always related to a server. Events are
#'     written during server creation, when health checks run, when backups
#'     are created, when system maintenance is performed, etc. When you
#'     delete a server, the server's events are also deleted.
#' 
#' -   **Account attributes**: Every account has attributes that are
#'     assigned in the AWS OpsWorks CM database. These attributes store
#'     information about configuration limits (servers, backups, etc.) and
#'     your customer account.
#' 
#' **Endpoints**
#' 
#' AWS OpsWorks CM supports the following endpoints, all HTTPS. You must
#' connect to one of the following endpoints. Your servers can only be
#' accessed or managed within the endpoint in which they are created.
#' 
#' -   opsworks-cm.us-east-1.amazonaws.com
#' 
#' -   opsworks-cm.us-east-2.amazonaws.com
#' 
#' -   opsworks-cm.us-west-1.amazonaws.com
#' 
#' -   opsworks-cm.us-west-2.amazonaws.com
#' 
#' -   opsworks-cm.ap-northeast-1.amazonaws.com
#' 
#' -   opsworks-cm.ap-southeast-1.amazonaws.com
#' 
#' -   opsworks-cm.ap-southeast-2.amazonaws.com
#' 
#' -   opsworks-cm.eu-central-1.amazonaws.com
#' 
#' -   opsworks-cm.eu-west-1.amazonaws.com
#' 
#' For more information, see [AWS OpsWorks endpoints and
#' quotas](https://docs.aws.amazon.com/general/latest/gr/opsworks-service.html)
#' in the AWS General Reference.
#' 
#' **Throttling limits**
#' 
#' All API operations allow for five requests per second with a burst of 10
#' requests per second.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- opsworkscm(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- opsworkscm()
#' svc$associate_node(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:opsworkscm_associate_node]{associate_node} \tab Associates a new node with the server\cr
#'  \link[paws.management:opsworkscm_create_backup]{create_backup} \tab Creates an application-level backup of a server\cr
#'  \link[paws.management:opsworkscm_create_server]{create_server} \tab Creates and immedately starts a new server\cr
#'  \link[paws.management:opsworkscm_delete_backup]{delete_backup} \tab Deletes a backup\cr
#'  \link[paws.management:opsworkscm_delete_server]{delete_server} \tab Deletes the server and the underlying AWS CloudFormation stacks (including the server's EC2 instance)\cr
#'  \link[paws.management:opsworkscm_describe_account_attributes]{describe_account_attributes} \tab Describes your OpsWorks-CM account attributes\cr
#'  \link[paws.management:opsworkscm_describe_backups]{describe_backups} \tab Describes backups\cr
#'  \link[paws.management:opsworkscm_describe_events]{describe_events} \tab Describes events for a specified server\cr
#'  \link[paws.management:opsworkscm_describe_node_association_status]{describe_node_association_status} \tab Returns the current status of an existing association or disassociation request\cr
#'  \link[paws.management:opsworkscm_describe_servers]{describe_servers} \tab Lists all configuration management servers that are identified with your account\cr
#'  \link[paws.management:opsworkscm_disassociate_node]{disassociate_node} \tab Disassociates a node from an AWS OpsWorks CM server, and removes the node from the server's managed nodes\cr
#'  \link[paws.management:opsworkscm_export_server_engine_attribute]{export_server_engine_attribute} \tab Exports a specified server engine attribute as a base64-encoded string\cr
#'  \link[paws.management:opsworkscm_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags that are applied to the specified AWS OpsWorks for Chef Automate or AWS OpsWorks for Puppet Enterprise servers or backups\cr
#'  \link[paws.management:opsworkscm_restore_server]{restore_server} \tab Restores a backup to a server that is in a CONNECTION_LOST, HEALTHY, RUNNING, UNHEALTHY, or TERMINATED state\cr
#'  \link[paws.management:opsworkscm_start_maintenance]{start_maintenance} \tab Manually starts server maintenance\cr
#'  \link[paws.management:opsworkscm_tag_resource]{tag_resource} \tab Applies tags to an AWS OpsWorks for Chef Automate or AWS OpsWorks for Puppet Enterprise server, or to server backups\cr
#'  \link[paws.management:opsworkscm_untag_resource]{untag_resource} \tab Removes specified tags from an AWS OpsWorks-CM server or backup\cr
#'  \link[paws.management:opsworkscm_update_server]{update_server} \tab Updates settings for a server\cr
#'  \link[paws.management:opsworkscm_update_server_engine_attributes]{update_server_engine_attributes} \tab Updates engine-specific attributes on a specified server
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname opsworkscm
#' @export
opsworkscm <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::opsworkscm(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Organizations
#'
#' @description
#' Organizations is a web service that enables you to consolidate your
#' multiple Amazon Web Services accounts into an *organization* and
#' centrally manage your accounts and their resources.
#' 
#' This guide provides descriptions of the Organizations operations. For
#' more information about using this service, see the [Organizations User
#' Guide](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_introduction.html).
#' 
#' **Support and feedback for Organizations**
#' 
#' We welcome your feedback. Send your comments to
#' <feedback-awsorganizations@@amazon.com> or post your feedback and
#' questions in the Organizations support forum. For more information about
#' the Amazon Web Services support forums, see Forums Help.
#' 
#' **Endpoint to call When using the CLI or the Amazon Web Services SDK**
#' 
#' For the current release of Organizations, specify the `us-east-1` region
#' for all Amazon Web Services API and CLI calls made from the commercial
#' Amazon Web Services Regions outside of China. If calling from one of the
#' Amazon Web Services Regions in China, then specify `cn-northwest-1`. You
#' can do this in the CLI by using these parameters and commands:
#' 
#' -   Use the following parameter with each command to specify both the
#'     endpoint and its region:
#' 
#'     `--endpoint-url https://organizations.us-east-1.amazonaws.com`
#'     *(from commercial Amazon Web Services Regions outside of China)*
#' 
#'     or
#' 
#'     `--endpoint-url https://organizations.cn-northwest-1.amazonaws.com.cn`
#'     *(from Amazon Web Services Regions in China)*
#' 
#' -   Use the default endpoint, but configure your default region with
#'     this command:
#' 
#'     `aws configure set default.region us-east-1` *(from commercial
#'     Amazon Web Services Regions outside of China)*
#' 
#'     or
#' 
#'     `aws configure set default.region cn-northwest-1` *(from Amazon Web
#'     Services Regions in China)*
#' 
#' -   Use the following parameter with each command to specify the
#'     endpoint:
#' 
#'     `--region us-east-1` *(from commercial Amazon Web Services Regions
#'     outside of China)*
#' 
#'     or
#' 
#'     `--region cn-northwest-1` *(from Amazon Web Services Regions in
#'     China)*
#' 
#' **Recording API Requests**
#' 
#' Organizations supports CloudTrail, a service that records Amazon Web
#' Services API calls for your Amazon Web Services account and delivers log
#' files to an Amazon S3 bucket. By using information collected by
#' CloudTrail, you can determine which requests the Organizations service
#' received, who made the request and when, and so on. For more about
#' Organizations and its support for CloudTrail, see [Logging Organizations
#' API calls with
#' CloudTrail](https://docs.aws.amazon.com/organizations/latest/userguide/#orgs_cloudtrail-integration)
#' in the *Organizations User Guide*. To learn more about CloudTrail,
#' including how to turn it on and find your log files, see the [CloudTrail
#' User
#' Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-user-guide.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- organizations(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- organizations()
#' # Bill is the owner of an organization, and he invites Juan's account
#' # (222222222222) to join his organization. The following example shows
#' # Juan's account accepting the handshake and thus agreeing to the
#' # invitation.
#' svc$accept_handshake(
#'   HandshakeId = "h-examplehandshakeid111"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:organizations_accept_handshake]{accept_handshake} \tab Sends a response to the originator of a handshake agreeing to the action proposed by the handshake request\cr
#'  \link[paws.management:organizations_attach_policy]{attach_policy} \tab Attaches a policy to a root, an organizational unit (OU), or an individual account\cr
#'  \link[paws.management:organizations_cancel_handshake]{cancel_handshake} \tab Cancels a handshake\cr
#'  \link[paws.management:organizations_close_account]{close_account} \tab Closes an Amazon Web Services member account within an organization\cr
#'  \link[paws.management:organizations_create_account]{create_account} \tab Creates an Amazon Web Services account that is automatically a member of the organization whose credentials made the request\cr
#'  \link[paws.management:organizations_create_gov_cloud_account]{create_gov_cloud_account} \tab This action is available if all of the following are true:\cr
#'  \link[paws.management:organizations_create_organization]{create_organization} \tab Creates an Amazon Web Services organization\cr
#'  \link[paws.management:organizations_create_organizational_unit]{create_organizational_unit} \tab Creates an organizational unit (OU) within a root or parent OU\cr
#'  \link[paws.management:organizations_create_policy]{create_policy} \tab Creates a policy of a specified type that you can attach to a root, an organizational unit (OU), or an individual Amazon Web Services account\cr
#'  \link[paws.management:organizations_decline_handshake]{decline_handshake} \tab Declines a handshake request\cr
#'  \link[paws.management:organizations_delete_organization]{delete_organization} \tab Deletes the organization\cr
#'  \link[paws.management:organizations_delete_organizational_unit]{delete_organizational_unit} \tab Deletes an organizational unit (OU) from a root or another OU\cr
#'  \link[paws.management:organizations_delete_policy]{delete_policy} \tab Deletes the specified policy from your organization\cr
#'  \link[paws.management:organizations_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource policy from your organization\cr
#'  \link[paws.management:organizations_deregister_delegated_administrator]{deregister_delegated_administrator} \tab Removes the specified member Amazon Web Services account as a delegated administrator for the specified Amazon Web Services service\cr
#'  \link[paws.management:organizations_describe_account]{describe_account} \tab Retrieves Organizations-related information about the specified account\cr
#'  \link[paws.management:organizations_describe_create_account_status]{describe_create_account_status} \tab Retrieves the current status of an asynchronous request to create an account\cr
#'  \link[paws.management:organizations_describe_effective_policy]{describe_effective_policy} \tab Returns the contents of the effective policy for specified policy type and account\cr
#'  \link[paws.management:organizations_describe_handshake]{describe_handshake} \tab Retrieves information about a previously requested handshake\cr
#'  \link[paws.management:organizations_describe_organization]{describe_organization} \tab Retrieves information about the organization that the user's account belongs to\cr
#'  \link[paws.management:organizations_describe_organizational_unit]{describe_organizational_unit} \tab Retrieves information about an organizational unit (OU)\cr
#'  \link[paws.management:organizations_describe_policy]{describe_policy} \tab Retrieves information about a policy\cr
#'  \link[paws.management:organizations_describe_resource_policy]{describe_resource_policy} \tab Retrieves information about a resource policy\cr
#'  \link[paws.management:organizations_detach_policy]{detach_policy} \tab Detaches a policy from a target root, organizational unit (OU), or account\cr
#'  \link[paws.management:organizations_disable_aws_service_access]{disable_aws_service_access} \tab Disables the integration of an Amazon Web Services service (the service that is specified by ServicePrincipal) with Organizations\cr
#'  \link[paws.management:organizations_disable_policy_type]{disable_policy_type} \tab Disables an organizational policy type in a root\cr
#'  \link[paws.management:organizations_enable_all_features]{enable_all_features} \tab Enables all features in an organization\cr
#'  \link[paws.management:organizations_enable_aws_service_access]{enable_aws_service_access} \tab Provides an Amazon Web Services service (the service that is specified by ServicePrincipal) with permissions to view the structure of an organization, create a service-linked role in all the accounts in the organization, and allow the service to perform operations on behalf of the organization and its accounts\cr
#'  \link[paws.management:organizations_enable_policy_type]{enable_policy_type} \tab Enables a policy type in a root\cr
#'  \link[paws.management:organizations_invite_account_to_organization]{invite_account_to_organization} \tab Sends an invitation to another account to join your organization as a member account\cr
#'  \link[paws.management:organizations_leave_organization]{leave_organization} \tab Removes a member account from its parent organization\cr
#'  \link[paws.management:organizations_list_accounts]{list_accounts} \tab Lists all the accounts in the organization\cr
#'  \link[paws.management:organizations_list_accounts_for_parent]{list_accounts_for_parent} \tab Lists the accounts in an organization that are contained by the specified target root or organizational unit (OU)\cr
#'  \link[paws.management:organizations_list_aws_service_access_for_organization]{list_aws_service_access_for_organization} \tab Returns a list of the Amazon Web Services services that you enabled to integrate with your organization\cr
#'  \link[paws.management:organizations_list_children]{list_children} \tab Lists all of the organizational units (OUs) or accounts that are contained in the specified parent OU or root\cr
#'  \link[paws.management:organizations_list_create_account_status]{list_create_account_status} \tab Lists the account creation requests that match the specified status that is currently being tracked for the organization\cr
#'  \link[paws.management:organizations_list_delegated_administrators]{list_delegated_administrators} \tab Lists the Amazon Web Services accounts that are designated as delegated administrators in this organization\cr
#'  \link[paws.management:organizations_list_delegated_services_for_account]{list_delegated_services_for_account} \tab List the Amazon Web Services services for which the specified account is a delegated administrator\cr
#'  \link[paws.management:organizations_list_handshakes_for_account]{list_handshakes_for_account} \tab Lists the current handshakes that are associated with the account of the requesting user\cr
#'  \link[paws.management:organizations_list_handshakes_for_organization]{list_handshakes_for_organization} \tab Lists the handshakes that are associated with the organization that the requesting user is part of\cr
#'  \link[paws.management:organizations_list_organizational_units_for_parent]{list_organizational_units_for_parent} \tab Lists the organizational units (OUs) in a parent organizational unit or root\cr
#'  \link[paws.management:organizations_list_parents]{list_parents} \tab Lists the root or organizational units (OUs) that serve as the immediate parent of the specified child OU or account\cr
#'  \link[paws.management:organizations_list_policies]{list_policies} \tab Retrieves the list of all policies in an organization of a specified type\cr
#'  \link[paws.management:organizations_list_policies_for_target]{list_policies_for_target} \tab Lists the policies that are directly attached to the specified target root, organizational unit (OU), or account\cr
#'  \link[paws.management:organizations_list_roots]{list_roots} \tab Lists the roots that are defined in the current organization\cr
#'  \link[paws.management:organizations_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags that are attached to the specified resource\cr
#'  \link[paws.management:organizations_list_targets_for_policy]{list_targets_for_policy} \tab Lists all the roots, organizational units (OUs), and accounts that the specified policy is attached to\cr
#'  \link[paws.management:organizations_move_account]{move_account} \tab Moves an account from its current source parent root or organizational unit (OU) to the specified destination parent root or OU\cr
#'  \link[paws.management:organizations_put_resource_policy]{put_resource_policy} \tab Creates or updates a resource policy\cr
#'  \link[paws.management:organizations_register_delegated_administrator]{register_delegated_administrator} \tab Enables the specified member account to administer the Organizations features of the specified Amazon Web Services service\cr
#'  \link[paws.management:organizations_remove_account_from_organization]{remove_account_from_organization} \tab Removes the specified account from the organization\cr
#'  \link[paws.management:organizations_tag_resource]{tag_resource} \tab Adds one or more tags to the specified resource\cr
#'  \link[paws.management:organizations_untag_resource]{untag_resource} \tab Removes any tags with the specified keys from the specified resource\cr
#'  \link[paws.management:organizations_update_organizational_unit]{update_organizational_unit} \tab Renames the specified organizational unit (OU)\cr
#'  \link[paws.management:organizations_update_policy]{update_policy} \tab Updates an existing policy with a new name, description, or content
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname organizations
#' @export
organizations <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::organizations(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Performance Insights
#'
#' @description
#' Amazon RDS Performance Insights
#' 
#' Amazon RDS Performance Insights enables you to monitor and explore
#' different dimensions of database load based on data captured from a
#' running DB instance. The guide provides detailed information about
#' Performance Insights data types, parameters and errors.
#' 
#' When Performance Insights is enabled, the Amazon RDS Performance
#' Insights API provides visibility into the performance of your DB
#' instance. Amazon CloudWatch provides the authoritative source for Amazon
#' Web Services service-vended monitoring metrics. Performance Insights
#' offers a domain-specific view of DB load.
#' 
#' DB load is measured as average active sessions. Performance Insights
#' provides the data to API consumers as a two-dimensional time-series
#' dataset. The time dimension provides DB load data for each time point in
#' the queried time range. Each time point decomposes overall load in
#' relation to the requested dimensions, measured at that time point.
#' Examples include SQL, Wait event, User, and Host.
#' 
#' -   To learn more about Performance Insights and Amazon Aurora DB
#'     instances, go to the *\href{https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_PerfInsights.html}{ Amazon Aurora User Guide}* .
#' 
#' -   To learn more about Performance Insights and Amazon RDS DB
#'     instances, go to the *\href{https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_PerfInsights.html}{ Amazon RDS User Guide}* .
#' 
#' -   To learn more about Performance Insights and Amazon DocumentDB
#'     clusters, go to the *\href{https://docs.aws.amazon.com/documentdb/latest/developerguide/performance-insights.html}{ Amazon DocumentDB Developer Guide}* .
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- pi(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- pi()
#' svc$create_performance_analysis_report(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:pi_create_performance_analysis_report]{create_performance_analysis_report} \tab Creates a new performance analysis report for a specific time period for the DB instance\cr
#'  \link[paws.management:pi_delete_performance_analysis_report]{delete_performance_analysis_report} \tab Deletes a performance analysis report\cr
#'  \link[paws.management:pi_describe_dimension_keys]{describe_dimension_keys} \tab For a specific time period, retrieve the top N dimension keys for a metric\cr
#'  \link[paws.management:pi_get_dimension_key_details]{get_dimension_key_details} \tab Get the attributes of the specified dimension group for a DB instance or data source\cr
#'  \link[paws.management:pi_get_performance_analysis_report]{get_performance_analysis_report} \tab Retrieves the report including the report ID, status, time details, and the insights with recommendations\cr
#'  \link[paws.management:pi_get_resource_metadata]{get_resource_metadata} \tab Retrieve the metadata for different features\cr
#'  \link[paws.management:pi_get_resource_metrics]{get_resource_metrics} \tab Retrieve Performance Insights metrics for a set of data sources over a time period\cr
#'  \link[paws.management:pi_list_available_resource_dimensions]{list_available_resource_dimensions} \tab Retrieve the dimensions that can be queried for each specified metric type on a specified DB instance\cr
#'  \link[paws.management:pi_list_available_resource_metrics]{list_available_resource_metrics} \tab Retrieve metrics of the specified types that can be queried for a specified DB instance\cr
#'  \link[paws.management:pi_list_performance_analysis_reports]{list_performance_analysis_reports} \tab Lists all the analysis reports created for the DB instance\cr
#'  \link[paws.management:pi_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves all the metadata tags associated with Amazon RDS Performance Insights resource\cr
#'  \link[paws.management:pi_tag_resource]{tag_resource} \tab Adds metadata tags to the Amazon RDS Performance Insights resource\cr
#'  \link[paws.management:pi_untag_resource]{untag_resource} \tab Deletes the metadata tags from the Amazon RDS Performance Insights resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname pi
#' @export
pi <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::pi(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Resilience Hub
#'
#' @description
#' Resilience Hub helps you proactively prepare and protect your Amazon Web
#' Services applications from disruptions. It offers continual resiliency
#' assessment and validation that integrates into your software development
#' lifecycle. This enables you to uncover resiliency weaknesses, ensure
#' recovery time objective (RTO) and recovery point objective (RPO) targets
#' for your applications are met, and resolve issues before they are
#' released into production.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- resiliencehub(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- resiliencehub()
#' svc$accept_resource_grouping_recommendations(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:resiliencehub_accept_resource_grouping_recommendations]{accept_resource_grouping_recommendations} \tab Accepts the resource grouping recommendations suggested by Resilience Hub for your application\cr
#'  \link[paws.management:resiliencehub_add_draft_app_version_resource_mappings]{add_draft_app_version_resource_mappings} \tab Adds the source of resource-maps to the draft version of an application\cr
#'  \link[paws.management:resiliencehub_batch_update_recommendation_status]{batch_update_recommendation_status} \tab Enables you to include or exclude one or more operational recommendations\cr
#'  \link[paws.management:resiliencehub_create_app]{create_app} \tab Creates an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_create_app_version_app_component]{create_app_version_app_component} \tab Creates a new Application Component in the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_create_app_version_resource]{create_app_version_resource} \tab Adds a resource to the Resilience Hub application and assigns it to the specified Application Components\cr
#'  \link[paws.management:resiliencehub_create_recommendation_template]{create_recommendation_template} \tab Creates a new recommendation template for the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_create_resiliency_policy]{create_resiliency_policy} \tab Creates a resiliency policy for an application\cr
#'  \link[paws.management:resiliencehub_delete_app]{delete_app} \tab Deletes an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_delete_app_assessment]{delete_app_assessment} \tab Deletes an Resilience Hub application assessment\cr
#'  \link[paws.management:resiliencehub_delete_app_input_source]{delete_app_input_source} \tab Deletes the input source and all of its imported resources from the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_delete_app_version_app_component]{delete_app_version_app_component} \tab Deletes an Application Component from the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_delete_app_version_resource]{delete_app_version_resource} \tab Deletes a resource from the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_delete_recommendation_template]{delete_recommendation_template} \tab Deletes a recommendation template\cr
#'  \link[paws.management:resiliencehub_delete_resiliency_policy]{delete_resiliency_policy} \tab Deletes a resiliency policy\cr
#'  \link[paws.management:resiliencehub_describe_app]{describe_app} \tab Describes an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_describe_app_assessment]{describe_app_assessment} \tab Describes an assessment for an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_describe_app_version]{describe_app_version} \tab Describes the Resilience Hub application version\cr
#'  \link[paws.management:resiliencehub_describe_app_version_app_component]{describe_app_version_app_component} \tab Describes an Application Component in the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_describe_app_version_resource]{describe_app_version_resource} \tab Describes a resource of the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_describe_app_version_resources_resolution_status]{describe_app_version_resources_resolution_status} \tab Returns the resolution status for the specified resolution identifier for an application version\cr
#'  \link[paws.management:resiliencehub_describe_app_version_template]{describe_app_version_template} \tab Describes details about an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_describe_draft_app_version_resources_import_status]{describe_draft_app_version_resources_import_status} \tab Describes the status of importing resources to an application version\cr
#'  \link[paws.management:resiliencehub_describe_metrics_export]{describe_metrics_export} \tab Describes the metrics of the application configuration being exported\cr
#'  \link[paws.management:resiliencehub_describe_resiliency_policy]{describe_resiliency_policy} \tab Describes a specified resiliency policy for an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_describe_resource_grouping_recommendation_task]{describe_resource_grouping_recommendation_task} \tab Describes the resource grouping recommendation tasks run by Resilience Hub for your application\cr
#'  \link[paws.management:resiliencehub_import_resources_to_draft_app_version]{import_resources_to_draft_app_version} \tab Imports resources to Resilience Hub application draft version from different input sources\cr
#'  \link[paws.management:resiliencehub_list_alarm_recommendations]{list_alarm_recommendations} \tab Lists the alarm recommendations for an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_list_app_assessment_compliance_drifts]{list_app_assessment_compliance_drifts} \tab List of compliance drifts that were detected while running an assessment\cr
#'  \link[paws.management:resiliencehub_list_app_assessment_resource_drifts]{list_app_assessment_resource_drifts} \tab List of resource drifts that were detected while running an assessment\cr
#'  \link[paws.management:resiliencehub_list_app_assessments]{list_app_assessments} \tab Lists the assessments for an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_list_app_component_compliances]{list_app_component_compliances} \tab Lists the compliances for an Resilience Hub Application Component\cr
#'  \link[paws.management:resiliencehub_list_app_component_recommendations]{list_app_component_recommendations} \tab Lists the recommendations for an Resilience Hub Application Component\cr
#'  \link[paws.management:resiliencehub_list_app_input_sources]{list_app_input_sources} \tab Lists all the input sources of the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_list_apps]{list_apps} \tab Lists your Resilience Hub applications\cr
#'  \link[paws.management:resiliencehub_list_app_version_app_components]{list_app_version_app_components} \tab Lists all the Application Components in the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_list_app_version_resource_mappings]{list_app_version_resource_mappings} \tab Lists how the resources in an application version are mapped/sourced from\cr
#'  \link[paws.management:resiliencehub_list_app_version_resources]{list_app_version_resources} \tab Lists all the resources in an Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_list_app_versions]{list_app_versions} \tab Lists the different versions for the Resilience Hub applications\cr
#'  \link[paws.management:resiliencehub_list_metrics]{list_metrics} \tab Lists the metrics that can be exported\cr
#'  \link[paws.management:resiliencehub_list_recommendation_templates]{list_recommendation_templates} \tab Lists the recommendation templates for the Resilience Hub applications\cr
#'  \link[paws.management:resiliencehub_list_resiliency_policies]{list_resiliency_policies} \tab Lists the resiliency policies for the Resilience Hub applications\cr
#'  \link[paws.management:resiliencehub_list_resource_grouping_recommendations]{list_resource_grouping_recommendations} \tab Lists the resource grouping recommendations suggested by Resilience Hub for your application\cr
#'  \link[paws.management:resiliencehub_list_sop_recommendations]{list_sop_recommendations} \tab Lists the standard operating procedure (SOP) recommendations for the Resilience Hub applications\cr
#'  \link[paws.management:resiliencehub_list_suggested_resiliency_policies]{list_suggested_resiliency_policies} \tab Lists the suggested resiliency policies for the Resilience Hub applications\cr
#'  \link[paws.management:resiliencehub_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for your resources in your Resilience Hub applications\cr
#'  \link[paws.management:resiliencehub_list_test_recommendations]{list_test_recommendations} \tab Lists the test recommendations for the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_list_unsupported_app_version_resources]{list_unsupported_app_version_resources} \tab Lists the resources that are not currently supported in Resilience Hub\cr
#'  \link[paws.management:resiliencehub_publish_app_version]{publish_app_version} \tab Publishes a new version of a specific Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_put_draft_app_version_template]{put_draft_app_version_template} \tab Adds or updates the app template for an Resilience Hub application draft version\cr
#'  \link[paws.management:resiliencehub_reject_resource_grouping_recommendations]{reject_resource_grouping_recommendations} \tab Rejects resource grouping recommendations\cr
#'  \link[paws.management:resiliencehub_remove_draft_app_version_resource_mappings]{remove_draft_app_version_resource_mappings} \tab Removes resource mappings from a draft application version\cr
#'  \link[paws.management:resiliencehub_resolve_app_version_resources]{resolve_app_version_resources} \tab Resolves the resources for an application version\cr
#'  \link[paws.management:resiliencehub_start_app_assessment]{start_app_assessment} \tab Creates a new application assessment for an application\cr
#'  \link[paws.management:resiliencehub_start_metrics_export]{start_metrics_export} \tab Initiates the export task of metrics\cr
#'  \link[paws.management:resiliencehub_start_resource_grouping_recommendation_task]{start_resource_grouping_recommendation_task} \tab Starts grouping recommendation task\cr
#'  \link[paws.management:resiliencehub_tag_resource]{tag_resource} \tab Applies one or more tags to a resource\cr
#'  \link[paws.management:resiliencehub_untag_resource]{untag_resource} \tab Removes one or more tags from a resource\cr
#'  \link[paws.management:resiliencehub_update_app]{update_app} \tab Updates an application\cr
#'  \link[paws.management:resiliencehub_update_app_version]{update_app_version} \tab Updates the Resilience Hub application version\cr
#'  \link[paws.management:resiliencehub_update_app_version_app_component]{update_app_version_app_component} \tab Updates an existing Application Component in the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_update_app_version_resource]{update_app_version_resource} \tab Updates the resource details in the Resilience Hub application\cr
#'  \link[paws.management:resiliencehub_update_resiliency_policy]{update_resiliency_policy} \tab Updates a resiliency policy
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname resiliencehub
#' @export
resiliencehub <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::resiliencehub(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Resource Groups
#'
#' @description
#' Resource Groups lets you organize Amazon Web Services resources such as
#' Amazon Elastic Compute Cloud instances, Amazon Relational Database
#' Service databases, and Amazon Simple Storage Service buckets into groups
#' using criteria that you define as tags. A resource group is a collection
#' of resources that match the resource types specified in a query, and
#' share one or more tags or portions of tags. You can create a group of
#' resources based on their roles in your cloud infrastructure, lifecycle
#' stages, regions, application layers, or virtually any criteria. Resource
#' Groups enable you to automate management tasks, such as those in Amazon
#' Web Services Systems Manager Automation documents, on tag-related
#' resources in Amazon Web Services Systems Manager. Groups of tagged
#' resources also let you quickly view a custom console in Amazon Web
#' Services Systems Manager that shows Config compliance and other
#' monitoring data about member resources.
#' 
#' To create a resource group, build a resource query, and specify tags
#' that identify the criteria that members of the group have in common.
#' Tags are key-value pairs.
#' 
#' For more information about Resource Groups, see the [Resource Groups
#' User Guide](https://docs.aws.amazon.com/ARG/latest/userguide/).
#' 
#' Resource Groups uses a REST-compliant API that you can use to perform
#' the following types of operations.
#' 
#' -   Create, Read, Update, and Delete (CRUD) operations on resource
#'     groups and resource query entities
#' 
#' -   Applying, editing, and removing tags from resource groups
#' 
#' -   Resolving resource group member Amazon resource names (ARN)s so they
#'     can be returned as search results
#' 
#' -   Getting data about resources that are members of a group
#' 
#' -   Searching Amazon Web Services resources based on a resource query
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- resourcegroups(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- resourcegroups()
#' svc$cancel_tag_sync_task(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:resourcegroups_cancel_tag_sync_task]{cancel_tag_sync_task} \tab Cancels the specified tag-sync task\cr
#'  \link[paws.management:resourcegroups_create_group]{create_group} \tab Creates a resource group with the specified name and description\cr
#'  \link[paws.management:resourcegroups_delete_group]{delete_group} \tab Deletes the specified resource group\cr
#'  \link[paws.management:resourcegroups_get_account_settings]{get_account_settings} \tab Retrieves the current status of optional features in Resource Groups\cr
#'  \link[paws.management:resourcegroups_get_group]{get_group} \tab Returns information about a specified resource group\cr
#'  \link[paws.management:resourcegroups_get_group_configuration]{get_group_configuration} \tab Retrieves the service configuration associated with the specified resource group\cr
#'  \link[paws.management:resourcegroups_get_group_query]{get_group_query} \tab Retrieves the resource query associated with the specified resource group\cr
#'  \link[paws.management:resourcegroups_get_tags]{get_tags} \tab Returns a list of tags that are associated with a resource group, specified by an Amazon resource name (ARN)\cr
#'  \link[paws.management:resourcegroups_get_tag_sync_task]{get_tag_sync_task} \tab Returns information about a specified tag-sync task\cr
#'  \link[paws.management:resourcegroups_group_resources]{group_resources} \tab Adds the specified resources to the specified group\cr
#'  \link[paws.management:resourcegroups_list_grouping_statuses]{list_grouping_statuses} \tab Returns the status of the last grouping or ungrouping action for each resource in the specified application group\cr
#'  \link[paws.management:resourcegroups_list_group_resources]{list_group_resources} \tab Returns a list of Amazon resource names (ARNs) of the resources that are members of a specified resource group\cr
#'  \link[paws.management:resourcegroups_list_groups]{list_groups} \tab Returns a list of existing Resource Groups in your account\cr
#'  \link[paws.management:resourcegroups_list_tag_sync_tasks]{list_tag_sync_tasks} \tab Returns a list of tag-sync tasks\cr
#'  \link[paws.management:resourcegroups_put_group_configuration]{put_group_configuration} \tab Attaches a service configuration to the specified group\cr
#'  \link[paws.management:resourcegroups_search_resources]{search_resources} \tab Returns a list of Amazon Web Services resource identifiers that matches the specified query\cr
#'  \link[paws.management:resourcegroups_start_tag_sync_task]{start_tag_sync_task} \tab Creates a new tag-sync task to onboard and sync resources tagged with a specific tag key-value pair to an application\cr
#'  \link[paws.management:resourcegroups_tag]{tag} \tab Adds tags to a resource group with the specified Amazon resource name (ARN)\cr
#'  \link[paws.management:resourcegroups_ungroup_resources]{ungroup_resources} \tab Removes the specified resources from the specified group\cr
#'  \link[paws.management:resourcegroups_untag]{untag} \tab Deletes tags from a specified resource group\cr
#'  \link[paws.management:resourcegroups_update_account_settings]{update_account_settings} \tab Turns on or turns off optional features in Resource Groups\cr
#'  \link[paws.management:resourcegroups_update_group]{update_group} \tab Updates the description for an existing group\cr
#'  \link[paws.management:resourcegroups_update_group_query]{update_group_query} \tab Updates the resource query of a group
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname resourcegroups
#' @export
resourcegroups <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::resourcegroups(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Resource Groups Tagging API
#'
#' @description
#' Resource Groups Tagging API
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- resourcegroupstaggingapi(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- resourcegroupstaggingapi()
#' svc$describe_report_creation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:resourcegroupstaggingapi_describe_report_creation]{describe_report_creation} \tab Describes the status of the StartReportCreation operation\cr
#'  \link[paws.management:resourcegroupstaggingapi_get_compliance_summary]{get_compliance_summary} \tab Returns a table that shows counts of resources that are noncompliant with their tag policies\cr
#'  \link[paws.management:resourcegroupstaggingapi_get_resources]{get_resources} \tab Returns all the tagged or previously tagged resources that are located in the specified Amazon Web Services Region for the account\cr
#'  \link[paws.management:resourcegroupstaggingapi_get_tag_keys]{get_tag_keys} \tab Returns all tag keys currently in use in the specified Amazon Web Services Region for the calling account\cr
#'  \link[paws.management:resourcegroupstaggingapi_get_tag_values]{get_tag_values} \tab Returns all tag values for the specified key that are used in the specified Amazon Web Services Region for the calling account\cr
#'  \link[paws.management:resourcegroupstaggingapi_start_report_creation]{start_report_creation} \tab Generates a report that lists all tagged resources in the accounts across your organization and tells whether each resource is compliant with the effective tag policy\cr
#'  \link[paws.management:resourcegroupstaggingapi_tag_resources]{tag_resources} \tab Applies one or more tags to the specified resources\cr
#'  \link[paws.management:resourcegroupstaggingapi_untag_resources]{untag_resources} \tab Removes the specified tags from the specified resources
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname resourcegroupstaggingapi
#' @export
resourcegroupstaggingapi <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::resourcegroupstaggingapi(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' CloudWatch RUM
#'
#' @description
#' With Amazon CloudWatch RUM, you can perform real-user monitoring to
#' collect client-side data about your web application performance from
#' actual user sessions in real time. The data collected includes page load
#' times, client-side errors, and user behavior. When you view this data,
#' you can see it all aggregated together and also see breakdowns by the
#' browsers and devices that your customers use.
#' 
#' You can use the collected data to quickly identify and debug client-side
#' performance issues. CloudWatch RUM helps you visualize anomalies in your
#' application performance and find relevant debugging data such as error
#' messages, stack traces, and user sessions. You can also use RUM to
#' understand the range of end-user impact including the number of users,
#' geolocations, and browsers used.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudwatchrum(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudwatchrum()
#' svc$batch_create_rum_metric_definitions(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:cloudwatchrum_batch_create_rum_metric_definitions]{batch_create_rum_metric_definitions} \tab Specifies the extended metrics and custom metrics that you want a CloudWatch RUM app monitor to send to a destination\cr
#'  \link[paws.management:cloudwatchrum_batch_delete_rum_metric_definitions]{batch_delete_rum_metric_definitions} \tab Removes the specified metrics from being sent to an extended metrics destination\cr
#'  \link[paws.management:cloudwatchrum_batch_get_rum_metric_definitions]{batch_get_rum_metric_definitions} \tab Retrieves the list of metrics and dimensions that a RUM app monitor is sending to a single destination\cr
#'  \link[paws.management:cloudwatchrum_create_app_monitor]{create_app_monitor} \tab Creates a Amazon CloudWatch RUM app monitor, which collects telemetry data from your application and sends that data to RUM\cr
#'  \link[paws.management:cloudwatchrum_delete_app_monitor]{delete_app_monitor} \tab Deletes an existing app monitor\cr
#'  \link[paws.management:cloudwatchrum_delete_rum_metrics_destination]{delete_rum_metrics_destination} \tab Deletes a destination for CloudWatch RUM extended metrics, so that the specified app monitor stops sending extended metrics to that destination\cr
#'  \link[paws.management:cloudwatchrum_get_app_monitor]{get_app_monitor} \tab Retrieves the complete configuration information for one app monitor\cr
#'  \link[paws.management:cloudwatchrum_get_app_monitor_data]{get_app_monitor_data} \tab Retrieves the raw performance events that RUM has collected from your web application, so that you can do your own processing or analysis of this data\cr
#'  \link[paws.management:cloudwatchrum_list_app_monitors]{list_app_monitors} \tab Returns a list of the Amazon CloudWatch RUM app monitors in the account\cr
#'  \link[paws.management:cloudwatchrum_list_rum_metrics_destinations]{list_rum_metrics_destinations} \tab Returns a list of destinations that you have created to receive RUM extended metrics, for the specified app monitor\cr
#'  \link[paws.management:cloudwatchrum_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with a CloudWatch RUM resource\cr
#'  \link[paws.management:cloudwatchrum_put_rum_events]{put_rum_events} \tab Sends telemetry events about your application performance and user behavior to CloudWatch RUM\cr
#'  \link[paws.management:cloudwatchrum_put_rum_metrics_destination]{put_rum_metrics_destination} \tab Creates or updates a destination to receive extended metrics from CloudWatch RUM\cr
#'  \link[paws.management:cloudwatchrum_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified CloudWatch RUM resource\cr
#'  \link[paws.management:cloudwatchrum_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.management:cloudwatchrum_update_app_monitor]{update_app_monitor} \tab Updates the configuration of an existing app monitor\cr
#'  \link[paws.management:cloudwatchrum_update_rum_metric_definition]{update_rum_metric_definition} \tab Modifies one existing metric definition for CloudWatch RUM extended metrics
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudwatchrum
#' @export
cloudwatchrum <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::cloudwatchrum(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Service Quotas
#'
#' @description
#' With Service Quotas, you can view and manage your quotas easily as your
#' Amazon Web Services workloads grow. Quotas, also referred to as limits,
#' are the maximum number of resources that you can create in your Amazon
#' Web Services account. For more information, see the [Service Quotas User
#' Guide](https://docs.aws.amazon.com/servicequotas/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- servicequotas(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- servicequotas()
#' svc$associate_service_quota_template(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:servicequotas_associate_service_quota_template]{associate_service_quota_template} \tab Associates your quota request template with your organization\cr
#'  \link[paws.management:servicequotas_delete_service_quota_increase_request_from_template]{delete_service_quota_increase_request_from_template} \tab Deletes the quota increase request for the specified quota from your quota request template\cr
#'  \link[paws.management:servicequotas_disassociate_service_quota_template]{disassociate_service_quota_template} \tab Disables your quota request template\cr
#'  \link[paws.management:servicequotas_get_association_for_service_quota_template]{get_association_for_service_quota_template} \tab Retrieves the status of the association for the quota request template\cr
#'  \link[paws.management:servicequotas_get_aws_default_service_quota]{get_aws_default_service_quota} \tab Retrieves the default value for the specified quota\cr
#'  \link[paws.management:servicequotas_get_requested_service_quota_change]{get_requested_service_quota_change} \tab Retrieves information about the specified quota increase request\cr
#'  \link[paws.management:servicequotas_get_service_quota]{get_service_quota} \tab Retrieves the applied quota value for the specified quota\cr
#'  \link[paws.management:servicequotas_get_service_quota_increase_request_from_template]{get_service_quota_increase_request_from_template} \tab Retrieves information about the specified quota increase request in your quota request template\cr
#'  \link[paws.management:servicequotas_list_aws_default_service_quotas]{list_aws_default_service_quotas} \tab Lists the default values for the quotas for the specified Amazon Web Service\cr
#'  \link[paws.management:servicequotas_list_requested_service_quota_change_history]{list_requested_service_quota_change_history} \tab Retrieves the quota increase requests for the specified Amazon Web Service\cr
#'  \link[paws.management:servicequotas_list_requested_service_quota_change_history_by_quota]{list_requested_service_quota_change_history_by_quota} \tab Retrieves the quota increase requests for the specified quota\cr
#'  \link[paws.management:servicequotas_list_service_quota_increase_requests_in_template]{list_service_quota_increase_requests_in_template} \tab Lists the quota increase requests in the specified quota request template\cr
#'  \link[paws.management:servicequotas_list_service_quotas]{list_service_quotas} \tab Lists the applied quota values for the specified Amazon Web Service\cr
#'  \link[paws.management:servicequotas_list_services]{list_services} \tab Lists the names and codes for the Amazon Web Services integrated with Service Quotas\cr
#'  \link[paws.management:servicequotas_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of the tags assigned to the specified applied quota\cr
#'  \link[paws.management:servicequotas_put_service_quota_increase_request_into_template]{put_service_quota_increase_request_into_template} \tab Adds a quota increase request to your quota request template\cr
#'  \link[paws.management:servicequotas_request_service_quota_increase]{request_service_quota_increase} \tab Submits a quota increase request for the specified quota\cr
#'  \link[paws.management:servicequotas_tag_resource]{tag_resource} \tab Adds tags to the specified applied quota\cr
#'  \link[paws.management:servicequotas_untag_resource]{untag_resource} \tab Removes tags from the specified applied quota
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname servicequotas
#' @export
servicequotas <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::servicequotas(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Service Catalog
#'
#' @description
#' Service Catalog
#' 
#' [Service Catalog](https://aws.amazon.com/servicecatalog/) enables
#' organizations to create and manage catalogs of IT services that are
#' approved for Amazon Web Services. To get the most out of this
#' documentation, you should be familiar with the terminology discussed in
#' [Service Catalog
#' Concepts](https://docs.aws.amazon.com/servicecatalog/latest/adminguide/what-is_concepts.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- servicecatalog(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- servicecatalog()
#' svc$accept_portfolio_share(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:servicecatalog_accept_portfolio_share]{accept_portfolio_share} \tab Accepts an offer to share the specified portfolio\cr
#'  \link[paws.management:servicecatalog_associate_budget_with_resource]{associate_budget_with_resource} \tab Associates the specified budget with the specified resource\cr
#'  \link[paws.management:servicecatalog_associate_principal_with_portfolio]{associate_principal_with_portfolio} \tab Associates the specified principal ARN with the specified portfolio\cr
#'  \link[paws.management:servicecatalog_associate_product_with_portfolio]{associate_product_with_portfolio} \tab Associates the specified product with the specified portfolio\cr
#'  \link[paws.management:servicecatalog_associate_service_action_with_provisioning_artifact]{associate_service_action_with_provisioning_artifact} \tab Associates a self-service action with a provisioning artifact\cr
#'  \link[paws.management:servicecatalog_associate_tag_option_with_resource]{associate_tag_option_with_resource} \tab Associate the specified TagOption with the specified portfolio or product\cr
#'  \link[paws.management:servicecatalog_batch_associate_service_action_with_provisioning_artifact]{batch_associate_service_action_with_provisioning_artifact} \tab Associates multiple self-service actions with provisioning artifacts\cr
#'  \link[paws.management:servicecatalog_batch_disassociate_service_action_from_provisioning_artifact]{batch_disassociate_service_action_from_provisioning_artifact} \tab Disassociates a batch of self-service actions from the specified provisioning artifact\cr
#'  \link[paws.management:servicecatalog_copy_product]{copy_product} \tab Copies the specified source product to the specified target product or a new product\cr
#'  \link[paws.management:servicecatalog_create_constraint]{create_constraint} \tab Creates a constraint\cr
#'  \link[paws.management:servicecatalog_create_portfolio]{create_portfolio} \tab Creates a portfolio\cr
#'  \link[paws.management:servicecatalog_create_portfolio_share]{create_portfolio_share} \tab Shares the specified portfolio with the specified account or organization node\cr
#'  \link[paws.management:servicecatalog_create_product]{create_product} \tab Creates a product\cr
#'  \link[paws.management:servicecatalog_create_provisioned_product_plan]{create_provisioned_product_plan} \tab Creates a plan\cr
#'  \link[paws.management:servicecatalog_create_provisioning_artifact]{create_provisioning_artifact} \tab Creates a provisioning artifact (also known as a version) for the specified product\cr
#'  \link[paws.management:servicecatalog_create_service_action]{create_service_action} \tab Creates a self-service action\cr
#'  \link[paws.management:servicecatalog_create_tag_option]{create_tag_option} \tab Creates a TagOption\cr
#'  \link[paws.management:servicecatalog_delete_constraint]{delete_constraint} \tab Deletes the specified constraint\cr
#'  \link[paws.management:servicecatalog_delete_portfolio]{delete_portfolio} \tab Deletes the specified portfolio\cr
#'  \link[paws.management:servicecatalog_delete_portfolio_share]{delete_portfolio_share} \tab Stops sharing the specified portfolio with the specified account or organization node\cr
#'  \link[paws.management:servicecatalog_delete_product]{delete_product} \tab Deletes the specified product\cr
#'  \link[paws.management:servicecatalog_delete_provisioned_product_plan]{delete_provisioned_product_plan} \tab Deletes the specified plan\cr
#'  \link[paws.management:servicecatalog_delete_provisioning_artifact]{delete_provisioning_artifact} \tab Deletes the specified provisioning artifact (also known as a version) for the specified product\cr
#'  \link[paws.management:servicecatalog_delete_service_action]{delete_service_action} \tab Deletes a self-service action\cr
#'  \link[paws.management:servicecatalog_delete_tag_option]{delete_tag_option} \tab Deletes the specified TagOption\cr
#'  \link[paws.management:servicecatalog_describe_constraint]{describe_constraint} \tab Gets information about the specified constraint\cr
#'  \link[paws.management:servicecatalog_describe_copy_product_status]{describe_copy_product_status} \tab Gets the status of the specified copy product operation\cr
#'  \link[paws.management:servicecatalog_describe_portfolio]{describe_portfolio} \tab Gets information about the specified portfolio\cr
#'  \link[paws.management:servicecatalog_describe_portfolio_shares]{describe_portfolio_shares} \tab Returns a summary of each of the portfolio shares that were created for the specified portfolio\cr
#'  \link[paws.management:servicecatalog_describe_portfolio_share_status]{describe_portfolio_share_status} \tab Gets the status of the specified portfolio share operation\cr
#'  \link[paws.management:servicecatalog_describe_product]{describe_product} \tab Gets information about the specified product\cr
#'  \link[paws.management:servicecatalog_describe_product_as_admin]{describe_product_as_admin} \tab Gets information about the specified product\cr
#'  \link[paws.management:servicecatalog_describe_product_view]{describe_product_view} \tab Gets information about the specified product\cr
#'  \link[paws.management:servicecatalog_describe_provisioned_product]{describe_provisioned_product} \tab Gets information about the specified provisioned product\cr
#'  \link[paws.management:servicecatalog_describe_provisioned_product_plan]{describe_provisioned_product_plan} \tab Gets information about the resource changes for the specified plan\cr
#'  \link[paws.management:servicecatalog_describe_provisioning_artifact]{describe_provisioning_artifact} \tab Gets information about the specified provisioning artifact (also known as a version) for the specified product\cr
#'  \link[paws.management:servicecatalog_describe_provisioning_parameters]{describe_provisioning_parameters} \tab Gets information about the configuration required to provision the specified product using the specified provisioning artifact\cr
#'  \link[paws.management:servicecatalog_describe_record]{describe_record} \tab Gets information about the specified request operation\cr
#'  \link[paws.management:servicecatalog_describe_service_action]{describe_service_action} \tab Describes a self-service action\cr
#'  \link[paws.management:servicecatalog_describe_service_action_execution_parameters]{describe_service_action_execution_parameters} \tab Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user\cr
#'  \link[paws.management:servicecatalog_describe_tag_option]{describe_tag_option} \tab Gets information about the specified TagOption\cr
#'  \link[paws.management:servicecatalog_disable_aws_organizations_access]{disable_aws_organizations_access} \tab Disable portfolio sharing through the Organizations service\cr
#'  \link[paws.management:servicecatalog_disassociate_budget_from_resource]{disassociate_budget_from_resource} \tab Disassociates the specified budget from the specified resource\cr
#'  \link[paws.management:servicecatalog_disassociate_principal_from_portfolio]{disassociate_principal_from_portfolio} \tab Disassociates a previously associated principal ARN from a specified portfolio\cr
#'  \link[paws.management:servicecatalog_disassociate_product_from_portfolio]{disassociate_product_from_portfolio} \tab Disassociates the specified product from the specified portfolio\cr
#'  \link[paws.management:servicecatalog_disassociate_service_action_from_provisioning_artifact]{disassociate_service_action_from_provisioning_artifact} \tab Disassociates the specified self-service action association from the specified provisioning artifact\cr
#'  \link[paws.management:servicecatalog_disassociate_tag_option_from_resource]{disassociate_tag_option_from_resource} \tab Disassociates the specified TagOption from the specified resource\cr
#'  \link[paws.management:servicecatalog_enable_aws_organizations_access]{enable_aws_organizations_access} \tab Enable portfolio sharing feature through Organizations\cr
#'  \link[paws.management:servicecatalog_execute_provisioned_product_plan]{execute_provisioned_product_plan} \tab Provisions or modifies a product based on the resource changes for the specified plan\cr
#'  \link[paws.management:servicecatalog_execute_provisioned_product_service_action]{execute_provisioned_product_service_action} \tab Executes a self-service action against a provisioned product\cr
#'  \link[paws.management:servicecatalog_get_aws_organizations_access_status]{get_aws_organizations_access_status} \tab Get the Access Status for Organizations portfolio share feature\cr
#'  \link[paws.management:servicecatalog_get_provisioned_product_outputs]{get_provisioned_product_outputs} \tab This API takes either a ProvisonedProductId or a ProvisionedProductName, along with a list of one or more output keys, and responds with the key/value pairs of those outputs\cr
#'  \link[paws.management:servicecatalog_import_as_provisioned_product]{import_as_provisioned_product} \tab Requests the import of a resource as an Service Catalog provisioned product that is associated to an Service Catalog product and provisioning artifact\cr
#'  \link[paws.management:servicecatalog_list_accepted_portfolio_shares]{list_accepted_portfolio_shares} \tab Lists all imported portfolios for which account-to-account shares were accepted by this account\cr
#'  \link[paws.management:servicecatalog_list_budgets_for_resource]{list_budgets_for_resource} \tab Lists all the budgets associated to the specified resource\cr
#'  \link[paws.management:servicecatalog_list_constraints_for_portfolio]{list_constraints_for_portfolio} \tab Lists the constraints for the specified portfolio and product\cr
#'  \link[paws.management:servicecatalog_list_launch_paths]{list_launch_paths} \tab Lists the paths to the specified product\cr
#'  \link[paws.management:servicecatalog_list_organization_portfolio_access]{list_organization_portfolio_access} \tab Lists the organization nodes that have access to the specified portfolio\cr
#'  \link[paws.management:servicecatalog_list_portfolio_access]{list_portfolio_access} \tab Lists the account IDs that have access to the specified portfolio\cr
#'  \link[paws.management:servicecatalog_list_portfolios]{list_portfolios} \tab Lists all portfolios in the catalog\cr
#'  \link[paws.management:servicecatalog_list_portfolios_for_product]{list_portfolios_for_product} \tab Lists all portfolios that the specified product is associated with\cr
#'  \link[paws.management:servicecatalog_list_principals_for_portfolio]{list_principals_for_portfolio} \tab Lists all PrincipalARNs and corresponding PrincipalTypes associated with the specified portfolio\cr
#'  \link[paws.management:servicecatalog_list_provisioned_product_plans]{list_provisioned_product_plans} \tab Lists the plans for the specified provisioned product or all plans to which the user has access\cr
#'  \link[paws.management:servicecatalog_list_provisioning_artifacts]{list_provisioning_artifacts} \tab Lists all provisioning artifacts (also known as versions) for the specified product\cr
#'  \link[paws.management:servicecatalog_list_provisioning_artifacts_for_service_action]{list_provisioning_artifacts_for_service_action} \tab Lists all provisioning artifacts (also known as versions) for the specified self-service action\cr
#'  \link[paws.management:servicecatalog_list_record_history]{list_record_history} \tab Lists the specified requests or all performed requests\cr
#'  \link[paws.management:servicecatalog_list_resources_for_tag_option]{list_resources_for_tag_option} \tab Lists the resources associated with the specified TagOption\cr
#'  \link[paws.management:servicecatalog_list_service_actions]{list_service_actions} \tab Lists all self-service actions\cr
#'  \link[paws.management:servicecatalog_list_service_actions_for_provisioning_artifact]{list_service_actions_for_provisioning_artifact} \tab Returns a paginated list of self-service actions associated with the specified Product ID and Provisioning Artifact ID\cr
#'  \link[paws.management:servicecatalog_list_stack_instances_for_provisioned_product]{list_stack_instances_for_provisioned_product} \tab Returns summary information about stack instances that are associated with the specified CFN_STACKSET type provisioned product\cr
#'  \link[paws.management:servicecatalog_list_tag_options]{list_tag_options} \tab Lists the specified TagOptions or all TagOptions\cr
#'  \link[paws.management:servicecatalog_notify_provision_product_engine_workflow_result]{notify_provision_product_engine_workflow_result} \tab Notifies the result of the provisioning engine execution\cr
#'  \link[paws.management:servicecatalog_notify_terminate_provisioned_product_engine_workflow_result]{notify_terminate_provisioned_product_engine_workflow_result} \tab Notifies the result of the terminate engine execution\cr
#'  \link[paws.management:servicecatalog_notify_update_provisioned_product_engine_workflow_result]{notify_update_provisioned_product_engine_workflow_result} \tab Notifies the result of the update engine execution\cr
#'  \link[paws.management:servicecatalog_provision_product]{provision_product} \tab Provisions the specified product\cr
#'  \link[paws.management:servicecatalog_reject_portfolio_share]{reject_portfolio_share} \tab Rejects an offer to share the specified portfolio\cr
#'  \link[paws.management:servicecatalog_scan_provisioned_products]{scan_provisioned_products} \tab Lists the provisioned products that are available (not terminated)\cr
#'  \link[paws.management:servicecatalog_search_products]{search_products} \tab Gets information about the products to which the caller has access\cr
#'  \link[paws.management:servicecatalog_search_products_as_admin]{search_products_as_admin} \tab Gets information about the products for the specified portfolio or all products\cr
#'  \link[paws.management:servicecatalog_search_provisioned_products]{search_provisioned_products} \tab Gets information about the provisioned products that meet the specified criteria\cr
#'  \link[paws.management:servicecatalog_terminate_provisioned_product]{terminate_provisioned_product} \tab Terminates the specified provisioned product\cr
#'  \link[paws.management:servicecatalog_update_constraint]{update_constraint} \tab Updates the specified constraint\cr
#'  \link[paws.management:servicecatalog_update_portfolio]{update_portfolio} \tab Updates the specified portfolio\cr
#'  \link[paws.management:servicecatalog_update_portfolio_share]{update_portfolio_share} \tab Updates the specified portfolio share\cr
#'  \link[paws.management:servicecatalog_update_product]{update_product} \tab Updates the specified product\cr
#'  \link[paws.management:servicecatalog_update_provisioned_product]{update_provisioned_product} \tab Requests updates to the configuration of the specified provisioned product\cr
#'  \link[paws.management:servicecatalog_update_provisioned_product_properties]{update_provisioned_product_properties} \tab Requests updates to the properties of the specified provisioned product\cr
#'  \link[paws.management:servicecatalog_update_provisioning_artifact]{update_provisioning_artifact} \tab Updates the specified provisioning artifact (also known as a version) for the specified product\cr
#'  \link[paws.management:servicecatalog_update_service_action]{update_service_action} \tab Updates a self-service action\cr
#'  \link[paws.management:servicecatalog_update_tag_option]{update_tag_option} \tab Updates the specified TagOption
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname servicecatalog
#' @export
servicecatalog <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::servicecatalog(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Service Catalog App Registry
#'
#' @description
#' Amazon Web Services Service Catalog AppRegistry enables organizations to
#' understand the application context of their Amazon Web Services
#' resources. AppRegistry provides a repository of your applications, their
#' resources, and the application metadata that you use within your
#' enterprise.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- appregistry(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- appregistry()
#' svc$associate_attribute_group(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:appregistry_associate_attribute_group]{associate_attribute_group} \tab Associates an attribute group with an application to augment the application's metadata with the group's attributes\cr
#'  \link[paws.management:appregistry_associate_resource]{associate_resource} \tab Associates a resource with an application\cr
#'  \link[paws.management:appregistry_create_application]{create_application} \tab Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions\cr
#'  \link[paws.management:appregistry_create_attribute_group]{create_attribute_group} \tab Creates a new attribute group as a container for user-defined attributes\cr
#'  \link[paws.management:appregistry_delete_application]{delete_application} \tab Deletes an application that is specified either by its application ID, name, or ARN\cr
#'  \link[paws.management:appregistry_delete_attribute_group]{delete_attribute_group} \tab Deletes an attribute group, specified either by its attribute group ID, name, or ARN\cr
#'  \link[paws.management:appregistry_disassociate_attribute_group]{disassociate_attribute_group} \tab Disassociates an attribute group from an application to remove the extra attributes contained in the attribute group from the application's metadata\cr
#'  \link[paws.management:appregistry_disassociate_resource]{disassociate_resource} \tab Disassociates a resource from application\cr
#'  \link[paws.management:appregistry_get_application]{get_application} \tab Retrieves metadata information about one of your applications\cr
#'  \link[paws.management:appregistry_get_associated_resource]{get_associated_resource} \tab Gets the resource associated with the application\cr
#'  \link[paws.management:appregistry_get_attribute_group]{get_attribute_group} \tab Retrieves an attribute group by its ARN, ID, or name\cr
#'  \link[paws.management:appregistry_get_configuration]{get_configuration} \tab Retrieves a TagKey configuration from an account\cr
#'  \link[paws.management:appregistry_list_applications]{list_applications} \tab Retrieves a list of all of your applications\cr
#'  \link[paws.management:appregistry_list_associated_attribute_groups]{list_associated_attribute_groups} \tab Lists all attribute groups that are associated with specified application\cr
#'  \link[paws.management:appregistry_list_associated_resources]{list_associated_resources} \tab Lists all of the resources that are associated with the specified application\cr
#'  \link[paws.management:appregistry_list_attribute_groups]{list_attribute_groups} \tab Lists all attribute groups which you have access to\cr
#'  \link[paws.management:appregistry_list_attribute_groups_for_application]{list_attribute_groups_for_application} \tab Lists the details of all attribute groups associated with a specific application\cr
#'  \link[paws.management:appregistry_list_tags_for_resource]{list_tags_for_resource} \tab Lists all of the tags on the resource\cr
#'  \link[paws.management:appregistry_put_configuration]{put_configuration} \tab Associates a TagKey configuration to an account\cr
#'  \link[paws.management:appregistry_sync_resource]{sync_resource} \tab Syncs the resource with current AppRegistry records\cr
#'  \link[paws.management:appregistry_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified resource\cr
#'  \link[paws.management:appregistry_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.management:appregistry_update_application]{update_application} \tab Updates an existing application with new attributes\cr
#'  \link[paws.management:appregistry_update_attribute_group]{update_attribute_group} \tab Updates an existing attribute group with new details
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname appregistry
#' @export
appregistry <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::appregistry(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Simple Systems Manager (SSM)
#'
#' @description
#' Amazon Web Services Systems Manager is the operations hub for your
#' Amazon Web Services applications and resources and a secure end-to-end
#' management solution for hybrid cloud environments that enables safe and
#' secure operations at scale.
#' 
#' This reference is intended to be used with the [Amazon Web Services
#' Systems Manager User
#' Guide](https://docs.aws.amazon.com/systems-manager/latest/userguide/).
#' To get started, see [Setting up Amazon Web Services Systems
#' Manager](https://docs.aws.amazon.com/systems-manager/latest/userguide/).
#' 
#' **Related resources**
#' 
#' -   For information about each of the tools that comprise Systems
#'     Manager, see [Using Systems Manager
#'     tools](https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-tools.html)
#'     in the *Amazon Web Services Systems Manager User Guide*.
#' 
#' -   For details about predefined runbooks for Automation, a tool in
#'     Amazon Web Services Systems Manager, see the *\href{https://docs.aws.amazon.com/systems-manager-automation-runbooks/latest/userguide/automation-runbook-reference.html}{Systems Manager Automation runbook reference}* .
#' 
#' -   For information about AppConfig, a tool in Systems Manager, see the
#'     *\href{https://docs.aws.amazon.com/appconfig/latest/userguide/}{AppConfig User Guide}* and the *
#'     \href{https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/}{AppConfig API Reference}* .
#' 
#' -   For information about Incident Manager, a tool in Systems Manager,
#'     see the *\href{https://docs.aws.amazon.com/incident-manager/latest/userguide/}{Systems Manager Incident Manager User Guide}* and the *
#'     \href{https://docs.aws.amazon.com/incident-manager/latest/APIReference/}{Systems Manager Incident Manager API Reference}* .
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ssm(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ssm()
#' svc$add_tags_to_resource(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:ssm_add_tags_to_resource]{add_tags_to_resource} \tab Adds or overwrites one or more tags for the specified resource\cr
#'  \link[paws.management:ssm_associate_ops_item_related_item]{associate_ops_item_related_item} \tab Associates a related item to a Systems Manager OpsCenter OpsItem\cr
#'  \link[paws.management:ssm_cancel_command]{cancel_command} \tab Attempts to cancel the command specified by the Command ID\cr
#'  \link[paws.management:ssm_cancel_maintenance_window_execution]{cancel_maintenance_window_execution} \tab Stops a maintenance window execution that is already in progress and cancels any tasks in the window that haven't already starting running\cr
#'  \link[paws.management:ssm_create_activation]{create_activation} \tab Generates an activation code and activation ID you can use to register your on-premises servers, edge devices, or virtual machine (VM) with Amazon Web Services Systems Manager\cr
#'  \link[paws.management:ssm_create_association]{create_association} \tab A State Manager association defines the state that you want to maintain on your managed nodes\cr
#'  \link[paws.management:ssm_create_association_batch]{create_association_batch} \tab Associates the specified Amazon Web Services Systems Manager document (SSM document) with the specified managed nodes or targets\cr
#'  \link[paws.management:ssm_create_document]{create_document} \tab Creates a Amazon Web Services Systems Manager (SSM document)\cr
#'  \link[paws.management:ssm_create_maintenance_window]{create_maintenance_window} \tab Creates a new maintenance window\cr
#'  \link[paws.management:ssm_create_ops_item]{create_ops_item} \tab Creates a new OpsItem\cr
#'  \link[paws.management:ssm_create_ops_metadata]{create_ops_metadata} \tab If you create a new application in Application Manager, Amazon Web Services Systems Manager calls this API operation to specify information about the new application, including the application type\cr
#'  \link[paws.management:ssm_create_patch_baseline]{create_patch_baseline} \tab Creates a patch baseline\cr
#'  \link[paws.management:ssm_create_resource_data_sync]{create_resource_data_sync} \tab A resource data sync helps you view data from multiple sources in a single location\cr
#'  \link[paws.management:ssm_delete_activation]{delete_activation} \tab Deletes an activation\cr
#'  \link[paws.management:ssm_delete_association]{delete_association} \tab Disassociates the specified Amazon Web Services Systems Manager document (SSM document) from the specified managed node\cr
#'  \link[paws.management:ssm_delete_document]{delete_document} \tab Deletes the Amazon Web Services Systems Manager document (SSM document) and all managed node associations to the document\cr
#'  \link[paws.management:ssm_delete_inventory]{delete_inventory} \tab Delete a custom inventory type or the data associated with a custom Inventory type\cr
#'  \link[paws.management:ssm_delete_maintenance_window]{delete_maintenance_window} \tab Deletes a maintenance window\cr
#'  \link[paws.management:ssm_delete_ops_item]{delete_ops_item} \tab Delete an OpsItem\cr
#'  \link[paws.management:ssm_delete_ops_metadata]{delete_ops_metadata} \tab Delete OpsMetadata related to an application\cr
#'  \link[paws.management:ssm_delete_parameter]{delete_parameter} \tab Delete a parameter from the system\cr
#'  \link[paws.management:ssm_delete_parameters]{delete_parameters} \tab Delete a list of parameters\cr
#'  \link[paws.management:ssm_delete_patch_baseline]{delete_patch_baseline} \tab Deletes a patch baseline\cr
#'  \link[paws.management:ssm_delete_resource_data_sync]{delete_resource_data_sync} \tab Deletes a resource data sync configuration\cr
#'  \link[paws.management:ssm_delete_resource_policy]{delete_resource_policy} \tab Deletes a Systems Manager resource policy\cr
#'  \link[paws.management:ssm_deregister_managed_instance]{deregister_managed_instance} \tab Removes the server or virtual machine from the list of registered servers\cr
#'  \link[paws.management:ssm_deregister_patch_baseline_for_patch_group]{deregister_patch_baseline_for_patch_group} \tab Removes a patch group from a patch baseline\cr
#'  \link[paws.management:ssm_deregister_target_from_maintenance_window]{deregister_target_from_maintenance_window} \tab Removes a target from a maintenance window\cr
#'  \link[paws.management:ssm_deregister_task_from_maintenance_window]{deregister_task_from_maintenance_window} \tab Removes a task from a maintenance window\cr
#'  \link[paws.management:ssm_describe_activations]{describe_activations} \tab Describes details about the activation, such as the date and time the activation was created, its expiration date, the Identity and Access Management (IAM) role assigned to the managed nodes in the activation, and the number of nodes registered by using this activation\cr
#'  \link[paws.management:ssm_describe_association]{describe_association} \tab Describes the association for the specified target or managed node\cr
#'  \link[paws.management:ssm_describe_association_executions]{describe_association_executions} \tab Views all executions for a specific association ID\cr
#'  \link[paws.management:ssm_describe_association_execution_targets]{describe_association_execution_targets} \tab Views information about a specific execution of a specific association\cr
#'  \link[paws.management:ssm_describe_automation_executions]{describe_automation_executions} \tab Provides details about all active and terminated Automation executions\cr
#'  \link[paws.management:ssm_describe_automation_step_executions]{describe_automation_step_executions} \tab Information about all active and terminated step executions in an Automation workflow\cr
#'  \link[paws.management:ssm_describe_available_patches]{describe_available_patches} \tab Lists all patches eligible to be included in a patch baseline\cr
#'  \link[paws.management:ssm_describe_document]{describe_document} \tab Describes the specified Amazon Web Services Systems Manager document (SSM document)\cr
#'  \link[paws.management:ssm_describe_document_permission]{describe_document_permission} \tab Describes the permissions for a Amazon Web Services Systems Manager document (SSM document)\cr
#'  \link[paws.management:ssm_describe_effective_instance_associations]{describe_effective_instance_associations} \tab All associations for the managed nodes\cr
#'  \link[paws.management:ssm_describe_effective_patches_for_patch_baseline]{describe_effective_patches_for_patch_baseline} \tab Retrieves the current effective patches (the patch and the approval state) for the specified patch baseline\cr
#'  \link[paws.management:ssm_describe_instance_associations_status]{describe_instance_associations_status} \tab The status of the associations for the managed nodes\cr
#'  \link[paws.management:ssm_describe_instance_information]{describe_instance_information} \tab Provides information about one or more of your managed nodes, including the operating system platform, SSM Agent version, association status, and IP address\cr
#'  \link[paws.management:ssm_describe_instance_patches]{describe_instance_patches} \tab Retrieves information about the patches on the specified managed node and their state relative to the patch baseline being used for the node\cr
#'  \link[paws.management:ssm_describe_instance_patch_states]{describe_instance_patch_states} \tab Retrieves the high-level patch state of one or more managed nodes\cr
#'  \link[paws.management:ssm_describe_instance_patch_states_for_patch_group]{describe_instance_patch_states_for_patch_group} \tab Retrieves the high-level patch state for the managed nodes in the specified patch group\cr
#'  \link[paws.management:ssm_describe_instance_properties]{describe_instance_properties} \tab An API operation used by the Systems Manager console to display information about Systems Manager managed nodes\cr
#'  \link[paws.management:ssm_describe_inventory_deletions]{describe_inventory_deletions} \tab Describes a specific delete inventory operation\cr
#'  \link[paws.management:ssm_describe_maintenance_window_executions]{describe_maintenance_window_executions} \tab Lists the executions of a maintenance window\cr
#'  \link[paws.management:ssm_describe_maintenance_window_execution_task_invocations]{describe_maintenance_window_execution_task_invocations} \tab Retrieves the individual task executions (one per target) for a particular task run as part of a maintenance window execution\cr
#'  \link[paws.management:ssm_describe_maintenance_window_execution_tasks]{describe_maintenance_window_execution_tasks} \tab For a given maintenance window execution, lists the tasks that were run\cr
#'  \link[paws.management:ssm_describe_maintenance_windows]{describe_maintenance_windows} \tab Retrieves the maintenance windows in an Amazon Web Services account\cr
#'  \link[paws.management:ssm_describe_maintenance_window_schedule]{describe_maintenance_window_schedule} \tab Retrieves information about upcoming executions of a maintenance window\cr
#'  \link[paws.management:ssm_describe_maintenance_windows_for_target]{describe_maintenance_windows_for_target} \tab Retrieves information about the maintenance window targets or tasks that a managed node is associated with\cr
#'  \link[paws.management:ssm_describe_maintenance_window_targets]{describe_maintenance_window_targets} \tab Lists the targets registered with the maintenance window\cr
#'  \link[paws.management:ssm_describe_maintenance_window_tasks]{describe_maintenance_window_tasks} \tab Lists the tasks in a maintenance window\cr
#'  \link[paws.management:ssm_describe_ops_items]{describe_ops_items} \tab Query a set of OpsItems\cr
#'  \link[paws.management:ssm_describe_parameters]{describe_parameters} \tab Lists the parameters in your Amazon Web Services account or the parameters shared with you when you enable the Shared option\cr
#'  \link[paws.management:ssm_describe_patch_baselines]{describe_patch_baselines} \tab Lists the patch baselines in your Amazon Web Services account\cr
#'  \link[paws.management:ssm_describe_patch_groups]{describe_patch_groups} \tab Lists all patch groups that have been registered with patch baselines\cr
#'  \link[paws.management:ssm_describe_patch_group_state]{describe_patch_group_state} \tab Returns high-level aggregated patch compliance state information for a patch group\cr
#'  \link[paws.management:ssm_describe_patch_properties]{describe_patch_properties} \tab Lists the properties of available patches organized by product, product family, classification, severity, and other properties of available patches\cr
#'  \link[paws.management:ssm_describe_sessions]{describe_sessions} \tab Retrieves a list of all active sessions (both connected and disconnected) or terminated sessions from the past 30 days\cr
#'  \link[paws.management:ssm_disassociate_ops_item_related_item]{disassociate_ops_item_related_item} \tab Deletes the association between an OpsItem and a related item\cr
#'  \link[paws.management:ssm_get_automation_execution]{get_automation_execution} \tab Get detailed information about a particular Automation execution\cr
#'  \link[paws.management:ssm_get_calendar_state]{get_calendar_state} \tab Gets the state of a Amazon Web Services Systems Manager change calendar at the current time or a specified time\cr
#'  \link[paws.management:ssm_get_command_invocation]{get_command_invocation} \tab Returns detailed information about command execution for an invocation or plugin\cr
#'  \link[paws.management:ssm_get_connection_status]{get_connection_status} \tab Retrieves the Session Manager connection status for a managed node to determine whether it is running and ready to receive Session Manager connections\cr
#'  \link[paws.management:ssm_get_default_patch_baseline]{get_default_patch_baseline} \tab Retrieves the default patch baseline\cr
#'  \link[paws.management:ssm_get_deployable_patch_snapshot_for_instance]{get_deployable_patch_snapshot_for_instance} \tab Retrieves the current snapshot for the patch baseline the managed node uses\cr
#'  \link[paws.management:ssm_get_document]{get_document} \tab Gets the contents of the specified Amazon Web Services Systems Manager document (SSM document)\cr
#'  \link[paws.management:ssm_get_execution_preview]{get_execution_preview} \tab Initiates the process of retrieving an existing preview that shows the effects that running a specified Automation runbook would have on the targeted resources\cr
#'  \link[paws.management:ssm_get_inventory]{get_inventory} \tab Query inventory information\cr
#'  \link[paws.management:ssm_get_inventory_schema]{get_inventory_schema} \tab Return a list of inventory type names for the account, or return a list of attribute names for a specific Inventory item type\cr
#'  \link[paws.management:ssm_get_maintenance_window]{get_maintenance_window} \tab Retrieves a maintenance window\cr
#'  \link[paws.management:ssm_get_maintenance_window_execution]{get_maintenance_window_execution} \tab Retrieves details about a specific a maintenance window execution\cr
#'  \link[paws.management:ssm_get_maintenance_window_execution_task]{get_maintenance_window_execution_task} \tab Retrieves the details about a specific task run as part of a maintenance window execution\cr
#'  \link[paws.management:ssm_get_maintenance_window_execution_task_invocation]{get_maintenance_window_execution_task_invocation} \tab Retrieves information about a specific task running on a specific target\cr
#'  \link[paws.management:ssm_get_maintenance_window_task]{get_maintenance_window_task} \tab Retrieves the details of a maintenance window task\cr
#'  \link[paws.management:ssm_get_ops_item]{get_ops_item} \tab Get information about an OpsItem by using the ID\cr
#'  \link[paws.management:ssm_get_ops_metadata]{get_ops_metadata} \tab View operational metadata related to an application in Application Manager\cr
#'  \link[paws.management:ssm_get_ops_summary]{get_ops_summary} \tab View a summary of operations metadata (OpsData) based on specified filters and aggregators\cr
#'  \link[paws.management:ssm_get_parameter]{get_parameter} \tab Get information about a single parameter by specifying the parameter name\cr
#'  \link[paws.management:ssm_get_parameter_history]{get_parameter_history} \tab Retrieves the history of all changes to a parameter\cr
#'  \link[paws.management:ssm_get_parameters]{get_parameters} \tab Get information about one or more parameters by specifying multiple parameter names\cr
#'  \link[paws.management:ssm_get_parameters_by_path]{get_parameters_by_path} \tab Retrieve information about one or more parameters under a specified level in a hierarchy\cr
#'  \link[paws.management:ssm_get_patch_baseline]{get_patch_baseline} \tab Retrieves information about a patch baseline\cr
#'  \link[paws.management:ssm_get_patch_baseline_for_patch_group]{get_patch_baseline_for_patch_group} \tab Retrieves the patch baseline that should be used for the specified patch group\cr
#'  \link[paws.management:ssm_get_resource_policies]{get_resource_policies} \tab Returns an array of the Policy object\cr
#'  \link[paws.management:ssm_get_service_setting]{get_service_setting} \tab ServiceSetting is an account-level setting for an Amazon Web Services service\cr
#'  \link[paws.management:ssm_label_parameter_version]{label_parameter_version} \tab A parameter label is a user-defined alias to help you manage different versions of a parameter\cr
#'  \link[paws.management:ssm_list_associations]{list_associations} \tab Returns all State Manager associations in the current Amazon Web Services account and Amazon Web Services Region\cr
#'  \link[paws.management:ssm_list_association_versions]{list_association_versions} \tab Retrieves all versions of an association for a specific association ID\cr
#'  \link[paws.management:ssm_list_command_invocations]{list_command_invocations} \tab An invocation is copy of a command sent to a specific managed node\cr
#'  \link[paws.management:ssm_list_commands]{list_commands} \tab Lists the commands requested by users of the Amazon Web Services account\cr
#'  \link[paws.management:ssm_list_compliance_items]{list_compliance_items} \tab For a specified resource ID, this API operation returns a list of compliance statuses for different resource types\cr
#'  \link[paws.management:ssm_list_compliance_summaries]{list_compliance_summaries} \tab Returns a summary count of compliant and non-compliant resources for a compliance type\cr
#'  \link[paws.management:ssm_list_document_metadata_history]{list_document_metadata_history} \tab Information about approval reviews for a version of a change template in Change Manager\cr
#'  \link[paws.management:ssm_list_documents]{list_documents} \tab Returns all Systems Manager (SSM) documents in the current Amazon Web Services account and Amazon Web Services Region\cr
#'  \link[paws.management:ssm_list_document_versions]{list_document_versions} \tab List all versions for a document\cr
#'  \link[paws.management:ssm_list_inventory_entries]{list_inventory_entries} \tab A list of inventory items returned by the request\cr
#'  \link[paws.management:ssm_list_nodes]{list_nodes} \tab Takes in filters and returns a list of managed nodes matching the filter criteria\cr
#'  \link[paws.management:ssm_list_nodes_summary]{list_nodes_summary} \tab Generates a summary of managed instance/node metadata based on the filters and aggregators you specify\cr
#'  \link[paws.management:ssm_list_ops_item_events]{list_ops_item_events} \tab Returns a list of all OpsItem events in the current Amazon Web Services Region and Amazon Web Services account\cr
#'  \link[paws.management:ssm_list_ops_item_related_items]{list_ops_item_related_items} \tab Lists all related-item resources associated with a Systems Manager OpsCenter OpsItem\cr
#'  \link[paws.management:ssm_list_ops_metadata]{list_ops_metadata} \tab Amazon Web Services Systems Manager calls this API operation when displaying all Application Manager OpsMetadata objects or blobs\cr
#'  \link[paws.management:ssm_list_resource_compliance_summaries]{list_resource_compliance_summaries} \tab Returns a resource-level summary count\cr
#'  \link[paws.management:ssm_list_resource_data_sync]{list_resource_data_sync} \tab Lists your resource data sync configurations\cr
#'  \link[paws.management:ssm_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of the tags assigned to the specified resource\cr
#'  \link[paws.management:ssm_modify_document_permission]{modify_document_permission} \tab Shares a Amazon Web Services Systems Manager document (SSM document)publicly or privately\cr
#'  \link[paws.management:ssm_put_compliance_items]{put_compliance_items} \tab Registers a compliance type and other compliance details on a designated resource\cr
#'  \link[paws.management:ssm_put_inventory]{put_inventory} \tab Bulk update custom inventory items on one or more managed nodes\cr
#'  \link[paws.management:ssm_put_parameter]{put_parameter} \tab Add a parameter to the system\cr
#'  \link[paws.management:ssm_put_resource_policy]{put_resource_policy} \tab Creates or updates a Systems Manager resource policy\cr
#'  \link[paws.management:ssm_register_default_patch_baseline]{register_default_patch_baseline} \tab Defines the default patch baseline for the relevant operating system\cr
#'  \link[paws.management:ssm_register_patch_baseline_for_patch_group]{register_patch_baseline_for_patch_group} \tab Registers a patch baseline for a patch group\cr
#'  \link[paws.management:ssm_register_target_with_maintenance_window]{register_target_with_maintenance_window} \tab Registers a target with a maintenance window\cr
#'  \link[paws.management:ssm_register_task_with_maintenance_window]{register_task_with_maintenance_window} \tab Adds a new task to a maintenance window\cr
#'  \link[paws.management:ssm_remove_tags_from_resource]{remove_tags_from_resource} \tab Removes tag keys from the specified resource\cr
#'  \link[paws.management:ssm_reset_service_setting]{reset_service_setting} \tab ServiceSetting is an account-level setting for an Amazon Web Services service\cr
#'  \link[paws.management:ssm_resume_session]{resume_session} \tab Reconnects a session to a managed node after it has been disconnected\cr
#'  \link[paws.management:ssm_send_automation_signal]{send_automation_signal} \tab Sends a signal to an Automation execution to change the current behavior or status of the execution\cr
#'  \link[paws.management:ssm_send_command]{send_command} \tab Runs commands on one or more managed nodes\cr
#'  \link[paws.management:ssm_start_associations_once]{start_associations_once} \tab Runs an association immediately and only one time\cr
#'  \link[paws.management:ssm_start_automation_execution]{start_automation_execution} \tab Initiates execution of an Automation runbook\cr
#'  \link[paws.management:ssm_start_change_request_execution]{start_change_request_execution} \tab Creates a change request for Change Manager\cr
#'  \link[paws.management:ssm_start_execution_preview]{start_execution_preview} \tab Initiates the process of creating a preview showing the effects that running a specified Automation runbook would have on the targeted resources\cr
#'  \link[paws.management:ssm_start_session]{start_session} \tab Initiates a connection to a target (for example, a managed node) for a Session Manager session\cr
#'  \link[paws.management:ssm_stop_automation_execution]{stop_automation_execution} \tab Stop an Automation that is currently running\cr
#'  \link[paws.management:ssm_terminate_session]{terminate_session} \tab Permanently ends a session and closes the data connection between the Session Manager client and SSM Agent on the managed node\cr
#'  \link[paws.management:ssm_unlabel_parameter_version]{unlabel_parameter_version} \tab Remove a label or labels from a parameter\cr
#'  \link[paws.management:ssm_update_association]{update_association} \tab Updates an association\cr
#'  \link[paws.management:ssm_update_association_status]{update_association_status} \tab Updates the status of the Amazon Web Services Systems Manager document (SSM document) associated with the specified managed node\cr
#'  \link[paws.management:ssm_update_document]{update_document} \tab Updates one or more values for an SSM document\cr
#'  \link[paws.management:ssm_update_document_default_version]{update_document_default_version} \tab Set the default version of a document\cr
#'  \link[paws.management:ssm_update_document_metadata]{update_document_metadata} \tab Updates information related to approval reviews for a specific version of a change template in Change Manager\cr
#'  \link[paws.management:ssm_update_maintenance_window]{update_maintenance_window} \tab Updates an existing maintenance window\cr
#'  \link[paws.management:ssm_update_maintenance_window_target]{update_maintenance_window_target} \tab Modifies the target of an existing maintenance window\cr
#'  \link[paws.management:ssm_update_maintenance_window_task]{update_maintenance_window_task} \tab Modifies a task assigned to a maintenance window\cr
#'  \link[paws.management:ssm_update_managed_instance_role]{update_managed_instance_role} \tab Changes the Identity and Access Management (IAM) role that is assigned to the on-premises server, edge device, or virtual machines (VM)\cr
#'  \link[paws.management:ssm_update_ops_item]{update_ops_item} \tab Edit or change an OpsItem\cr
#'  \link[paws.management:ssm_update_ops_metadata]{update_ops_metadata} \tab Amazon Web Services Systems Manager calls this API operation when you edit OpsMetadata in Application Manager\cr
#'  \link[paws.management:ssm_update_patch_baseline]{update_patch_baseline} \tab Modifies an existing patch baseline\cr
#'  \link[paws.management:ssm_update_resource_data_sync]{update_resource_data_sync} \tab Update a resource data sync\cr
#'  \link[paws.management:ssm_update_service_setting]{update_service_setting} \tab ServiceSetting is an account-level setting for an Amazon Web Services service
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ssm
#' @export
ssm <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::ssm(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Systems Manager Incident Manager Contacts
#'
#' @description
#' Systems Manager Incident Manager is an incident management console
#' designed to help users mitigate and recover from incidents affecting
#' their Amazon Web Services-hosted applications. An incident is any
#' unplanned interruption or reduction in quality of services.
#' 
#' Incident Manager increases incident resolution by notifying responders
#' of impact, highlighting relevant troubleshooting data, and providing
#' collaboration tools to get services back up and running. To achieve the
#' primary goal of reducing the time-to-resolution of critical incidents,
#' Incident Manager automates response plans and enables responder team
#' escalation.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ssmcontacts(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ssmcontacts()
#' # The following accept-page operation uses an accept code sent to the
#' # contact channel to accept a page.
#' svc$accept_page(
#'   AcceptCode = "425440",
#'   AcceptType = "READ",
#'   PageId = "arn:aws:ssm-contacts:us-east-2:682428703967:page/akuam/94ea0c7b..."
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:ssmcontacts_accept_page]{accept_page} \tab Used to acknowledge an engagement to a contact channel during an incident\cr
#'  \link[paws.management:ssmcontacts_activate_contact_channel]{activate_contact_channel} \tab Activates a contact's contact channel\cr
#'  \link[paws.management:ssmcontacts_create_contact]{create_contact} \tab Contacts are either the contacts that Incident Manager engages during an incident or the escalation plans that Incident Manager uses to engage contacts in phases during an incident\cr
#'  \link[paws.management:ssmcontacts_create_contact_channel]{create_contact_channel} \tab A contact channel is the method that Incident Manager uses to engage your contact\cr
#'  \link[paws.management:ssmcontacts_create_rotation]{create_rotation} \tab Creates a rotation in an on-call schedule\cr
#'  \link[paws.management:ssmcontacts_create_rotation_override]{create_rotation_override} \tab Creates an override for a rotation in an on-call schedule\cr
#'  \link[paws.management:ssmcontacts_deactivate_contact_channel]{deactivate_contact_channel} \tab To no longer receive Incident Manager engagements to a contact channel, you can deactivate the channel\cr
#'  \link[paws.management:ssmcontacts_delete_contact]{delete_contact} \tab To remove a contact from Incident Manager, you can delete the contact\cr
#'  \link[paws.management:ssmcontacts_delete_contact_channel]{delete_contact_channel} \tab To no longer receive engagements on a contact channel, you can delete the channel from a contact\cr
#'  \link[paws.management:ssmcontacts_delete_rotation]{delete_rotation} \tab Deletes a rotation from the system\cr
#'  \link[paws.management:ssmcontacts_delete_rotation_override]{delete_rotation_override} \tab Deletes an existing override for an on-call rotation\cr
#'  \link[paws.management:ssmcontacts_describe_engagement]{describe_engagement} \tab Incident Manager uses engagements to engage contacts and escalation plans during an incident\cr
#'  \link[paws.management:ssmcontacts_describe_page]{describe_page} \tab Lists details of the engagement to a contact channel\cr
#'  \link[paws.management:ssmcontacts_get_contact]{get_contact} \tab Retrieves information about the specified contact or escalation plan\cr
#'  \link[paws.management:ssmcontacts_get_contact_channel]{get_contact_channel} \tab List details about a specific contact channel\cr
#'  \link[paws.management:ssmcontacts_get_contact_policy]{get_contact_policy} \tab Retrieves the resource policies attached to the specified contact or escalation plan\cr
#'  \link[paws.management:ssmcontacts_get_rotation]{get_rotation} \tab Retrieves information about an on-call rotation\cr
#'  \link[paws.management:ssmcontacts_get_rotation_override]{get_rotation_override} \tab Retrieves information about an override to an on-call rotation\cr
#'  \link[paws.management:ssmcontacts_list_contact_channels]{list_contact_channels} \tab Lists all contact channels for the specified contact\cr
#'  \link[paws.management:ssmcontacts_list_contacts]{list_contacts} \tab Lists all contacts and escalation plans in Incident Manager\cr
#'  \link[paws.management:ssmcontacts_list_engagements]{list_engagements} \tab Lists all engagements that have happened in an incident\cr
#'  \link[paws.management:ssmcontacts_list_page_receipts]{list_page_receipts} \tab Lists all of the engagements to contact channels that have been acknowledged\cr
#'  \link[paws.management:ssmcontacts_list_page_resolutions]{list_page_resolutions} \tab Returns the resolution path of an engagement\cr
#'  \link[paws.management:ssmcontacts_list_pages_by_contact]{list_pages_by_contact} \tab Lists the engagements to a contact's contact channels\cr
#'  \link[paws.management:ssmcontacts_list_pages_by_engagement]{list_pages_by_engagement} \tab Lists the engagements to contact channels that occurred by engaging a contact\cr
#'  \link[paws.management:ssmcontacts_list_preview_rotation_shifts]{list_preview_rotation_shifts} \tab Returns a list of shifts based on rotation configuration parameters\cr
#'  \link[paws.management:ssmcontacts_list_rotation_overrides]{list_rotation_overrides} \tab Retrieves a list of overrides currently specified for an on-call rotation\cr
#'  \link[paws.management:ssmcontacts_list_rotations]{list_rotations} \tab Retrieves a list of on-call rotations\cr
#'  \link[paws.management:ssmcontacts_list_rotation_shifts]{list_rotation_shifts} \tab Returns a list of shifts generated by an existing rotation in the system\cr
#'  \link[paws.management:ssmcontacts_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags of an escalation plan or contact\cr
#'  \link[paws.management:ssmcontacts_put_contact_policy]{put_contact_policy} \tab Adds a resource policy to the specified contact or escalation plan\cr
#'  \link[paws.management:ssmcontacts_send_activation_code]{send_activation_code} \tab Sends an activation code to a contact channel\cr
#'  \link[paws.management:ssmcontacts_start_engagement]{start_engagement} \tab Starts an engagement to a contact or escalation plan\cr
#'  \link[paws.management:ssmcontacts_stop_engagement]{stop_engagement} \tab Stops an engagement before it finishes the final stage of the escalation plan or engagement plan\cr
#'  \link[paws.management:ssmcontacts_tag_resource]{tag_resource} \tab Tags a contact or escalation plan\cr
#'  \link[paws.management:ssmcontacts_untag_resource]{untag_resource} \tab Removes tags from the specified resource\cr
#'  \link[paws.management:ssmcontacts_update_contact]{update_contact} \tab Updates the contact or escalation plan specified\cr
#'  \link[paws.management:ssmcontacts_update_contact_channel]{update_contact_channel} \tab Updates a contact's contact channel\cr
#'  \link[paws.management:ssmcontacts_update_rotation]{update_rotation} \tab Updates the information specified for an on-call rotation
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ssmcontacts
#' @export
ssmcontacts <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::ssmcontacts(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Systems Manager Incident Manager
#'
#' @description
#' Systems Manager Incident Manager is an incident management console
#' designed to help users mitigate and recover from incidents affecting
#' their Amazon Web Services-hosted applications. An incident is any
#' unplanned interruption or reduction in quality of services.
#' 
#' Incident Manager increases incident resolution by notifying responders
#' of impact, highlighting relevant troubleshooting data, and providing
#' collaboration tools to get services back up and running. To achieve the
#' primary goal of reducing the time-to-resolution of critical incidents,
#' Incident Manager automates response plans and enables responder team
#' escalation.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ssmincidents(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ssmincidents()
#' svc$batch_get_incident_findings(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:ssmincidents_batch_get_incident_findings]{batch_get_incident_findings} \tab Retrieves details about all specified findings for an incident, including descriptive details about each finding\cr
#'  \link[paws.management:ssmincidents_create_replication_set]{create_replication_set} \tab A replication set replicates and encrypts your data to the provided Regions with the provided KMS key\cr
#'  \link[paws.management:ssmincidents_create_response_plan]{create_response_plan} \tab Creates a response plan that automates the initial response to incidents\cr
#'  \link[paws.management:ssmincidents_create_timeline_event]{create_timeline_event} \tab Creates a custom timeline event on the incident details page of an incident record\cr
#'  \link[paws.management:ssmincidents_delete_incident_record]{delete_incident_record} \tab Delete an incident record from Incident Manager\cr
#'  \link[paws.management:ssmincidents_delete_replication_set]{delete_replication_set} \tab Deletes all Regions in your replication set\cr
#'  \link[paws.management:ssmincidents_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource policy that Resource Access Manager uses to share your Incident Manager resource\cr
#'  \link[paws.management:ssmincidents_delete_response_plan]{delete_response_plan} \tab Deletes the specified response plan\cr
#'  \link[paws.management:ssmincidents_delete_timeline_event]{delete_timeline_event} \tab Deletes a timeline event from an incident\cr
#'  \link[paws.management:ssmincidents_get_incident_record]{get_incident_record} \tab Returns the details for the specified incident record\cr
#'  \link[paws.management:ssmincidents_get_replication_set]{get_replication_set} \tab Retrieve your Incident Manager replication set\cr
#'  \link[paws.management:ssmincidents_get_resource_policies]{get_resource_policies} \tab Retrieves the resource policies attached to the specified response plan\cr
#'  \link[paws.management:ssmincidents_get_response_plan]{get_response_plan} \tab Retrieves the details of the specified response plan\cr
#'  \link[paws.management:ssmincidents_get_timeline_event]{get_timeline_event} \tab Retrieves a timeline event based on its ID and incident record\cr
#'  \link[paws.management:ssmincidents_list_incident_findings]{list_incident_findings} \tab Retrieves a list of the IDs of findings, plus their last modified times, that have been identified for a specified incident\cr
#'  \link[paws.management:ssmincidents_list_incident_records]{list_incident_records} \tab Lists all incident records in your account\cr
#'  \link[paws.management:ssmincidents_list_related_items]{list_related_items} \tab List all related items for an incident record\cr
#'  \link[paws.management:ssmincidents_list_replication_sets]{list_replication_sets} \tab Lists details about the replication set configured in your account\cr
#'  \link[paws.management:ssmincidents_list_response_plans]{list_response_plans} \tab Lists all response plans in your account\cr
#'  \link[paws.management:ssmincidents_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that are attached to the specified response plan or incident\cr
#'  \link[paws.management:ssmincidents_list_timeline_events]{list_timeline_events} \tab Lists timeline events for the specified incident record\cr
#'  \link[paws.management:ssmincidents_put_resource_policy]{put_resource_policy} \tab Adds a resource policy to the specified response plan\cr
#'  \link[paws.management:ssmincidents_start_incident]{start_incident} \tab Used to start an incident from CloudWatch alarms, EventBridge events, or manually\cr
#'  \link[paws.management:ssmincidents_tag_resource]{tag_resource} \tab Adds a tag to a response plan\cr
#'  \link[paws.management:ssmincidents_untag_resource]{untag_resource} \tab Removes a tag from a resource\cr
#'  \link[paws.management:ssmincidents_update_deletion_protection]{update_deletion_protection} \tab Update deletion protection to either allow or deny deletion of the final Region in a replication set\cr
#'  \link[paws.management:ssmincidents_update_incident_record]{update_incident_record} \tab Update the details of an incident record\cr
#'  \link[paws.management:ssmincidents_update_related_items]{update_related_items} \tab Add or remove related items from the related items tab of an incident record\cr
#'  \link[paws.management:ssmincidents_update_replication_set]{update_replication_set} \tab Add or delete Regions from your replication set\cr
#'  \link[paws.management:ssmincidents_update_response_plan]{update_response_plan} \tab Updates the specified response plan\cr
#'  \link[paws.management:ssmincidents_update_timeline_event]{update_timeline_event} \tab Updates a timeline event
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ssmincidents
#' @export
ssmincidents <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::ssmincidents(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Systems Manager for SAP
#'
#' @description
#' This API reference provides descriptions, syntax, and other details
#' about each of the actions and data types for AWS Systems Manager for
#' SAP. The topic for each action shows the API request parameters and
#' responses.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ssmsap(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ssmsap()
#' svc$delete_resource_permission(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:ssmsap_delete_resource_permission]{delete_resource_permission} \tab Removes permissions associated with the target database\cr
#'  \link[paws.management:ssmsap_deregister_application]{deregister_application} \tab Deregister an SAP application with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_get_application]{get_application} \tab Gets an application registered with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_get_component]{get_component} \tab Gets the component of an application registered with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_get_database]{get_database} \tab Gets the SAP HANA database of an application registered with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_get_operation]{get_operation} \tab Gets the details of an operation by specifying the operation ID\cr
#'  \link[paws.management:ssmsap_get_resource_permission]{get_resource_permission} \tab Gets permissions associated with the target database\cr
#'  \link[paws.management:ssmsap_list_applications]{list_applications} \tab Lists all the applications registered with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_list_components]{list_components} \tab Lists all the components registered with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_list_databases]{list_databases} \tab Lists the SAP HANA databases of an application registered with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_list_operation_events]{list_operation_events} \tab Returns a list of operations events\cr
#'  \link[paws.management:ssmsap_list_operations]{list_operations} \tab Lists the operations performed by AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags on an SAP HANA application and/or database registered with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_put_resource_permission]{put_resource_permission} \tab Adds permissions to the target database\cr
#'  \link[paws.management:ssmsap_register_application]{register_application} \tab Register an SAP application with AWS Systems Manager for SAP\cr
#'  \link[paws.management:ssmsap_start_application]{start_application} \tab Request is an operation which starts an application\cr
#'  \link[paws.management:ssmsap_start_application_refresh]{start_application_refresh} \tab Refreshes a registered application\cr
#'  \link[paws.management:ssmsap_stop_application]{stop_application} \tab Request is an operation to stop an application\cr
#'  \link[paws.management:ssmsap_tag_resource]{tag_resource} \tab Creates tag for a resource by specifying the ARN\cr
#'  \link[paws.management:ssmsap_untag_resource]{untag_resource} \tab Delete the tags for a resource\cr
#'  \link[paws.management:ssmsap_update_application_settings]{update_application_settings} \tab Updates the settings of an application registered with AWS Systems Manager for SAP
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ssmsap
#' @export
ssmsap <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::ssmsap(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Support
#'
#' @description
#' Amazon Web Services Support
#' 
#' The *Amazon Web Services Support API Reference* is intended for
#' programmers who need detailed information about the Amazon Web Services
#' Support operations and data types. You can use the API to manage your
#' support cases programmatically. The Amazon Web Services Support API uses
#' HTTP methods that return results in JSON format.
#' 
#' -   You must have a Business, Enterprise On-Ramp, or Enterprise Support
#'     plan to use the Amazon Web Services Support API.
#' 
#' -   If you call the Amazon Web Services Support API from an account that
#'     doesn't have a Business, Enterprise On-Ramp, or Enterprise Support
#'     plan, the `SubscriptionRequiredException` error message appears. For
#'     information about changing your support plan, see [Amazon Web
#'     Services Support](https://aws.amazon.com/premiumsupport/).
#' 
#' You can also use the Amazon Web Services Support API to access features
#' for [Trusted
#' Advisor](https://aws.amazon.com/premiumsupport/technology/trusted-advisor/).
#' You can return a list of checks and their descriptions, get check
#' results, specify checks to refresh, and get the refresh status of
#' checks.
#' 
#' You can manage your support cases with the following Amazon Web Services
#' Support API operations:
#' 
#' -   The `create_case`,
#'     `describe_cases`,
#'     `describe_attachment`, and
#'     `resolve_case` operations create Amazon Web
#'     Services Support cases, retrieve information about cases, and
#'     resolve cases.
#' 
#' -   The `describe_communications`,
#'     `add_communication_to_case`,
#'     and `add_attachments_to_set`
#'     operations retrieve and add communications and attachments to Amazon
#'     Web Services Support cases.
#' 
#' -   The `describe_services` and
#'     `describe_severity_levels`
#'     operations return Amazon Web Service names, service codes, service
#'     categories, and problem severity levels. You use these values when
#'     you call the `create_case` operation.
#' 
#' You can also use the Amazon Web Services Support API to call the Trusted
#' Advisor operations. For more information, see [Trusted
#' Advisor](https://docs.aws.amazon.com/awssupport/latest/user/trusted-advisor.html)
#' in the *Amazon Web Services Support User Guide*.
#' 
#' For authentication of requests, Amazon Web Services Support uses
#' [Signature Version 4 Signing
#' Process](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html).
#' 
#' For more information about this service and the endpoints to use, see
#' [About the Amazon Web Services Support
#' API](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html)
#' in the *Amazon Web Services Support User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- support(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- support()
#' svc$add_attachments_to_set(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:support_add_attachments_to_set]{add_attachments_to_set} \tab Adds one or more attachments to an attachment set\cr
#'  \link[paws.management:support_add_communication_to_case]{add_communication_to_case} \tab Adds additional customer communication to an Amazon Web Services Support case\cr
#'  \link[paws.management:support_create_case]{create_case} \tab Creates a case in the Amazon Web Services Support Center\cr
#'  \link[paws.management:support_describe_attachment]{describe_attachment} \tab Returns the attachment that has the specified ID\cr
#'  \link[paws.management:support_describe_cases]{describe_cases} \tab Returns a list of cases that you specify by passing one or more case IDs\cr
#'  \link[paws.management:support_describe_communications]{describe_communications} \tab Returns communications and attachments for one or more support cases\cr
#'  \link[paws.management:support_describe_create_case_options]{describe_create_case_options} \tab Returns a list of CreateCaseOption types along with the corresponding supported hours and language availability\cr
#'  \link[paws.management:support_describe_services]{describe_services} \tab Returns the current list of Amazon Web Services services and a list of service categories for each service\cr
#'  \link[paws.management:support_describe_severity_levels]{describe_severity_levels} \tab Returns the list of severity levels that you can assign to a support case\cr
#'  \link[paws.management:support_describe_supported_languages]{describe_supported_languages} \tab Returns a list of supported languages for a specified categoryCode, issueType and serviceCode\cr
#'  \link[paws.management:support_describe_trusted_advisor_check_refresh_statuses]{describe_trusted_advisor_check_refresh_statuses} \tab Returns the refresh status of the Trusted Advisor checks that have the specified check IDs\cr
#'  \link[paws.management:support_describe_trusted_advisor_check_result]{describe_trusted_advisor_check_result} \tab Returns the results of the Trusted Advisor check that has the specified check ID\cr
#'  \link[paws.management:support_describe_trusted_advisor_checks]{describe_trusted_advisor_checks} \tab Returns information about all available Trusted Advisor checks, including the name, ID, category, description, and metadata\cr
#'  \link[paws.management:support_describe_trusted_advisor_check_summaries]{describe_trusted_advisor_check_summaries} \tab Returns the results for the Trusted Advisor check summaries for the check IDs that you specified\cr
#'  \link[paws.management:support_refresh_trusted_advisor_check]{refresh_trusted_advisor_check} \tab Refreshes the Trusted Advisor check that you specify using the check ID\cr
#'  \link[paws.management:support_resolve_case]{resolve_case} \tab Resolves a support case
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname support
#' @export
support <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::support(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Support App
#'
#' @description
#' Amazon Web Services Support App in Slack
#' 
#' You can use the Amazon Web Services Support App in Slack API to manage
#' your support cases in Slack for your Amazon Web Services account. After
#' you configure your Slack workspace and channel with the Amazon Web
#' Services Support App, you can perform the following tasks directly in
#' your Slack channel:
#' 
#' -   Create, search, update, and resolve your support cases
#' 
#' -   Request service quota increases for your account
#' 
#' -   Invite Amazon Web Services Support agents to your channel so that
#'     you can chat directly about your support cases
#' 
#' For more information about how to perform these actions in Slack, see
#' the following documentation in the *Amazon Web Services Support User
#' Guide*:
#' 
#' -   [Amazon Web Services Support App in
#'     Slack](https://docs.aws.amazon.com/awssupport/latest/user/aws-support-app-for-slack.html)
#' 
#' -   [Joining a live chat session with Amazon Web Services
#'     Support](https://docs.aws.amazon.com/awssupport/latest/user/joining-a-live-chat-session.html)
#' 
#' -   [Requesting service quota
#'     increases](https://docs.aws.amazon.com/awssupport/latest/user/service-quota-increase.html)
#' 
#' -   [Amazon Web Services Support App commands in
#'     Slack](https://docs.aws.amazon.com/awssupport/latest/user/support-app-commands.html)
#' 
#' You can also use the Amazon Web Services Management Console instead of
#' the Amazon Web Services Support App API to manage your Slack
#' configurations. For more information, see [Authorize a Slack workspace
#' to enable the Amazon Web Services Support
#' App](https://docs.aws.amazon.com/awssupport/latest/user/authorize-slack-workspace.html).
#' 
#' -   You must have a Business or Enterprise Support plan to use the
#'     Amazon Web Services Support App API.
#' 
#' -   For more information about the Amazon Web Services Support App
#'     endpoints, see the [Amazon Web Services Support App in Slack
#'     endpoints](https://docs.aws.amazon.com/general/latest/gr/awssupport.html#awssupport_app_region)
#'     in the *Amazon Web Services General Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- supportapp(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- supportapp()
#' svc$create_slack_channel_configuration(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:supportapp_create_slack_channel_configuration]{create_slack_channel_configuration} \tab Creates a Slack channel configuration for your Amazon Web Services account\cr
#'  \link[paws.management:supportapp_delete_account_alias]{delete_account_alias} \tab Deletes an alias for an Amazon Web Services account ID\cr
#'  \link[paws.management:supportapp_delete_slack_channel_configuration]{delete_slack_channel_configuration} \tab Deletes a Slack channel configuration from your Amazon Web Services account\cr
#'  \link[paws.management:supportapp_delete_slack_workspace_configuration]{delete_slack_workspace_configuration} \tab Deletes a Slack workspace configuration from your Amazon Web Services account\cr
#'  \link[paws.management:supportapp_get_account_alias]{get_account_alias} \tab Retrieves the alias from an Amazon Web Services account ID\cr
#'  \link[paws.management:supportapp_list_slack_channel_configurations]{list_slack_channel_configurations} \tab Lists the Slack channel configurations for an Amazon Web Services account\cr
#'  \link[paws.management:supportapp_list_slack_workspace_configurations]{list_slack_workspace_configurations} \tab Lists the Slack workspace configurations for an Amazon Web Services account\cr
#'  \link[paws.management:supportapp_put_account_alias]{put_account_alias} \tab Creates or updates an individual alias for each Amazon Web Services account ID\cr
#'  \link[paws.management:supportapp_register_slack_workspace_for_organization]{register_slack_workspace_for_organization} \tab Registers a Slack workspace for your Amazon Web Services account\cr
#'  \link[paws.management:supportapp_update_slack_channel_configuration]{update_slack_channel_configuration} \tab Updates the configuration for a Slack channel, such as case update notifications
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname supportapp
#' @export
supportapp <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::supportapp(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Synthetics
#'
#' @description
#' Amazon CloudWatch Synthetics
#' 
#' You can use Amazon CloudWatch Synthetics to continually monitor your
#' services. You can create and manage *canaries*, which are modular,
#' lightweight scripts that monitor your endpoints and APIs from the
#' outside-in. You can set up your canaries to run 24 hours a day, once per
#' minute. The canaries help you check the availability and latency of your
#' web services and troubleshoot anomalies by investigating load time data,
#' screenshots of the UI, logs, and metrics. The canaries seamlessly
#' integrate with CloudWatch ServiceLens to help you trace the causes of
#' impacted nodes in your applications. For more information, see [Using
#' ServiceLens to Monitor the Health of Your
#' Applications](https://docs.aws.amazon.com/xray/latest/devguide/xray-console-servicemap.html)
#' in the *Amazon CloudWatch User Guide*.
#' 
#' Before you create and manage canaries, be aware of the security
#' considerations. For more information, see [Security Considerations for
#' Synthetics
#' Canaries](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/servicelens_canaries_security.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- synthetics(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- synthetics()
#' svc$associate_resource(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.management:synthetics_associate_resource]{associate_resource} \tab Associates a canary with a group\cr
#'  \link[paws.management:synthetics_create_canary]{create_canary} \tab Creates a canary\cr
#'  \link[paws.management:synthetics_create_group]{create_group} \tab Creates a group which you can use to associate canaries with each other, including cross-Region canaries\cr
#'  \link[paws.management:synthetics_delete_canary]{delete_canary} \tab Permanently deletes the specified canary\cr
#'  \link[paws.management:synthetics_delete_group]{delete_group} \tab Deletes a group\cr
#'  \link[paws.management:synthetics_describe_canaries]{describe_canaries} \tab This operation returns a list of the canaries in your account, along with full details about each canary\cr
#'  \link[paws.management:synthetics_describe_canaries_last_run]{describe_canaries_last_run} \tab Use this operation to see information from the most recent run of each canary that you have created\cr
#'  \link[paws.management:synthetics_describe_runtime_versions]{describe_runtime_versions} \tab Returns a list of Synthetics canary runtime versions\cr
#'  \link[paws.management:synthetics_disassociate_resource]{disassociate_resource} \tab Removes a canary from a group\cr
#'  \link[paws.management:synthetics_get_canary]{get_canary} \tab Retrieves complete information about one canary\cr
#'  \link[paws.management:synthetics_get_canary_runs]{get_canary_runs} \tab Retrieves a list of runs for a specified canary\cr
#'  \link[paws.management:synthetics_get_group]{get_group} \tab Returns information about one group\cr
#'  \link[paws.management:synthetics_list_associated_groups]{list_associated_groups} \tab Returns a list of the groups that the specified canary is associated with\cr
#'  \link[paws.management:synthetics_list_group_resources]{list_group_resources} \tab This operation returns a list of the ARNs of the canaries that are associated with the specified group\cr
#'  \link[paws.management:synthetics_list_groups]{list_groups} \tab Returns a list of all groups in the account, displaying their names, unique IDs, and ARNs\cr
#'  \link[paws.management:synthetics_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with a canary or group\cr
#'  \link[paws.management:synthetics_start_canary]{start_canary} \tab Use this operation to run a canary that has already been created\cr
#'  \link[paws.management:synthetics_stop_canary]{stop_canary} \tab Stops the canary to prevent all future runs\cr
#'  \link[paws.management:synthetics_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified canary or group\cr
#'  \link[paws.management:synthetics_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.management:synthetics_update_canary]{update_canary} \tab Updates the configuration of a canary that has already been created
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname synthetics
#' @export
synthetics <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.management::synthetics(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Comprehend
#'
#' @description
#' Amazon Comprehend is an Amazon Web Services service for gaining insight
#' into the content of documents. Use these actions to determine the topics
#' contained in your documents, the topics they discuss, the predominant
#' sentiment expressed in them, the predominant language used, and more.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- comprehend(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- comprehend()
#' svc$batch_detect_dominant_language(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:comprehend_batch_detect_dominant_language]{batch_detect_dominant_language} \tab Determines the dominant language of the input text for a batch of documents\cr
#'  \link[paws.machine.learning:comprehend_batch_detect_entities]{batch_detect_entities} \tab Inspects the text of a batch of documents for named entities and returns information about them\cr
#'  \link[paws.machine.learning:comprehend_batch_detect_key_phrases]{batch_detect_key_phrases} \tab Detects the key noun phrases found in a batch of documents\cr
#'  \link[paws.machine.learning:comprehend_batch_detect_sentiment]{batch_detect_sentiment} \tab Inspects a batch of documents and returns an inference of the prevailing sentiment, POSITIVE, NEUTRAL, MIXED, or NEGATIVE, in each one\cr
#'  \link[paws.machine.learning:comprehend_batch_detect_syntax]{batch_detect_syntax} \tab Inspects the text of a batch of documents for the syntax and part of speech of the words in the document and returns information about them\cr
#'  \link[paws.machine.learning:comprehend_batch_detect_targeted_sentiment]{batch_detect_targeted_sentiment} \tab Inspects a batch of documents and returns a sentiment analysis for each entity identified in the documents\cr
#'  \link[paws.machine.learning:comprehend_classify_document]{classify_document} \tab Creates a classification request to analyze a single document in real-time\cr
#'  \link[paws.machine.learning:comprehend_contains_pii_entities]{contains_pii_entities} \tab Analyzes input text for the presence of personally identifiable information (PII) and returns the labels of identified PII entity types such as name, address, bank account number, or phone number\cr
#'  \link[paws.machine.learning:comprehend_create_dataset]{create_dataset} \tab Creates a dataset to upload training or test data for a model associated with a flywheel\cr
#'  \link[paws.machine.learning:comprehend_create_document_classifier]{create_document_classifier} \tab Creates a new document classifier that you can use to categorize documents\cr
#'  \link[paws.machine.learning:comprehend_create_endpoint]{create_endpoint} \tab Creates a model-specific endpoint for synchronous inference for a previously trained custom model For information about endpoints, see Managing endpoints\cr
#'  \link[paws.machine.learning:comprehend_create_entity_recognizer]{create_entity_recognizer} \tab Creates an entity recognizer using submitted files\cr
#'  \link[paws.machine.learning:comprehend_create_flywheel]{create_flywheel} \tab A flywheel is an Amazon Web Services resource that orchestrates the ongoing training of a model for custom classification or custom entity recognition\cr
#'  \link[paws.machine.learning:comprehend_delete_document_classifier]{delete_document_classifier} \tab Deletes a previously created document classifier\cr
#'  \link[paws.machine.learning:comprehend_delete_endpoint]{delete_endpoint} \tab Deletes a model-specific endpoint for a previously-trained custom model\cr
#'  \link[paws.machine.learning:comprehend_delete_entity_recognizer]{delete_entity_recognizer} \tab Deletes an entity recognizer\cr
#'  \link[paws.machine.learning:comprehend_delete_flywheel]{delete_flywheel} \tab Deletes a flywheel\cr
#'  \link[paws.machine.learning:comprehend_delete_resource_policy]{delete_resource_policy} \tab Deletes a resource-based policy that is attached to a custom model\cr
#'  \link[paws.machine.learning:comprehend_describe_dataset]{describe_dataset} \tab Returns information about the dataset that you specify\cr
#'  \link[paws.machine.learning:comprehend_describe_document_classification_job]{describe_document_classification_job} \tab Gets the properties associated with a document classification job\cr
#'  \link[paws.machine.learning:comprehend_describe_document_classifier]{describe_document_classifier} \tab Gets the properties associated with a document classifier\cr
#'  \link[paws.machine.learning:comprehend_describe_dominant_language_detection_job]{describe_dominant_language_detection_job} \tab Gets the properties associated with a dominant language detection job\cr
#'  \link[paws.machine.learning:comprehend_describe_endpoint]{describe_endpoint} \tab Gets the properties associated with a specific endpoint\cr
#'  \link[paws.machine.learning:comprehend_describe_entities_detection_job]{describe_entities_detection_job} \tab Gets the properties associated with an entities detection job\cr
#'  \link[paws.machine.learning:comprehend_describe_entity_recognizer]{describe_entity_recognizer} \tab Provides details about an entity recognizer including status, S3 buckets containing training data, recognizer metadata, metrics, and so on\cr
#'  \link[paws.machine.learning:comprehend_describe_events_detection_job]{describe_events_detection_job} \tab Gets the status and details of an events detection job\cr
#'  \link[paws.machine.learning:comprehend_describe_flywheel]{describe_flywheel} \tab Provides configuration information about the flywheel\cr
#'  \link[paws.machine.learning:comprehend_describe_flywheel_iteration]{describe_flywheel_iteration} \tab Retrieve the configuration properties of a flywheel iteration\cr
#'  \link[paws.machine.learning:comprehend_describe_key_phrases_detection_job]{describe_key_phrases_detection_job} \tab Gets the properties associated with a key phrases detection job\cr
#'  \link[paws.machine.learning:comprehend_describe_pii_entities_detection_job]{describe_pii_entities_detection_job} \tab Gets the properties associated with a PII entities detection job\cr
#'  \link[paws.machine.learning:comprehend_describe_resource_policy]{describe_resource_policy} \tab Gets the details of a resource-based policy that is attached to a custom model, including the JSON body of the policy\cr
#'  \link[paws.machine.learning:comprehend_describe_sentiment_detection_job]{describe_sentiment_detection_job} \tab Gets the properties associated with a sentiment detection job\cr
#'  \link[paws.machine.learning:comprehend_describe_targeted_sentiment_detection_job]{describe_targeted_sentiment_detection_job} \tab Gets the properties associated with a targeted sentiment detection job\cr
#'  \link[paws.machine.learning:comprehend_describe_topics_detection_job]{describe_topics_detection_job} \tab Gets the properties associated with a topic detection job\cr
#'  \link[paws.machine.learning:comprehend_detect_dominant_language]{detect_dominant_language} \tab Determines the dominant language of the input text\cr
#'  \link[paws.machine.learning:comprehend_detect_entities]{detect_entities} \tab Detects named entities in input text when you use the pre-trained model\cr
#'  \link[paws.machine.learning:comprehend_detect_key_phrases]{detect_key_phrases} \tab Detects the key noun phrases found in the text\cr
#'  \link[paws.machine.learning:comprehend_detect_pii_entities]{detect_pii_entities} \tab Inspects the input text for entities that contain personally identifiable information (PII) and returns information about them\cr
#'  \link[paws.machine.learning:comprehend_detect_sentiment]{detect_sentiment} \tab Inspects text and returns an inference of the prevailing sentiment (POSITIVE, NEUTRAL, MIXED, or NEGATIVE)\cr
#'  \link[paws.machine.learning:comprehend_detect_syntax]{detect_syntax} \tab Inspects text for syntax and the part of speech of words in the document\cr
#'  \link[paws.machine.learning:comprehend_detect_targeted_sentiment]{detect_targeted_sentiment} \tab Inspects the input text and returns a sentiment analysis for each entity identified in the text\cr
#'  \link[paws.machine.learning:comprehend_detect_toxic_content]{detect_toxic_content} \tab Performs toxicity analysis on the list of text strings that you provide as input\cr
#'  \link[paws.machine.learning:comprehend_import_model]{import_model} \tab Creates a new custom model that replicates a source custom model that you import\cr
#'  \link[paws.machine.learning:comprehend_list_datasets]{list_datasets} \tab List the datasets that you have configured in this Region\cr
#'  \link[paws.machine.learning:comprehend_list_document_classification_jobs]{list_document_classification_jobs} \tab Gets a list of the documentation classification jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_list_document_classifiers]{list_document_classifiers} \tab Gets a list of the document classifiers that you have created\cr
#'  \link[paws.machine.learning:comprehend_list_document_classifier_summaries]{list_document_classifier_summaries} \tab Gets a list of summaries of the document classifiers that you have created\cr
#'  \link[paws.machine.learning:comprehend_list_dominant_language_detection_jobs]{list_dominant_language_detection_jobs} \tab Gets a list of the dominant language detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_list_endpoints]{list_endpoints} \tab Gets a list of all existing endpoints that you've created\cr
#'  \link[paws.machine.learning:comprehend_list_entities_detection_jobs]{list_entities_detection_jobs} \tab Gets a list of the entity detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_list_entity_recognizers]{list_entity_recognizers} \tab Gets a list of the properties of all entity recognizers that you created, including recognizers currently in training\cr
#'  \link[paws.machine.learning:comprehend_list_entity_recognizer_summaries]{list_entity_recognizer_summaries} \tab Gets a list of summaries for the entity recognizers that you have created\cr
#'  \link[paws.machine.learning:comprehend_list_events_detection_jobs]{list_events_detection_jobs} \tab Gets a list of the events detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_list_flywheel_iteration_history]{list_flywheel_iteration_history} \tab Information about the history of a flywheel iteration\cr
#'  \link[paws.machine.learning:comprehend_list_flywheels]{list_flywheels} \tab Gets a list of the flywheels that you have created\cr
#'  \link[paws.machine.learning:comprehend_list_key_phrases_detection_jobs]{list_key_phrases_detection_jobs} \tab Get a list of key phrase detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_list_pii_entities_detection_jobs]{list_pii_entities_detection_jobs} \tab Gets a list of the PII entity detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_list_sentiment_detection_jobs]{list_sentiment_detection_jobs} \tab Gets a list of sentiment detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags associated with a given Amazon Comprehend resource\cr
#'  \link[paws.machine.learning:comprehend_list_targeted_sentiment_detection_jobs]{list_targeted_sentiment_detection_jobs} \tab Gets a list of targeted sentiment detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_list_topics_detection_jobs]{list_topics_detection_jobs} \tab Gets a list of the topic detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehend_put_resource_policy]{put_resource_policy} \tab Attaches a resource-based policy to a custom model\cr
#'  \link[paws.machine.learning:comprehend_start_document_classification_job]{start_document_classification_job} \tab Starts an asynchronous document classification job using a custom classification model\cr
#'  \link[paws.machine.learning:comprehend_start_dominant_language_detection_job]{start_dominant_language_detection_job} \tab Starts an asynchronous dominant language detection job for a collection of documents\cr
#'  \link[paws.machine.learning:comprehend_start_entities_detection_job]{start_entities_detection_job} \tab Starts an asynchronous entity detection job for a collection of documents\cr
#'  \link[paws.machine.learning:comprehend_start_events_detection_job]{start_events_detection_job} \tab Starts an asynchronous event detection job for a collection of documents\cr
#'  \link[paws.machine.learning:comprehend_start_flywheel_iteration]{start_flywheel_iteration} \tab Start the flywheel iteration\cr
#'  \link[paws.machine.learning:comprehend_start_key_phrases_detection_job]{start_key_phrases_detection_job} \tab Starts an asynchronous key phrase detection job for a collection of documents\cr
#'  \link[paws.machine.learning:comprehend_start_pii_entities_detection_job]{start_pii_entities_detection_job} \tab Starts an asynchronous PII entity detection job for a collection of documents\cr
#'  \link[paws.machine.learning:comprehend_start_sentiment_detection_job]{start_sentiment_detection_job} \tab Starts an asynchronous sentiment detection job for a collection of documents\cr
#'  \link[paws.machine.learning:comprehend_start_targeted_sentiment_detection_job]{start_targeted_sentiment_detection_job} \tab Starts an asynchronous targeted sentiment detection job for a collection of documents\cr
#'  \link[paws.machine.learning:comprehend_start_topics_detection_job]{start_topics_detection_job} \tab Starts an asynchronous topic detection job\cr
#'  \link[paws.machine.learning:comprehend_stop_dominant_language_detection_job]{stop_dominant_language_detection_job} \tab Stops a dominant language detection job in progress\cr
#'  \link[paws.machine.learning:comprehend_stop_entities_detection_job]{stop_entities_detection_job} \tab Stops an entities detection job in progress\cr
#'  \link[paws.machine.learning:comprehend_stop_events_detection_job]{stop_events_detection_job} \tab Stops an events detection job in progress\cr
#'  \link[paws.machine.learning:comprehend_stop_key_phrases_detection_job]{stop_key_phrases_detection_job} \tab Stops a key phrases detection job in progress\cr
#'  \link[paws.machine.learning:comprehend_stop_pii_entities_detection_job]{stop_pii_entities_detection_job} \tab Stops a PII entities detection job in progress\cr
#'  \link[paws.machine.learning:comprehend_stop_sentiment_detection_job]{stop_sentiment_detection_job} \tab Stops a sentiment detection job in progress\cr
#'  \link[paws.machine.learning:comprehend_stop_targeted_sentiment_detection_job]{stop_targeted_sentiment_detection_job} \tab Stops a targeted sentiment detection job in progress\cr
#'  \link[paws.machine.learning:comprehend_stop_training_document_classifier]{stop_training_document_classifier} \tab Stops a document classifier training job while in progress\cr
#'  \link[paws.machine.learning:comprehend_stop_training_entity_recognizer]{stop_training_entity_recognizer} \tab Stops an entity recognizer training job while in progress\cr
#'  \link[paws.machine.learning:comprehend_tag_resource]{tag_resource} \tab Associates a specific tag with an Amazon Comprehend resource\cr
#'  \link[paws.machine.learning:comprehend_untag_resource]{untag_resource} \tab Removes a specific tag associated with an Amazon Comprehend resource\cr
#'  \link[paws.machine.learning:comprehend_update_endpoint]{update_endpoint} \tab Updates information about the specified endpoint\cr
#'  \link[paws.machine.learning:comprehend_update_flywheel]{update_flywheel} \tab Update the configuration information for an existing flywheel
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname comprehend
#' @export
comprehend <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::comprehend(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Comprehend Medical
#'
#' @description
#' Amazon Comprehend Medical extracts structured information from
#' unstructured clinical text. Use these actions to gain insight in your
#' documents. Amazon Comprehend Medical only detects entities in English
#' language texts. Amazon Comprehend Medical places limits on the sizes of
#' files allowed for different API operations. To learn more, see
#' [Guidelines and
#' quotas](https://docs.aws.amazon.com/comprehend-medical/latest/dev/comprehendmedical-quotas.html)
#' in the *Amazon Comprehend Medical Developer Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- comprehendmedical(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- comprehendmedical()
#' svc$describe_entities_detection_v2_job(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:comprehendmedical_describe_entities_detection_v2_job]{describe_entities_detection_v2_job} \tab Gets the properties associated with a medical entities detection job\cr
#'  \link[paws.machine.learning:comprehendmedical_describe_icd10cm_inference_job]{describe_icd10cm_inference_job} \tab Gets the properties associated with an InferICD10CM job\cr
#'  \link[paws.machine.learning:comprehendmedical_describe_phi_detection_job]{describe_phi_detection_job} \tab Gets the properties associated with a protected health information (PHI) detection job\cr
#'  \link[paws.machine.learning:comprehendmedical_describe_rx_norm_inference_job]{describe_rx_norm_inference_job} \tab Gets the properties associated with an InferRxNorm job\cr
#'  \link[paws.machine.learning:comprehendmedical_describe_snomedct_inference_job]{describe_snomedct_inference_job} \tab Gets the properties associated with an InferSNOMEDCT job\cr
#'  \link[paws.machine.learning:comprehendmedical_detect_entities]{detect_entities} \tab The DetectEntities operation is deprecated\cr
#'  \link[paws.machine.learning:comprehendmedical_detect_entities_v2]{detect_entities_v2} \tab Inspects the clinical text for a variety of medical entities and returns specific information about them such as entity category, location, and confidence score on that information\cr
#'  \link[paws.machine.learning:comprehendmedical_detect_phi]{detect_phi} \tab Inspects the clinical text for protected health information (PHI) entities and returns the entity category, location, and confidence score for each entity\cr
#'  \link[paws.machine.learning:comprehendmedical_infer_icd10cm]{infer_icd10cm} \tab InferICD10CM detects medical conditions as entities listed in a patient record and links those entities to normalized concept identifiers in the ICD-10-CM knowledge base from the Centers for Disease Control\cr
#'  \link[paws.machine.learning:comprehendmedical_infer_rx_norm]{infer_rx_norm} \tab InferRxNorm detects medications as entities listed in a patient record and links to the normalized concept identifiers in the RxNorm database from the National Library of Medicine\cr
#'  \link[paws.machine.learning:comprehendmedical_infer_snomedct]{infer_snomedct} \tab InferSNOMEDCT detects possible medical concepts as entities and links them to codes from the Systematized Nomenclature of Medicine, Clinical Terms (SNOMED-CT) ontology\cr
#'  \link[paws.machine.learning:comprehendmedical_list_entities_detection_v2_jobs]{list_entities_detection_v2_jobs} \tab Gets a list of medical entity detection jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehendmedical_list_icd10cm_inference_jobs]{list_icd10cm_inference_jobs} \tab Gets a list of InferICD10CM jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehendmedical_list_phi_detection_jobs]{list_phi_detection_jobs} \tab Gets a list of protected health information (PHI) detection jobs you have submitted\cr
#'  \link[paws.machine.learning:comprehendmedical_list_rx_norm_inference_jobs]{list_rx_norm_inference_jobs} \tab Gets a list of InferRxNorm jobs that you have submitted\cr
#'  \link[paws.machine.learning:comprehendmedical_list_snomedct_inference_jobs]{list_snomedct_inference_jobs} \tab Gets a list of InferSNOMEDCT jobs a user has submitted\cr
#'  \link[paws.machine.learning:comprehendmedical_start_entities_detection_v2_job]{start_entities_detection_v2_job} \tab Starts an asynchronous medical entity detection job for a collection of documents\cr
#'  \link[paws.machine.learning:comprehendmedical_start_icd10cm_inference_job]{start_icd10cm_inference_job} \tab Starts an asynchronous job to detect medical conditions and link them to the ICD-10-CM ontology\cr
#'  \link[paws.machine.learning:comprehendmedical_start_phi_detection_job]{start_phi_detection_job} \tab Starts an asynchronous job to detect protected health information (PHI)\cr
#'  \link[paws.machine.learning:comprehendmedical_start_rx_norm_inference_job]{start_rx_norm_inference_job} \tab Starts an asynchronous job to detect medication entities and link them to the RxNorm ontology\cr
#'  \link[paws.machine.learning:comprehendmedical_start_snomedct_inference_job]{start_snomedct_inference_job} \tab Starts an asynchronous job to detect medical concepts and link them to the SNOMED-CT ontology\cr
#'  \link[paws.machine.learning:comprehendmedical_stop_entities_detection_v2_job]{stop_entities_detection_v2_job} \tab Stops a medical entities detection job in progress\cr
#'  \link[paws.machine.learning:comprehendmedical_stop_icd10cm_inference_job]{stop_icd10cm_inference_job} \tab Stops an InferICD10CM inference job in progress\cr
#'  \link[paws.machine.learning:comprehendmedical_stop_phi_detection_job]{stop_phi_detection_job} \tab Stops a protected health information (PHI) detection job in progress\cr
#'  \link[paws.machine.learning:comprehendmedical_stop_rx_norm_inference_job]{stop_rx_norm_inference_job} \tab Stops an InferRxNorm inference job in progress\cr
#'  \link[paws.machine.learning:comprehendmedical_stop_snomedct_inference_job]{stop_snomedct_inference_job} \tab Stops an InferSNOMEDCT inference job in progress
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname comprehendmedical
#' @export
comprehendmedical <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::comprehendmedical(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Forecast Query Service
#'
#' @description
#' Provides APIs for creating and managing Amazon Forecast resources.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- forecastqueryservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- forecastqueryservice()
#' svc$query_forecast(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:forecastqueryservice_query_forecast]{query_forecast} \tab Retrieves a forecast for a single item, filtered by the supplied criteria\cr
#'  \link[paws.machine.learning:forecastqueryservice_query_what_if_forecast]{query_what_if_forecast} \tab Retrieves a what-if forecast
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname forecastqueryservice
#' @export
forecastqueryservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::forecastqueryservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Forecast Service
#'
#' @description
#' Provides APIs for creating and managing Amazon Forecast resources.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- forecastservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- forecastservice()
#' svc$create_auto_predictor(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:forecastservice_create_auto_predictor]{create_auto_predictor} \tab Creates an Amazon Forecast predictor\cr
#'  \link[paws.machine.learning:forecastservice_create_dataset]{create_dataset} \tab Creates an Amazon Forecast dataset\cr
#'  \link[paws.machine.learning:forecastservice_create_dataset_group]{create_dataset_group} \tab Creates a dataset group, which holds a collection of related datasets\cr
#'  \link[paws.machine.learning:forecastservice_create_dataset_import_job]{create_dataset_import_job} \tab Imports your training data to an Amazon Forecast dataset\cr
#'  \link[paws.machine.learning:forecastservice_create_explainability]{create_explainability} \tab Explainability is only available for Forecasts and Predictors generated from an AutoPredictor (CreateAutoPredictor)\cr
#'  \link[paws.machine.learning:forecastservice_create_explainability_export]{create_explainability_export} \tab Exports an Explainability resource created by the CreateExplainability operation\cr
#'  \link[paws.machine.learning:forecastservice_create_forecast]{create_forecast} \tab Creates a forecast for each item in the TARGET_TIME_SERIES dataset that was used to train the predictor\cr
#'  \link[paws.machine.learning:forecastservice_create_forecast_export_job]{create_forecast_export_job} \tab Exports a forecast created by the CreateForecast operation to your Amazon Simple Storage Service (Amazon S3) bucket\cr
#'  \link[paws.machine.learning:forecastservice_create_monitor]{create_monitor} \tab Creates a predictor monitor resource for an existing auto predictor\cr
#'  \link[paws.machine.learning:forecastservice_create_predictor]{create_predictor} \tab This operation creates a legacy predictor that does not include all the predictor functionalities provided by Amazon Forecast\cr
#'  \link[paws.machine.learning:forecastservice_create_predictor_backtest_export_job]{create_predictor_backtest_export_job} \tab Exports backtest forecasts and accuracy metrics generated by the CreateAutoPredictor or CreatePredictor operations\cr
#'  \link[paws.machine.learning:forecastservice_create_what_if_analysis]{create_what_if_analysis} \tab What-if analysis is a scenario modeling technique where you make a hypothetical change to a time series and compare the forecasts generated by these changes against the baseline, unchanged time series\cr
#'  \link[paws.machine.learning:forecastservice_create_what_if_forecast]{create_what_if_forecast} \tab A what-if forecast is a forecast that is created from a modified version of the baseline forecast\cr
#'  \link[paws.machine.learning:forecastservice_create_what_if_forecast_export]{create_what_if_forecast_export} \tab Exports a forecast created by the CreateWhatIfForecast operation to your Amazon Simple Storage Service (Amazon S3) bucket\cr
#'  \link[paws.machine.learning:forecastservice_delete_dataset]{delete_dataset} \tab Deletes an Amazon Forecast dataset that was created using the CreateDataset operation\cr
#'  \link[paws.machine.learning:forecastservice_delete_dataset_group]{delete_dataset_group} \tab Deletes a dataset group created using the CreateDatasetGroup operation\cr
#'  \link[paws.machine.learning:forecastservice_delete_dataset_import_job]{delete_dataset_import_job} \tab Deletes a dataset import job created using the CreateDatasetImportJob operation\cr
#'  \link[paws.machine.learning:forecastservice_delete_explainability]{delete_explainability} \tab Deletes an Explainability resource\cr
#'  \link[paws.machine.learning:forecastservice_delete_explainability_export]{delete_explainability_export} \tab Deletes an Explainability export\cr
#'  \link[paws.machine.learning:forecastservice_delete_forecast]{delete_forecast} \tab Deletes a forecast created using the CreateForecast operation\cr
#'  \link[paws.machine.learning:forecastservice_delete_forecast_export_job]{delete_forecast_export_job} \tab Deletes a forecast export job created using the CreateForecastExportJob operation\cr
#'  \link[paws.machine.learning:forecastservice_delete_monitor]{delete_monitor} \tab Deletes a monitor resource\cr
#'  \link[paws.machine.learning:forecastservice_delete_predictor]{delete_predictor} \tab Deletes a predictor created using the DescribePredictor or CreatePredictor operations\cr
#'  \link[paws.machine.learning:forecastservice_delete_predictor_backtest_export_job]{delete_predictor_backtest_export_job} \tab Deletes a predictor backtest export job\cr
#'  \link[paws.machine.learning:forecastservice_delete_resource_tree]{delete_resource_tree} \tab Deletes an entire resource tree\cr
#'  \link[paws.machine.learning:forecastservice_delete_what_if_analysis]{delete_what_if_analysis} \tab Deletes a what-if analysis created using the CreateWhatIfAnalysis operation\cr
#'  \link[paws.machine.learning:forecastservice_delete_what_if_forecast]{delete_what_if_forecast} \tab Deletes a what-if forecast created using the CreateWhatIfForecast operation\cr
#'  \link[paws.machine.learning:forecastservice_delete_what_if_forecast_export]{delete_what_if_forecast_export} \tab Deletes a what-if forecast export created using the CreateWhatIfForecastExport operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_auto_predictor]{describe_auto_predictor} \tab Describes a predictor created using the CreateAutoPredictor operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_dataset]{describe_dataset} \tab Describes an Amazon Forecast dataset created using the CreateDataset operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_dataset_group]{describe_dataset_group} \tab Describes a dataset group created using the CreateDatasetGroup operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_dataset_import_job]{describe_dataset_import_job} \tab Describes a dataset import job created using the CreateDatasetImportJob operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_explainability]{describe_explainability} \tab Describes an Explainability resource created using the CreateExplainability operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_explainability_export]{describe_explainability_export} \tab Describes an Explainability export created using the CreateExplainabilityExport operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_forecast]{describe_forecast} \tab Describes a forecast created using the CreateForecast operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_forecast_export_job]{describe_forecast_export_job} \tab Describes a forecast export job created using the CreateForecastExportJob operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_monitor]{describe_monitor} \tab Describes a monitor resource\cr
#'  \link[paws.machine.learning:forecastservice_describe_predictor]{describe_predictor} \tab This operation is only valid for legacy predictors created with CreatePredictor\cr
#'  \link[paws.machine.learning:forecastservice_describe_predictor_backtest_export_job]{describe_predictor_backtest_export_job} \tab Describes a predictor backtest export job created using the CreatePredictorBacktestExportJob operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_what_if_analysis]{describe_what_if_analysis} \tab Describes the what-if analysis created using the CreateWhatIfAnalysis operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_what_if_forecast]{describe_what_if_forecast} \tab Describes the what-if forecast created using the CreateWhatIfForecast operation\cr
#'  \link[paws.machine.learning:forecastservice_describe_what_if_forecast_export]{describe_what_if_forecast_export} \tab Describes the what-if forecast export created using the CreateWhatIfForecastExport operation\cr
#'  \link[paws.machine.learning:forecastservice_get_accuracy_metrics]{get_accuracy_metrics} \tab Provides metrics on the accuracy of the models that were trained by the CreatePredictor operation\cr
#'  \link[paws.machine.learning:forecastservice_list_dataset_groups]{list_dataset_groups} \tab Returns a list of dataset groups created using the CreateDatasetGroup operation\cr
#'  \link[paws.machine.learning:forecastservice_list_dataset_import_jobs]{list_dataset_import_jobs} \tab Returns a list of dataset import jobs created using the CreateDatasetImportJob operation\cr
#'  \link[paws.machine.learning:forecastservice_list_datasets]{list_datasets} \tab Returns a list of datasets created using the CreateDataset operation\cr
#'  \link[paws.machine.learning:forecastservice_list_explainabilities]{list_explainabilities} \tab Returns a list of Explainability resources created using the CreateExplainability operation\cr
#'  \link[paws.machine.learning:forecastservice_list_explainability_exports]{list_explainability_exports} \tab Returns a list of Explainability exports created using the CreateExplainabilityExport operation\cr
#'  \link[paws.machine.learning:forecastservice_list_forecast_export_jobs]{list_forecast_export_jobs} \tab Returns a list of forecast export jobs created using the CreateForecastExportJob operation\cr
#'  \link[paws.machine.learning:forecastservice_list_forecasts]{list_forecasts} \tab Returns a list of forecasts created using the CreateForecast operation\cr
#'  \link[paws.machine.learning:forecastservice_list_monitor_evaluations]{list_monitor_evaluations} \tab Returns a list of the monitoring evaluation results and predictor events collected by the monitor resource during different windows of time\cr
#'  \link[paws.machine.learning:forecastservice_list_monitors]{list_monitors} \tab Returns a list of monitors created with the CreateMonitor operation and CreateAutoPredictor operation\cr
#'  \link[paws.machine.learning:forecastservice_list_predictor_backtest_export_jobs]{list_predictor_backtest_export_jobs} \tab Returns a list of predictor backtest export jobs created using the CreatePredictorBacktestExportJob operation\cr
#'  \link[paws.machine.learning:forecastservice_list_predictors]{list_predictors} \tab Returns a list of predictors created using the CreateAutoPredictor or CreatePredictor operations\cr
#'  \link[paws.machine.learning:forecastservice_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for an Amazon Forecast resource\cr
#'  \link[paws.machine.learning:forecastservice_list_what_if_analyses]{list_what_if_analyses} \tab Returns a list of what-if analyses created using the CreateWhatIfAnalysis operation\cr
#'  \link[paws.machine.learning:forecastservice_list_what_if_forecast_exports]{list_what_if_forecast_exports} \tab Returns a list of what-if forecast exports created using the CreateWhatIfForecastExport operation\cr
#'  \link[paws.machine.learning:forecastservice_list_what_if_forecasts]{list_what_if_forecasts} \tab Returns a list of what-if forecasts created using the CreateWhatIfForecast operation\cr
#'  \link[paws.machine.learning:forecastservice_resume_resource]{resume_resource} \tab Resumes a stopped monitor resource\cr
#'  \link[paws.machine.learning:forecastservice_stop_resource]{stop_resource} \tab Stops a resource\cr
#'  \link[paws.machine.learning:forecastservice_tag_resource]{tag_resource} \tab Associates the specified tags to a resource with the specified resourceArn\cr
#'  \link[paws.machine.learning:forecastservice_untag_resource]{untag_resource} \tab Deletes the specified tags from a resource\cr
#'  \link[paws.machine.learning:forecastservice_update_dataset_group]{update_dataset_group} \tab Replaces the datasets in a dataset group with the specified datasets
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname forecastservice
#' @export
forecastservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::forecastservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Fraud Detector
#'
#' @description
#' This is the Amazon Fraud Detector API Reference. This guide is for
#' developers who need detailed information about Amazon Fraud Detector API
#' actions, data types, and errors. For more information about Amazon Fraud
#' Detector features, see the [Amazon Fraud Detector User
#' Guide](https://docs.aws.amazon.com/frauddetector/latest/ug/).
#' 
#' We provide the Query API as well as AWS software development kits (SDK)
#' for Amazon Fraud Detector in Java and Python programming languages.
#' 
#' The Amazon Fraud Detector Query API provides HTTPS requests that use the
#' HTTP verb GET or POST and a Query parameter `Action`. AWS SDK provides
#' libraries, sample code, tutorials, and other resources for software
#' developers who prefer to build applications using language-specific APIs
#' instead of submitting a request over HTTP or HTTPS. These libraries
#' provide basic functions that automatically take care of tasks such as
#' cryptographically signing your requests, retrying requests, and handling
#' error responses, so that it is easier for you to get started. For more
#' information about the AWS SDKs, go to [Tools to build on
#' AWS](https://aws.amazon.com/developer/tools/) page, scroll down to the
#' **SDK** section, and choose plus (+) sign to expand the section.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- frauddetector(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- frauddetector()
#' svc$batch_create_variable(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:frauddetector_batch_create_variable]{batch_create_variable} \tab Creates a batch of variables\cr
#'  \link[paws.machine.learning:frauddetector_batch_get_variable]{batch_get_variable} \tab Gets a batch of variables\cr
#'  \link[paws.machine.learning:frauddetector_cancel_batch_import_job]{cancel_batch_import_job} \tab Cancels an in-progress batch import job\cr
#'  \link[paws.machine.learning:frauddetector_cancel_batch_prediction_job]{cancel_batch_prediction_job} \tab Cancels the specified batch prediction job\cr
#'  \link[paws.machine.learning:frauddetector_create_batch_import_job]{create_batch_import_job} \tab Creates a batch import job\cr
#'  \link[paws.machine.learning:frauddetector_create_batch_prediction_job]{create_batch_prediction_job} \tab Creates a batch prediction job\cr
#'  \link[paws.machine.learning:frauddetector_create_detector_version]{create_detector_version} \tab Creates a detector version\cr
#'  \link[paws.machine.learning:frauddetector_create_list]{create_list} \tab Creates a list\cr
#'  \link[paws.machine.learning:frauddetector_create_model]{create_model} \tab Creates a model using the specified model type\cr
#'  \link[paws.machine.learning:frauddetector_create_model_version]{create_model_version} \tab Creates a version of the model using the specified model type and model id\cr
#'  \link[paws.machine.learning:frauddetector_create_rule]{create_rule} \tab Creates a rule for use with the specified detector\cr
#'  \link[paws.machine.learning:frauddetector_create_variable]{create_variable} \tab Creates a variable\cr
#'  \link[paws.machine.learning:frauddetector_delete_batch_import_job]{delete_batch_import_job} \tab Deletes the specified batch import job ID record\cr
#'  \link[paws.machine.learning:frauddetector_delete_batch_prediction_job]{delete_batch_prediction_job} \tab Deletes a batch prediction job\cr
#'  \link[paws.machine.learning:frauddetector_delete_detector]{delete_detector} \tab Deletes the detector\cr
#'  \link[paws.machine.learning:frauddetector_delete_detector_version]{delete_detector_version} \tab Deletes the detector version\cr
#'  \link[paws.machine.learning:frauddetector_delete_entity_type]{delete_entity_type} \tab Deletes an entity type\cr
#'  \link[paws.machine.learning:frauddetector_delete_event]{delete_event} \tab Deletes the specified event\cr
#'  \link[paws.machine.learning:frauddetector_delete_events_by_event_type]{delete_events_by_event_type} \tab Deletes all events of a particular event type\cr
#'  \link[paws.machine.learning:frauddetector_delete_event_type]{delete_event_type} \tab Deletes an event type\cr
#'  \link[paws.machine.learning:frauddetector_delete_external_model]{delete_external_model} \tab Removes a SageMaker model from Amazon Fraud Detector\cr
#'  \link[paws.machine.learning:frauddetector_delete_label]{delete_label} \tab Deletes a label\cr
#'  \link[paws.machine.learning:frauddetector_delete_list]{delete_list} \tab Deletes the list, provided it is not used in a rule\cr
#'  \link[paws.machine.learning:frauddetector_delete_model]{delete_model} \tab Deletes a model\cr
#'  \link[paws.machine.learning:frauddetector_delete_model_version]{delete_model_version} \tab Deletes a model version\cr
#'  \link[paws.machine.learning:frauddetector_delete_outcome]{delete_outcome} \tab Deletes an outcome\cr
#'  \link[paws.machine.learning:frauddetector_delete_rule]{delete_rule} \tab Deletes the rule\cr
#'  \link[paws.machine.learning:frauddetector_delete_variable]{delete_variable} \tab Deletes a variable\cr
#'  \link[paws.machine.learning:frauddetector_describe_detector]{describe_detector} \tab Gets all versions for a specified detector\cr
#'  \link[paws.machine.learning:frauddetector_describe_model_versions]{describe_model_versions} \tab Gets all of the model versions for the specified model type or for the specified model type and model ID\cr
#'  \link[paws.machine.learning:frauddetector_get_batch_import_jobs]{get_batch_import_jobs} \tab Gets all batch import jobs or a specific job of the specified ID\cr
#'  \link[paws.machine.learning:frauddetector_get_batch_prediction_jobs]{get_batch_prediction_jobs} \tab Gets all batch prediction jobs or a specific job if you specify a job ID\cr
#'  \link[paws.machine.learning:frauddetector_get_delete_events_by_event_type_status]{get_delete_events_by_event_type_status} \tab Retrieves the status of a DeleteEventsByEventType action\cr
#'  \link[paws.machine.learning:frauddetector_get_detectors]{get_detectors} \tab Gets all detectors or a single detector if a detectorId is specified\cr
#'  \link[paws.machine.learning:frauddetector_get_detector_version]{get_detector_version} \tab Gets a particular detector version\cr
#'  \link[paws.machine.learning:frauddetector_get_entity_types]{get_entity_types} \tab Gets all entity types or a specific entity type if a name is specified\cr
#'  \link[paws.machine.learning:frauddetector_get_event]{get_event} \tab Retrieves details of events stored with Amazon Fraud Detector\cr
#'  \link[paws.machine.learning:frauddetector_get_event_prediction]{get_event_prediction} \tab Evaluates an event against a detector version\cr
#'  \link[paws.machine.learning:frauddetector_get_event_prediction_metadata]{get_event_prediction_metadata} \tab Gets details of the past fraud predictions for the specified event ID, event type, detector ID, and detector version ID that was generated in the specified time period\cr
#'  \link[paws.machine.learning:frauddetector_get_event_types]{get_event_types} \tab Gets all event types or a specific event type if name is provided\cr
#'  \link[paws.machine.learning:frauddetector_get_external_models]{get_external_models} \tab Gets the details for one or more Amazon SageMaker models that have been imported into the service\cr
#'  \link[paws.machine.learning:frauddetector_get_kms_encryption_key]{get_kms_encryption_key} \tab Gets the encryption key if a KMS key has been specified to be used to encrypt content in Amazon Fraud Detector\cr
#'  \link[paws.machine.learning:frauddetector_get_labels]{get_labels} \tab Gets all labels or a specific label if name is provided\cr
#'  \link[paws.machine.learning:frauddetector_get_list_elements]{get_list_elements} \tab Gets all the elements in the specified list\cr
#'  \link[paws.machine.learning:frauddetector_get_lists_metadata]{get_lists_metadata} \tab Gets the metadata of either all the lists under the account or the specified list\cr
#'  \link[paws.machine.learning:frauddetector_get_models]{get_models} \tab Gets one or more models\cr
#'  \link[paws.machine.learning:frauddetector_get_model_version]{get_model_version} \tab Gets the details of the specified model version\cr
#'  \link[paws.machine.learning:frauddetector_get_outcomes]{get_outcomes} \tab Gets one or more outcomes\cr
#'  \link[paws.machine.learning:frauddetector_get_rules]{get_rules} \tab Get all rules for a detector (paginated) if ruleId and ruleVersion are not specified\cr
#'  \link[paws.machine.learning:frauddetector_get_variables]{get_variables} \tab Gets all of the variables or the specific variable\cr
#'  \link[paws.machine.learning:frauddetector_list_event_predictions]{list_event_predictions} \tab Gets a list of past predictions\cr
#'  \link[paws.machine.learning:frauddetector_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags associated with the resource\cr
#'  \link[paws.machine.learning:frauddetector_put_detector]{put_detector} \tab Creates or updates a detector\cr
#'  \link[paws.machine.learning:frauddetector_put_entity_type]{put_entity_type} \tab Creates or updates an entity type\cr
#'  \link[paws.machine.learning:frauddetector_put_event_type]{put_event_type} \tab Creates or updates an event type\cr
#'  \link[paws.machine.learning:frauddetector_put_external_model]{put_external_model} \tab Creates or updates an Amazon SageMaker model endpoint\cr
#'  \link[paws.machine.learning:frauddetector_put_kms_encryption_key]{put_kms_encryption_key} \tab Specifies the KMS key to be used to encrypt content in Amazon Fraud Detector\cr
#'  \link[paws.machine.learning:frauddetector_put_label]{put_label} \tab Creates or updates label\cr
#'  \link[paws.machine.learning:frauddetector_put_outcome]{put_outcome} \tab Creates or updates an outcome\cr
#'  \link[paws.machine.learning:frauddetector_send_event]{send_event} \tab Stores events in Amazon Fraud Detector without generating fraud predictions for those events\cr
#'  \link[paws.machine.learning:frauddetector_tag_resource]{tag_resource} \tab Assigns tags to a resource\cr
#'  \link[paws.machine.learning:frauddetector_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.machine.learning:frauddetector_update_detector_version]{update_detector_version} \tab Updates a detector version\cr
#'  \link[paws.machine.learning:frauddetector_update_detector_version_metadata]{update_detector_version_metadata} \tab Updates the detector version's description\cr
#'  \link[paws.machine.learning:frauddetector_update_detector_version_status]{update_detector_version_status} \tab Updates the detector version’s status\cr
#'  \link[paws.machine.learning:frauddetector_update_event_label]{update_event_label} \tab Updates the specified event with a new label\cr
#'  \link[paws.machine.learning:frauddetector_update_list]{update_list} \tab Updates a list\cr
#'  \link[paws.machine.learning:frauddetector_update_model]{update_model} \tab Updates model description\cr
#'  \link[paws.machine.learning:frauddetector_update_model_version]{update_model_version} \tab Updates a model version\cr
#'  \link[paws.machine.learning:frauddetector_update_model_version_status]{update_model_version_status} \tab Updates the status of a model version\cr
#'  \link[paws.machine.learning:frauddetector_update_rule_metadata]{update_rule_metadata} \tab Updates a rule's metadata\cr
#'  \link[paws.machine.learning:frauddetector_update_rule_version]{update_rule_version} \tab Updates a rule version resulting in a new rule version\cr
#'  \link[paws.machine.learning:frauddetector_update_variable]{update_variable} \tab Updates a variable
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname frauddetector
#' @export
frauddetector <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::frauddetector(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Lex Model Building Service
#'
#' @description
#' Amazon Lex Build-Time Actions
#' 
#' Amazon Lex is an AWS service for building conversational voice and text
#' interfaces. Use these actions to create, update, and delete
#' conversational bots for new and existing client applications.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lexmodelbuildingservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lexmodelbuildingservice()
#' # This example shows how to get configuration information for a bot.
#' svc$get_bot(
#'   name = "DocOrderPizza",
#'   versionOrAlias = "$LATEST"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:lexmodelbuildingservice_create_bot_version]{create_bot_version} \tab Creates a new version of the bot based on the $LATEST version\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_create_intent_version]{create_intent_version} \tab Creates a new version of an intent based on the $LATEST version of the intent\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_create_slot_type_version]{create_slot_type_version} \tab Creates a new version of a slot type based on the $LATEST version of the specified slot type\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_bot]{delete_bot} \tab Deletes all versions of the bot, including the $LATEST version\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_bot_alias]{delete_bot_alias} \tab Deletes an alias for the specified bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_bot_channel_association]{delete_bot_channel_association} \tab Deletes the association between an Amazon Lex bot and a messaging platform\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_bot_version]{delete_bot_version} \tab Deletes a specific version of a bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_intent]{delete_intent} \tab Deletes all versions of the intent, including the $LATEST version\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_intent_version]{delete_intent_version} \tab Deletes a specific version of an intent\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_slot_type]{delete_slot_type} \tab Deletes all versions of the slot type, including the $LATEST version\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_slot_type_version]{delete_slot_type_version} \tab Deletes a specific version of a slot type\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_delete_utterances]{delete_utterances} \tab Deletes stored utterances\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_bot]{get_bot} \tab Returns metadata information for a specific bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_bot_alias]{get_bot_alias} \tab Returns information about an Amazon Lex bot alias\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_bot_aliases]{get_bot_aliases} \tab Returns a list of aliases for a specified Amazon Lex bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_bot_channel_association]{get_bot_channel_association} \tab Returns information about the association between an Amazon Lex bot and a messaging platform\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_bot_channel_associations]{get_bot_channel_associations} \tab Returns a list of all of the channels associated with the specified bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_bots]{get_bots} \tab Returns bot information as follows:\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_bot_versions]{get_bot_versions} \tab Gets information about all of the versions of a bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_builtin_intent]{get_builtin_intent} \tab Returns information about a built-in intent\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_builtin_intents]{get_builtin_intents} \tab Gets a list of built-in intents that meet the specified criteria\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_builtin_slot_types]{get_builtin_slot_types} \tab Gets a list of built-in slot types that meet the specified criteria\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_export]{get_export} \tab Exports the contents of a Amazon Lex resource in a specified format\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_import]{get_import} \tab Gets information about an import job started with the StartImport operation\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_intent]{get_intent} \tab Returns information about an intent\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_intents]{get_intents} \tab Returns intent information as follows:\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_intent_versions]{get_intent_versions} \tab Gets information about all of the versions of an intent\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_migration]{get_migration} \tab Provides details about an ongoing or complete migration from an Amazon Lex V1 bot to an Amazon Lex V2 bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_migrations]{get_migrations} \tab Gets a list of migrations between Amazon Lex V1 and Amazon Lex V2\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_slot_type]{get_slot_type} \tab Returns information about a specific version of a slot type\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_slot_types]{get_slot_types} \tab Returns slot type information as follows:\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_slot_type_versions]{get_slot_type_versions} \tab Gets information about all versions of a slot type\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_get_utterances_view]{get_utterances_view} \tab Use the GetUtterancesView operation to get information about the utterances that your users have made to your bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_list_tags_for_resource]{list_tags_for_resource} \tab Gets a list of tags associated with the specified resource\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_put_bot]{put_bot} \tab Creates an Amazon Lex conversational bot or replaces an existing bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_put_bot_alias]{put_bot_alias} \tab Creates an alias for the specified version of the bot or replaces an alias for the specified bot\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_put_intent]{put_intent} \tab Creates an intent or replaces an existing intent\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_put_slot_type]{put_slot_type} \tab Creates a custom slot type or replaces an existing custom slot type\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_start_import]{start_import} \tab Starts a job to import a resource to Amazon Lex\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_start_migration]{start_migration} \tab Starts migrating a bot from Amazon Lex V1 to Amazon Lex V2\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_tag_resource]{tag_resource} \tab Adds the specified tags to the specified resource\cr
#'  \link[paws.machine.learning:lexmodelbuildingservice_untag_resource]{untag_resource} \tab Removes tags from a bot, bot alias or bot channel
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lexmodelbuildingservice
#' @export
lexmodelbuildingservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::lexmodelbuildingservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Lex Model Building V2
#'
#' 
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lexmodelsv2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lexmodelsv2()
#' svc$batch_create_custom_vocabulary_item(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:lexmodelsv2_batch_create_custom_vocabulary_item]{batch_create_custom_vocabulary_item} \tab Create a batch of custom vocabulary items for a given bot locale's custom vocabulary\cr
#'  \link[paws.machine.learning:lexmodelsv2_batch_delete_custom_vocabulary_item]{batch_delete_custom_vocabulary_item} \tab Delete a batch of custom vocabulary items for a given bot locale's custom vocabulary\cr
#'  \link[paws.machine.learning:lexmodelsv2_batch_update_custom_vocabulary_item]{batch_update_custom_vocabulary_item} \tab Update a batch of custom vocabulary items for a given bot locale's custom vocabulary\cr
#'  \link[paws.machine.learning:lexmodelsv2_build_bot_locale]{build_bot_locale} \tab Builds a bot, its intents, and its slot types into a specific locale\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_bot]{create_bot} \tab Creates an Amazon Lex conversational bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_bot_alias]{create_bot_alias} \tab Creates an alias for the specified version of a bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_bot_locale]{create_bot_locale} \tab Creates a locale in the bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_bot_replica]{create_bot_replica} \tab Action to create a replication of the source bot in the secondary region\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_bot_version]{create_bot_version} \tab Creates an immutable version of the bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_export]{create_export} \tab Creates a zip archive containing the contents of a bot or a bot locale\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_intent]{create_intent} \tab Creates an intent\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_resource_policy]{create_resource_policy} \tab Creates a new resource policy with the specified policy statements\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_resource_policy_statement]{create_resource_policy_statement} \tab Adds a new resource policy statement to a bot or bot alias\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_slot]{create_slot} \tab Creates a slot in an intent\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_slot_type]{create_slot_type} \tab Creates a custom slot type\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_test_set_discrepancy_report]{create_test_set_discrepancy_report} \tab Create a report that describes the differences between the bot and the test set\cr
#'  \link[paws.machine.learning:lexmodelsv2_create_upload_url]{create_upload_url} \tab Gets a pre-signed S3 write URL that you use to upload the zip archive when importing a bot or a bot locale\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_bot]{delete_bot} \tab Deletes all versions of a bot, including the Draft version\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_bot_alias]{delete_bot_alias} \tab Deletes the specified bot alias\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_bot_locale]{delete_bot_locale} \tab Removes a locale from a bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_bot_replica]{delete_bot_replica} \tab The action to delete the replicated bot in the secondary region\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_bot_version]{delete_bot_version} \tab Deletes a specific version of a bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_custom_vocabulary]{delete_custom_vocabulary} \tab Removes a custom vocabulary from the specified locale in the specified bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_export]{delete_export} \tab Removes a previous export and the associated files stored in an S3 bucket\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_import]{delete_import} \tab Removes a previous import and the associated file stored in an S3 bucket\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_intent]{delete_intent} \tab Removes the specified intent\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_resource_policy]{delete_resource_policy} \tab Removes an existing policy from a bot or bot alias\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_resource_policy_statement]{delete_resource_policy_statement} \tab Deletes a policy statement from a resource policy\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_slot]{delete_slot} \tab Deletes the specified slot from an intent\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_slot_type]{delete_slot_type} \tab Deletes a slot type from a bot locale\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_test_set]{delete_test_set} \tab The action to delete the selected test set\cr
#'  \link[paws.machine.learning:lexmodelsv2_delete_utterances]{delete_utterances} \tab Deletes stored utterances\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_bot]{describe_bot} \tab Provides metadata information about a bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_bot_alias]{describe_bot_alias} \tab Get information about a specific bot alias\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_bot_locale]{describe_bot_locale} \tab Describes the settings that a bot has for a specific locale\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_bot_recommendation]{describe_bot_recommendation} \tab Provides metadata information about a bot recommendation\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_bot_replica]{describe_bot_replica} \tab Monitors the bot replication status through the UI console\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_bot_resource_generation]{describe_bot_resource_generation} \tab Returns information about a request to generate a bot through natural language description, made through the StartBotResource API\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_bot_version]{describe_bot_version} \tab Provides metadata about a version of a bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_custom_vocabulary_metadata]{describe_custom_vocabulary_metadata} \tab Provides metadata information about a custom vocabulary\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_export]{describe_export} \tab Gets information about a specific export\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_import]{describe_import} \tab Gets information about a specific import\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_intent]{describe_intent} \tab Returns metadata about an intent\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_resource_policy]{describe_resource_policy} \tab Gets the resource policy and policy revision for a bot or bot alias\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_slot]{describe_slot} \tab Gets metadata information about a slot\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_slot_type]{describe_slot_type} \tab Gets metadata information about a slot type\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_test_execution]{describe_test_execution} \tab Gets metadata information about the test execution\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_test_set]{describe_test_set} \tab Gets metadata information about the test set\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_test_set_discrepancy_report]{describe_test_set_discrepancy_report} \tab Gets metadata information about the test set discrepancy report\cr
#'  \link[paws.machine.learning:lexmodelsv2_describe_test_set_generation]{describe_test_set_generation} \tab Gets metadata information about the test set generation\cr
#'  \link[paws.machine.learning:lexmodelsv2_generate_bot_element]{generate_bot_element} \tab Generates sample utterances for an intent\cr
#'  \link[paws.machine.learning:lexmodelsv2_get_test_execution_artifacts_url]{get_test_execution_artifacts_url} \tab The pre-signed Amazon S3 URL to download the test execution result artifacts\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_aggregated_utterances]{list_aggregated_utterances} \tab Provides a list of utterances that users have sent to the bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bot_aliases]{list_bot_aliases} \tab Gets a list of aliases for the specified bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bot_alias_replicas]{list_bot_alias_replicas} \tab The action to list the replicated bots created from the source bot alias\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bot_locales]{list_bot_locales} \tab Gets a list of locales for the specified bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bot_recommendations]{list_bot_recommendations} \tab Get a list of bot recommendations that meet the specified criteria\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bot_replicas]{list_bot_replicas} \tab The action to list the replicated bots\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bot_resource_generations]{list_bot_resource_generations} \tab Lists the generation requests made for a bot locale\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bots]{list_bots} \tab Gets a list of available bots\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bot_version_replicas]{list_bot_version_replicas} \tab Contains information about all the versions replication statuses applicable for Global Resiliency\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_bot_versions]{list_bot_versions} \tab Gets information about all of the versions of a bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_built_in_intents]{list_built_in_intents} \tab Gets a list of built-in intents provided by Amazon Lex that you can use in your bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_built_in_slot_types]{list_built_in_slot_types} \tab Gets a list of built-in slot types that meet the specified criteria\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_custom_vocabulary_items]{list_custom_vocabulary_items} \tab Paginated list of custom vocabulary items for a given bot locale's custom vocabulary\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_exports]{list_exports} \tab Lists the exports for a bot, bot locale, or custom vocabulary\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_imports]{list_imports} \tab Lists the imports for a bot, bot locale, or custom vocabulary\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_intent_metrics]{list_intent_metrics} \tab Retrieves summary metrics for the intents in your bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_intent_paths]{list_intent_paths} \tab Retrieves summary statistics for a path of intents that users take over sessions with your bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_intents]{list_intents} \tab Get a list of intents that meet the specified criteria\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_intent_stage_metrics]{list_intent_stage_metrics} \tab Retrieves summary metrics for the stages within intents in your bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_recommended_intents]{list_recommended_intents} \tab Gets a list of recommended intents provided by the bot recommendation that you can use in your bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_session_analytics_data]{list_session_analytics_data} \tab Retrieves a list of metadata for individual user sessions with your bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_session_metrics]{list_session_metrics} \tab Retrieves summary metrics for the user sessions with your bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_slots]{list_slots} \tab Gets a list of slots that match the specified criteria\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_slot_types]{list_slot_types} \tab Gets a list of slot types that match the specified criteria\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_tags_for_resource]{list_tags_for_resource} \tab Gets a list of tags associated with a resource\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_test_execution_result_items]{list_test_execution_result_items} \tab Gets a list of test execution result items\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_test_executions]{list_test_executions} \tab The list of test set executions\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_test_set_records]{list_test_set_records} \tab The list of test set records\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_test_sets]{list_test_sets} \tab The list of the test sets\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_utterance_analytics_data]{list_utterance_analytics_data} \tab To use this API operation, your IAM role must have permissions to perform the ListAggregatedUtterances operation, which provides access to utterance-related analytics\cr
#'  \link[paws.machine.learning:lexmodelsv2_list_utterance_metrics]{list_utterance_metrics} \tab To use this API operation, your IAM role must have permissions to perform the ListAggregatedUtterances operation, which provides access to utterance-related analytics\cr
#'  \link[paws.machine.learning:lexmodelsv2_search_associated_transcripts]{search_associated_transcripts} \tab Search for associated transcripts that meet the specified criteria\cr
#'  \link[paws.machine.learning:lexmodelsv2_start_bot_recommendation]{start_bot_recommendation} \tab Use this to provide your transcript data, and to start the bot recommendation process\cr
#'  \link[paws.machine.learning:lexmodelsv2_start_bot_resource_generation]{start_bot_resource_generation} \tab Starts a request for the descriptive bot builder to generate a bot locale configuration based on the prompt you provide it\cr
#'  \link[paws.machine.learning:lexmodelsv2_start_import]{start_import} \tab Starts importing a bot, bot locale, or custom vocabulary from a zip archive that you uploaded to an S3 bucket\cr
#'  \link[paws.machine.learning:lexmodelsv2_start_test_execution]{start_test_execution} \tab The action to start test set execution\cr
#'  \link[paws.machine.learning:lexmodelsv2_start_test_set_generation]{start_test_set_generation} \tab The action to start the generation of test set\cr
#'  \link[paws.machine.learning:lexmodelsv2_stop_bot_recommendation]{stop_bot_recommendation} \tab Stop an already running Bot Recommendation request\cr
#'  \link[paws.machine.learning:lexmodelsv2_tag_resource]{tag_resource} \tab Adds the specified tags to the specified resource\cr
#'  \link[paws.machine.learning:lexmodelsv2_untag_resource]{untag_resource} \tab Removes tags from a bot, bot alias, or bot channel\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_bot]{update_bot} \tab Updates the configuration of an existing bot\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_bot_alias]{update_bot_alias} \tab Updates the configuration of an existing bot alias\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_bot_locale]{update_bot_locale} \tab Updates the settings that a bot has for a specific locale\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_bot_recommendation]{update_bot_recommendation} \tab Updates an existing bot recommendation request\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_export]{update_export} \tab Updates the password used to protect an export zip archive\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_intent]{update_intent} \tab Updates the settings for an intent\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_resource_policy]{update_resource_policy} \tab Replaces the existing resource policy for a bot or bot alias with a new one\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_slot]{update_slot} \tab Updates the settings for a slot\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_slot_type]{update_slot_type} \tab Updates the configuration of an existing slot type\cr
#'  \link[paws.machine.learning:lexmodelsv2_update_test_set]{update_test_set} \tab The action to update the test set
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lexmodelsv2
#' @export
lexmodelsv2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::lexmodelsv2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Lex Runtime Service
#'
#' @description
#' Amazon Lex provides both build and runtime endpoints. Each endpoint
#' provides a set of operations (API). Your conversational bot uses the
#' runtime API to understand user utterances (user input text or voice).
#' For example, suppose a user says "I want pizza", your bot sends this
#' input to Amazon Lex using the runtime API. Amazon Lex recognizes that
#' the user request is for the OrderPizza intent (one of the intents
#' defined in the bot). Then Amazon Lex engages in user conversation on
#' behalf of the bot to elicit required information (slot values, such as
#' pizza size and crust type), and then performs fulfillment activity (that
#' you configured when you created the bot). You use the build-time API to
#' create and manage your Amazon Lex bot. For a list of build-time
#' operations, see the build-time API, .
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lexruntimeservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lexruntimeservice()
#' svc$delete_session(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:lexruntimeservice_delete_session]{delete_session} \tab Removes session information for a specified bot, alias, and user ID\cr
#'  \link[paws.machine.learning:lexruntimeservice_get_session]{get_session} \tab Returns session information for a specified bot, alias, and user ID\cr
#'  \link[paws.machine.learning:lexruntimeservice_post_content]{post_content} \tab Sends user input (text or speech) to Amazon Lex\cr
#'  \link[paws.machine.learning:lexruntimeservice_post_text]{post_text} \tab Sends user input to Amazon Lex\cr
#'  \link[paws.machine.learning:lexruntimeservice_put_session]{put_session} \tab Creates a new session or modifies an existing session with an Amazon Lex bot
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lexruntimeservice
#' @export
lexruntimeservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::lexruntimeservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Lex Runtime V2
#'
#' @description
#' This section contains documentation for the Amazon Lex V2 Runtime V2 API
#' operations.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lexruntimev2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lexruntimev2()
#' svc$delete_session(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:lexruntimev2_delete_session]{delete_session} \tab Removes session information for a specified bot, alias, and user ID\cr
#'  \link[paws.machine.learning:lexruntimev2_get_session]{get_session} \tab Returns session information for a specified bot, alias, and user\cr
#'  \link[paws.machine.learning:lexruntimev2_put_session]{put_session} \tab Creates a new session or modifies an existing session with an Amazon Lex V2 bot\cr
#'  \link[paws.machine.learning:lexruntimev2_recognize_text]{recognize_text} \tab Sends user input to Amazon Lex V2\cr
#'  \link[paws.machine.learning:lexruntimev2_recognize_utterance]{recognize_utterance} \tab Sends user input to Amazon Lex V2\cr
#'  \link[paws.machine.learning:lexruntimev2_start_conversation]{start_conversation} \tab Starts an HTTP/2 bidirectional event stream that enables you to send audio, text, or DTMF input in real time
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lexruntimev2
#' @export
lexruntimev2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::lexruntimev2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Lookout for Equipment
#'
#' @description
#' Amazon Lookout for Equipment is a machine learning service that uses
#' advanced analytics to identify anomalies in machines from sensor data
#' for use in predictive maintenance.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lookoutequipment(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lookoutequipment()
#' svc$create_dataset(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:lookoutequipment_create_dataset]{create_dataset} \tab Creates a container for a collection of data being ingested for analysis\cr
#'  \link[paws.machine.learning:lookoutequipment_create_inference_scheduler]{create_inference_scheduler} \tab Creates a scheduled inference\cr
#'  \link[paws.machine.learning:lookoutequipment_create_label]{create_label} \tab Creates a label for an event\cr
#'  \link[paws.machine.learning:lookoutequipment_create_label_group]{create_label_group} \tab Creates a group of labels\cr
#'  \link[paws.machine.learning:lookoutequipment_create_model]{create_model} \tab Creates a machine learning model for data inference\cr
#'  \link[paws.machine.learning:lookoutequipment_create_retraining_scheduler]{create_retraining_scheduler} \tab Creates a retraining scheduler on the specified model\cr
#'  \link[paws.machine.learning:lookoutequipment_delete_dataset]{delete_dataset} \tab Deletes a dataset and associated artifacts\cr
#'  \link[paws.machine.learning:lookoutequipment_delete_inference_scheduler]{delete_inference_scheduler} \tab Deletes an inference scheduler that has been set up\cr
#'  \link[paws.machine.learning:lookoutequipment_delete_label]{delete_label} \tab Deletes a label\cr
#'  \link[paws.machine.learning:lookoutequipment_delete_label_group]{delete_label_group} \tab Deletes a group of labels\cr
#'  \link[paws.machine.learning:lookoutequipment_delete_model]{delete_model} \tab Deletes a machine learning model currently available for Amazon Lookout for Equipment\cr
#'  \link[paws.machine.learning:lookoutequipment_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource policy attached to the resource\cr
#'  \link[paws.machine.learning:lookoutequipment_delete_retraining_scheduler]{delete_retraining_scheduler} \tab Deletes a retraining scheduler from a model\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_data_ingestion_job]{describe_data_ingestion_job} \tab Provides information on a specific data ingestion job such as creation time, dataset ARN, and status\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_dataset]{describe_dataset} \tab Provides a JSON description of the data in each time series dataset, including names, column names, and data types\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_inference_scheduler]{describe_inference_scheduler} \tab Specifies information about the inference scheduler being used, including name, model, status, and associated metadata\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_label]{describe_label} \tab Returns the name of the label\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_label_group]{describe_label_group} \tab Returns information about the label group\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_model]{describe_model} \tab Provides a JSON containing the overall information about a specific machine learning model, including model name and ARN, dataset, training and evaluation information, status, and so on\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_model_version]{describe_model_version} \tab Retrieves information about a specific machine learning model version\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_resource_policy]{describe_resource_policy} \tab Provides the details of a resource policy attached to a resource\cr
#'  \link[paws.machine.learning:lookoutequipment_describe_retraining_scheduler]{describe_retraining_scheduler} \tab Provides a description of the retraining scheduler, including information such as the model name and retraining parameters\cr
#'  \link[paws.machine.learning:lookoutequipment_import_dataset]{import_dataset} \tab Imports a dataset\cr
#'  \link[paws.machine.learning:lookoutequipment_import_model_version]{import_model_version} \tab Imports a model that has been trained successfully\cr
#'  \link[paws.machine.learning:lookoutequipment_list_data_ingestion_jobs]{list_data_ingestion_jobs} \tab Provides a list of all data ingestion jobs, including dataset name and ARN, S3 location of the input data, status, and so on\cr
#'  \link[paws.machine.learning:lookoutequipment_list_datasets]{list_datasets} \tab Lists all datasets currently available in your account, filtering on the dataset name\cr
#'  \link[paws.machine.learning:lookoutequipment_list_inference_events]{list_inference_events} \tab Lists all inference events that have been found for the specified inference scheduler\cr
#'  \link[paws.machine.learning:lookoutequipment_list_inference_executions]{list_inference_executions} \tab Lists all inference executions that have been performed by the specified inference scheduler\cr
#'  \link[paws.machine.learning:lookoutequipment_list_inference_schedulers]{list_inference_schedulers} \tab Retrieves a list of all inference schedulers currently available for your account\cr
#'  \link[paws.machine.learning:lookoutequipment_list_label_groups]{list_label_groups} \tab Returns a list of the label groups\cr
#'  \link[paws.machine.learning:lookoutequipment_list_labels]{list_labels} \tab Provides a list of labels\cr
#'  \link[paws.machine.learning:lookoutequipment_list_models]{list_models} \tab Generates a list of all models in the account, including model name and ARN, dataset, and status\cr
#'  \link[paws.machine.learning:lookoutequipment_list_model_versions]{list_model_versions} \tab Generates a list of all model versions for a given model, including the model version, model version ARN, and status\cr
#'  \link[paws.machine.learning:lookoutequipment_list_retraining_schedulers]{list_retraining_schedulers} \tab Lists all retraining schedulers in your account, filtering by model name prefix and status\cr
#'  \link[paws.machine.learning:lookoutequipment_list_sensor_statistics]{list_sensor_statistics} \tab Lists statistics about the data collected for each of the sensors that have been successfully ingested in the particular dataset\cr
#'  \link[paws.machine.learning:lookoutequipment_list_tags_for_resource]{list_tags_for_resource} \tab Lists all the tags for a specified resource, including key and value\cr
#'  \link[paws.machine.learning:lookoutequipment_put_resource_policy]{put_resource_policy} \tab Creates a resource control policy for a given resource\cr
#'  \link[paws.machine.learning:lookoutequipment_start_data_ingestion_job]{start_data_ingestion_job} \tab Starts a data ingestion job\cr
#'  \link[paws.machine.learning:lookoutequipment_start_inference_scheduler]{start_inference_scheduler} \tab Starts an inference scheduler\cr
#'  \link[paws.machine.learning:lookoutequipment_start_retraining_scheduler]{start_retraining_scheduler} \tab Starts a retraining scheduler\cr
#'  \link[paws.machine.learning:lookoutequipment_stop_inference_scheduler]{stop_inference_scheduler} \tab Stops an inference scheduler\cr
#'  \link[paws.machine.learning:lookoutequipment_stop_retraining_scheduler]{stop_retraining_scheduler} \tab Stops a retraining scheduler\cr
#'  \link[paws.machine.learning:lookoutequipment_tag_resource]{tag_resource} \tab Associates a given tag to a resource in your account\cr
#'  \link[paws.machine.learning:lookoutequipment_untag_resource]{untag_resource} \tab Removes a specific tag from a given resource\cr
#'  \link[paws.machine.learning:lookoutequipment_update_active_model_version]{update_active_model_version} \tab Sets the active model version for a given machine learning model\cr
#'  \link[paws.machine.learning:lookoutequipment_update_inference_scheduler]{update_inference_scheduler} \tab Updates an inference scheduler\cr
#'  \link[paws.machine.learning:lookoutequipment_update_label_group]{update_label_group} \tab Updates the label group\cr
#'  \link[paws.machine.learning:lookoutequipment_update_model]{update_model} \tab Updates a model in the account\cr
#'  \link[paws.machine.learning:lookoutequipment_update_retraining_scheduler]{update_retraining_scheduler} \tab Updates a retraining scheduler
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lookoutequipment
#' @export
lookoutequipment <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::lookoutequipment(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Lookout for Metrics
#'
#' @description
#' This is the *Amazon Lookout for Metrics API Reference*. For an
#' introduction to the service with tutorials for getting started, visit
#' [Amazon Lookout for Metrics Developer
#' Guide](https://docs.aws.amazon.com/lookoutmetrics/latest/dev/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- lookoutmetrics(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- lookoutmetrics()
#' svc$activate_anomaly_detector(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:lookoutmetrics_activate_anomaly_detector]{activate_anomaly_detector} \tab Activates an anomaly detector\cr
#'  \link[paws.machine.learning:lookoutmetrics_back_test_anomaly_detector]{back_test_anomaly_detector} \tab Runs a backtest for anomaly detection for the specified resource\cr
#'  \link[paws.machine.learning:lookoutmetrics_create_alert]{create_alert} \tab Creates an alert for an anomaly detector\cr
#'  \link[paws.machine.learning:lookoutmetrics_create_anomaly_detector]{create_anomaly_detector} \tab Creates an anomaly detector\cr
#'  \link[paws.machine.learning:lookoutmetrics_create_metric_set]{create_metric_set} \tab Creates a dataset\cr
#'  \link[paws.machine.learning:lookoutmetrics_deactivate_anomaly_detector]{deactivate_anomaly_detector} \tab Deactivates an anomaly detector\cr
#'  \link[paws.machine.learning:lookoutmetrics_delete_alert]{delete_alert} \tab Deletes an alert\cr
#'  \link[paws.machine.learning:lookoutmetrics_delete_anomaly_detector]{delete_anomaly_detector} \tab Deletes a detector\cr
#'  \link[paws.machine.learning:lookoutmetrics_describe_alert]{describe_alert} \tab Describes an alert\cr
#'  \link[paws.machine.learning:lookoutmetrics_describe_anomaly_detection_executions]{describe_anomaly_detection_executions} \tab Returns information about the status of the specified anomaly detection jobs\cr
#'  \link[paws.machine.learning:lookoutmetrics_describe_anomaly_detector]{describe_anomaly_detector} \tab Describes a detector\cr
#'  \link[paws.machine.learning:lookoutmetrics_describe_metric_set]{describe_metric_set} \tab Describes a dataset\cr
#'  \link[paws.machine.learning:lookoutmetrics_detect_metric_set_config]{detect_metric_set_config} \tab Detects an Amazon S3 dataset's file format, interval, and offset\cr
#'  \link[paws.machine.learning:lookoutmetrics_get_anomaly_group]{get_anomaly_group} \tab Returns details about a group of anomalous metrics\cr
#'  \link[paws.machine.learning:lookoutmetrics_get_data_quality_metrics]{get_data_quality_metrics} \tab Returns details about the requested data quality metrics\cr
#'  \link[paws.machine.learning:lookoutmetrics_get_feedback]{get_feedback} \tab Get feedback for an anomaly group\cr
#'  \link[paws.machine.learning:lookoutmetrics_get_sample_data]{get_sample_data} \tab Returns a selection of sample records from an Amazon S3 datasource\cr
#'  \link[paws.machine.learning:lookoutmetrics_list_alerts]{list_alerts} \tab Lists the alerts attached to a detector\cr
#'  \link[paws.machine.learning:lookoutmetrics_list_anomaly_detectors]{list_anomaly_detectors} \tab Lists the detectors in the current AWS Region\cr
#'  \link[paws.machine.learning:lookoutmetrics_list_anomaly_group_related_metrics]{list_anomaly_group_related_metrics} \tab Returns a list of measures that are potential causes or effects of an anomaly group\cr
#'  \link[paws.machine.learning:lookoutmetrics_list_anomaly_group_summaries]{list_anomaly_group_summaries} \tab Returns a list of anomaly groups\cr
#'  \link[paws.machine.learning:lookoutmetrics_list_anomaly_group_time_series]{list_anomaly_group_time_series} \tab Gets a list of anomalous metrics for a measure in an anomaly group\cr
#'  \link[paws.machine.learning:lookoutmetrics_list_metric_sets]{list_metric_sets} \tab Lists the datasets in the current AWS Region\cr
#'  \link[paws.machine.learning:lookoutmetrics_list_tags_for_resource]{list_tags_for_resource} \tab Gets a list of tags for a detector, dataset, or alert\cr
#'  \link[paws.machine.learning:lookoutmetrics_put_feedback]{put_feedback} \tab Add feedback for an anomalous metric\cr
#'  \link[paws.machine.learning:lookoutmetrics_tag_resource]{tag_resource} \tab Adds tags to a detector, dataset, or alert\cr
#'  \link[paws.machine.learning:lookoutmetrics_untag_resource]{untag_resource} \tab Removes tags from a detector, dataset, or alert\cr
#'  \link[paws.machine.learning:lookoutmetrics_update_alert]{update_alert} \tab Make changes to an existing alert\cr
#'  \link[paws.machine.learning:lookoutmetrics_update_anomaly_detector]{update_anomaly_detector} \tab Updates a detector\cr
#'  \link[paws.machine.learning:lookoutmetrics_update_metric_set]{update_metric_set} \tab Updates a dataset
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname lookoutmetrics
#' @export
lookoutmetrics <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::lookoutmetrics(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Machine Learning
#'
#' @description
#' Definition of the public APIs exposed by Amazon Machine Learning
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- machinelearning(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- machinelearning()
#' svc$add_tags(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:machinelearning_add_tags]{add_tags} \tab Adds one or more tags to an object, up to a limit of 10\cr
#'  \link[paws.machine.learning:machinelearning_create_batch_prediction]{create_batch_prediction} \tab Generates predictions for a group of observations\cr
#'  \link[paws.machine.learning:machinelearning_create_data_source_from_rds]{create_data_source_from_rds} \tab Creates a DataSource object from an Amazon Relational Database Service (Amazon RDS)\cr
#'  \link[paws.machine.learning:machinelearning_create_data_source_from_redshift]{create_data_source_from_redshift} \tab Creates a DataSource from a database hosted on an Amazon Redshift cluster\cr
#'  \link[paws.machine.learning:machinelearning_create_data_source_from_s3]{create_data_source_from_s3} \tab Creates a DataSource object\cr
#'  \link[paws.machine.learning:machinelearning_create_evaluation]{create_evaluation} \tab Creates a new Evaluation of an MLModel\cr
#'  \link[paws.machine.learning:machinelearning_create_ml_model]{create_ml_model} \tab Creates a new MLModel using the DataSource and the recipe as information sources\cr
#'  \link[paws.machine.learning:machinelearning_create_realtime_endpoint]{create_realtime_endpoint} \tab Creates a real-time endpoint for the MLModel\cr
#'  \link[paws.machine.learning:machinelearning_delete_batch_prediction]{delete_batch_prediction} \tab Assigns the DELETED status to a BatchPrediction, rendering it unusable\cr
#'  \link[paws.machine.learning:machinelearning_delete_data_source]{delete_data_source} \tab Assigns the DELETED status to a DataSource, rendering it unusable\cr
#'  \link[paws.machine.learning:machinelearning_delete_evaluation]{delete_evaluation} \tab Assigns the DELETED status to an Evaluation, rendering it unusable\cr
#'  \link[paws.machine.learning:machinelearning_delete_ml_model]{delete_ml_model} \tab Assigns the DELETED status to an MLModel, rendering it unusable\cr
#'  \link[paws.machine.learning:machinelearning_delete_realtime_endpoint]{delete_realtime_endpoint} \tab Deletes a real time endpoint of an MLModel\cr
#'  \link[paws.machine.learning:machinelearning_delete_tags]{delete_tags} \tab Deletes the specified tags associated with an ML object\cr
#'  \link[paws.machine.learning:machinelearning_describe_batch_predictions]{describe_batch_predictions} \tab Returns a list of BatchPrediction operations that match the search criteria in the request\cr
#'  \link[paws.machine.learning:machinelearning_describe_data_sources]{describe_data_sources} \tab Returns a list of DataSource that match the search criteria in the request\cr
#'  \link[paws.machine.learning:machinelearning_describe_evaluations]{describe_evaluations} \tab Returns a list of DescribeEvaluations that match the search criteria in the request\cr
#'  \link[paws.machine.learning:machinelearning_describe_ml_models]{describe_ml_models} \tab Returns a list of MLModel that match the search criteria in the request\cr
#'  \link[paws.machine.learning:machinelearning_describe_tags]{describe_tags} \tab Describes one or more of the tags for your Amazon ML object\cr
#'  \link[paws.machine.learning:machinelearning_get_batch_prediction]{get_batch_prediction} \tab Returns a BatchPrediction that includes detailed metadata, status, and data file information for a Batch Prediction request\cr
#'  \link[paws.machine.learning:machinelearning_get_data_source]{get_data_source} \tab Returns a DataSource that includes metadata and data file information, as well as the current status of the DataSource\cr
#'  \link[paws.machine.learning:machinelearning_get_evaluation]{get_evaluation} \tab Returns an Evaluation that includes metadata as well as the current status of the Evaluation\cr
#'  \link[paws.machine.learning:machinelearning_get_ml_model]{get_ml_model} \tab Returns an MLModel that includes detailed metadata, data source information, and the current status of the MLModel\cr
#'  \link[paws.machine.learning:machinelearning_predict]{predict} \tab Generates a prediction for the observation using the specified ML Model\cr
#'  \link[paws.machine.learning:machinelearning_update_batch_prediction]{update_batch_prediction} \tab Updates the BatchPredictionName of a BatchPrediction\cr
#'  \link[paws.machine.learning:machinelearning_update_data_source]{update_data_source} \tab Updates the DataSourceName of a DataSource\cr
#'  \link[paws.machine.learning:machinelearning_update_evaluation]{update_evaluation} \tab Updates the EvaluationName of an Evaluation\cr
#'  \link[paws.machine.learning:machinelearning_update_ml_model]{update_ml_model} \tab Updates the MLModelName and the ScoreThreshold of an MLModel
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname machinelearning
#' @export
machinelearning <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::machinelearning(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Panorama
#'
#' @description
#' **Overview**
#' 
#' This is the *AWS Panorama API Reference*. For an introduction to the
#' service, see [What is AWS
#' Panorama?](https://docs.aws.amazon.com/panorama/latest/dev/panorama-welcome.html)
#' in the *AWS Panorama Developer Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- panorama(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- panorama()
#' svc$create_application_instance(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:panorama_create_application_instance]{create_application_instance} \tab Creates an application instance and deploys it to a device\cr
#'  \link[paws.machine.learning:panorama_create_job_for_devices]{create_job_for_devices} \tab Creates a job to run on a device\cr
#'  \link[paws.machine.learning:panorama_create_node_from_template_job]{create_node_from_template_job} \tab Creates a camera stream node\cr
#'  \link[paws.machine.learning:panorama_create_package]{create_package} \tab Creates a package and storage location in an Amazon S3 access point\cr
#'  \link[paws.machine.learning:panorama_create_package_import_job]{create_package_import_job} \tab Imports a node package\cr
#'  \link[paws.machine.learning:panorama_delete_device]{delete_device} \tab Deletes a device\cr
#'  \link[paws.machine.learning:panorama_delete_package]{delete_package} \tab Deletes a package\cr
#'  \link[paws.machine.learning:panorama_deregister_package_version]{deregister_package_version} \tab Deregisters a package version\cr
#'  \link[paws.machine.learning:panorama_describe_application_instance]{describe_application_instance} \tab Returns information about an application instance on a device\cr
#'  \link[paws.machine.learning:panorama_describe_application_instance_details]{describe_application_instance_details} \tab Returns information about an application instance's configuration manifest\cr
#'  \link[paws.machine.learning:panorama_describe_device]{describe_device} \tab Returns information about a device\cr
#'  \link[paws.machine.learning:panorama_describe_device_job]{describe_device_job} \tab Returns information about a device job\cr
#'  \link[paws.machine.learning:panorama_describe_node]{describe_node} \tab Returns information about a node\cr
#'  \link[paws.machine.learning:panorama_describe_node_from_template_job]{describe_node_from_template_job} \tab Returns information about a job to create a camera stream node\cr
#'  \link[paws.machine.learning:panorama_describe_package]{describe_package} \tab Returns information about a package\cr
#'  \link[paws.machine.learning:panorama_describe_package_import_job]{describe_package_import_job} \tab Returns information about a package import job\cr
#'  \link[paws.machine.learning:panorama_describe_package_version]{describe_package_version} \tab Returns information about a package version\cr
#'  \link[paws.machine.learning:panorama_list_application_instance_dependencies]{list_application_instance_dependencies} \tab Returns a list of application instance dependencies\cr
#'  \link[paws.machine.learning:panorama_list_application_instance_node_instances]{list_application_instance_node_instances} \tab Returns a list of application node instances\cr
#'  \link[paws.machine.learning:panorama_list_application_instances]{list_application_instances} \tab Returns a list of application instances\cr
#'  \link[paws.machine.learning:panorama_list_devices]{list_devices} \tab Returns a list of devices\cr
#'  \link[paws.machine.learning:panorama_list_devices_jobs]{list_devices_jobs} \tab Returns a list of jobs\cr
#'  \link[paws.machine.learning:panorama_list_node_from_template_jobs]{list_node_from_template_jobs} \tab Returns a list of camera stream node jobs\cr
#'  \link[paws.machine.learning:panorama_list_nodes]{list_nodes} \tab Returns a list of nodes\cr
#'  \link[paws.machine.learning:panorama_list_package_import_jobs]{list_package_import_jobs} \tab Returns a list of package import jobs\cr
#'  \link[paws.machine.learning:panorama_list_packages]{list_packages} \tab Returns a list of packages\cr
#'  \link[paws.machine.learning:panorama_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags for a resource\cr
#'  \link[paws.machine.learning:panorama_provision_device]{provision_device} \tab Creates a device and returns a configuration archive\cr
#'  \link[paws.machine.learning:panorama_register_package_version]{register_package_version} \tab Registers a package version\cr
#'  \link[paws.machine.learning:panorama_remove_application_instance]{remove_application_instance} \tab Removes an application instance\cr
#'  \link[paws.machine.learning:panorama_signal_application_instance_node_instances]{signal_application_instance_node_instances} \tab Signal camera nodes to stop or resume\cr
#'  \link[paws.machine.learning:panorama_tag_resource]{tag_resource} \tab Tags a resource\cr
#'  \link[paws.machine.learning:panorama_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.machine.learning:panorama_update_device_metadata]{update_device_metadata} \tab Updates a device's metadata
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname panorama
#' @export
panorama <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::panorama(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Personalize
#'
#' @description
#' Amazon Personalize is a machine learning service that makes it easy to
#' add individualized recommendations to customers.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- personalize(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- personalize()
#' svc$create_batch_inference_job(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:personalize_create_batch_inference_job]{create_batch_inference_job} \tab Generates batch recommendations based on a list of items or users stored in Amazon S3 and exports the recommendations to an Amazon S3 bucket\cr
#'  \link[paws.machine.learning:personalize_create_batch_segment_job]{create_batch_segment_job} \tab Creates a batch segment job\cr
#'  \link[paws.machine.learning:personalize_create_campaign]{create_campaign} \tab You incur campaign costs while it is active\cr
#'  \link[paws.machine.learning:personalize_create_data_deletion_job]{create_data_deletion_job} \tab Creates a batch job that deletes all references to specific users from an Amazon Personalize dataset group in batches\cr
#'  \link[paws.machine.learning:personalize_create_dataset]{create_dataset} \tab Creates an empty dataset and adds it to the specified dataset group\cr
#'  \link[paws.machine.learning:personalize_create_dataset_export_job]{create_dataset_export_job} \tab Creates a job that exports data from your dataset to an Amazon S3 bucket\cr
#'  \link[paws.machine.learning:personalize_create_dataset_group]{create_dataset_group} \tab Creates an empty dataset group\cr
#'  \link[paws.machine.learning:personalize_create_dataset_import_job]{create_dataset_import_job} \tab Creates a job that imports training data from your data source (an Amazon S3 bucket) to an Amazon Personalize dataset\cr
#'  \link[paws.machine.learning:personalize_create_event_tracker]{create_event_tracker} \tab Creates an event tracker that you use when adding event data to a specified dataset group using the PutEvents API\cr
#'  \link[paws.machine.learning:personalize_create_filter]{create_filter} \tab Creates a recommendation filter\cr
#'  \link[paws.machine.learning:personalize_create_metric_attribution]{create_metric_attribution} \tab Creates a metric attribution\cr
#'  \link[paws.machine.learning:personalize_create_recommender]{create_recommender} \tab Creates a recommender with the recipe (a Domain dataset group use case) you specify\cr
#'  \link[paws.machine.learning:personalize_create_schema]{create_schema} \tab Creates an Amazon Personalize schema from the specified schema string\cr
#'  \link[paws.machine.learning:personalize_create_solution]{create_solution} \tab By default, all new solutions use automatic training\cr
#'  \link[paws.machine.learning:personalize_create_solution_version]{create_solution_version} \tab Trains or retrains an active solution in a Custom dataset group\cr
#'  \link[paws.machine.learning:personalize_delete_campaign]{delete_campaign} \tab Removes a campaign by deleting the solution deployment\cr
#'  \link[paws.machine.learning:personalize_delete_dataset]{delete_dataset} \tab Deletes a dataset\cr
#'  \link[paws.machine.learning:personalize_delete_dataset_group]{delete_dataset_group} \tab Deletes a dataset group\cr
#'  \link[paws.machine.learning:personalize_delete_event_tracker]{delete_event_tracker} \tab Deletes the event tracker\cr
#'  \link[paws.machine.learning:personalize_delete_filter]{delete_filter} \tab Deletes a filter\cr
#'  \link[paws.machine.learning:personalize_delete_metric_attribution]{delete_metric_attribution} \tab Deletes a metric attribution\cr
#'  \link[paws.machine.learning:personalize_delete_recommender]{delete_recommender} \tab Deactivates and removes a recommender\cr
#'  \link[paws.machine.learning:personalize_delete_schema]{delete_schema} \tab Deletes a schema\cr
#'  \link[paws.machine.learning:personalize_delete_solution]{delete_solution} \tab Deletes all versions of a solution and the Solution object itself\cr
#'  \link[paws.machine.learning:personalize_describe_algorithm]{describe_algorithm} \tab Describes the given algorithm\cr
#'  \link[paws.machine.learning:personalize_describe_batch_inference_job]{describe_batch_inference_job} \tab Gets the properties of a batch inference job including name, Amazon Resource Name (ARN), status, input and output configurations, and the ARN of the solution version used to generate the recommendations\cr
#'  \link[paws.machine.learning:personalize_describe_batch_segment_job]{describe_batch_segment_job} \tab Gets the properties of a batch segment job including name, Amazon Resource Name (ARN), status, input and output configurations, and the ARN of the solution version used to generate segments\cr
#'  \link[paws.machine.learning:personalize_describe_campaign]{describe_campaign} \tab Describes the given campaign, including its status\cr
#'  \link[paws.machine.learning:personalize_describe_data_deletion_job]{describe_data_deletion_job} \tab Describes the data deletion job created by CreateDataDeletionJob, including the job status\cr
#'  \link[paws.machine.learning:personalize_describe_dataset]{describe_dataset} \tab Describes the given dataset\cr
#'  \link[paws.machine.learning:personalize_describe_dataset_export_job]{describe_dataset_export_job} \tab Describes the dataset export job created by CreateDatasetExportJob, including the export job status\cr
#'  \link[paws.machine.learning:personalize_describe_dataset_group]{describe_dataset_group} \tab Describes the given dataset group\cr
#'  \link[paws.machine.learning:personalize_describe_dataset_import_job]{describe_dataset_import_job} \tab Describes the dataset import job created by CreateDatasetImportJob, including the import job status\cr
#'  \link[paws.machine.learning:personalize_describe_event_tracker]{describe_event_tracker} \tab Describes an event tracker\cr
#'  \link[paws.machine.learning:personalize_describe_feature_transformation]{describe_feature_transformation} \tab Describes the given feature transformation\cr
#'  \link[paws.machine.learning:personalize_describe_filter]{describe_filter} \tab Describes a filter's properties\cr
#'  \link[paws.machine.learning:personalize_describe_metric_attribution]{describe_metric_attribution} \tab Describes a metric attribution\cr
#'  \link[paws.machine.learning:personalize_describe_recipe]{describe_recipe} \tab Describes a recipe\cr
#'  \link[paws.machine.learning:personalize_describe_recommender]{describe_recommender} \tab Describes the given recommender, including its status\cr
#'  \link[paws.machine.learning:personalize_describe_schema]{describe_schema} \tab Describes a schema\cr
#'  \link[paws.machine.learning:personalize_describe_solution]{describe_solution} \tab Describes a solution\cr
#'  \link[paws.machine.learning:personalize_describe_solution_version]{describe_solution_version} \tab Describes a specific version of a solution\cr
#'  \link[paws.machine.learning:personalize_get_solution_metrics]{get_solution_metrics} \tab Gets the metrics for the specified solution version\cr
#'  \link[paws.machine.learning:personalize_list_batch_inference_jobs]{list_batch_inference_jobs} \tab Gets a list of the batch inference jobs that have been performed off of a solution version\cr
#'  \link[paws.machine.learning:personalize_list_batch_segment_jobs]{list_batch_segment_jobs} \tab Gets a list of the batch segment jobs that have been performed off of a solution version that you specify\cr
#'  \link[paws.machine.learning:personalize_list_campaigns]{list_campaigns} \tab Returns a list of campaigns that use the given solution\cr
#'  \link[paws.machine.learning:personalize_list_data_deletion_jobs]{list_data_deletion_jobs} \tab Returns a list of data deletion jobs for a dataset group ordered by creation time, with the most recent first\cr
#'  \link[paws.machine.learning:personalize_list_dataset_export_jobs]{list_dataset_export_jobs} \tab Returns a list of dataset export jobs that use the given dataset\cr
#'  \link[paws.machine.learning:personalize_list_dataset_groups]{list_dataset_groups} \tab Returns a list of dataset groups\cr
#'  \link[paws.machine.learning:personalize_list_dataset_import_jobs]{list_dataset_import_jobs} \tab Returns a list of dataset import jobs that use the given dataset\cr
#'  \link[paws.machine.learning:personalize_list_datasets]{list_datasets} \tab Returns the list of datasets contained in the given dataset group\cr
#'  \link[paws.machine.learning:personalize_list_event_trackers]{list_event_trackers} \tab Returns the list of event trackers associated with the account\cr
#'  \link[paws.machine.learning:personalize_list_filters]{list_filters} \tab Lists all filters that belong to a given dataset group\cr
#'  \link[paws.machine.learning:personalize_list_metric_attribution_metrics]{list_metric_attribution_metrics} \tab Lists the metrics for the metric attribution\cr
#'  \link[paws.machine.learning:personalize_list_metric_attributions]{list_metric_attributions} \tab Lists metric attributions\cr
#'  \link[paws.machine.learning:personalize_list_recipes]{list_recipes} \tab Returns a list of available recipes\cr
#'  \link[paws.machine.learning:personalize_list_recommenders]{list_recommenders} \tab Returns a list of recommenders in a given Domain dataset group\cr
#'  \link[paws.machine.learning:personalize_list_schemas]{list_schemas} \tab Returns the list of schemas associated with the account\cr
#'  \link[paws.machine.learning:personalize_list_solutions]{list_solutions} \tab Returns a list of solutions in a given dataset group\cr
#'  \link[paws.machine.learning:personalize_list_solution_versions]{list_solution_versions} \tab Returns a list of solution versions for the given solution\cr
#'  \link[paws.machine.learning:personalize_list_tags_for_resource]{list_tags_for_resource} \tab Get a list of tags attached to a resource\cr
#'  \link[paws.machine.learning:personalize_start_recommender]{start_recommender} \tab Starts a recommender that is INACTIVE\cr
#'  \link[paws.machine.learning:personalize_stop_recommender]{stop_recommender} \tab Stops a recommender that is ACTIVE\cr
#'  \link[paws.machine.learning:personalize_stop_solution_version_creation]{stop_solution_version_creation} \tab Stops creating a solution version that is in a state of CREATE_PENDING or CREATE IN_PROGRESS\cr
#'  \link[paws.machine.learning:personalize_tag_resource]{tag_resource} \tab Add a list of tags to a resource\cr
#'  \link[paws.machine.learning:personalize_untag_resource]{untag_resource} \tab Removes the specified tags that are attached to a resource\cr
#'  \link[paws.machine.learning:personalize_update_campaign]{update_campaign} \tab Updates a campaign to deploy a retrained solution version with an existing campaign, change your campaign's minProvisionedTPS, or modify your campaign's configuration\cr
#'  \link[paws.machine.learning:personalize_update_dataset]{update_dataset} \tab Update a dataset to replace its schema with a new or existing one\cr
#'  \link[paws.machine.learning:personalize_update_metric_attribution]{update_metric_attribution} \tab Updates a metric attribution\cr
#'  \link[paws.machine.learning:personalize_update_recommender]{update_recommender} \tab Updates the recommender to modify the recommender configuration\cr
#'  \link[paws.machine.learning:personalize_update_solution]{update_solution} \tab Updates an Amazon Personalize solution to use a different automatic training configuration
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname personalize
#' @export
personalize <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::personalize(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Personalize Events
#'
#' @description
#' Amazon Personalize can consume real-time user event data, such as
#' *stream* or *click* data, and use it for model training either alone or
#' combined with historical data. For more information see [Recording item
#' interaction
#' events](https://docs.aws.amazon.com/personalize/latest/dg/recording-item-interaction-events.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- personalizeevents(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- personalizeevents()
#' svc$put_action_interactions(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:personalizeevents_put_action_interactions]{put_action_interactions} \tab Records action interaction event data\cr
#'  \link[paws.machine.learning:personalizeevents_put_actions]{put_actions} \tab Adds one or more actions to an Actions dataset\cr
#'  \link[paws.machine.learning:personalizeevents_put_events]{put_events} \tab Records item interaction event data\cr
#'  \link[paws.machine.learning:personalizeevents_put_items]{put_items} \tab Adds one or more items to an Items dataset\cr
#'  \link[paws.machine.learning:personalizeevents_put_users]{put_users} \tab Adds one or more users to a Users dataset
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname personalizeevents
#' @export
personalizeevents <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::personalizeevents(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Personalize Runtime
#'
#' 
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- personalizeruntime(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- personalizeruntime()
#' svc$get_action_recommendations(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:personalizeruntime_get_action_recommendations]{get_action_recommendations} \tab Returns a list of recommended actions in sorted in descending order by prediction score\cr
#'  \link[paws.machine.learning:personalizeruntime_get_personalized_ranking]{get_personalized_ranking} \tab Re-ranks a list of recommended items for the given user\cr
#'  \link[paws.machine.learning:personalizeruntime_get_recommendations]{get_recommendations} \tab Returns a list of recommended items
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname personalizeruntime
#' @export
personalizeruntime <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::personalizeruntime(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Polly
#'
#' @description
#' Amazon Polly is a web service that makes it easy to synthesize speech
#' from text.
#' 
#' The Amazon Polly service provides API operations for synthesizing
#' high-quality speech from plain text and Speech Synthesis Markup Language
#' (SSML), along with managing pronunciations lexicons that enable you to
#' get the best results for your application domain.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- polly(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- polly()
#' # Deletes a specified pronunciation lexicon stored in an AWS Region.
#' svc$delete_lexicon(
#'   Name = "example"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:polly_delete_lexicon]{delete_lexicon} \tab Deletes the specified pronunciation lexicon stored in an Amazon Web Services Region\cr
#'  \link[paws.machine.learning:polly_describe_voices]{describe_voices} \tab Returns the list of voices that are available for use when requesting speech synthesis\cr
#'  \link[paws.machine.learning:polly_get_lexicon]{get_lexicon} \tab Returns the content of the specified pronunciation lexicon stored in an Amazon Web Services Region\cr
#'  \link[paws.machine.learning:polly_get_speech_synthesis_task]{get_speech_synthesis_task} \tab Retrieves a specific SpeechSynthesisTask object based on its TaskID\cr
#'  \link[paws.machine.learning:polly_list_lexicons]{list_lexicons} \tab Returns a list of pronunciation lexicons stored in an Amazon Web Services Region\cr
#'  \link[paws.machine.learning:polly_list_speech_synthesis_tasks]{list_speech_synthesis_tasks} \tab Returns a list of SpeechSynthesisTask objects ordered by their creation date\cr
#'  \link[paws.machine.learning:polly_put_lexicon]{put_lexicon} \tab Stores a pronunciation lexicon in an Amazon Web Services Region\cr
#'  \link[paws.machine.learning:polly_start_speech_synthesis_task]{start_speech_synthesis_task} \tab Allows the creation of an asynchronous synthesis task, by starting a new SpeechSynthesisTask\cr
#'  \link[paws.machine.learning:polly_synthesize_speech]{synthesize_speech} \tab Synthesizes UTF-8 input, plain text or SSML, to a stream of bytes
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname polly
#' @export
polly <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::polly(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Rekognition
#'
#' @description
#' This is the API Reference for [Amazon Rekognition
#' Image](https://docs.aws.amazon.com/rekognition/latest/dg/images.html),
#' [Amazon Rekognition Custom
#' Labels](https://docs.aws.amazon.com/rekognition/latest/customlabels-dg/what-is.html),
#' [Amazon Rekognition Stored
#' Video](https://docs.aws.amazon.com/rekognition/latest/dg/video.html),
#' [Amazon Rekognition Streaming
#' Video](https://docs.aws.amazon.com/rekognition/latest/dg/streaming-video.html).
#' It provides descriptions of actions, data types, common parameters, and
#' common errors.
#' 
#' **Amazon Rekognition Image**
#' 
#' -   `associate_faces`
#' 
#' -   `compare_faces`
#' 
#' -   `create_collection`
#' 
#' -   `create_user`
#' 
#' -   `delete_collection`
#' 
#' -   `delete_faces`
#' 
#' -   `delete_user`
#' 
#' -   `describe_collection`
#' 
#' -   `detect_faces`
#' 
#' -   `detect_labels`
#' 
#' -   `detect_moderation_labels`
#' 
#' -   `detect_protective_equipment`
#' 
#' -   `detect_text`
#' 
#' -   `disassociate_faces`
#' 
#' -   `get_celebrity_info`
#' 
#' -   `get_media_analysis_job`
#' 
#' -   `index_faces`
#' 
#' -   `list_collections`
#' 
#' -   [ListMediaAnalysisJob](https://docs.aws.amazon.com/rekognition/latest/APIReference/)
#' 
#' -   `list_faces`
#' 
#' -   `list_users`
#' 
#' -   `recognize_celebrities`
#' 
#' -   `search_faces`
#' 
#' -   `search_faces_by_image`
#' 
#' -   `search_users`
#' 
#' -   `search_users_by_image`
#' 
#' -   `start_media_analysis_job`
#' 
#' **Amazon Rekognition Custom Labels**
#' 
#' -   `copy_project_version`
#' 
#' -   `create_dataset`
#' 
#' -   `create_project`
#' 
#' -   `create_project_version`
#' 
#' -   `delete_dataset`
#' 
#' -   `delete_project`
#' 
#' -   `delete_project_policy`
#' 
#' -   `delete_project_version`
#' 
#' -   `describe_dataset`
#' 
#' -   `describe_projects`
#' 
#' -   `describe_project_versions`
#' 
#' -   `detect_custom_labels`
#' 
#' -   `distribute_dataset_entries`
#' 
#' -   `list_dataset_entries`
#' 
#' -   `list_dataset_labels`
#' 
#' -   `list_project_policies`
#' 
#' -   `put_project_policy`
#' 
#' -   `start_project_version`
#' 
#' -   `stop_project_version`
#' 
#' -   `update_dataset_entries`
#' 
#' **Amazon Rekognition Video Stored Video**
#' 
#' -   `get_celebrity_recognition`
#' 
#' -   `get_content_moderation`
#' 
#' -   `get_face_detection`
#' 
#' -   `get_face_search`
#' 
#' -   `get_label_detection`
#' 
#' -   `get_person_tracking`
#' 
#' -   `get_segment_detection`
#' 
#' -   `get_text_detection`
#' 
#' -   `start_celebrity_recognition`
#' 
#' -   `start_content_moderation`
#' 
#' -   `start_face_detection`
#' 
#' -   `start_face_search`
#' 
#' -   `start_label_detection`
#' 
#' -   `start_person_tracking`
#' 
#' -   `start_segment_detection`
#' 
#' -   `start_text_detection`
#' 
#' **Amazon Rekognition Video Streaming Video**
#' 
#' -   `create_stream_processor`
#' 
#' -   `delete_stream_processor`
#' 
#' -   `describe_stream_processor`
#' 
#' -   `list_stream_processors`
#' 
#' -   `start_stream_processor`
#' 
#' -   `stop_stream_processor`
#' 
#' -   `update_stream_processor`
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- rekognition(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- rekognition()
#' # This operation compares the largest face detected in the source image
#' # with each face detected in the target image.
#' svc$compare_faces(
#'   SimilarityThreshold = 90L,
#'   SourceImage = list(
#'     S3Object = list(
#'       Bucket = "mybucket",
#'       Name = "mysourceimage"
#'     )
#'   ),
#'   TargetImage = list(
#'     S3Object = list(
#'       Bucket = "mybucket",
#'       Name = "mytargetimage"
#'     )
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:rekognition_associate_faces]{associate_faces} \tab Associates one or more faces with an existing UserID\cr
#'  \link[paws.machine.learning:rekognition_compare_faces]{compare_faces} \tab Compares a face in the source input image with each of the 100 largest faces detected in the target input image\cr
#'  \link[paws.machine.learning:rekognition_copy_project_version]{copy_project_version} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_create_collection]{create_collection} \tab Creates a collection in an AWS Region\cr
#'  \link[paws.machine.learning:rekognition_create_dataset]{create_dataset} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_create_face_liveness_session]{create_face_liveness_session} \tab This API operation initiates a Face Liveness session\cr
#'  \link[paws.machine.learning:rekognition_create_project]{create_project} \tab Creates a new Amazon Rekognition project\cr
#'  \link[paws.machine.learning:rekognition_create_project_version]{create_project_version} \tab Creates a new version of Amazon Rekognition project (like a Custom Labels model or a custom adapter) and begins training\cr
#'  \link[paws.machine.learning:rekognition_create_stream_processor]{create_stream_processor} \tab Creates an Amazon Rekognition stream processor that you can use to detect and recognize faces or to detect labels in a streaming video\cr
#'  \link[paws.machine.learning:rekognition_create_user]{create_user} \tab Creates a new User within a collection specified by CollectionId\cr
#'  \link[paws.machine.learning:rekognition_delete_collection]{delete_collection} \tab Deletes the specified collection\cr
#'  \link[paws.machine.learning:rekognition_delete_dataset]{delete_dataset} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_delete_faces]{delete_faces} \tab Deletes faces from a collection\cr
#'  \link[paws.machine.learning:rekognition_delete_project]{delete_project} \tab Deletes a Amazon Rekognition project\cr
#'  \link[paws.machine.learning:rekognition_delete_project_policy]{delete_project_policy} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_delete_project_version]{delete_project_version} \tab Deletes a Rekognition project model or project version, like a Amazon Rekognition Custom Labels model or a custom adapter\cr
#'  \link[paws.machine.learning:rekognition_delete_stream_processor]{delete_stream_processor} \tab Deletes the stream processor identified by Name\cr
#'  \link[paws.machine.learning:rekognition_delete_user]{delete_user} \tab Deletes the specified UserID within the collection\cr
#'  \link[paws.machine.learning:rekognition_describe_collection]{describe_collection} \tab Describes the specified collection\cr
#'  \link[paws.machine.learning:rekognition_describe_dataset]{describe_dataset} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_describe_projects]{describe_projects} \tab Gets information about your Rekognition projects\cr
#'  \link[paws.machine.learning:rekognition_describe_project_versions]{describe_project_versions} \tab Lists and describes the versions of an Amazon Rekognition project\cr
#'  \link[paws.machine.learning:rekognition_describe_stream_processor]{describe_stream_processor} \tab Provides information about a stream processor created by CreateStreamProcessor\cr
#'  \link[paws.machine.learning:rekognition_detect_custom_labels]{detect_custom_labels} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_detect_faces]{detect_faces} \tab Detects faces within an image that is provided as input\cr
#'  \link[paws.machine.learning:rekognition_detect_labels]{detect_labels} \tab Detects instances of real-world entities within an image (JPEG or PNG) provided as input\cr
#'  \link[paws.machine.learning:rekognition_detect_moderation_labels]{detect_moderation_labels} \tab Detects unsafe content in a specified JPEG or PNG format image\cr
#'  \link[paws.machine.learning:rekognition_detect_protective_equipment]{detect_protective_equipment} \tab Detects Personal Protective Equipment (PPE) worn by people detected in an image\cr
#'  \link[paws.machine.learning:rekognition_detect_text]{detect_text} \tab Detects text in the input image and converts it into machine-readable text\cr
#'  \link[paws.machine.learning:rekognition_disassociate_faces]{disassociate_faces} \tab Removes the association between a Face supplied in an array of FaceIds and the User\cr
#'  \link[paws.machine.learning:rekognition_distribute_dataset_entries]{distribute_dataset_entries} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_get_celebrity_info]{get_celebrity_info} \tab Gets the name and additional information about a celebrity based on their Amazon Rekognition ID\cr
#'  \link[paws.machine.learning:rekognition_get_celebrity_recognition]{get_celebrity_recognition} \tab Gets the celebrity recognition results for a Amazon Rekognition Video analysis started by StartCelebrityRecognition\cr
#'  \link[paws.machine.learning:rekognition_get_content_moderation]{get_content_moderation} \tab Gets the inappropriate, unwanted, or offensive content analysis results for a Amazon Rekognition Video analysis started by StartContentModeration\cr
#'  \link[paws.machine.learning:rekognition_get_face_detection]{get_face_detection} \tab Gets face detection results for a Amazon Rekognition Video analysis started by StartFaceDetection\cr
#'  \link[paws.machine.learning:rekognition_get_face_liveness_session_results]{get_face_liveness_session_results} \tab Retrieves the results of a specific Face Liveness session\cr
#'  \link[paws.machine.learning:rekognition_get_face_search]{get_face_search} \tab Gets the face search results for Amazon Rekognition Video face search started by StartFaceSearch\cr
#'  \link[paws.machine.learning:rekognition_get_label_detection]{get_label_detection} \tab Gets the label detection results of a Amazon Rekognition Video analysis started by StartLabelDetection\cr
#'  \link[paws.machine.learning:rekognition_get_media_analysis_job]{get_media_analysis_job} \tab Retrieves the results for a given media analysis job\cr
#'  \link[paws.machine.learning:rekognition_get_person_tracking]{get_person_tracking} \tab Gets the path tracking results of a Amazon Rekognition Video analysis started by StartPersonTracking\cr
#'  \link[paws.machine.learning:rekognition_get_segment_detection]{get_segment_detection} \tab Gets the segment detection results of a Amazon Rekognition Video analysis started by StartSegmentDetection\cr
#'  \link[paws.machine.learning:rekognition_get_text_detection]{get_text_detection} \tab Gets the text detection results of a Amazon Rekognition Video analysis started by StartTextDetection\cr
#'  \link[paws.machine.learning:rekognition_index_faces]{index_faces} \tab Detects faces in the input image and adds them to the specified collection\cr
#'  \link[paws.machine.learning:rekognition_list_collections]{list_collections} \tab Returns list of collection IDs in your account\cr
#'  \link[paws.machine.learning:rekognition_list_dataset_entries]{list_dataset_entries} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_list_dataset_labels]{list_dataset_labels} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_list_faces]{list_faces} \tab Returns metadata for faces in the specified collection\cr
#'  \link[paws.machine.learning:rekognition_list_media_analysis_jobs]{list_media_analysis_jobs} \tab Returns a list of media analysis jobs\cr
#'  \link[paws.machine.learning:rekognition_list_project_policies]{list_project_policies} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_list_stream_processors]{list_stream_processors} \tab Gets a list of stream processors that you have created with CreateStreamProcessor\cr
#'  \link[paws.machine.learning:rekognition_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags in an Amazon Rekognition collection, stream processor, or Custom Labels model\cr
#'  \link[paws.machine.learning:rekognition_list_users]{list_users} \tab Returns metadata of the User such as UserID in the specified collection\cr
#'  \link[paws.machine.learning:rekognition_put_project_policy]{put_project_policy} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_recognize_celebrities]{recognize_celebrities} \tab Returns an array of celebrities recognized in the input image\cr
#'  \link[paws.machine.learning:rekognition_search_faces]{search_faces} \tab For a given input face ID, searches for matching faces in the collection the face belongs to\cr
#'  \link[paws.machine.learning:rekognition_search_faces_by_image]{search_faces_by_image} \tab For a given input image, first detects the largest face in the image, and then searches the specified collection for matching faces\cr
#'  \link[paws.machine.learning:rekognition_search_users]{search_users} \tab Searches for UserIDs within a collection based on a FaceId or UserId\cr
#'  \link[paws.machine.learning:rekognition_search_users_by_image]{search_users_by_image} \tab Searches for UserIDs using a supplied image\cr
#'  \link[paws.machine.learning:rekognition_start_celebrity_recognition]{start_celebrity_recognition} \tab Starts asynchronous recognition of celebrities in a stored video\cr
#'  \link[paws.machine.learning:rekognition_start_content_moderation]{start_content_moderation} \tab Starts asynchronous detection of inappropriate, unwanted, or offensive content in a stored video\cr
#'  \link[paws.machine.learning:rekognition_start_face_detection]{start_face_detection} \tab Starts asynchronous detection of faces in a stored video\cr
#'  \link[paws.machine.learning:rekognition_start_face_search]{start_face_search} \tab Starts the asynchronous search for faces in a collection that match the faces of persons detected in a stored video\cr
#'  \link[paws.machine.learning:rekognition_start_label_detection]{start_label_detection} \tab Starts asynchronous detection of labels in a stored video\cr
#'  \link[paws.machine.learning:rekognition_start_media_analysis_job]{start_media_analysis_job} \tab Initiates a new media analysis job\cr
#'  \link[paws.machine.learning:rekognition_start_person_tracking]{start_person_tracking} \tab Starts the asynchronous tracking of a person's path in a stored video\cr
#'  \link[paws.machine.learning:rekognition_start_project_version]{start_project_version} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_start_segment_detection]{start_segment_detection} \tab Starts asynchronous detection of segment detection in a stored video\cr
#'  \link[paws.machine.learning:rekognition_start_stream_processor]{start_stream_processor} \tab Starts processing a stream processor\cr
#'  \link[paws.machine.learning:rekognition_start_text_detection]{start_text_detection} \tab Starts asynchronous detection of text in a stored video\cr
#'  \link[paws.machine.learning:rekognition_stop_project_version]{stop_project_version} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_stop_stream_processor]{stop_stream_processor} \tab Stops a running stream processor that was created by CreateStreamProcessor\cr
#'  \link[paws.machine.learning:rekognition_tag_resource]{tag_resource} \tab Adds one or more key-value tags to an Amazon Rekognition collection, stream processor, or Custom Labels model\cr
#'  \link[paws.machine.learning:rekognition_untag_resource]{untag_resource} \tab Removes one or more tags from an Amazon Rekognition collection, stream processor, or Custom Labels model\cr
#'  \link[paws.machine.learning:rekognition_update_dataset_entries]{update_dataset_entries} \tab This operation applies only to Amazon Rekognition Custom Labels\cr
#'  \link[paws.machine.learning:rekognition_update_stream_processor]{update_stream_processor} \tab Allows you to update a stream processor
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname rekognition
#' @export
rekognition <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::rekognition(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon SageMaker Service
#'
#' @description
#' Provides APIs for creating and managing SageMaker resources.
#' 
#' Other Resources:
#' 
#' -   [SageMaker Developer
#'     Guide](https://docs.aws.amazon.com/sagemaker/latest/dg/whatis.html#first-time-user)
#' 
#' -   [Amazon Augmented AI Runtime API
#'     Reference](https://docs.aws.amazon.com/augmented-ai/2019-11-07/APIReference/Welcome.html)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sagemaker(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sagemaker()
#' svc$add_association(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:sagemaker_add_association]{add_association} \tab Creates an association between the source and the destination\cr
#'  \link[paws.machine.learning:sagemaker_add_tags]{add_tags} \tab Adds or overwrites one or more tags for the specified SageMaker resource\cr
#'  \link[paws.machine.learning:sagemaker_associate_trial_component]{associate_trial_component} \tab Associates a trial component with a trial\cr
#'  \link[paws.machine.learning:sagemaker_batch_delete_cluster_nodes]{batch_delete_cluster_nodes} \tab Deletes specific nodes within a SageMaker HyperPod cluster\cr
#'  \link[paws.machine.learning:sagemaker_batch_describe_model_package]{batch_describe_model_package} \tab This action batch describes a list of versioned model packages\cr
#'  \link[paws.machine.learning:sagemaker_create_action]{create_action} \tab Creates an action\cr
#'  \link[paws.machine.learning:sagemaker_create_algorithm]{create_algorithm} \tab Create a machine learning algorithm that you can use in SageMaker and list in the Amazon Web Services Marketplace\cr
#'  \link[paws.machine.learning:sagemaker_create_app]{create_app} \tab Creates a running app for the specified UserProfile\cr
#'  \link[paws.machine.learning:sagemaker_create_app_image_config]{create_app_image_config} \tab Creates a configuration for running a SageMaker AI image as a KernelGateway app\cr
#'  \link[paws.machine.learning:sagemaker_create_artifact]{create_artifact} \tab Creates an artifact\cr
#'  \link[paws.machine.learning:sagemaker_create_auto_ml_job]{create_auto_ml_job} \tab Creates an Autopilot job also referred to as Autopilot experiment or AutoML job\cr
#'  \link[paws.machine.learning:sagemaker_create_auto_ml_job_v2]{create_auto_ml_job_v2} \tab Creates an Autopilot job also referred to as Autopilot experiment or AutoML job V2\cr
#'  \link[paws.machine.learning:sagemaker_create_cluster]{create_cluster} \tab Creates a SageMaker HyperPod cluster\cr
#'  \link[paws.machine.learning:sagemaker_create_cluster_scheduler_config]{create_cluster_scheduler_config} \tab Create cluster policy configuration\cr
#'  \link[paws.machine.learning:sagemaker_create_code_repository]{create_code_repository} \tab Creates a Git repository as a resource in your SageMaker AI account\cr
#'  \link[paws.machine.learning:sagemaker_create_compilation_job]{create_compilation_job} \tab Starts a model compilation job\cr
#'  \link[paws.machine.learning:sagemaker_create_compute_quota]{create_compute_quota} \tab Create compute allocation definition\cr
#'  \link[paws.machine.learning:sagemaker_create_context]{create_context} \tab Creates a context\cr
#'  \link[paws.machine.learning:sagemaker_create_data_quality_job_definition]{create_data_quality_job_definition} \tab Creates a definition for a job that monitors data quality and drift\cr
#'  \link[paws.machine.learning:sagemaker_create_device_fleet]{create_device_fleet} \tab Creates a device fleet\cr
#'  \link[paws.machine.learning:sagemaker_create_domain]{create_domain} \tab Creates a Domain\cr
#'  \link[paws.machine.learning:sagemaker_create_edge_deployment_plan]{create_edge_deployment_plan} \tab Creates an edge deployment plan, consisting of multiple stages\cr
#'  \link[paws.machine.learning:sagemaker_create_edge_deployment_stage]{create_edge_deployment_stage} \tab Creates a new stage in an existing edge deployment plan\cr
#'  \link[paws.machine.learning:sagemaker_create_edge_packaging_job]{create_edge_packaging_job} \tab Starts a SageMaker Edge Manager model packaging job\cr
#'  \link[paws.machine.learning:sagemaker_create_endpoint]{create_endpoint} \tab Creates an endpoint using the endpoint configuration specified in the request\cr
#'  \link[paws.machine.learning:sagemaker_create_endpoint_config]{create_endpoint_config} \tab Creates an endpoint configuration that SageMaker hosting services uses to deploy models\cr
#'  \link[paws.machine.learning:sagemaker_create_experiment]{create_experiment} \tab Creates a SageMaker experiment\cr
#'  \link[paws.machine.learning:sagemaker_create_feature_group]{create_feature_group} \tab Create a new FeatureGroup\cr
#'  \link[paws.machine.learning:sagemaker_create_flow_definition]{create_flow_definition} \tab Creates a flow definition\cr
#'  \link[paws.machine.learning:sagemaker_create_hub]{create_hub} \tab Create a hub\cr
#'  \link[paws.machine.learning:sagemaker_create_hub_content_reference]{create_hub_content_reference} \tab Create a hub content reference in order to add a model in the JumpStart public hub to a private hub\cr
#'  \link[paws.machine.learning:sagemaker_create_human_task_ui]{create_human_task_ui} \tab Defines the settings you will use for the human review workflow user interface\cr
#'  \link[paws.machine.learning:sagemaker_create_hyper_parameter_tuning_job]{create_hyper_parameter_tuning_job} \tab Starts a hyperparameter tuning job\cr
#'  \link[paws.machine.learning:sagemaker_create_image]{create_image} \tab Creates a custom SageMaker AI image\cr
#'  \link[paws.machine.learning:sagemaker_create_image_version]{create_image_version} \tab Creates a version of the SageMaker AI image specified by ImageName\cr
#'  \link[paws.machine.learning:sagemaker_create_inference_component]{create_inference_component} \tab Creates an inference component, which is a SageMaker AI hosting object that you can use to deploy a model to an endpoint\cr
#'  \link[paws.machine.learning:sagemaker_create_inference_experiment]{create_inference_experiment} \tab Creates an inference experiment using the configurations specified in the request\cr
#'  \link[paws.machine.learning:sagemaker_create_inference_recommendations_job]{create_inference_recommendations_job} \tab Starts a recommendation job\cr
#'  \link[paws.machine.learning:sagemaker_create_labeling_job]{create_labeling_job} \tab Creates a job that uses workers to label the data objects in your input dataset\cr
#'  \link[paws.machine.learning:sagemaker_create_mlflow_tracking_server]{create_mlflow_tracking_server} \tab Creates an MLflow Tracking Server using a general purpose Amazon S3 bucket as the artifact store\cr
#'  \link[paws.machine.learning:sagemaker_create_model]{create_model} \tab Creates a model in SageMaker\cr
#'  \link[paws.machine.learning:sagemaker_create_model_bias_job_definition]{create_model_bias_job_definition} \tab Creates the definition for a model bias job\cr
#'  \link[paws.machine.learning:sagemaker_create_model_card]{create_model_card} \tab Creates an Amazon SageMaker Model Card\cr
#'  \link[paws.machine.learning:sagemaker_create_model_card_export_job]{create_model_card_export_job} \tab Creates an Amazon SageMaker Model Card export job\cr
#'  \link[paws.machine.learning:sagemaker_create_model_explainability_job_definition]{create_model_explainability_job_definition} \tab Creates the definition for a model explainability job\cr
#'  \link[paws.machine.learning:sagemaker_create_model_package]{create_model_package} \tab Creates a model package that you can use to create SageMaker models or list on Amazon Web Services Marketplace, or a versioned model that is part of a model group\cr
#'  \link[paws.machine.learning:sagemaker_create_model_package_group]{create_model_package_group} \tab Creates a model group\cr
#'  \link[paws.machine.learning:sagemaker_create_model_quality_job_definition]{create_model_quality_job_definition} \tab Creates a definition for a job that monitors model quality and drift\cr
#'  \link[paws.machine.learning:sagemaker_create_monitoring_schedule]{create_monitoring_schedule} \tab Creates a schedule that regularly starts Amazon SageMaker AI Processing Jobs to monitor the data captured for an Amazon SageMaker AI Endpoint\cr
#'  \link[paws.machine.learning:sagemaker_create_notebook_instance]{create_notebook_instance} \tab Creates an SageMaker AI notebook instance\cr
#'  \link[paws.machine.learning:sagemaker_create_notebook_instance_lifecycle_config]{create_notebook_instance_lifecycle_config} \tab Creates a lifecycle configuration that you can associate with a notebook instance\cr
#'  \link[paws.machine.learning:sagemaker_create_optimization_job]{create_optimization_job} \tab Creates a job that optimizes a model for inference performance\cr
#'  \link[paws.machine.learning:sagemaker_create_partner_app]{create_partner_app} \tab Creates an Amazon SageMaker Partner AI App\cr
#'  \link[paws.machine.learning:sagemaker_create_partner_app_presigned_url]{create_partner_app_presigned_url} \tab Creates a presigned URL to access an Amazon SageMaker Partner AI App\cr
#'  \link[paws.machine.learning:sagemaker_create_pipeline]{create_pipeline} \tab Creates a pipeline using a JSON pipeline definition\cr
#'  \link[paws.machine.learning:sagemaker_create_presigned_domain_url]{create_presigned_domain_url} \tab Creates a URL for a specified UserProfile in a Domain\cr
#'  \link[paws.machine.learning:sagemaker_create_presigned_mlflow_tracking_server_url]{create_presigned_mlflow_tracking_server_url} \tab Returns a presigned URL that you can use to connect to the MLflow UI attached to your tracking server\cr
#'  \link[paws.machine.learning:sagemaker_create_presigned_notebook_instance_url]{create_presigned_notebook_instance_url} \tab Returns a URL that you can use to connect to the Jupyter server from a notebook instance\cr
#'  \link[paws.machine.learning:sagemaker_create_processing_job]{create_processing_job} \tab Creates a processing job\cr
#'  \link[paws.machine.learning:sagemaker_create_project]{create_project} \tab Creates a machine learning (ML) project that can contain one or more templates that set up an ML pipeline from training to deploying an approved model\cr
#'  \link[paws.machine.learning:sagemaker_create_space]{create_space} \tab Creates a private space or a space used for real time collaboration in a domain\cr
#'  \link[paws.machine.learning:sagemaker_create_studio_lifecycle_config]{create_studio_lifecycle_config} \tab Creates a new Amazon SageMaker AI Studio Lifecycle Configuration\cr
#'  \link[paws.machine.learning:sagemaker_create_training_job]{create_training_job} \tab Starts a model training job\cr
#'  \link[paws.machine.learning:sagemaker_create_training_plan]{create_training_plan} \tab Creates a new training plan in SageMaker to reserve compute capacity\cr
#'  \link[paws.machine.learning:sagemaker_create_transform_job]{create_transform_job} \tab Starts a transform job\cr
#'  \link[paws.machine.learning:sagemaker_create_trial]{create_trial} \tab Creates an SageMaker trial\cr
#'  \link[paws.machine.learning:sagemaker_create_trial_component]{create_trial_component} \tab Creates a trial component, which is a stage of a machine learning trial\cr
#'  \link[paws.machine.learning:sagemaker_create_user_profile]{create_user_profile} \tab Creates a user profile\cr
#'  \link[paws.machine.learning:sagemaker_create_workforce]{create_workforce} \tab Use this operation to create a workforce\cr
#'  \link[paws.machine.learning:sagemaker_create_workteam]{create_workteam} \tab Creates a new work team for labeling your data\cr
#'  \link[paws.machine.learning:sagemaker_delete_action]{delete_action} \tab Deletes an action\cr
#'  \link[paws.machine.learning:sagemaker_delete_algorithm]{delete_algorithm} \tab Removes the specified algorithm from your account\cr
#'  \link[paws.machine.learning:sagemaker_delete_app]{delete_app} \tab Used to stop and delete an app\cr
#'  \link[paws.machine.learning:sagemaker_delete_app_image_config]{delete_app_image_config} \tab Deletes an AppImageConfig\cr
#'  \link[paws.machine.learning:sagemaker_delete_artifact]{delete_artifact} \tab Deletes an artifact\cr
#'  \link[paws.machine.learning:sagemaker_delete_association]{delete_association} \tab Deletes an association\cr
#'  \link[paws.machine.learning:sagemaker_delete_cluster]{delete_cluster} \tab Delete a SageMaker HyperPod cluster\cr
#'  \link[paws.machine.learning:sagemaker_delete_cluster_scheduler_config]{delete_cluster_scheduler_config} \tab Deletes the cluster policy of the cluster\cr
#'  \link[paws.machine.learning:sagemaker_delete_code_repository]{delete_code_repository} \tab Deletes the specified Git repository from your account\cr
#'  \link[paws.machine.learning:sagemaker_delete_compilation_job]{delete_compilation_job} \tab Deletes the specified compilation job\cr
#'  \link[paws.machine.learning:sagemaker_delete_compute_quota]{delete_compute_quota} \tab Deletes the compute allocation from the cluster\cr
#'  \link[paws.machine.learning:sagemaker_delete_context]{delete_context} \tab Deletes an context\cr
#'  \link[paws.machine.learning:sagemaker_delete_data_quality_job_definition]{delete_data_quality_job_definition} \tab Deletes a data quality monitoring job definition\cr
#'  \link[paws.machine.learning:sagemaker_delete_device_fleet]{delete_device_fleet} \tab Deletes a fleet\cr
#'  \link[paws.machine.learning:sagemaker_delete_domain]{delete_domain} \tab Used to delete a domain\cr
#'  \link[paws.machine.learning:sagemaker_delete_edge_deployment_plan]{delete_edge_deployment_plan} \tab Deletes an edge deployment plan if (and only if) all the stages in the plan are inactive or there are no stages in the plan\cr
#'  \link[paws.machine.learning:sagemaker_delete_edge_deployment_stage]{delete_edge_deployment_stage} \tab Delete a stage in an edge deployment plan if (and only if) the stage is inactive\cr
#'  \link[paws.machine.learning:sagemaker_delete_endpoint]{delete_endpoint} \tab Deletes an endpoint\cr
#'  \link[paws.machine.learning:sagemaker_delete_endpoint_config]{delete_endpoint_config} \tab Deletes an endpoint configuration\cr
#'  \link[paws.machine.learning:sagemaker_delete_experiment]{delete_experiment} \tab Deletes an SageMaker experiment\cr
#'  \link[paws.machine.learning:sagemaker_delete_feature_group]{delete_feature_group} \tab Delete the FeatureGroup and any data that was written to the OnlineStore of the FeatureGroup\cr
#'  \link[paws.machine.learning:sagemaker_delete_flow_definition]{delete_flow_definition} \tab Deletes the specified flow definition\cr
#'  \link[paws.machine.learning:sagemaker_delete_hub]{delete_hub} \tab Delete a hub\cr
#'  \link[paws.machine.learning:sagemaker_delete_hub_content]{delete_hub_content} \tab Delete the contents of a hub\cr
#'  \link[paws.machine.learning:sagemaker_delete_hub_content_reference]{delete_hub_content_reference} \tab Delete a hub content reference in order to remove a model from a private hub\cr
#'  \link[paws.machine.learning:sagemaker_delete_human_task_ui]{delete_human_task_ui} \tab Use this operation to delete a human task user interface (worker task template)\cr
#'  \link[paws.machine.learning:sagemaker_delete_hyper_parameter_tuning_job]{delete_hyper_parameter_tuning_job} \tab Deletes a hyperparameter tuning job\cr
#'  \link[paws.machine.learning:sagemaker_delete_image]{delete_image} \tab Deletes a SageMaker AI image and all versions of the image\cr
#'  \link[paws.machine.learning:sagemaker_delete_image_version]{delete_image_version} \tab Deletes a version of a SageMaker AI image\cr
#'  \link[paws.machine.learning:sagemaker_delete_inference_component]{delete_inference_component} \tab Deletes an inference component\cr
#'  \link[paws.machine.learning:sagemaker_delete_inference_experiment]{delete_inference_experiment} \tab Deletes an inference experiment\cr
#'  \link[paws.machine.learning:sagemaker_delete_mlflow_tracking_server]{delete_mlflow_tracking_server} \tab Deletes an MLflow Tracking Server\cr
#'  \link[paws.machine.learning:sagemaker_delete_model]{delete_model} \tab Deletes a model\cr
#'  \link[paws.machine.learning:sagemaker_delete_model_bias_job_definition]{delete_model_bias_job_definition} \tab Deletes an Amazon SageMaker AI model bias job definition\cr
#'  \link[paws.machine.learning:sagemaker_delete_model_card]{delete_model_card} \tab Deletes an Amazon SageMaker Model Card\cr
#'  \link[paws.machine.learning:sagemaker_delete_model_explainability_job_definition]{delete_model_explainability_job_definition} \tab Deletes an Amazon SageMaker AI model explainability job definition\cr
#'  \link[paws.machine.learning:sagemaker_delete_model_package]{delete_model_package} \tab Deletes a model package\cr
#'  \link[paws.machine.learning:sagemaker_delete_model_package_group]{delete_model_package_group} \tab Deletes the specified model group\cr
#'  \link[paws.machine.learning:sagemaker_delete_model_package_group_policy]{delete_model_package_group_policy} \tab Deletes a model group resource policy\cr
#'  \link[paws.machine.learning:sagemaker_delete_model_quality_job_definition]{delete_model_quality_job_definition} \tab Deletes the secified model quality monitoring job definition\cr
#'  \link[paws.machine.learning:sagemaker_delete_monitoring_schedule]{delete_monitoring_schedule} \tab Deletes a monitoring schedule\cr
#'  \link[paws.machine.learning:sagemaker_delete_notebook_instance]{delete_notebook_instance} \tab Deletes an SageMaker AI notebook instance\cr
#'  \link[paws.machine.learning:sagemaker_delete_notebook_instance_lifecycle_config]{delete_notebook_instance_lifecycle_config} \tab Deletes a notebook instance lifecycle configuration\cr
#'  \link[paws.machine.learning:sagemaker_delete_optimization_job]{delete_optimization_job} \tab Deletes an optimization job\cr
#'  \link[paws.machine.learning:sagemaker_delete_partner_app]{delete_partner_app} \tab Deletes a SageMaker Partner AI App\cr
#'  \link[paws.machine.learning:sagemaker_delete_pipeline]{delete_pipeline} \tab Deletes a pipeline if there are no running instances of the pipeline\cr
#'  \link[paws.machine.learning:sagemaker_delete_project]{delete_project} \tab Delete the specified project\cr
#'  \link[paws.machine.learning:sagemaker_delete_space]{delete_space} \tab Used to delete a space\cr
#'  \link[paws.machine.learning:sagemaker_delete_studio_lifecycle_config]{delete_studio_lifecycle_config} \tab Deletes the Amazon SageMaker AI Studio Lifecycle Configuration\cr
#'  \link[paws.machine.learning:sagemaker_delete_tags]{delete_tags} \tab Deletes the specified tags from an SageMaker resource\cr
#'  \link[paws.machine.learning:sagemaker_delete_trial]{delete_trial} \tab Deletes the specified trial\cr
#'  \link[paws.machine.learning:sagemaker_delete_trial_component]{delete_trial_component} \tab Deletes the specified trial component\cr
#'  \link[paws.machine.learning:sagemaker_delete_user_profile]{delete_user_profile} \tab Deletes a user profile\cr
#'  \link[paws.machine.learning:sagemaker_delete_workforce]{delete_workforce} \tab Use this operation to delete a workforce\cr
#'  \link[paws.machine.learning:sagemaker_delete_workteam]{delete_workteam} \tab Deletes an existing work team\cr
#'  \link[paws.machine.learning:sagemaker_deregister_devices]{deregister_devices} \tab Deregisters the specified devices\cr
#'  \link[paws.machine.learning:sagemaker_describe_action]{describe_action} \tab Describes an action\cr
#'  \link[paws.machine.learning:sagemaker_describe_algorithm]{describe_algorithm} \tab Returns a description of the specified algorithm that is in your account\cr
#'  \link[paws.machine.learning:sagemaker_describe_app]{describe_app} \tab Describes the app\cr
#'  \link[paws.machine.learning:sagemaker_describe_app_image_config]{describe_app_image_config} \tab Describes an AppImageConfig\cr
#'  \link[paws.machine.learning:sagemaker_describe_artifact]{describe_artifact} \tab Describes an artifact\cr
#'  \link[paws.machine.learning:sagemaker_describe_auto_ml_job]{describe_auto_ml_job} \tab Returns information about an AutoML job created by calling CreateAutoMLJob\cr
#'  \link[paws.machine.learning:sagemaker_describe_auto_ml_job_v2]{describe_auto_ml_job_v2} \tab Returns information about an AutoML job created by calling CreateAutoMLJobV2 or CreateAutoMLJob\cr
#'  \link[paws.machine.learning:sagemaker_describe_cluster]{describe_cluster} \tab Retrieves information of a SageMaker HyperPod cluster\cr
#'  \link[paws.machine.learning:sagemaker_describe_cluster_node]{describe_cluster_node} \tab Retrieves information of a node (also called a instance interchangeably) of a SageMaker HyperPod cluster\cr
#'  \link[paws.machine.learning:sagemaker_describe_cluster_scheduler_config]{describe_cluster_scheduler_config} \tab Description of the cluster policy\cr
#'  \link[paws.machine.learning:sagemaker_describe_code_repository]{describe_code_repository} \tab Gets details about the specified Git repository\cr
#'  \link[paws.machine.learning:sagemaker_describe_compilation_job]{describe_compilation_job} \tab Returns information about a model compilation job\cr
#'  \link[paws.machine.learning:sagemaker_describe_compute_quota]{describe_compute_quota} \tab Description of the compute allocation definition\cr
#'  \link[paws.machine.learning:sagemaker_describe_context]{describe_context} \tab Describes a context\cr
#'  \link[paws.machine.learning:sagemaker_describe_data_quality_job_definition]{describe_data_quality_job_definition} \tab Gets the details of a data quality monitoring job definition\cr
#'  \link[paws.machine.learning:sagemaker_describe_device]{describe_device} \tab Describes the device\cr
#'  \link[paws.machine.learning:sagemaker_describe_device_fleet]{describe_device_fleet} \tab A description of the fleet the device belongs to\cr
#'  \link[paws.machine.learning:sagemaker_describe_domain]{describe_domain} \tab The description of the domain\cr
#'  \link[paws.machine.learning:sagemaker_describe_edge_deployment_plan]{describe_edge_deployment_plan} \tab Describes an edge deployment plan with deployment status per stage\cr
#'  \link[paws.machine.learning:sagemaker_describe_edge_packaging_job]{describe_edge_packaging_job} \tab A description of edge packaging jobs\cr
#'  \link[paws.machine.learning:sagemaker_describe_endpoint]{describe_endpoint} \tab Returns the description of an endpoint\cr
#'  \link[paws.machine.learning:sagemaker_describe_endpoint_config]{describe_endpoint_config} \tab Returns the description of an endpoint configuration created using the CreateEndpointConfig API\cr
#'  \link[paws.machine.learning:sagemaker_describe_experiment]{describe_experiment} \tab Provides a list of an experiment's properties\cr
#'  \link[paws.machine.learning:sagemaker_describe_feature_group]{describe_feature_group} \tab Use this operation to describe a FeatureGroup\cr
#'  \link[paws.machine.learning:sagemaker_describe_feature_metadata]{describe_feature_metadata} \tab Shows the metadata for a feature within a feature group\cr
#'  \link[paws.machine.learning:sagemaker_describe_flow_definition]{describe_flow_definition} \tab Returns information about the specified flow definition\cr
#'  \link[paws.machine.learning:sagemaker_describe_hub]{describe_hub} \tab Describes a hub\cr
#'  \link[paws.machine.learning:sagemaker_describe_hub_content]{describe_hub_content} \tab Describe the content of a hub\cr
#'  \link[paws.machine.learning:sagemaker_describe_human_task_ui]{describe_human_task_ui} \tab Returns information about the requested human task user interface (worker task template)\cr
#'  \link[paws.machine.learning:sagemaker_describe_hyper_parameter_tuning_job]{describe_hyper_parameter_tuning_job} \tab Returns a description of a hyperparameter tuning job, depending on the fields selected\cr
#'  \link[paws.machine.learning:sagemaker_describe_image]{describe_image} \tab Describes a SageMaker AI image\cr
#'  \link[paws.machine.learning:sagemaker_describe_image_version]{describe_image_version} \tab Describes a version of a SageMaker AI image\cr
#'  \link[paws.machine.learning:sagemaker_describe_inference_component]{describe_inference_component} \tab Returns information about an inference component\cr
#'  \link[paws.machine.learning:sagemaker_describe_inference_experiment]{describe_inference_experiment} \tab Returns details about an inference experiment\cr
#'  \link[paws.machine.learning:sagemaker_describe_inference_recommendations_job]{describe_inference_recommendations_job} \tab Provides the results of the Inference Recommender job\cr
#'  \link[paws.machine.learning:sagemaker_describe_labeling_job]{describe_labeling_job} \tab Gets information about a labeling job\cr
#'  \link[paws.machine.learning:sagemaker_describe_lineage_group]{describe_lineage_group} \tab Provides a list of properties for the requested lineage group\cr
#'  \link[paws.machine.learning:sagemaker_describe_mlflow_tracking_server]{describe_mlflow_tracking_server} \tab Returns information about an MLflow Tracking Server\cr
#'  \link[paws.machine.learning:sagemaker_describe_model]{describe_model} \tab Describes a model that you created using the CreateModel API\cr
#'  \link[paws.machine.learning:sagemaker_describe_model_bias_job_definition]{describe_model_bias_job_definition} \tab Returns a description of a model bias job definition\cr
#'  \link[paws.machine.learning:sagemaker_describe_model_card]{describe_model_card} \tab Describes the content, creation time, and security configuration of an Amazon SageMaker Model Card\cr
#'  \link[paws.machine.learning:sagemaker_describe_model_card_export_job]{describe_model_card_export_job} \tab Describes an Amazon SageMaker Model Card export job\cr
#'  \link[paws.machine.learning:sagemaker_describe_model_explainability_job_definition]{describe_model_explainability_job_definition} \tab Returns a description of a model explainability job definition\cr
#'  \link[paws.machine.learning:sagemaker_describe_model_package]{describe_model_package} \tab Returns a description of the specified model package, which is used to create SageMaker models or list them on Amazon Web Services Marketplace\cr
#'  \link[paws.machine.learning:sagemaker_describe_model_package_group]{describe_model_package_group} \tab Gets a description for the specified model group\cr
#'  \link[paws.machine.learning:sagemaker_describe_model_quality_job_definition]{describe_model_quality_job_definition} \tab Returns a description of a model quality job definition\cr
#'  \link[paws.machine.learning:sagemaker_describe_monitoring_schedule]{describe_monitoring_schedule} \tab Describes the schedule for a monitoring job\cr
#'  \link[paws.machine.learning:sagemaker_describe_notebook_instance]{describe_notebook_instance} \tab Returns information about a notebook instance\cr
#'  \link[paws.machine.learning:sagemaker_describe_notebook_instance_lifecycle_config]{describe_notebook_instance_lifecycle_config} \tab Returns a description of a notebook instance lifecycle configuration\cr
#'  \link[paws.machine.learning:sagemaker_describe_optimization_job]{describe_optimization_job} \tab Provides the properties of the specified optimization job\cr
#'  \link[paws.machine.learning:sagemaker_describe_partner_app]{describe_partner_app} \tab Gets information about a SageMaker Partner AI App\cr
#'  \link[paws.machine.learning:sagemaker_describe_pipeline]{describe_pipeline} \tab Describes the details of a pipeline\cr
#'  \link[paws.machine.learning:sagemaker_describe_pipeline_definition_for_execution]{describe_pipeline_definition_for_execution} \tab Describes the details of an execution's pipeline definition\cr
#'  \link[paws.machine.learning:sagemaker_describe_pipeline_execution]{describe_pipeline_execution} \tab Describes the details of a pipeline execution\cr
#'  \link[paws.machine.learning:sagemaker_describe_processing_job]{describe_processing_job} \tab Returns a description of a processing job\cr
#'  \link[paws.machine.learning:sagemaker_describe_project]{describe_project} \tab Describes the details of a project\cr
#'  \link[paws.machine.learning:sagemaker_describe_space]{describe_space} \tab Describes the space\cr
#'  \link[paws.machine.learning:sagemaker_describe_studio_lifecycle_config]{describe_studio_lifecycle_config} \tab Describes the Amazon SageMaker AI Studio Lifecycle Configuration\cr
#'  \link[paws.machine.learning:sagemaker_describe_subscribed_workteam]{describe_subscribed_workteam} \tab Gets information about a work team provided by a vendor\cr
#'  \link[paws.machine.learning:sagemaker_describe_training_job]{describe_training_job} \tab Returns information about a training job\cr
#'  \link[paws.machine.learning:sagemaker_describe_training_plan]{describe_training_plan} \tab Retrieves detailed information about a specific training plan\cr
#'  \link[paws.machine.learning:sagemaker_describe_transform_job]{describe_transform_job} \tab Returns information about a transform job\cr
#'  \link[paws.machine.learning:sagemaker_describe_trial]{describe_trial} \tab Provides a list of a trial's properties\cr
#'  \link[paws.machine.learning:sagemaker_describe_trial_component]{describe_trial_component} \tab Provides a list of a trials component's properties\cr
#'  \link[paws.machine.learning:sagemaker_describe_user_profile]{describe_user_profile} \tab Describes a user profile\cr
#'  \link[paws.machine.learning:sagemaker_describe_workforce]{describe_workforce} \tab Lists private workforce information, including workforce name, Amazon Resource Name (ARN), and, if applicable, allowed IP address ranges (CIDRs)\cr
#'  \link[paws.machine.learning:sagemaker_describe_workteam]{describe_workteam} \tab Gets information about a specific work team\cr
#'  \link[paws.machine.learning:sagemaker_disable_sagemaker_servicecatalog_portfolio]{disable_sagemaker_servicecatalog_portfolio} \tab Disables using Service Catalog in SageMaker\cr
#'  \link[paws.machine.learning:sagemaker_disassociate_trial_component]{disassociate_trial_component} \tab Disassociates a trial component from a trial\cr
#'  \link[paws.machine.learning:sagemaker_enable_sagemaker_servicecatalog_portfolio]{enable_sagemaker_servicecatalog_portfolio} \tab Enables using Service Catalog in SageMaker\cr
#'  \link[paws.machine.learning:sagemaker_get_device_fleet_report]{get_device_fleet_report} \tab Describes a fleet\cr
#'  \link[paws.machine.learning:sagemaker_get_lineage_group_policy]{get_lineage_group_policy} \tab The resource policy for the lineage group\cr
#'  \link[paws.machine.learning:sagemaker_get_model_package_group_policy]{get_model_package_group_policy} \tab Gets a resource policy that manages access for a model group\cr
#'  \link[paws.machine.learning:sagemaker_get_sagemaker_servicecatalog_portfolio_status]{get_sagemaker_servicecatalog_portfolio_status} \tab Gets the status of Service Catalog in SageMaker\cr
#'  \link[paws.machine.learning:sagemaker_get_scaling_configuration_recommendation]{get_scaling_configuration_recommendation} \tab Starts an Amazon SageMaker Inference Recommender autoscaling recommendation job\cr
#'  \link[paws.machine.learning:sagemaker_get_search_suggestions]{get_search_suggestions} \tab An auto-complete API for the search functionality in the SageMaker console\cr
#'  \link[paws.machine.learning:sagemaker_import_hub_content]{import_hub_content} \tab Import hub content\cr
#'  \link[paws.machine.learning:sagemaker_list_actions]{list_actions} \tab Lists the actions in your account and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_algorithms]{list_algorithms} \tab Lists the machine learning algorithms that have been created\cr
#'  \link[paws.machine.learning:sagemaker_list_aliases]{list_aliases} \tab Lists the aliases of a specified image or image version\cr
#'  \link[paws.machine.learning:sagemaker_list_app_image_configs]{list_app_image_configs} \tab Lists the AppImageConfigs in your account and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_apps]{list_apps} \tab Lists apps\cr
#'  \link[paws.machine.learning:sagemaker_list_artifacts]{list_artifacts} \tab Lists the artifacts in your account and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_associations]{list_associations} \tab Lists the associations in your account and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_auto_ml_jobs]{list_auto_ml_jobs} \tab Request a list of jobs\cr
#'  \link[paws.machine.learning:sagemaker_list_candidates_for_auto_ml_job]{list_candidates_for_auto_ml_job} \tab List the candidates created for the job\cr
#'  \link[paws.machine.learning:sagemaker_list_cluster_nodes]{list_cluster_nodes} \tab Retrieves the list of instances (also called nodes interchangeably) in a SageMaker HyperPod cluster\cr
#'  \link[paws.machine.learning:sagemaker_list_clusters]{list_clusters} \tab Retrieves the list of SageMaker HyperPod clusters\cr
#'  \link[paws.machine.learning:sagemaker_list_cluster_scheduler_configs]{list_cluster_scheduler_configs} \tab List the cluster policy configurations\cr
#'  \link[paws.machine.learning:sagemaker_list_code_repositories]{list_code_repositories} \tab Gets a list of the Git repositories in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_compilation_jobs]{list_compilation_jobs} \tab Lists model compilation jobs that satisfy various filters\cr
#'  \link[paws.machine.learning:sagemaker_list_compute_quotas]{list_compute_quotas} \tab List the resource allocation definitions\cr
#'  \link[paws.machine.learning:sagemaker_list_contexts]{list_contexts} \tab Lists the contexts in your account and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_data_quality_job_definitions]{list_data_quality_job_definitions} \tab Lists the data quality job definitions in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_device_fleets]{list_device_fleets} \tab Returns a list of devices in the fleet\cr
#'  \link[paws.machine.learning:sagemaker_list_devices]{list_devices} \tab A list of devices\cr
#'  \link[paws.machine.learning:sagemaker_list_domains]{list_domains} \tab Lists the domains\cr
#'  \link[paws.machine.learning:sagemaker_list_edge_deployment_plans]{list_edge_deployment_plans} \tab Lists all edge deployment plans\cr
#'  \link[paws.machine.learning:sagemaker_list_edge_packaging_jobs]{list_edge_packaging_jobs} \tab Returns a list of edge packaging jobs\cr
#'  \link[paws.machine.learning:sagemaker_list_endpoint_configs]{list_endpoint_configs} \tab Lists endpoint configurations\cr
#'  \link[paws.machine.learning:sagemaker_list_endpoints]{list_endpoints} \tab Lists endpoints\cr
#'  \link[paws.machine.learning:sagemaker_list_experiments]{list_experiments} \tab Lists all the experiments in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_feature_groups]{list_feature_groups} \tab List FeatureGroups based on given filter and order\cr
#'  \link[paws.machine.learning:sagemaker_list_flow_definitions]{list_flow_definitions} \tab Returns information about the flow definitions in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_hub_contents]{list_hub_contents} \tab List the contents of a hub\cr
#'  \link[paws.machine.learning:sagemaker_list_hub_content_versions]{list_hub_content_versions} \tab List hub content versions\cr
#'  \link[paws.machine.learning:sagemaker_list_hubs]{list_hubs} \tab List all existing hubs\cr
#'  \link[paws.machine.learning:sagemaker_list_human_task_uis]{list_human_task_uis} \tab Returns information about the human task user interfaces in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_hyper_parameter_tuning_jobs]{list_hyper_parameter_tuning_jobs} \tab Gets a list of HyperParameterTuningJobSummary objects that describe the hyperparameter tuning jobs launched in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_images]{list_images} \tab Lists the images in your account and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_image_versions]{list_image_versions} \tab Lists the versions of a specified image and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_inference_components]{list_inference_components} \tab Lists the inference components in your account and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_inference_experiments]{list_inference_experiments} \tab Returns the list of all inference experiments\cr
#'  \link[paws.machine.learning:sagemaker_list_inference_recommendations_jobs]{list_inference_recommendations_jobs} \tab Lists recommendation jobs that satisfy various filters\cr
#'  \link[paws.machine.learning:sagemaker_list_inference_recommendations_job_steps]{list_inference_recommendations_job_steps} \tab Returns a list of the subtasks for an Inference Recommender job\cr
#'  \link[paws.machine.learning:sagemaker_list_labeling_jobs]{list_labeling_jobs} \tab Gets a list of labeling jobs\cr
#'  \link[paws.machine.learning:sagemaker_list_labeling_jobs_for_workteam]{list_labeling_jobs_for_workteam} \tab Gets a list of labeling jobs assigned to a specified work team\cr
#'  \link[paws.machine.learning:sagemaker_list_lineage_groups]{list_lineage_groups} \tab A list of lineage groups shared with your Amazon Web Services account\cr
#'  \link[paws.machine.learning:sagemaker_list_mlflow_tracking_servers]{list_mlflow_tracking_servers} \tab Lists all MLflow Tracking Servers\cr
#'  \link[paws.machine.learning:sagemaker_list_model_bias_job_definitions]{list_model_bias_job_definitions} \tab Lists model bias jobs definitions that satisfy various filters\cr
#'  \link[paws.machine.learning:sagemaker_list_model_card_export_jobs]{list_model_card_export_jobs} \tab List the export jobs for the Amazon SageMaker Model Card\cr
#'  \link[paws.machine.learning:sagemaker_list_model_cards]{list_model_cards} \tab List existing model cards\cr
#'  \link[paws.machine.learning:sagemaker_list_model_card_versions]{list_model_card_versions} \tab List existing versions of an Amazon SageMaker Model Card\cr
#'  \link[paws.machine.learning:sagemaker_list_model_explainability_job_definitions]{list_model_explainability_job_definitions} \tab Lists model explainability job definitions that satisfy various filters\cr
#'  \link[paws.machine.learning:sagemaker_list_model_metadata]{list_model_metadata} \tab Lists the domain, framework, task, and model name of standard machine learning models found in common model zoos\cr
#'  \link[paws.machine.learning:sagemaker_list_model_package_groups]{list_model_package_groups} \tab Gets a list of the model groups in your Amazon Web Services account\cr
#'  \link[paws.machine.learning:sagemaker_list_model_packages]{list_model_packages} \tab Lists the model packages that have been created\cr
#'  \link[paws.machine.learning:sagemaker_list_model_quality_job_definitions]{list_model_quality_job_definitions} \tab Gets a list of model quality monitoring job definitions in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_models]{list_models} \tab Lists models created with the CreateModel API\cr
#'  \link[paws.machine.learning:sagemaker_list_monitoring_alert_history]{list_monitoring_alert_history} \tab Gets a list of past alerts in a model monitoring schedule\cr
#'  \link[paws.machine.learning:sagemaker_list_monitoring_alerts]{list_monitoring_alerts} \tab Gets the alerts for a single monitoring schedule\cr
#'  \link[paws.machine.learning:sagemaker_list_monitoring_executions]{list_monitoring_executions} \tab Returns list of all monitoring job executions\cr
#'  \link[paws.machine.learning:sagemaker_list_monitoring_schedules]{list_monitoring_schedules} \tab Returns list of all monitoring schedules\cr
#'  \link[paws.machine.learning:sagemaker_list_notebook_instance_lifecycle_configs]{list_notebook_instance_lifecycle_configs} \tab Lists notebook instance lifestyle configurations created with the CreateNotebookInstanceLifecycleConfig API\cr
#'  \link[paws.machine.learning:sagemaker_list_notebook_instances]{list_notebook_instances} \tab Returns a list of the SageMaker AI notebook instances in the requester's account in an Amazon Web Services Region\cr
#'  \link[paws.machine.learning:sagemaker_list_optimization_jobs]{list_optimization_jobs} \tab Lists the optimization jobs in your account and their properties\cr
#'  \link[paws.machine.learning:sagemaker_list_partner_apps]{list_partner_apps} \tab Lists all of the SageMaker Partner AI Apps in an account\cr
#'  \link[paws.machine.learning:sagemaker_list_pipeline_executions]{list_pipeline_executions} \tab Gets a list of the pipeline executions\cr
#'  \link[paws.machine.learning:sagemaker_list_pipeline_execution_steps]{list_pipeline_execution_steps} \tab Gets a list of PipeLineExecutionStep objects\cr
#'  \link[paws.machine.learning:sagemaker_list_pipeline_parameters_for_execution]{list_pipeline_parameters_for_execution} \tab Gets a list of parameters for a pipeline execution\cr
#'  \link[paws.machine.learning:sagemaker_list_pipelines]{list_pipelines} \tab Gets a list of pipelines\cr
#'  \link[paws.machine.learning:sagemaker_list_processing_jobs]{list_processing_jobs} \tab Lists processing jobs that satisfy various filters\cr
#'  \link[paws.machine.learning:sagemaker_list_projects]{list_projects} \tab Gets a list of the projects in an Amazon Web Services account\cr
#'  \link[paws.machine.learning:sagemaker_list_resource_catalogs]{list_resource_catalogs} \tab Lists Amazon SageMaker Catalogs based on given filters and orders\cr
#'  \link[paws.machine.learning:sagemaker_list_spaces]{list_spaces} \tab Lists spaces\cr
#'  \link[paws.machine.learning:sagemaker_list_stage_devices]{list_stage_devices} \tab Lists devices allocated to the stage, containing detailed device information and deployment status\cr
#'  \link[paws.machine.learning:sagemaker_list_studio_lifecycle_configs]{list_studio_lifecycle_configs} \tab Lists the Amazon SageMaker AI Studio Lifecycle Configurations in your Amazon Web Services Account\cr
#'  \link[paws.machine.learning:sagemaker_list_subscribed_workteams]{list_subscribed_workteams} \tab Gets a list of the work teams that you are subscribed to in the Amazon Web Services Marketplace\cr
#'  \link[paws.machine.learning:sagemaker_list_tags]{list_tags} \tab Returns the tags for the specified SageMaker resource\cr
#'  \link[paws.machine.learning:sagemaker_list_training_jobs]{list_training_jobs} \tab Lists training jobs\cr
#'  \link[paws.machine.learning:sagemaker_list_training_jobs_for_hyper_parameter_tuning_job]{list_training_jobs_for_hyper_parameter_tuning_job} \tab Gets a list of TrainingJobSummary objects that describe the training jobs that a hyperparameter tuning job launched\cr
#'  \link[paws.machine.learning:sagemaker_list_training_plans]{list_training_plans} \tab Retrieves a list of training plans for the current account\cr
#'  \link[paws.machine.learning:sagemaker_list_transform_jobs]{list_transform_jobs} \tab Lists transform jobs\cr
#'  \link[paws.machine.learning:sagemaker_list_trial_components]{list_trial_components} \tab Lists the trial components in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_trials]{list_trials} \tab Lists the trials in your account\cr
#'  \link[paws.machine.learning:sagemaker_list_user_profiles]{list_user_profiles} \tab Lists user profiles\cr
#'  \link[paws.machine.learning:sagemaker_list_workforces]{list_workforces} \tab Use this operation to list all private and vendor workforces in an Amazon Web Services Region\cr
#'  \link[paws.machine.learning:sagemaker_list_workteams]{list_workteams} \tab Gets a list of private work teams that you have defined in a region\cr
#'  \link[paws.machine.learning:sagemaker_put_model_package_group_policy]{put_model_package_group_policy} \tab Adds a resouce policy to control access to a model group\cr
#'  \link[paws.machine.learning:sagemaker_query_lineage]{query_lineage} \tab Use this action to inspect your lineage and discover relationships between entities\cr
#'  \link[paws.machine.learning:sagemaker_register_devices]{register_devices} \tab Register devices\cr
#'  \link[paws.machine.learning:sagemaker_render_ui_template]{render_ui_template} \tab Renders the UI template so that you can preview the worker's experience\cr
#'  \link[paws.machine.learning:sagemaker_retry_pipeline_execution]{retry_pipeline_execution} \tab Retry the execution of the pipeline\cr
#'  \link[paws.machine.learning:sagemaker_search]{search} \tab Finds SageMaker resources that match a search query\cr
#'  \link[paws.machine.learning:sagemaker_search_training_plan_offerings]{search_training_plan_offerings} \tab Searches for available training plan offerings based on specified criteria\cr
#'  \link[paws.machine.learning:sagemaker_send_pipeline_execution_step_failure]{send_pipeline_execution_step_failure} \tab Notifies the pipeline that the execution of a callback step failed, along with a message describing why\cr
#'  \link[paws.machine.learning:sagemaker_send_pipeline_execution_step_success]{send_pipeline_execution_step_success} \tab Notifies the pipeline that the execution of a callback step succeeded and provides a list of the step's output parameters\cr
#'  \link[paws.machine.learning:sagemaker_start_edge_deployment_stage]{start_edge_deployment_stage} \tab Starts a stage in an edge deployment plan\cr
#'  \link[paws.machine.learning:sagemaker_start_inference_experiment]{start_inference_experiment} \tab Starts an inference experiment\cr
#'  \link[paws.machine.learning:sagemaker_start_mlflow_tracking_server]{start_mlflow_tracking_server} \tab Programmatically start an MLflow Tracking Server\cr
#'  \link[paws.machine.learning:sagemaker_start_monitoring_schedule]{start_monitoring_schedule} \tab Starts a previously stopped monitoring schedule\cr
#'  \link[paws.machine.learning:sagemaker_start_notebook_instance]{start_notebook_instance} \tab Launches an ML compute instance with the latest version of the libraries and attaches your ML storage volume\cr
#'  \link[paws.machine.learning:sagemaker_start_pipeline_execution]{start_pipeline_execution} \tab Starts a pipeline execution\cr
#'  \link[paws.machine.learning:sagemaker_stop_auto_ml_job]{stop_auto_ml_job} \tab A method for forcing a running job to shut down\cr
#'  \link[paws.machine.learning:sagemaker_stop_compilation_job]{stop_compilation_job} \tab Stops a model compilation job\cr
#'  \link[paws.machine.learning:sagemaker_stop_edge_deployment_stage]{stop_edge_deployment_stage} \tab Stops a stage in an edge deployment plan\cr
#'  \link[paws.machine.learning:sagemaker_stop_edge_packaging_job]{stop_edge_packaging_job} \tab Request to stop an edge packaging job\cr
#'  \link[paws.machine.learning:sagemaker_stop_hyper_parameter_tuning_job]{stop_hyper_parameter_tuning_job} \tab Stops a running hyperparameter tuning job and all running training jobs that the tuning job launched\cr
#'  \link[paws.machine.learning:sagemaker_stop_inference_experiment]{stop_inference_experiment} \tab Stops an inference experiment\cr
#'  \link[paws.machine.learning:sagemaker_stop_inference_recommendations_job]{stop_inference_recommendations_job} \tab Stops an Inference Recommender job\cr
#'  \link[paws.machine.learning:sagemaker_stop_labeling_job]{stop_labeling_job} \tab Stops a running labeling job\cr
#'  \link[paws.machine.learning:sagemaker_stop_mlflow_tracking_server]{stop_mlflow_tracking_server} \tab Programmatically stop an MLflow Tracking Server\cr
#'  \link[paws.machine.learning:sagemaker_stop_monitoring_schedule]{stop_monitoring_schedule} \tab Stops a previously started monitoring schedule\cr
#'  \link[paws.machine.learning:sagemaker_stop_notebook_instance]{stop_notebook_instance} \tab Terminates the ML compute instance\cr
#'  \link[paws.machine.learning:sagemaker_stop_optimization_job]{stop_optimization_job} \tab Ends a running inference optimization job\cr
#'  \link[paws.machine.learning:sagemaker_stop_pipeline_execution]{stop_pipeline_execution} \tab Stops a pipeline execution\cr
#'  \link[paws.machine.learning:sagemaker_stop_processing_job]{stop_processing_job} \tab Stops a processing job\cr
#'  \link[paws.machine.learning:sagemaker_stop_training_job]{stop_training_job} \tab Stops a training job\cr
#'  \link[paws.machine.learning:sagemaker_stop_transform_job]{stop_transform_job} \tab Stops a batch transform job\cr
#'  \link[paws.machine.learning:sagemaker_update_action]{update_action} \tab Updates an action\cr
#'  \link[paws.machine.learning:sagemaker_update_app_image_config]{update_app_image_config} \tab Updates the properties of an AppImageConfig\cr
#'  \link[paws.machine.learning:sagemaker_update_artifact]{update_artifact} \tab Updates an artifact\cr
#'  \link[paws.machine.learning:sagemaker_update_cluster]{update_cluster} \tab Updates a SageMaker HyperPod cluster\cr
#'  \link[paws.machine.learning:sagemaker_update_cluster_scheduler_config]{update_cluster_scheduler_config} \tab Update the cluster policy configuration\cr
#'  \link[paws.machine.learning:sagemaker_update_cluster_software]{update_cluster_software} \tab Updates the platform software of a SageMaker HyperPod cluster for security patching\cr
#'  \link[paws.machine.learning:sagemaker_update_code_repository]{update_code_repository} \tab Updates the specified Git repository with the specified values\cr
#'  \link[paws.machine.learning:sagemaker_update_compute_quota]{update_compute_quota} \tab Update the compute allocation definition\cr
#'  \link[paws.machine.learning:sagemaker_update_context]{update_context} \tab Updates a context\cr
#'  \link[paws.machine.learning:sagemaker_update_device_fleet]{update_device_fleet} \tab Updates a fleet of devices\cr
#'  \link[paws.machine.learning:sagemaker_update_devices]{update_devices} \tab Updates one or more devices in a fleet\cr
#'  \link[paws.machine.learning:sagemaker_update_domain]{update_domain} \tab Updates the default settings for new user profiles in the domain\cr
#'  \link[paws.machine.learning:sagemaker_update_endpoint]{update_endpoint} \tab Deploys the EndpointConfig specified in the request to a new fleet of instances\cr
#'  \link[paws.machine.learning:sagemaker_update_endpoint_weights_and_capacities]{update_endpoint_weights_and_capacities} \tab Updates variant weight of one or more variants associated with an existing endpoint, or capacity of one variant associated with an existing endpoint\cr
#'  \link[paws.machine.learning:sagemaker_update_experiment]{update_experiment} \tab Adds, updates, or removes the description of an experiment\cr
#'  \link[paws.machine.learning:sagemaker_update_feature_group]{update_feature_group} \tab Updates the feature group by either adding features or updating the online store configuration\cr
#'  \link[paws.machine.learning:sagemaker_update_feature_metadata]{update_feature_metadata} \tab Updates the description and parameters of the feature group\cr
#'  \link[paws.machine.learning:sagemaker_update_hub]{update_hub} \tab Update a hub\cr
#'  \link[paws.machine.learning:sagemaker_update_image]{update_image} \tab Updates the properties of a SageMaker AI image\cr
#'  \link[paws.machine.learning:sagemaker_update_image_version]{update_image_version} \tab Updates the properties of a SageMaker AI image version\cr
#'  \link[paws.machine.learning:sagemaker_update_inference_component]{update_inference_component} \tab Updates an inference component\cr
#'  \link[paws.machine.learning:sagemaker_update_inference_component_runtime_config]{update_inference_component_runtime_config} \tab Runtime settings for a model that is deployed with an inference component\cr
#'  \link[paws.machine.learning:sagemaker_update_inference_experiment]{update_inference_experiment} \tab Updates an inference experiment that you created\cr
#'  \link[paws.machine.learning:sagemaker_update_mlflow_tracking_server]{update_mlflow_tracking_server} \tab Updates properties of an existing MLflow Tracking Server\cr
#'  \link[paws.machine.learning:sagemaker_update_model_card]{update_model_card} \tab Update an Amazon SageMaker Model Card\cr
#'  \link[paws.machine.learning:sagemaker_update_model_package]{update_model_package} \tab Updates a versioned model\cr
#'  \link[paws.machine.learning:sagemaker_update_monitoring_alert]{update_monitoring_alert} \tab Update the parameters of a model monitor alert\cr
#'  \link[paws.machine.learning:sagemaker_update_monitoring_schedule]{update_monitoring_schedule} \tab Updates a previously created schedule\cr
#'  \link[paws.machine.learning:sagemaker_update_notebook_instance]{update_notebook_instance} \tab Updates a notebook instance\cr
#'  \link[paws.machine.learning:sagemaker_update_notebook_instance_lifecycle_config]{update_notebook_instance_lifecycle_config} \tab Updates a notebook instance lifecycle configuration created with the CreateNotebookInstanceLifecycleConfig API\cr
#'  \link[paws.machine.learning:sagemaker_update_partner_app]{update_partner_app} \tab Updates all of the SageMaker Partner AI Apps in an account\cr
#'  \link[paws.machine.learning:sagemaker_update_pipeline]{update_pipeline} \tab Updates a pipeline\cr
#'  \link[paws.machine.learning:sagemaker_update_pipeline_execution]{update_pipeline_execution} \tab Updates a pipeline execution\cr
#'  \link[paws.machine.learning:sagemaker_update_project]{update_project} \tab Updates a machine learning (ML) project that is created from a template that sets up an ML pipeline from training to deploying an approved model\cr
#'  \link[paws.machine.learning:sagemaker_update_space]{update_space} \tab Updates the settings of a space\cr
#'  \link[paws.machine.learning:sagemaker_update_training_job]{update_training_job} \tab Update a model training job to request a new Debugger profiling configuration or to change warm pool retention length\cr
#'  \link[paws.machine.learning:sagemaker_update_trial]{update_trial} \tab Updates the display name of a trial\cr
#'  \link[paws.machine.learning:sagemaker_update_trial_component]{update_trial_component} \tab Updates one or more properties of a trial component\cr
#'  \link[paws.machine.learning:sagemaker_update_user_profile]{update_user_profile} \tab Updates a user profile\cr
#'  \link[paws.machine.learning:sagemaker_update_workforce]{update_workforce} \tab Use this operation to update your workforce\cr
#'  \link[paws.machine.learning:sagemaker_update_workteam]{update_workteam} \tab Updates an existing work team with new member definitions or description
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sagemaker
#' @export
sagemaker <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::sagemaker(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Augmented AI Runtime
#'
#' @description
#' Amazon Augmented AI (Amazon A2I) adds the benefit of human judgment to
#' any machine learning application. When an AI application can't evaluate
#' data with a high degree of confidence, human reviewers can take over.
#' This human review is called a human review workflow. To create and start
#' a human review workflow, you need three resources: a *worker task
#' template*, a *flow definition*, and a *human loop*.
#' 
#' For information about these resources and prerequisites for using Amazon
#' A2I, see [Get Started with Amazon Augmented
#' AI](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-getting-started.html)
#' in the Amazon SageMaker Developer Guide.
#' 
#' This API reference includes information about API actions and data types
#' that you can use to interact with Amazon A2I programmatically. Use this
#' guide to:
#' 
#' -   Start a human loop with the
#'     `start_human_loop` operation
#'     when using Amazon A2I with a *custom task type*. To learn more about
#'     the difference between custom and built-in task types, see [Use Task
#'     Types](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-task-types-general.html)
#'     . To learn how to start a human loop using this API, see [Create and
#'     Start a Human Loop for a Custom Task
#'     Type](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-start-human-loop.html#a2i-instructions-starthumanloop)
#'     in the Amazon SageMaker Developer Guide.
#' 
#' -   Manage your human loops. You can list all human loops that you have
#'     created, describe individual human loops, and stop and delete human
#'     loops. To learn more, see [Monitor and Manage Your Human
#'     Loop](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-monitor-humanloop-results.html)
#'     in the Amazon SageMaker Developer Guide.
#' 
#' Amazon A2I integrates APIs from various AWS services to create and start
#' human review workflows for those services. To learn how Amazon A2I uses
#' these APIs, see [Use APIs in Amazon
#' A2I](https://docs.aws.amazon.com/sagemaker/latest/dg/a2i-api-references.html)
#' in the Amazon SageMaker Developer Guide.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- augmentedairuntime(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- augmentedairuntime()
#' svc$delete_human_loop(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:augmentedairuntime_delete_human_loop]{delete_human_loop} \tab Deletes the specified human loop for a flow definition\cr
#'  \link[paws.machine.learning:augmentedairuntime_describe_human_loop]{describe_human_loop} \tab Returns information about the specified human loop\cr
#'  \link[paws.machine.learning:augmentedairuntime_list_human_loops]{list_human_loops} \tab Returns information about human loops, given the specified parameters\cr
#'  \link[paws.machine.learning:augmentedairuntime_start_human_loop]{start_human_loop} \tab Starts a human loop, provided that at least one activation condition is met\cr
#'  \link[paws.machine.learning:augmentedairuntime_stop_human_loop]{stop_human_loop} \tab Stops the specified human loop
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname augmentedairuntime
#' @export
augmentedairuntime <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::augmentedairuntime(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Sagemaker Edge Manager
#'
#' @description
#' SageMaker Edge Manager dataplane service for communicating with active
#' agents.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sagemakeredgemanager(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sagemakeredgemanager()
#' svc$get_deployments(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:sagemakeredgemanager_get_deployments]{get_deployments} \tab Use to get the active deployments from a device\cr
#'  \link[paws.machine.learning:sagemakeredgemanager_get_device_registration]{get_device_registration} \tab Use to check if a device is registered with SageMaker Edge Manager\cr
#'  \link[paws.machine.learning:sagemakeredgemanager_send_heartbeat]{send_heartbeat} \tab Use to get the current status of devices registered on SageMaker Edge Manager
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sagemakeredgemanager
#' @export
sagemakeredgemanager <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::sagemakeredgemanager(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon SageMaker Feature Store Runtime
#'
#' @description
#' Contains all data plane API operations and data types for the Amazon
#' SageMaker Feature Store. Use this API to put, delete, and retrieve (get)
#' features from a feature store.
#' 
#' Use the following operations to configure your `OnlineStore` and
#' `OfflineStore` features, and to create and manage feature groups:
#' 
#' -   [CreateFeatureGroup](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateFeatureGroup.html)
#' 
#' -   [DeleteFeatureGroup](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DeleteFeatureGroup.html)
#' 
#' -   [DescribeFeatureGroup](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_DescribeFeatureGroup.html)
#' 
#' -   [ListFeatureGroups](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_ListFeatureGroups.html)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sagemakerfeaturestoreruntime(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sagemakerfeaturestoreruntime()
#' svc$batch_get_record(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:sagemakerfeaturestoreruntime_batch_get_record]{batch_get_record} \tab Retrieves a batch of Records from a FeatureGroup\cr
#'  \link[paws.machine.learning:sagemakerfeaturestoreruntime_delete_record]{delete_record} \tab Deletes a Record from a FeatureGroup in the OnlineStore\cr
#'  \link[paws.machine.learning:sagemakerfeaturestoreruntime_get_record]{get_record} \tab Use for OnlineStore serving from a FeatureStore\cr
#'  \link[paws.machine.learning:sagemakerfeaturestoreruntime_put_record]{put_record} \tab The PutRecord API is used to ingest a list of Records into your feature group
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sagemakerfeaturestoreruntime
#' @export
sagemakerfeaturestoreruntime <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::sagemakerfeaturestoreruntime(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon SageMaker geospatial capabilities
#'
#' @description
#' Provides APIs for creating and managing SageMaker geospatial resources.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sagemakergeospatialcapabilities(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sagemakergeospatialcapabilities()
#' svc$delete_earth_observation_job(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_delete_earth_observation_job]{delete_earth_observation_job} \tab Use this operation to delete an Earth Observation job\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_delete_vector_enrichment_job]{delete_vector_enrichment_job} \tab Use this operation to delete a Vector Enrichment job\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_export_earth_observation_job]{export_earth_observation_job} \tab Use this operation to export results of an Earth Observation job and optionally source images used as input to the EOJ to an Amazon S3 location\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_export_vector_enrichment_job]{export_vector_enrichment_job} \tab Use this operation to copy results of a Vector Enrichment job to an Amazon S3 location\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_get_earth_observation_job]{get_earth_observation_job} \tab Get the details for a previously initiated Earth Observation job\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_get_raster_data_collection]{get_raster_data_collection} \tab Use this operation to get details of a specific raster data collection\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_get_tile]{get_tile} \tab Gets a web mercator tile for the given Earth Observation job\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_get_vector_enrichment_job]{get_vector_enrichment_job} \tab Retrieves details of a Vector Enrichment Job for a given job Amazon Resource Name (ARN)\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_list_earth_observation_jobs]{list_earth_observation_jobs} \tab Use this operation to get a list of the Earth Observation jobs associated with the calling Amazon Web Services account\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_list_raster_data_collections]{list_raster_data_collections} \tab Use this operation to get raster data collections\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags attached to the resource\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_list_vector_enrichment_jobs]{list_vector_enrichment_jobs} \tab Retrieves a list of vector enrichment jobs\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_search_raster_data_collection]{search_raster_data_collection} \tab Allows you run image query on a specific raster data collection to get a list of the satellite imagery matching the selected filters\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_start_earth_observation_job]{start_earth_observation_job} \tab Use this operation to create an Earth observation job\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_start_vector_enrichment_job]{start_vector_enrichment_job} \tab Creates a Vector Enrichment job for the supplied job type\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_stop_earth_observation_job]{stop_earth_observation_job} \tab Use this operation to stop an existing earth observation job\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_stop_vector_enrichment_job]{stop_vector_enrichment_job} \tab Stops the Vector Enrichment job for a given job ARN\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_tag_resource]{tag_resource} \tab The resource you want to tag\cr
#'  \link[paws.machine.learning:sagemakergeospatialcapabilities_untag_resource]{untag_resource} \tab The resource you want to untag
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sagemakergeospatialcapabilities
#' @export
sagemakergeospatialcapabilities <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::sagemakergeospatialcapabilities(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon SageMaker Metrics Service
#'
#' @description
#' Contains all data plane API operations and data types for Amazon
#' SageMaker Metrics. Use these APIs to put and retrieve (get) features
#' related to your training run.
#' 
#' -   `batch_put_metrics`
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sagemakermetrics(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sagemakermetrics()
#' svc$batch_get_metrics(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:sagemakermetrics_batch_get_metrics]{batch_get_metrics} \tab Used to retrieve training metrics from SageMaker\cr
#'  \link[paws.machine.learning:sagemakermetrics_batch_put_metrics]{batch_put_metrics} \tab Used to ingest training metrics into SageMaker
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sagemakermetrics
#' @export
sagemakermetrics <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::sagemakermetrics(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon SageMaker Runtime
#'
#' @description
#' The Amazon SageMaker runtime API.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sagemakerruntime(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sagemakerruntime()
#' svc$invoke_endpoint(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:sagemakerruntime_invoke_endpoint]{invoke_endpoint} \tab After you deploy a model into production using Amazon SageMaker hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint\cr
#'  \link[paws.machine.learning:sagemakerruntime_invoke_endpoint_async]{invoke_endpoint_async} \tab After you deploy a model into production using Amazon SageMaker hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint in an asynchronous manner\cr
#'  \link[paws.machine.learning:sagemakerruntime_invoke_endpoint_with_response_stream]{invoke_endpoint_with_response_stream} \tab Invokes a model at the specified endpoint to return the inference response as a stream
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sagemakerruntime
#' @export
sagemakerruntime <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::sagemakerruntime(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Textract
#'
#' @description
#' Amazon Textract detects and analyzes text in documents and converts it
#' into machine-readable text. This is the API reference documentation for
#' Amazon Textract.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- textract(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- textract()
#' svc$analyze_document(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:textract_analyze_document]{analyze_document} \tab Analyzes an input document for relationships between detected items\cr
#'  \link[paws.machine.learning:textract_analyze_expense]{analyze_expense} \tab AnalyzeExpense synchronously analyzes an input document for financially related relationships between text\cr
#'  \link[paws.machine.learning:textract_analyze_id]{analyze_id} \tab Analyzes identity documents for relevant information\cr
#'  \link[paws.machine.learning:textract_create_adapter]{create_adapter} \tab Creates an adapter, which can be fine-tuned for enhanced performance on user provided documents\cr
#'  \link[paws.machine.learning:textract_create_adapter_version]{create_adapter_version} \tab Creates a new version of an adapter\cr
#'  \link[paws.machine.learning:textract_delete_adapter]{delete_adapter} \tab Deletes an Amazon Textract adapter\cr
#'  \link[paws.machine.learning:textract_delete_adapter_version]{delete_adapter_version} \tab Deletes an Amazon Textract adapter version\cr
#'  \link[paws.machine.learning:textract_detect_document_text]{detect_document_text} \tab Detects text in the input document\cr
#'  \link[paws.machine.learning:textract_get_adapter]{get_adapter} \tab Gets configuration information for an adapter specified by an AdapterId, returning information on AdapterName, Description, CreationTime, AutoUpdate status, and FeatureTypes\cr
#'  \link[paws.machine.learning:textract_get_adapter_version]{get_adapter_version} \tab Gets configuration information for the specified adapter version, including: AdapterId, AdapterVersion, FeatureTypes, Status, StatusMessage, DatasetConfig, KMSKeyId, OutputConfig, Tags and EvaluationMetrics\cr
#'  \link[paws.machine.learning:textract_get_document_analysis]{get_document_analysis} \tab Gets the results for an Amazon Textract asynchronous operation that analyzes text in a document\cr
#'  \link[paws.machine.learning:textract_get_document_text_detection]{get_document_text_detection} \tab Gets the results for an Amazon Textract asynchronous operation that detects text in a document\cr
#'  \link[paws.machine.learning:textract_get_expense_analysis]{get_expense_analysis} \tab Gets the results for an Amazon Textract asynchronous operation that analyzes invoices and receipts\cr
#'  \link[paws.machine.learning:textract_get_lending_analysis]{get_lending_analysis} \tab Gets the results for an Amazon Textract asynchronous operation that analyzes text in a lending document\cr
#'  \link[paws.machine.learning:textract_get_lending_analysis_summary]{get_lending_analysis_summary} \tab Gets summarized results for the StartLendingAnalysis operation, which analyzes text in a lending document\cr
#'  \link[paws.machine.learning:textract_list_adapters]{list_adapters} \tab Lists all adapters that match the specified filtration criteria\cr
#'  \link[paws.machine.learning:textract_list_adapter_versions]{list_adapter_versions} \tab List all version of an adapter that meet the specified filtration criteria\cr
#'  \link[paws.machine.learning:textract_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags for an Amazon Textract resource\cr
#'  \link[paws.machine.learning:textract_start_document_analysis]{start_document_analysis} \tab Starts the asynchronous analysis of an input document for relationships between detected items such as key-value pairs, tables, and selection elements\cr
#'  \link[paws.machine.learning:textract_start_document_text_detection]{start_document_text_detection} \tab Starts the asynchronous detection of text in a document\cr
#'  \link[paws.machine.learning:textract_start_expense_analysis]{start_expense_analysis} \tab Starts the asynchronous analysis of invoices or receipts for data like contact information, items purchased, and vendor names\cr
#'  \link[paws.machine.learning:textract_start_lending_analysis]{start_lending_analysis} \tab Starts the classification and analysis of an input document\cr
#'  \link[paws.machine.learning:textract_tag_resource]{tag_resource} \tab Adds one or more tags to the specified resource\cr
#'  \link[paws.machine.learning:textract_untag_resource]{untag_resource} \tab Removes any tags with the specified keys from the specified resource\cr
#'  \link[paws.machine.learning:textract_update_adapter]{update_adapter} \tab Update the configuration for an adapter
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname textract
#' @export
textract <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::textract(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Transcribe Service
#'
#' @description
#' Amazon Transcribe offers three main types of batch transcription:
#' **Standard**, **Medical**, and **Call Analytics**.
#' 
#' -   **Standard transcriptions** are the most common option. Refer to for
#'     details.
#' 
#' -   **Medical transcriptions** are tailored to medical professionals and
#'     incorporate medical terms. A common use case for this service is
#'     transcribing doctor-patient dialogue into after-visit notes. Refer
#'     to for details.
#' 
#' -   **Call Analytics transcriptions** are designed for use with call
#'     center audio on two different channels; if you're looking for
#'     insight into customer service calls, use this option. Refer to for
#'     details.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- transcribeservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- transcribeservice()
#' svc$create_call_analytics_category(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:transcribeservice_create_call_analytics_category]{create_call_analytics_category} \tab Creates a new Call Analytics category\cr
#'  \link[paws.machine.learning:transcribeservice_create_language_model]{create_language_model} \tab Creates a new custom language model\cr
#'  \link[paws.machine.learning:transcribeservice_create_medical_vocabulary]{create_medical_vocabulary} \tab Creates a new custom medical vocabulary\cr
#'  \link[paws.machine.learning:transcribeservice_create_vocabulary]{create_vocabulary} \tab Creates a new custom vocabulary\cr
#'  \link[paws.machine.learning:transcribeservice_create_vocabulary_filter]{create_vocabulary_filter} \tab Creates a new custom vocabulary filter\cr
#'  \link[paws.machine.learning:transcribeservice_delete_call_analytics_category]{delete_call_analytics_category} \tab Deletes a Call Analytics category\cr
#'  \link[paws.machine.learning:transcribeservice_delete_call_analytics_job]{delete_call_analytics_job} \tab Deletes a Call Analytics job\cr
#'  \link[paws.machine.learning:transcribeservice_delete_language_model]{delete_language_model} \tab Deletes a custom language model\cr
#'  \link[paws.machine.learning:transcribeservice_delete_medical_scribe_job]{delete_medical_scribe_job} \tab Deletes a Medical Scribe job\cr
#'  \link[paws.machine.learning:transcribeservice_delete_medical_transcription_job]{delete_medical_transcription_job} \tab Deletes a medical transcription job\cr
#'  \link[paws.machine.learning:transcribeservice_delete_medical_vocabulary]{delete_medical_vocabulary} \tab Deletes a custom medical vocabulary\cr
#'  \link[paws.machine.learning:transcribeservice_delete_transcription_job]{delete_transcription_job} \tab Deletes a transcription job\cr
#'  \link[paws.machine.learning:transcribeservice_delete_vocabulary]{delete_vocabulary} \tab Deletes a custom vocabulary\cr
#'  \link[paws.machine.learning:transcribeservice_delete_vocabulary_filter]{delete_vocabulary_filter} \tab Deletes a custom vocabulary filter\cr
#'  \link[paws.machine.learning:transcribeservice_describe_language_model]{describe_language_model} \tab Provides information about the specified custom language model\cr
#'  \link[paws.machine.learning:transcribeservice_get_call_analytics_category]{get_call_analytics_category} \tab Provides information about the specified Call Analytics category\cr
#'  \link[paws.machine.learning:transcribeservice_get_call_analytics_job]{get_call_analytics_job} \tab Provides information about the specified Call Analytics job\cr
#'  \link[paws.machine.learning:transcribeservice_get_medical_scribe_job]{get_medical_scribe_job} \tab Provides information about the specified Medical Scribe job\cr
#'  \link[paws.machine.learning:transcribeservice_get_medical_transcription_job]{get_medical_transcription_job} \tab Provides information about the specified medical transcription job\cr
#'  \link[paws.machine.learning:transcribeservice_get_medical_vocabulary]{get_medical_vocabulary} \tab Provides information about the specified custom medical vocabulary\cr
#'  \link[paws.machine.learning:transcribeservice_get_transcription_job]{get_transcription_job} \tab Provides information about the specified transcription job\cr
#'  \link[paws.machine.learning:transcribeservice_get_vocabulary]{get_vocabulary} \tab Provides information about the specified custom vocabulary\cr
#'  \link[paws.machine.learning:transcribeservice_get_vocabulary_filter]{get_vocabulary_filter} \tab Provides information about the specified custom vocabulary filter\cr
#'  \link[paws.machine.learning:transcribeservice_list_call_analytics_categories]{list_call_analytics_categories} \tab Provides a list of Call Analytics categories, including all rules that make up each category\cr
#'  \link[paws.machine.learning:transcribeservice_list_call_analytics_jobs]{list_call_analytics_jobs} \tab Provides a list of Call Analytics jobs that match the specified criteria\cr
#'  \link[paws.machine.learning:transcribeservice_list_language_models]{list_language_models} \tab Provides a list of custom language models that match the specified criteria\cr
#'  \link[paws.machine.learning:transcribeservice_list_medical_scribe_jobs]{list_medical_scribe_jobs} \tab Provides a list of Medical Scribe jobs that match the specified criteria\cr
#'  \link[paws.machine.learning:transcribeservice_list_medical_transcription_jobs]{list_medical_transcription_jobs} \tab Provides a list of medical transcription jobs that match the specified criteria\cr
#'  \link[paws.machine.learning:transcribeservice_list_medical_vocabularies]{list_medical_vocabularies} \tab Provides a list of custom medical vocabularies that match the specified criteria\cr
#'  \link[paws.machine.learning:transcribeservice_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags associated with the specified transcription job, vocabulary, model, or resource\cr
#'  \link[paws.machine.learning:transcribeservice_list_transcription_jobs]{list_transcription_jobs} \tab Provides a list of transcription jobs that match the specified criteria\cr
#'  \link[paws.machine.learning:transcribeservice_list_vocabularies]{list_vocabularies} \tab Provides a list of custom vocabularies that match the specified criteria\cr
#'  \link[paws.machine.learning:transcribeservice_list_vocabulary_filters]{list_vocabulary_filters} \tab Provides a list of custom vocabulary filters that match the specified criteria\cr
#'  \link[paws.machine.learning:transcribeservice_start_call_analytics_job]{start_call_analytics_job} \tab Transcribes the audio from a customer service call and applies any additional Request Parameters you choose to include in your request\cr
#'  \link[paws.machine.learning:transcribeservice_start_medical_scribe_job]{start_medical_scribe_job} \tab Transcribes patient-clinician conversations and generates clinical notes\cr
#'  \link[paws.machine.learning:transcribeservice_start_medical_transcription_job]{start_medical_transcription_job} \tab Transcribes the audio from a medical dictation or conversation and applies any additional Request Parameters you choose to include in your request\cr
#'  \link[paws.machine.learning:transcribeservice_start_transcription_job]{start_transcription_job} \tab Transcribes the audio from a media file and applies any additional Request Parameters you choose to include in your request\cr
#'  \link[paws.machine.learning:transcribeservice_tag_resource]{tag_resource} \tab Adds one or more custom tags, each in the form of a key:value pair, to the specified resource\cr
#'  \link[paws.machine.learning:transcribeservice_untag_resource]{untag_resource} \tab Removes the specified tags from the specified Amazon Transcribe resource\cr
#'  \link[paws.machine.learning:transcribeservice_update_call_analytics_category]{update_call_analytics_category} \tab Updates the specified Call Analytics category with new rules\cr
#'  \link[paws.machine.learning:transcribeservice_update_medical_vocabulary]{update_medical_vocabulary} \tab Updates an existing custom medical vocabulary with new values\cr
#'  \link[paws.machine.learning:transcribeservice_update_vocabulary]{update_vocabulary} \tab Updates an existing custom vocabulary with new values\cr
#'  \link[paws.machine.learning:transcribeservice_update_vocabulary_filter]{update_vocabulary_filter} \tab Updates an existing custom vocabulary filter with a new list of words
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname transcribeservice
#' @export
transcribeservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::transcribeservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Translate
#'
#' @description
#' Provides translation of the input content from the source language to
#' the target language.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- translate(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- translate()
#' svc$create_parallel_data(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:translate_create_parallel_data]{create_parallel_data} \tab Creates a parallel data resource in Amazon Translate by importing an input file from Amazon S3\cr
#'  \link[paws.machine.learning:translate_delete_parallel_data]{delete_parallel_data} \tab Deletes a parallel data resource in Amazon Translate\cr
#'  \link[paws.machine.learning:translate_delete_terminology]{delete_terminology} \tab A synchronous action that deletes a custom terminology\cr
#'  \link[paws.machine.learning:translate_describe_text_translation_job]{describe_text_translation_job} \tab Gets the properties associated with an asynchronous batch translation job including name, ID, status, source and target languages, input/output S3 buckets, and so on\cr
#'  \link[paws.machine.learning:translate_get_parallel_data]{get_parallel_data} \tab Provides information about a parallel data resource\cr
#'  \link[paws.machine.learning:translate_get_terminology]{get_terminology} \tab Retrieves a custom terminology\cr
#'  \link[paws.machine.learning:translate_import_terminology]{import_terminology} \tab Creates or updates a custom terminology, depending on whether one already exists for the given terminology name\cr
#'  \link[paws.machine.learning:translate_list_languages]{list_languages} \tab Provides a list of languages (RFC-5646 codes and names) that Amazon Translate supports\cr
#'  \link[paws.machine.learning:translate_list_parallel_data]{list_parallel_data} \tab Provides a list of your parallel data resources in Amazon Translate\cr
#'  \link[paws.machine.learning:translate_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags associated with a given Amazon Translate resource\cr
#'  \link[paws.machine.learning:translate_list_terminologies]{list_terminologies} \tab Provides a list of custom terminologies associated with your account\cr
#'  \link[paws.machine.learning:translate_list_text_translation_jobs]{list_text_translation_jobs} \tab Gets a list of the batch translation jobs that you have submitted\cr
#'  \link[paws.machine.learning:translate_start_text_translation_job]{start_text_translation_job} \tab Starts an asynchronous batch translation job\cr
#'  \link[paws.machine.learning:translate_stop_text_translation_job]{stop_text_translation_job} \tab Stops an asynchronous batch translation job that is in progress\cr
#'  \link[paws.machine.learning:translate_tag_resource]{tag_resource} \tab Associates a specific tag with a resource\cr
#'  \link[paws.machine.learning:translate_translate_document]{translate_document} \tab Translates the input document from the source language to the target language\cr
#'  \link[paws.machine.learning:translate_translate_text]{translate_text} \tab Translates input text from the source language to the target language\cr
#'  \link[paws.machine.learning:translate_untag_resource]{untag_resource} \tab Removes a specific tag associated with an Amazon Translate resource\cr
#'  \link[paws.machine.learning:translate_update_parallel_data]{update_parallel_data} \tab Updates a previously created parallel data resource by importing a new input file from Amazon S3
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname translate
#' @export
translate <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::translate(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Voice ID
#'
#' @description
#' Amazon Connect Voice ID provides real-time caller authentication and
#' fraud risk detection, which make voice interactions in contact centers
#' more secure and efficient.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- voiceid(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- voiceid()
#' svc$associate_fraudster(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:voiceid_associate_fraudster]{associate_fraudster} \tab Associates the fraudsters with the watchlist specified in the same domain\cr
#'  \link[paws.machine.learning:voiceid_create_domain]{create_domain} \tab Creates a domain that contains all Amazon Connect Voice ID data, such as speakers, fraudsters, customer audio, and voiceprints\cr
#'  \link[paws.machine.learning:voiceid_create_watchlist]{create_watchlist} \tab Creates a watchlist that fraudsters can be a part of\cr
#'  \link[paws.machine.learning:voiceid_delete_domain]{delete_domain} \tab Deletes the specified domain from Voice ID\cr
#'  \link[paws.machine.learning:voiceid_delete_fraudster]{delete_fraudster} \tab Deletes the specified fraudster from Voice ID\cr
#'  \link[paws.machine.learning:voiceid_delete_speaker]{delete_speaker} \tab Deletes the specified speaker from Voice ID\cr
#'  \link[paws.machine.learning:voiceid_delete_watchlist]{delete_watchlist} \tab Deletes the specified watchlist from Voice ID\cr
#'  \link[paws.machine.learning:voiceid_describe_domain]{describe_domain} \tab Describes the specified domain\cr
#'  \link[paws.machine.learning:voiceid_describe_fraudster]{describe_fraudster} \tab Describes the specified fraudster\cr
#'  \link[paws.machine.learning:voiceid_describe_fraudster_registration_job]{describe_fraudster_registration_job} \tab Describes the specified fraudster registration job\cr
#'  \link[paws.machine.learning:voiceid_describe_speaker]{describe_speaker} \tab Describes the specified speaker\cr
#'  \link[paws.machine.learning:voiceid_describe_speaker_enrollment_job]{describe_speaker_enrollment_job} \tab Describes the specified speaker enrollment job\cr
#'  \link[paws.machine.learning:voiceid_describe_watchlist]{describe_watchlist} \tab Describes the specified watchlist\cr
#'  \link[paws.machine.learning:voiceid_disassociate_fraudster]{disassociate_fraudster} \tab Disassociates the fraudsters from the watchlist specified\cr
#'  \link[paws.machine.learning:voiceid_evaluate_session]{evaluate_session} \tab Evaluates a specified session based on audio data accumulated during a streaming Amazon Connect Voice ID call\cr
#'  \link[paws.machine.learning:voiceid_list_domains]{list_domains} \tab Lists all the domains in the Amazon Web Services account\cr
#'  \link[paws.machine.learning:voiceid_list_fraudster_registration_jobs]{list_fraudster_registration_jobs} \tab Lists all the fraudster registration jobs in the domain with the given JobStatus\cr
#'  \link[paws.machine.learning:voiceid_list_fraudsters]{list_fraudsters} \tab Lists all fraudsters in a specified watchlist or domain\cr
#'  \link[paws.machine.learning:voiceid_list_speaker_enrollment_jobs]{list_speaker_enrollment_jobs} \tab Lists all the speaker enrollment jobs in the domain with the specified JobStatus\cr
#'  \link[paws.machine.learning:voiceid_list_speakers]{list_speakers} \tab Lists all speakers in a specified domain\cr
#'  \link[paws.machine.learning:voiceid_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags associated with a specified Voice ID resource\cr
#'  \link[paws.machine.learning:voiceid_list_watchlists]{list_watchlists} \tab Lists all watchlists in a specified domain\cr
#'  \link[paws.machine.learning:voiceid_opt_out_speaker]{opt_out_speaker} \tab Opts out a speaker from Voice ID\cr
#'  \link[paws.machine.learning:voiceid_start_fraudster_registration_job]{start_fraudster_registration_job} \tab Starts a new batch fraudster registration job using provided details\cr
#'  \link[paws.machine.learning:voiceid_start_speaker_enrollment_job]{start_speaker_enrollment_job} \tab Starts a new batch speaker enrollment job using specified details\cr
#'  \link[paws.machine.learning:voiceid_tag_resource]{tag_resource} \tab Tags a Voice ID resource with the provided list of tags\cr
#'  \link[paws.machine.learning:voiceid_untag_resource]{untag_resource} \tab Removes specified tags from a specified Amazon Connect Voice ID resource\cr
#'  \link[paws.machine.learning:voiceid_update_domain]{update_domain} \tab Updates the specified domain\cr
#'  \link[paws.machine.learning:voiceid_update_watchlist]{update_watchlist} \tab Updates the specified watchlist
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname voiceid
#' @export
voiceid <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::voiceid(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Bedrock
#'
#' @description
#' Describes the API operations for creating, managing, fine-turning, and
#' evaluating Amazon Bedrock models.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- bedrock(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- bedrock()
#' svc$batch_delete_evaluation_job(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:bedrock_batch_delete_evaluation_job]{batch_delete_evaluation_job} \tab Deletes a batch of evaluation jobs\cr
#'  \link[paws.machine.learning:bedrock_create_evaluation_job]{create_evaluation_job} \tab Creates an evaluation job\cr
#'  \link[paws.machine.learning:bedrock_create_guardrail]{create_guardrail} \tab Creates a guardrail to block topics and to implement safeguards for your generative AI applications\cr
#'  \link[paws.machine.learning:bedrock_create_guardrail_version]{create_guardrail_version} \tab Creates a version of the guardrail\cr
#'  \link[paws.machine.learning:bedrock_create_inference_profile]{create_inference_profile} \tab Creates an application inference profile to track metrics and costs when invoking a model\cr
#'  \link[paws.machine.learning:bedrock_create_marketplace_model_endpoint]{create_marketplace_model_endpoint} \tab Creates an endpoint for a model from Amazon Bedrock Marketplace\cr
#'  \link[paws.machine.learning:bedrock_create_model_copy_job]{create_model_copy_job} \tab Copies a model to another region so that it can be used there\cr
#'  \link[paws.machine.learning:bedrock_create_model_customization_job]{create_model_customization_job} \tab Creates a fine-tuning job to customize a base model\cr
#'  \link[paws.machine.learning:bedrock_create_model_import_job]{create_model_import_job} \tab Creates a model import job to import model that you have customized in other environments, such as Amazon SageMaker\cr
#'  \link[paws.machine.learning:bedrock_create_model_invocation_job]{create_model_invocation_job} \tab Creates a batch inference job to invoke a model on multiple prompts\cr
#'  \link[paws.machine.learning:bedrock_create_provisioned_model_throughput]{create_provisioned_model_throughput} \tab Creates dedicated throughput for a base or custom model with the model units and for the duration that you specify\cr
#'  \link[paws.machine.learning:bedrock_delete_custom_model]{delete_custom_model} \tab Deletes a custom model that you created earlier\cr
#'  \link[paws.machine.learning:bedrock_delete_guardrail]{delete_guardrail} \tab Deletes a guardrail\cr
#'  \link[paws.machine.learning:bedrock_delete_imported_model]{delete_imported_model} \tab Deletes a custom model that you imported earlier\cr
#'  \link[paws.machine.learning:bedrock_delete_inference_profile]{delete_inference_profile} \tab Deletes an application inference profile\cr
#'  \link[paws.machine.learning:bedrock_delete_marketplace_model_endpoint]{delete_marketplace_model_endpoint} \tab Deletes an endpoint for a model from Amazon Bedrock Marketplace\cr
#'  \link[paws.machine.learning:bedrock_delete_model_invocation_logging_configuration]{delete_model_invocation_logging_configuration} \tab Delete the invocation logging\cr
#'  \link[paws.machine.learning:bedrock_delete_provisioned_model_throughput]{delete_provisioned_model_throughput} \tab Deletes a Provisioned Throughput\cr
#'  \link[paws.machine.learning:bedrock_deregister_marketplace_model_endpoint]{deregister_marketplace_model_endpoint} \tab Deregisters an endpoint for a model from Amazon Bedrock Marketplace\cr
#'  \link[paws.machine.learning:bedrock_get_custom_model]{get_custom_model} \tab Get the properties associated with a Amazon Bedrock custom model that you have created\cr
#'  \link[paws.machine.learning:bedrock_get_evaluation_job]{get_evaluation_job} \tab Gets information about an evaluation job, such as the status of the job\cr
#'  \link[paws.machine.learning:bedrock_get_foundation_model]{get_foundation_model} \tab Get details about a Amazon Bedrock foundation model\cr
#'  \link[paws.machine.learning:bedrock_get_guardrail]{get_guardrail} \tab Gets details about a guardrail\cr
#'  \link[paws.machine.learning:bedrock_get_imported_model]{get_imported_model} \tab Gets properties associated with a customized model you imported\cr
#'  \link[paws.machine.learning:bedrock_get_inference_profile]{get_inference_profile} \tab Gets information about an inference profile\cr
#'  \link[paws.machine.learning:bedrock_get_marketplace_model_endpoint]{get_marketplace_model_endpoint} \tab Retrieves details about a specific endpoint for a model from Amazon Bedrock Marketplace\cr
#'  \link[paws.machine.learning:bedrock_get_model_copy_job]{get_model_copy_job} \tab Retrieves information about a model copy job\cr
#'  \link[paws.machine.learning:bedrock_get_model_customization_job]{get_model_customization_job} \tab Retrieves the properties associated with a model-customization job, including the status of the job\cr
#'  \link[paws.machine.learning:bedrock_get_model_import_job]{get_model_import_job} \tab Retrieves the properties associated with import model job, including the status of the job\cr
#'  \link[paws.machine.learning:bedrock_get_model_invocation_job]{get_model_invocation_job} \tab Gets details about a batch inference job\cr
#'  \link[paws.machine.learning:bedrock_get_model_invocation_logging_configuration]{get_model_invocation_logging_configuration} \tab Get the current configuration values for model invocation logging\cr
#'  \link[paws.machine.learning:bedrock_get_prompt_router]{get_prompt_router} \tab Retrieves details about a prompt router\cr
#'  \link[paws.machine.learning:bedrock_get_provisioned_model_throughput]{get_provisioned_model_throughput} \tab Returns details for a Provisioned Throughput\cr
#'  \link[paws.machine.learning:bedrock_list_custom_models]{list_custom_models} \tab Returns a list of the custom models that you have created with the CreateModelCustomizationJob operation\cr
#'  \link[paws.machine.learning:bedrock_list_evaluation_jobs]{list_evaluation_jobs} \tab Lists all existing evaluation jobs\cr
#'  \link[paws.machine.learning:bedrock_list_foundation_models]{list_foundation_models} \tab Lists Amazon Bedrock foundation models that you can use\cr
#'  \link[paws.machine.learning:bedrock_list_guardrails]{list_guardrails} \tab Lists details about all the guardrails in an account\cr
#'  \link[paws.machine.learning:bedrock_list_imported_models]{list_imported_models} \tab Returns a list of models you've imported\cr
#'  \link[paws.machine.learning:bedrock_list_inference_profiles]{list_inference_profiles} \tab Returns a list of inference profiles that you can use\cr
#'  \link[paws.machine.learning:bedrock_list_marketplace_model_endpoints]{list_marketplace_model_endpoints} \tab Lists the endpoints for models from Amazon Bedrock Marketplace in your Amazon Web Services account\cr
#'  \link[paws.machine.learning:bedrock_list_model_copy_jobs]{list_model_copy_jobs} \tab Returns a list of model copy jobs that you have submitted\cr
#'  \link[paws.machine.learning:bedrock_list_model_customization_jobs]{list_model_customization_jobs} \tab Returns a list of model customization jobs that you have submitted\cr
#'  \link[paws.machine.learning:bedrock_list_model_import_jobs]{list_model_import_jobs} \tab Returns a list of import jobs you've submitted\cr
#'  \link[paws.machine.learning:bedrock_list_model_invocation_jobs]{list_model_invocation_jobs} \tab Lists all batch inference jobs in the account\cr
#'  \link[paws.machine.learning:bedrock_list_prompt_routers]{list_prompt_routers} \tab Retrieves a list of prompt routers\cr
#'  \link[paws.machine.learning:bedrock_list_provisioned_model_throughputs]{list_provisioned_model_throughputs} \tab Lists the Provisioned Throughputs in the account\cr
#'  \link[paws.machine.learning:bedrock_list_tags_for_resource]{list_tags_for_resource} \tab List the tags associated with the specified resource\cr
#'  \link[paws.machine.learning:bedrock_put_model_invocation_logging_configuration]{put_model_invocation_logging_configuration} \tab Set the configuration values for model invocation logging\cr
#'  \link[paws.machine.learning:bedrock_register_marketplace_model_endpoint]{register_marketplace_model_endpoint} \tab Registers an existing Amazon SageMaker endpoint with Amazon Bedrock Marketplace, allowing it to be used with Amazon Bedrock APIs\cr
#'  \link[paws.machine.learning:bedrock_stop_evaluation_job]{stop_evaluation_job} \tab Stops an evaluation job that is current being created or running\cr
#'  \link[paws.machine.learning:bedrock_stop_model_customization_job]{stop_model_customization_job} \tab Stops an active model customization job\cr
#'  \link[paws.machine.learning:bedrock_stop_model_invocation_job]{stop_model_invocation_job} \tab Stops a batch inference job\cr
#'  \link[paws.machine.learning:bedrock_tag_resource]{tag_resource} \tab Associate tags with a resource\cr
#'  \link[paws.machine.learning:bedrock_untag_resource]{untag_resource} \tab Remove one or more tags from a resource\cr
#'  \link[paws.machine.learning:bedrock_update_guardrail]{update_guardrail} \tab Updates a guardrail with the values you specify\cr
#'  \link[paws.machine.learning:bedrock_update_marketplace_model_endpoint]{update_marketplace_model_endpoint} \tab Updates the configuration of an existing endpoint for a model from Amazon Bedrock Marketplace\cr
#'  \link[paws.machine.learning:bedrock_update_provisioned_model_throughput]{update_provisioned_model_throughput} \tab Updates the name or associated model for a Provisioned Throughput
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname bedrock
#' @export
bedrock <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::bedrock(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Agents for Amazon Bedrock
#'
#' @description
#' Describes the API operations for creating and managing Amazon Bedrock
#' agents.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- bedrockagent(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- bedrockagent()
#' svc$associate_agent_collaborator(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:bedrockagent_associate_agent_collaborator]{associate_agent_collaborator} \tab Makes an agent a collaborator for another agent\cr
#'  \link[paws.machine.learning:bedrockagent_associate_agent_knowledge_base]{associate_agent_knowledge_base} \tab Associates a knowledge base with an agent\cr
#'  \link[paws.machine.learning:bedrockagent_create_agent]{create_agent} \tab Creates an agent that orchestrates interactions between foundation models, data sources, software applications, user conversations, and APIs to carry out tasks to help customers\cr
#'  \link[paws.machine.learning:bedrockagent_create_agent_action_group]{create_agent_action_group} \tab Creates an action group for an agent\cr
#'  \link[paws.machine.learning:bedrockagent_create_agent_alias]{create_agent_alias} \tab Creates an alias of an agent that can be used to deploy the agent\cr
#'  \link[paws.machine.learning:bedrockagent_create_data_source]{create_data_source} \tab Connects a knowledge base to a data source\cr
#'  \link[paws.machine.learning:bedrockagent_create_flow]{create_flow} \tab Creates a prompt flow that you can use to send an input through various steps to yield an output\cr
#'  \link[paws.machine.learning:bedrockagent_create_flow_alias]{create_flow_alias} \tab Creates an alias of a flow for deployment\cr
#'  \link[paws.machine.learning:bedrockagent_create_flow_version]{create_flow_version} \tab Creates a version of the flow that you can deploy\cr
#'  \link[paws.machine.learning:bedrockagent_create_knowledge_base]{create_knowledge_base} \tab Creates a knowledge base\cr
#'  \link[paws.machine.learning:bedrockagent_create_prompt]{create_prompt} \tab Creates a prompt in your prompt library that you can add to a flow\cr
#'  \link[paws.machine.learning:bedrockagent_create_prompt_version]{create_prompt_version} \tab Creates a static snapshot of your prompt that can be deployed to production\cr
#'  \link[paws.machine.learning:bedrockagent_delete_agent]{delete_agent} \tab Deletes an agent\cr
#'  \link[paws.machine.learning:bedrockagent_delete_agent_action_group]{delete_agent_action_group} \tab Deletes an action group in an agent\cr
#'  \link[paws.machine.learning:bedrockagent_delete_agent_alias]{delete_agent_alias} \tab Deletes an alias of an agent\cr
#'  \link[paws.machine.learning:bedrockagent_delete_agent_version]{delete_agent_version} \tab Deletes a version of an agent\cr
#'  \link[paws.machine.learning:bedrockagent_delete_data_source]{delete_data_source} \tab Deletes a data source from a knowledge base\cr
#'  \link[paws.machine.learning:bedrockagent_delete_flow]{delete_flow} \tab Deletes a flow\cr
#'  \link[paws.machine.learning:bedrockagent_delete_flow_alias]{delete_flow_alias} \tab Deletes an alias of a flow\cr
#'  \link[paws.machine.learning:bedrockagent_delete_flow_version]{delete_flow_version} \tab Deletes a version of a flow\cr
#'  \link[paws.machine.learning:bedrockagent_delete_knowledge_base]{delete_knowledge_base} \tab Deletes a knowledge base\cr
#'  \link[paws.machine.learning:bedrockagent_delete_knowledge_base_documents]{delete_knowledge_base_documents} \tab Deletes documents from a data source and syncs the changes to the knowledge base that is connected to it\cr
#'  \link[paws.machine.learning:bedrockagent_delete_prompt]{delete_prompt} \tab Deletes a prompt or a version of it, depending on whether you include the promptVersion field or not\cr
#'  \link[paws.machine.learning:bedrockagent_disassociate_agent_collaborator]{disassociate_agent_collaborator} \tab Disassociates an agent collaborator\cr
#'  \link[paws.machine.learning:bedrockagent_disassociate_agent_knowledge_base]{disassociate_agent_knowledge_base} \tab Disassociates a knowledge base from an agent\cr
#'  \link[paws.machine.learning:bedrockagent_get_agent]{get_agent} \tab Gets information about an agent\cr
#'  \link[paws.machine.learning:bedrockagent_get_agent_action_group]{get_agent_action_group} \tab Gets information about an action group for an agent\cr
#'  \link[paws.machine.learning:bedrockagent_get_agent_alias]{get_agent_alias} \tab Gets information about an alias of an agent\cr
#'  \link[paws.machine.learning:bedrockagent_get_agent_collaborator]{get_agent_collaborator} \tab Retrieves information about an agent's collaborator\cr
#'  \link[paws.machine.learning:bedrockagent_get_agent_knowledge_base]{get_agent_knowledge_base} \tab Gets information about a knowledge base associated with an agent\cr
#'  \link[paws.machine.learning:bedrockagent_get_agent_version]{get_agent_version} \tab Gets details about a version of an agent\cr
#'  \link[paws.machine.learning:bedrockagent_get_data_source]{get_data_source} \tab Gets information about a data source\cr
#'  \link[paws.machine.learning:bedrockagent_get_flow]{get_flow} \tab Retrieves information about a flow\cr
#'  \link[paws.machine.learning:bedrockagent_get_flow_alias]{get_flow_alias} \tab Retrieves information about a flow\cr
#'  \link[paws.machine.learning:bedrockagent_get_flow_version]{get_flow_version} \tab Retrieves information about a version of a flow\cr
#'  \link[paws.machine.learning:bedrockagent_get_ingestion_job]{get_ingestion_job} \tab Gets information about a data ingestion job\cr
#'  \link[paws.machine.learning:bedrockagent_get_knowledge_base]{get_knowledge_base} \tab Gets information about a knoweldge base\cr
#'  \link[paws.machine.learning:bedrockagent_get_knowledge_base_documents]{get_knowledge_base_documents} \tab Retrieves specific documents from a data source that is connected to a knowledge base\cr
#'  \link[paws.machine.learning:bedrockagent_get_prompt]{get_prompt} \tab Retrieves information about the working draft (DRAFT version) of a prompt or a version of it, depending on whether you include the promptVersion field or not\cr
#'  \link[paws.machine.learning:bedrockagent_ingest_knowledge_base_documents]{ingest_knowledge_base_documents} \tab Ingests documents directly into the knowledge base that is connected to the data source\cr
#'  \link[paws.machine.learning:bedrockagent_list_agent_action_groups]{list_agent_action_groups} \tab Lists the action groups for an agent and information about each one\cr
#'  \link[paws.machine.learning:bedrockagent_list_agent_aliases]{list_agent_aliases} \tab Lists the aliases of an agent and information about each one\cr
#'  \link[paws.machine.learning:bedrockagent_list_agent_collaborators]{list_agent_collaborators} \tab Retrieve a list of an agent's collaborators\cr
#'  \link[paws.machine.learning:bedrockagent_list_agent_knowledge_bases]{list_agent_knowledge_bases} \tab Lists knowledge bases associated with an agent and information about each one\cr
#'  \link[paws.machine.learning:bedrockagent_list_agents]{list_agents} \tab Lists the agents belonging to an account and information about each agent\cr
#'  \link[paws.machine.learning:bedrockagent_list_agent_versions]{list_agent_versions} \tab Lists the versions of an agent and information about each version\cr
#'  \link[paws.machine.learning:bedrockagent_list_data_sources]{list_data_sources} \tab Lists the data sources in a knowledge base and information about each one\cr
#'  \link[paws.machine.learning:bedrockagent_list_flow_aliases]{list_flow_aliases} \tab Returns a list of aliases for a flow\cr
#'  \link[paws.machine.learning:bedrockagent_list_flows]{list_flows} \tab Returns a list of flows and information about each flow\cr
#'  \link[paws.machine.learning:bedrockagent_list_flow_versions]{list_flow_versions} \tab Returns a list of information about each flow\cr
#'  \link[paws.machine.learning:bedrockagent_list_ingestion_jobs]{list_ingestion_jobs} \tab Lists the data ingestion jobs for a data source\cr
#'  \link[paws.machine.learning:bedrockagent_list_knowledge_base_documents]{list_knowledge_base_documents} \tab Retrieves all the documents contained in a data source that is connected to a knowledge base\cr
#'  \link[paws.machine.learning:bedrockagent_list_knowledge_bases]{list_knowledge_bases} \tab Lists the knowledge bases in an account\cr
#'  \link[paws.machine.learning:bedrockagent_list_prompts]{list_prompts} \tab Returns either information about the working draft (DRAFT version) of each prompt in an account, or information about of all versions of a prompt, depending on whether you include the promptIdentifier field or not\cr
#'  \link[paws.machine.learning:bedrockagent_list_tags_for_resource]{list_tags_for_resource} \tab List all the tags for the resource you specify\cr
#'  \link[paws.machine.learning:bedrockagent_prepare_agent]{prepare_agent} \tab Creates a DRAFT version of the agent that can be used for internal testing\cr
#'  \link[paws.machine.learning:bedrockagent_prepare_flow]{prepare_flow} \tab Prepares the DRAFT version of a flow so that it can be invoked\cr
#'  \link[paws.machine.learning:bedrockagent_start_ingestion_job]{start_ingestion_job} \tab Begins a data ingestion job\cr
#'  \link[paws.machine.learning:bedrockagent_stop_ingestion_job]{stop_ingestion_job} \tab Stops a currently running data ingestion job\cr
#'  \link[paws.machine.learning:bedrockagent_tag_resource]{tag_resource} \tab Associate tags with a resource\cr
#'  \link[paws.machine.learning:bedrockagent_untag_resource]{untag_resource} \tab Remove tags from a resource\cr
#'  \link[paws.machine.learning:bedrockagent_update_agent]{update_agent} \tab Updates the configuration of an agent\cr
#'  \link[paws.machine.learning:bedrockagent_update_agent_action_group]{update_agent_action_group} \tab Updates the configuration for an action group for an agent\cr
#'  \link[paws.machine.learning:bedrockagent_update_agent_alias]{update_agent_alias} \tab Updates configurations for an alias of an agent\cr
#'  \link[paws.machine.learning:bedrockagent_update_agent_collaborator]{update_agent_collaborator} \tab Updates an agent's collaborator\cr
#'  \link[paws.machine.learning:bedrockagent_update_agent_knowledge_base]{update_agent_knowledge_base} \tab Updates the configuration for a knowledge base that has been associated with an agent\cr
#'  \link[paws.machine.learning:bedrockagent_update_data_source]{update_data_source} \tab Updates the configurations for a data source connector\cr
#'  \link[paws.machine.learning:bedrockagent_update_flow]{update_flow} \tab Modifies a flow\cr
#'  \link[paws.machine.learning:bedrockagent_update_flow_alias]{update_flow_alias} \tab Modifies the alias of a flow\cr
#'  \link[paws.machine.learning:bedrockagent_update_knowledge_base]{update_knowledge_base} \tab Updates the configuration of a knowledge base with the fields that you specify\cr
#'  \link[paws.machine.learning:bedrockagent_update_prompt]{update_prompt} \tab Modifies a prompt in your prompt library\cr
#'  \link[paws.machine.learning:bedrockagent_validate_flow_definition]{validate_flow_definition} \tab Validates the definition of a flow
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname bedrockagent
#' @export
bedrockagent <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::bedrockagent(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Agents for Amazon Bedrock Runtime
#'
#' @description
#' Contains APIs related to model invocation and querying of knowledge
#' bases.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- bedrockagentruntime(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- bedrockagentruntime()
#' svc$delete_agent_memory(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:bedrockagentruntime_delete_agent_memory]{delete_agent_memory} \tab Deletes memory from the specified memory identifier\cr
#'  \link[paws.machine.learning:bedrockagentruntime_generate_query]{generate_query} \tab Generates an SQL query from a natural language query\cr
#'  \link[paws.machine.learning:bedrockagentruntime_get_agent_memory]{get_agent_memory} \tab Gets the sessions stored in the memory of the agent\cr
#'  \link[paws.machine.learning:bedrockagentruntime_invoke_agent]{invoke_agent} \tab Sends a prompt for the agent to process and respond to\cr
#'  \link[paws.machine.learning:bedrockagentruntime_invoke_flow]{invoke_flow} \tab Invokes an alias of a flow to run the inputs that you specify and return the output of each node as a stream\cr
#'  \link[paws.machine.learning:bedrockagentruntime_invoke_inline_agent]{invoke_inline_agent} \tab Invokes an inline Amazon Bedrock agent using the configurations you provide with the request\cr
#'  \link[paws.machine.learning:bedrockagentruntime_optimize_prompt]{optimize_prompt} \tab Optimizes a prompt for the task that you specify\cr
#'  \link[paws.machine.learning:bedrockagentruntime_rerank]{rerank} \tab Reranks the relevance of sources based on queries\cr
#'  \link[paws.machine.learning:bedrockagentruntime_retrieve]{retrieve} \tab Queries a knowledge base and retrieves information from it\cr
#'  \link[paws.machine.learning:bedrockagentruntime_retrieve_and_generate]{retrieve_and_generate} \tab Queries a knowledge base and generates responses based on the retrieved results and using the specified foundation model or inference profile\cr
#'  \link[paws.machine.learning:bedrockagentruntime_retrieve_and_generate_stream]{retrieve_and_generate_stream} \tab Queries a knowledge base and generates responses based on the retrieved results, with output in streaming format
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname bedrockagentruntime
#' @export
bedrockagentruntime <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::bedrockagentruntime(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Data Automation for Amazon Bedrock
#'
#' @description
#' Amazon Bedrock Data Automation BuildTime
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- bedrockdataautomation(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- bedrockdataautomation()
#' svc$create_blueprint(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:bedrockdataautomation_create_blueprint]{create_blueprint} \tab Creates an Amazon Bedrock Data Automation Blueprint\cr
#'  \link[paws.machine.learning:bedrockdataautomation_create_blueprint_version]{create_blueprint_version} \tab Creates a new version of an existing Amazon Bedrock Data Automation Blueprint\cr
#'  \link[paws.machine.learning:bedrockdataautomation_create_data_automation_project]{create_data_automation_project} \tab Creates an Amazon Bedrock Data Automation Project\cr
#'  \link[paws.machine.learning:bedrockdataautomation_delete_blueprint]{delete_blueprint} \tab Deletes an existing Amazon Bedrock Data Automation Blueprint\cr
#'  \link[paws.machine.learning:bedrockdataautomation_delete_data_automation_project]{delete_data_automation_project} \tab Deletes an existing Amazon Bedrock Data Automation Project\cr
#'  \link[paws.machine.learning:bedrockdataautomation_get_blueprint]{get_blueprint} \tab Gets an existing Amazon Bedrock Data Automation Blueprint\cr
#'  \link[paws.machine.learning:bedrockdataautomation_get_data_automation_project]{get_data_automation_project} \tab Gets an existing Amazon Bedrock Data Automation Project\cr
#'  \link[paws.machine.learning:bedrockdataautomation_list_blueprints]{list_blueprints} \tab Lists all existing Amazon Bedrock Data Automation Blueprints\cr
#'  \link[paws.machine.learning:bedrockdataautomation_list_data_automation_projects]{list_data_automation_projects} \tab Lists all existing Amazon Bedrock Data Automation Projects\cr
#'  \link[paws.machine.learning:bedrockdataautomation_update_blueprint]{update_blueprint} \tab Updates an existing Amazon Bedrock Data Automation Blueprint\cr
#'  \link[paws.machine.learning:bedrockdataautomation_update_data_automation_project]{update_data_automation_project} \tab Updates an existing Amazon Bedrock Data Automation Project
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname bedrockdataautomation
#' @export
bedrockdataautomation <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::bedrockdataautomation(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Runtime for Amazon Bedrock Data Automation
#'
#' @description
#' Amazon Bedrock Data Automation Runtime
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- bedrockdataautomationruntime(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- bedrockdataautomationruntime()
#' svc$get_data_automation_status(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:bedrockdataautomationruntime_get_data_automation_status]{get_data_automation_status} \tab API used to get data automation status\cr
#'  \link[paws.machine.learning:bedrockdataautomationruntime_invoke_data_automation_async]{invoke_data_automation_async} \tab Async API: Invoke data automation
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname bedrockdataautomationruntime
#' @export
bedrockdataautomationruntime <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::bedrockdataautomationruntime(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Bedrock Runtime
#'
#' @description
#' Describes the API operations for running inference using Amazon Bedrock
#' models.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- bedrockruntime(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- bedrockruntime()
#' svc$apply_guardrail(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.machine.learning:bedrockruntime_apply_guardrail]{apply_guardrail} \tab The action to apply a guardrail\cr
#'  \link[paws.machine.learning:bedrockruntime_converse]{converse} \tab Sends messages to the specified Amazon Bedrock model\cr
#'  \link[paws.machine.learning:bedrockruntime_converse_stream]{converse_stream} \tab Sends messages to the specified Amazon Bedrock model and returns the response in a stream\cr
#'  \link[paws.machine.learning:bedrockruntime_get_async_invoke]{get_async_invoke} \tab Retrieve information about an asynchronous invocation\cr
#'  \link[paws.machine.learning:bedrockruntime_invoke_model]{invoke_model} \tab Invokes the specified Amazon Bedrock model to run inference using the prompt and inference parameters provided in the request body\cr
#'  \link[paws.machine.learning:bedrockruntime_invoke_model_with_response_stream]{invoke_model_with_response_stream} \tab Invoke the specified Amazon Bedrock model to run inference using the prompt and inference parameters provided in the request body\cr
#'  \link[paws.machine.learning:bedrockruntime_list_async_invokes]{list_async_invokes} \tab Lists asynchronous invocations\cr
#'  \link[paws.machine.learning:bedrockruntime_start_async_invoke]{start_async_invoke} \tab Starts an asynchronous invocation
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname bedrockruntime
#' @export
bedrockruntime <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.machine.learning::bedrockruntime(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Athena
#'
#' @description
#' Amazon Athena is an interactive query service that lets you use standard
#' SQL to analyze data directly in Amazon S3. You can point Athena at your
#' data in Amazon S3 and run ad-hoc queries and get results in seconds.
#' Athena is serverless, so there is no infrastructure to set up or manage.
#' You pay only for the queries you run. Athena scales
#' automatically—executing queries in parallel—so results are fast, even
#' with large datasets and complex queries. For more information, see [What
#' is Amazon
#' Athena](https://docs.aws.amazon.com/athena/latest/ug/what-is.html) in
#' the *Amazon Athena User Guide*.
#' 
#' If you connect to Athena using the JDBC driver, use version 1.1.0 of the
#' driver or later with the Amazon Athena API. Earlier version drivers do
#' not support the API. For more information and to download the driver,
#' see [Accessing Amazon Athena with
#' JDBC](https://docs.aws.amazon.com/athena/latest/ug/connect-with-jdbc.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- athena(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- athena()
#' svc$batch_get_named_query(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:athena_batch_get_named_query]{batch_get_named_query} \tab Returns the details of a single named query or a list of up to 50 queries, which you provide as an array of query ID strings\cr
#'  \link[paws.analytics:athena_batch_get_prepared_statement]{batch_get_prepared_statement} \tab Returns the details of a single prepared statement or a list of up to 256 prepared statements for the array of prepared statement names that you provide\cr
#'  \link[paws.analytics:athena_batch_get_query_execution]{batch_get_query_execution} \tab Returns the details of a single query execution or a list of up to 50 query executions, which you provide as an array of query execution ID strings\cr
#'  \link[paws.analytics:athena_cancel_capacity_reservation]{cancel_capacity_reservation} \tab Cancels the capacity reservation with the specified name\cr
#'  \link[paws.analytics:athena_create_capacity_reservation]{create_capacity_reservation} \tab Creates a capacity reservation with the specified name and number of requested data processing units\cr
#'  \link[paws.analytics:athena_create_data_catalog]{create_data_catalog} \tab Creates (registers) a data catalog with the specified name and properties\cr
#'  \link[paws.analytics:athena_create_named_query]{create_named_query} \tab Creates a named query in the specified workgroup\cr
#'  \link[paws.analytics:athena_create_notebook]{create_notebook} \tab Creates an empty ipynb file in the specified Apache Spark enabled workgroup\cr
#'  \link[paws.analytics:athena_create_prepared_statement]{create_prepared_statement} \tab Creates a prepared statement for use with SQL queries in Athena\cr
#'  \link[paws.analytics:athena_create_presigned_notebook_url]{create_presigned_notebook_url} \tab Gets an authentication token and the URL at which the notebook can be accessed\cr
#'  \link[paws.analytics:athena_create_work_group]{create_work_group} \tab Creates a workgroup with the specified name\cr
#'  \link[paws.analytics:athena_delete_capacity_reservation]{delete_capacity_reservation} \tab Deletes a cancelled capacity reservation\cr
#'  \link[paws.analytics:athena_delete_data_catalog]{delete_data_catalog} \tab Deletes a data catalog\cr
#'  \link[paws.analytics:athena_delete_named_query]{delete_named_query} \tab Deletes the named query if you have access to the workgroup in which the query was saved\cr
#'  \link[paws.analytics:athena_delete_notebook]{delete_notebook} \tab Deletes the specified notebook\cr
#'  \link[paws.analytics:athena_delete_prepared_statement]{delete_prepared_statement} \tab Deletes the prepared statement with the specified name from the specified workgroup\cr
#'  \link[paws.analytics:athena_delete_work_group]{delete_work_group} \tab Deletes the workgroup with the specified name\cr
#'  \link[paws.analytics:athena_export_notebook]{export_notebook} \tab Exports the specified notebook and its metadata\cr
#'  \link[paws.analytics:athena_get_calculation_execution]{get_calculation_execution} \tab Describes a previously submitted calculation execution\cr
#'  \link[paws.analytics:athena_get_calculation_execution_code]{get_calculation_execution_code} \tab Retrieves the unencrypted code that was executed for the calculation\cr
#'  \link[paws.analytics:athena_get_calculation_execution_status]{get_calculation_execution_status} \tab Gets the status of a current calculation\cr
#'  \link[paws.analytics:athena_get_capacity_assignment_configuration]{get_capacity_assignment_configuration} \tab Gets the capacity assignment configuration for a capacity reservation, if one exists\cr
#'  \link[paws.analytics:athena_get_capacity_reservation]{get_capacity_reservation} \tab Returns information about the capacity reservation with the specified name\cr
#'  \link[paws.analytics:athena_get_database]{get_database} \tab Returns a database object for the specified database and data catalog\cr
#'  \link[paws.analytics:athena_get_data_catalog]{get_data_catalog} \tab Returns the specified data catalog\cr
#'  \link[paws.analytics:athena_get_named_query]{get_named_query} \tab Returns information about a single query\cr
#'  \link[paws.analytics:athena_get_notebook_metadata]{get_notebook_metadata} \tab Retrieves notebook metadata for the specified notebook ID\cr
#'  \link[paws.analytics:athena_get_prepared_statement]{get_prepared_statement} \tab Retrieves the prepared statement with the specified name from the specified workgroup\cr
#'  \link[paws.analytics:athena_get_query_execution]{get_query_execution} \tab Returns information about a single execution of a query if you have access to the workgroup in which the query ran\cr
#'  \link[paws.analytics:athena_get_query_results]{get_query_results} \tab Streams the results of a single query execution specified by QueryExecutionId from the Athena query results location in Amazon S3\cr
#'  \link[paws.analytics:athena_get_query_runtime_statistics]{get_query_runtime_statistics} \tab Returns query execution runtime statistics related to a single execution of a query if you have access to the workgroup in which the query ran\cr
#'  \link[paws.analytics:athena_get_session]{get_session} \tab Gets the full details of a previously created session, including the session status and configuration\cr
#'  \link[paws.analytics:athena_get_session_status]{get_session_status} \tab Gets the current status of a session\cr
#'  \link[paws.analytics:athena_get_table_metadata]{get_table_metadata} \tab Returns table metadata for the specified catalog, database, and table\cr
#'  \link[paws.analytics:athena_get_work_group]{get_work_group} \tab Returns information about the workgroup with the specified name\cr
#'  \link[paws.analytics:athena_import_notebook]{import_notebook} \tab Imports a single ipynb file to a Spark enabled workgroup\cr
#'  \link[paws.analytics:athena_list_application_dpu_sizes]{list_application_dpu_sizes} \tab Returns the supported DPU sizes for the supported application runtimes (for example, Athena notebook version 1)\cr
#'  \link[paws.analytics:athena_list_calculation_executions]{list_calculation_executions} \tab Lists the calculations that have been submitted to a session in descending order\cr
#'  \link[paws.analytics:athena_list_capacity_reservations]{list_capacity_reservations} \tab Lists the capacity reservations for the current account\cr
#'  \link[paws.analytics:athena_list_databases]{list_databases} \tab Lists the databases in the specified data catalog\cr
#'  \link[paws.analytics:athena_list_data_catalogs]{list_data_catalogs} \tab Lists the data catalogs in the current Amazon Web Services account\cr
#'  \link[paws.analytics:athena_list_engine_versions]{list_engine_versions} \tab Returns a list of engine versions that are available to choose from, including the Auto option\cr
#'  \link[paws.analytics:athena_list_executors]{list_executors} \tab Lists, in descending order, the executors that joined a session\cr
#'  \link[paws.analytics:athena_list_named_queries]{list_named_queries} \tab Provides a list of available query IDs only for queries saved in the specified workgroup\cr
#'  \link[paws.analytics:athena_list_notebook_metadata]{list_notebook_metadata} \tab Displays the notebook files for the specified workgroup in paginated format\cr
#'  \link[paws.analytics:athena_list_notebook_sessions]{list_notebook_sessions} \tab Lists, in descending order, the sessions that have been created in a notebook that are in an active state like CREATING, CREATED, IDLE or BUSY\cr
#'  \link[paws.analytics:athena_list_prepared_statements]{list_prepared_statements} \tab Lists the prepared statements in the specified workgroup\cr
#'  \link[paws.analytics:athena_list_query_executions]{list_query_executions} \tab Provides a list of available query execution IDs for the queries in the specified workgroup\cr
#'  \link[paws.analytics:athena_list_sessions]{list_sessions} \tab Lists the sessions in a workgroup that are in an active state like CREATING, CREATED, IDLE, or BUSY\cr
#'  \link[paws.analytics:athena_list_table_metadata]{list_table_metadata} \tab Lists the metadata for the tables in the specified data catalog database\cr
#'  \link[paws.analytics:athena_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags associated with an Athena resource\cr
#'  \link[paws.analytics:athena_list_work_groups]{list_work_groups} \tab Lists available workgroups for the account\cr
#'  \link[paws.analytics:athena_put_capacity_assignment_configuration]{put_capacity_assignment_configuration} \tab Puts a new capacity assignment configuration for a specified capacity reservation\cr
#'  \link[paws.analytics:athena_start_calculation_execution]{start_calculation_execution} \tab Submits calculations for execution within a session\cr
#'  \link[paws.analytics:athena_start_query_execution]{start_query_execution} \tab Runs the SQL query statements contained in the Query\cr
#'  \link[paws.analytics:athena_start_session]{start_session} \tab Creates a session for running calculations within a workgroup\cr
#'  \link[paws.analytics:athena_stop_calculation_execution]{stop_calculation_execution} \tab Requests the cancellation of a calculation\cr
#'  \link[paws.analytics:athena_stop_query_execution]{stop_query_execution} \tab Stops a query execution\cr
#'  \link[paws.analytics:athena_tag_resource]{tag_resource} \tab Adds one or more tags to an Athena resource\cr
#'  \link[paws.analytics:athena_terminate_session]{terminate_session} \tab Terminates an active session\cr
#'  \link[paws.analytics:athena_untag_resource]{untag_resource} \tab Removes one or more tags from an Athena resource\cr
#'  \link[paws.analytics:athena_update_capacity_reservation]{update_capacity_reservation} \tab Updates the number of requested data processing units for the capacity reservation with the specified name\cr
#'  \link[paws.analytics:athena_update_data_catalog]{update_data_catalog} \tab Updates the data catalog that has the specified name\cr
#'  \link[paws.analytics:athena_update_named_query]{update_named_query} \tab Updates a NamedQuery object\cr
#'  \link[paws.analytics:athena_update_notebook]{update_notebook} \tab Updates the contents of a Spark notebook\cr
#'  \link[paws.analytics:athena_update_notebook_metadata]{update_notebook_metadata} \tab Updates the metadata for a notebook\cr
#'  \link[paws.analytics:athena_update_prepared_statement]{update_prepared_statement} \tab Updates a prepared statement\cr
#'  \link[paws.analytics:athena_update_work_group]{update_work_group} \tab Updates the workgroup with the specified name
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname athena
#' @export
athena <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::athena(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudSearch
#'
#' @description
#' Amazon CloudSearch Configuration Service
#' 
#' You use the Amazon CloudSearch configuration service to create,
#' configure, and manage search domains. Configuration service requests are
#' submitted using the AWS Query protocol. AWS Query requests are HTTP or
#' HTTPS requests submitted via HTTP GET or POST with a query parameter
#' named Action.
#' 
#' The endpoint for configuration service requests is region-specific:
#' cloudsearch.*region*.amazonaws.com. For example,
#' cloudsearch.us-east-1.amazonaws.com. For a current list of supported
#' regions and endpoints, see <a
#' href="https://docs.aws.amazon.com/general/latest/gr/rande.html#cloudsearch_region"
#' target="_blank">Regions and Endpoints</a>.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudsearch(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudsearch()
#' svc$build_suggesters(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:cloudsearch_build_suggesters]{build_suggesters} \tab Indexes the search suggestions\cr
#'  \link[paws.analytics:cloudsearch_create_domain]{create_domain} \tab Creates a new search domain\cr
#'  \link[paws.analytics:cloudsearch_define_analysis_scheme]{define_analysis_scheme} \tab Configures an analysis scheme that can be applied to a text or text-array field to define language-specific text processing options\cr
#'  \link[paws.analytics:cloudsearch_define_expression]{define_expression} \tab Configures an Expression for the search domain\cr
#'  \link[paws.analytics:cloudsearch_define_index_field]{define_index_field} \tab Configures an IndexField for the search domain\cr
#'  \link[paws.analytics:cloudsearch_define_suggester]{define_suggester} \tab Configures a suggester for a domain\cr
#'  \link[paws.analytics:cloudsearch_delete_analysis_scheme]{delete_analysis_scheme} \tab Deletes an analysis scheme\cr
#'  \link[paws.analytics:cloudsearch_delete_domain]{delete_domain} \tab Permanently deletes a search domain and all of its data\cr
#'  \link[paws.analytics:cloudsearch_delete_expression]{delete_expression} \tab Removes an Expression from the search domain\cr
#'  \link[paws.analytics:cloudsearch_delete_index_field]{delete_index_field} \tab Removes an IndexField from the search domain\cr
#'  \link[paws.analytics:cloudsearch_delete_suggester]{delete_suggester} \tab Deletes a suggester\cr
#'  \link[paws.analytics:cloudsearch_describe_analysis_schemes]{describe_analysis_schemes} \tab Gets the analysis schemes configured for a domain\cr
#'  \link[paws.analytics:cloudsearch_describe_availability_options]{describe_availability_options} \tab Gets the availability options configured for a domain\cr
#'  \link[paws.analytics:cloudsearch_describe_domain_endpoint_options]{describe_domain_endpoint_options} \tab Returns the domain's endpoint options, specifically whether all requests to the domain must arrive over HTTPS\cr
#'  \link[paws.analytics:cloudsearch_describe_domains]{describe_domains} \tab Gets information about the search domains owned by this account\cr
#'  \link[paws.analytics:cloudsearch_describe_expressions]{describe_expressions} \tab Gets the expressions configured for the search domain\cr
#'  \link[paws.analytics:cloudsearch_describe_index_fields]{describe_index_fields} \tab Gets information about the index fields configured for the search domain\cr
#'  \link[paws.analytics:cloudsearch_describe_scaling_parameters]{describe_scaling_parameters} \tab Gets the scaling parameters configured for a domain\cr
#'  \link[paws.analytics:cloudsearch_describe_service_access_policies]{describe_service_access_policies} \tab Gets information about the access policies that control access to the domain's document and search endpoints\cr
#'  \link[paws.analytics:cloudsearch_describe_suggesters]{describe_suggesters} \tab Gets the suggesters configured for a domain\cr
#'  \link[paws.analytics:cloudsearch_index_documents]{index_documents} \tab Tells the search domain to start indexing its documents using the latest indexing options\cr
#'  \link[paws.analytics:cloudsearch_list_domain_names]{list_domain_names} \tab Lists all search domains owned by an account\cr
#'  \link[paws.analytics:cloudsearch_update_availability_options]{update_availability_options} \tab Configures the availability options for a domain\cr
#'  \link[paws.analytics:cloudsearch_update_domain_endpoint_options]{update_domain_endpoint_options} \tab Updates the domain's endpoint options, specifically whether all requests to the domain must arrive over HTTPS\cr
#'  \link[paws.analytics:cloudsearch_update_scaling_parameters]{update_scaling_parameters} \tab Configures scaling parameters for a domain\cr
#'  \link[paws.analytics:cloudsearch_update_service_access_policies]{update_service_access_policies} \tab Configures the access rules that control access to the domain's document and search endpoints
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudsearch
#' @export
cloudsearch <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::cloudsearch(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudSearch Domain
#'
#' @description
#' You use the AmazonCloudSearch2013 API to upload documents to a search
#' domain and search those documents.
#' 
#' The endpoints for submitting
#' `upload_documents`,
#' `search`, and
#' `suggest` requests are domain-specific. To
#' get the endpoints for your domain, use the Amazon CloudSearch
#' configuration service `DescribeDomains` action. The domain endpoints are
#' also displayed on the domain dashboard in the Amazon CloudSearch
#' console. You submit suggest requests to the search endpoint.
#' 
#' For more information, see the [Amazon CloudSearch Developer
#' Guide](https://docs.aws.amazon.com/cloudsearch/latest/developerguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudsearchdomain(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudsearchdomain()
#' svc$search(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:cloudsearchdomain_search]{search} \tab Retrieves a list of documents that match the specified search criteria\cr
#'  \link[paws.analytics:cloudsearchdomain_suggest]{suggest} \tab Retrieves autocomplete suggestions for a partial query string\cr
#'  \link[paws.analytics:cloudsearchdomain_upload_documents]{upload_documents} \tab Posts a batch of documents to a search domain for indexing
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudsearchdomain
#' @export
cloudsearchdomain <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::cloudsearchdomain(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Data Pipeline
#'
#' @description
#' AWS Data Pipeline configures and manages a data-driven workflow called a
#' pipeline. AWS Data Pipeline handles the details of scheduling and
#' ensuring that data dependencies are met so that your application can
#' focus on processing the data.
#' 
#' AWS Data Pipeline provides a JAR implementation of a task runner called
#' AWS Data Pipeline Task Runner. AWS Data Pipeline Task Runner provides
#' logic for common data management scenarios, such as performing database
#' queries and running data analysis using Amazon Elastic MapReduce (Amazon
#' EMR). You can use AWS Data Pipeline Task Runner as your task runner, or
#' you can write your own task runner to provide custom data management.
#' 
#' AWS Data Pipeline implements two main sets of functionality. Use the
#' first set to create a pipeline and define data sources, schedules,
#' dependencies, and the transforms to be performed on the data. Use the
#' second set in your task runner application to receive the next task
#' ready for processing. The logic for performing the task, such as
#' querying the data, running data analysis, or converting the data from
#' one format to another, is contained within the task runner. The task
#' runner performs the task assigned to it by the web service, reporting
#' progress to the web service as it does so. When the task is done, the
#' task runner reports the final success or failure of the task to the web
#' service.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- datapipeline(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- datapipeline()
#' svc$activate_pipeline(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:datapipeline_activate_pipeline]{activate_pipeline} \tab Validates the specified pipeline and starts processing pipeline tasks\cr
#'  \link[paws.analytics:datapipeline_add_tags]{add_tags} \tab Adds or modifies tags for the specified pipeline\cr
#'  \link[paws.analytics:datapipeline_create_pipeline]{create_pipeline} \tab Creates a new, empty pipeline\cr
#'  \link[paws.analytics:datapipeline_deactivate_pipeline]{deactivate_pipeline} \tab Deactivates the specified running pipeline\cr
#'  \link[paws.analytics:datapipeline_delete_pipeline]{delete_pipeline} \tab Deletes a pipeline, its pipeline definition, and its run history\cr
#'  \link[paws.analytics:datapipeline_describe_objects]{describe_objects} \tab Gets the object definitions for a set of objects associated with the pipeline\cr
#'  \link[paws.analytics:datapipeline_describe_pipelines]{describe_pipelines} \tab Retrieves metadata about one or more pipelines\cr
#'  \link[paws.analytics:datapipeline_evaluate_expression]{evaluate_expression} \tab Task runners call EvaluateExpression to evaluate a string in the context of the specified object\cr
#'  \link[paws.analytics:datapipeline_get_pipeline_definition]{get_pipeline_definition} \tab Gets the definition of the specified pipeline\cr
#'  \link[paws.analytics:datapipeline_list_pipelines]{list_pipelines} \tab Lists the pipeline identifiers for all active pipelines that you have permission to access\cr
#'  \link[paws.analytics:datapipeline_poll_for_task]{poll_for_task} \tab Task runners call PollForTask to receive a task to perform from AWS Data Pipeline\cr
#'  \link[paws.analytics:datapipeline_put_pipeline_definition]{put_pipeline_definition} \tab Adds tasks, schedules, and preconditions to the specified pipeline\cr
#'  \link[paws.analytics:datapipeline_query_objects]{query_objects} \tab Queries the specified pipeline for the names of objects that match the specified set of conditions\cr
#'  \link[paws.analytics:datapipeline_remove_tags]{remove_tags} \tab Removes existing tags from the specified pipeline\cr
#'  \link[paws.analytics:datapipeline_report_task_progress]{report_task_progress} \tab Task runners call ReportTaskProgress when assigned a task to acknowledge that it has the task\cr
#'  \link[paws.analytics:datapipeline_report_task_runner_heartbeat]{report_task_runner_heartbeat} \tab Task runners call ReportTaskRunnerHeartbeat every 15 minutes to indicate that they are operational\cr
#'  \link[paws.analytics:datapipeline_set_status]{set_status} \tab Requests that the status of the specified physical or logical pipeline objects be updated in the specified pipeline\cr
#'  \link[paws.analytics:datapipeline_set_task_status]{set_task_status} \tab Task runners call SetTaskStatus to notify AWS Data Pipeline that a task is completed and provide information about the final status\cr
#'  \link[paws.analytics:datapipeline_validate_pipeline_definition]{validate_pipeline_definition} \tab Validates the specified pipeline definition to ensure that it is well formed and can be run without error
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname datapipeline
#' @export
datapipeline <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::datapipeline(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon DataZone
#'
#' @description
#' Amazon DataZone is a data management service that enables you to
#' catalog, discover, govern, share, and analyze your data. With Amazon
#' DataZone, you can share and access your data across accounts and
#' supported regions. Amazon DataZone simplifies your experience across
#' Amazon Web Services services, including, but not limited to, Amazon
#' Redshift, Amazon Athena, Amazon Web Services Glue, and Amazon Web
#' Services Lake Formation.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- datazone(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- datazone()
#' svc$accept_predictions(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:datazone_accept_predictions]{accept_predictions} \tab Accepts automatically generated business-friendly metadata for your Amazon DataZone assets\cr
#'  \link[paws.analytics:datazone_accept_subscription_request]{accept_subscription_request} \tab Accepts a subscription request to a specific asset\cr
#'  \link[paws.analytics:datazone_add_entity_owner]{add_entity_owner} \tab Adds the owner of an entity (a domain unit)\cr
#'  \link[paws.analytics:datazone_add_policy_grant]{add_policy_grant} \tab Adds a policy grant (an authorization policy) to a specified entity, including domain units, environment blueprint configurations, or environment profiles\cr
#'  \link[paws.analytics:datazone_associate_environment_role]{associate_environment_role} \tab Associates the environment role in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_cancel_metadata_generation_run]{cancel_metadata_generation_run} \tab Cancels the metadata generation run\cr
#'  \link[paws.analytics:datazone_cancel_subscription]{cancel_subscription} \tab Cancels the subscription to the specified asset\cr
#'  \link[paws.analytics:datazone_create_asset]{create_asset} \tab Creates an asset in Amazon DataZone catalog\cr
#'  \link[paws.analytics:datazone_create_asset_filter]{create_asset_filter} \tab Creates a data asset filter\cr
#'  \link[paws.analytics:datazone_create_asset_revision]{create_asset_revision} \tab Creates a revision of the asset\cr
#'  \link[paws.analytics:datazone_create_asset_type]{create_asset_type} \tab Creates a custom asset type\cr
#'  \link[paws.analytics:datazone_create_connection]{create_connection} \tab Creates a new connection\cr
#'  \link[paws.analytics:datazone_create_data_product]{create_data_product} \tab Creates a data product\cr
#'  \link[paws.analytics:datazone_create_data_product_revision]{create_data_product_revision} \tab Creates a data product revision\cr
#'  \link[paws.analytics:datazone_create_data_source]{create_data_source} \tab Creates an Amazon DataZone data source\cr
#'  \link[paws.analytics:datazone_create_domain]{create_domain} \tab Creates an Amazon DataZone domain\cr
#'  \link[paws.analytics:datazone_create_domain_unit]{create_domain_unit} \tab Creates a domain unit in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_create_environment]{create_environment} \tab Create an Amazon DataZone environment\cr
#'  \link[paws.analytics:datazone_create_environment_action]{create_environment_action} \tab Creates an action for the environment, for example, creates a console link for an analytics tool that is available in this environment\cr
#'  \link[paws.analytics:datazone_create_environment_profile]{create_environment_profile} \tab Creates an Amazon DataZone environment profile\cr
#'  \link[paws.analytics:datazone_create_form_type]{create_form_type} \tab Creates a metadata form type\cr
#'  \link[paws.analytics:datazone_create_glossary]{create_glossary} \tab Creates an Amazon DataZone business glossary\cr
#'  \link[paws.analytics:datazone_create_glossary_term]{create_glossary_term} \tab Creates a business glossary term\cr
#'  \link[paws.analytics:datazone_create_group_profile]{create_group_profile} \tab Creates a group profile in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_create_listing_change_set]{create_listing_change_set} \tab Publishes a listing (a record of an asset at a given time) or removes a listing from the catalog\cr
#'  \link[paws.analytics:datazone_create_project]{create_project} \tab Creates an Amazon DataZone project\cr
#'  \link[paws.analytics:datazone_create_project_membership]{create_project_membership} \tab Creates a project membership in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_create_project_profile]{create_project_profile} \tab Creates a project profile\cr
#'  \link[paws.analytics:datazone_create_rule]{create_rule} \tab Creates a rule in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_create_subscription_grant]{create_subscription_grant} \tab Creates a subsscription grant in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_create_subscription_request]{create_subscription_request} \tab Creates a subscription request in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_create_subscription_target]{create_subscription_target} \tab Creates a subscription target in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_create_user_profile]{create_user_profile} \tab Creates a user profile in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_asset]{delete_asset} \tab Deletes an asset in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_asset_filter]{delete_asset_filter} \tab Deletes an asset filter\cr
#'  \link[paws.analytics:datazone_delete_asset_type]{delete_asset_type} \tab Deletes an asset type in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_connection]{delete_connection} \tab Deletes and connection\cr
#'  \link[paws.analytics:datazone_delete_data_product]{delete_data_product} \tab Deletes a data product in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_data_source]{delete_data_source} \tab Deletes a data source in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_domain]{delete_domain} \tab Deletes a Amazon DataZone domain\cr
#'  \link[paws.analytics:datazone_delete_domain_unit]{delete_domain_unit} \tab Deletes a domain unit\cr
#'  \link[paws.analytics:datazone_delete_environment]{delete_environment} \tab Deletes an environment in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_environment_action]{delete_environment_action} \tab Deletes an action for the environment, for example, deletes a console link for an analytics tool that is available in this environment\cr
#'  \link[paws.analytics:datazone_delete_environment_blueprint_configuration]{delete_environment_blueprint_configuration} \tab Deletes the blueprint configuration in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_environment_profile]{delete_environment_profile} \tab Deletes an environment profile in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_form_type]{delete_form_type} \tab Delets and metadata form type in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_glossary]{delete_glossary} \tab Deletes a business glossary in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_glossary_term]{delete_glossary_term} \tab Deletes a business glossary term in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_listing]{delete_listing} \tab Deletes a listing (a record of an asset at a given time)\cr
#'  \link[paws.analytics:datazone_delete_project]{delete_project} \tab Deletes a project in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_project_membership]{delete_project_membership} \tab Deletes project membership in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_project_profile]{delete_project_profile} \tab Deletes a project profile\cr
#'  \link[paws.analytics:datazone_delete_rule]{delete_rule} \tab Deletes a rule in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_subscription_grant]{delete_subscription_grant} \tab Deletes and subscription grant in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_subscription_request]{delete_subscription_request} \tab Deletes a subscription request in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_subscription_target]{delete_subscription_target} \tab Deletes a subscription target in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_delete_time_series_data_points]{delete_time_series_data_points} \tab Deletes the specified time series form for the specified asset\cr
#'  \link[paws.analytics:datazone_disassociate_environment_role]{disassociate_environment_role} \tab Disassociates the environment role in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_asset]{get_asset} \tab Gets an Amazon DataZone asset\cr
#'  \link[paws.analytics:datazone_get_asset_filter]{get_asset_filter} \tab Gets an asset filter\cr
#'  \link[paws.analytics:datazone_get_asset_type]{get_asset_type} \tab Gets an Amazon DataZone asset type\cr
#'  \link[paws.analytics:datazone_get_connection]{get_connection} \tab Gets a connection\cr
#'  \link[paws.analytics:datazone_get_data_product]{get_data_product} \tab Gets the data product\cr
#'  \link[paws.analytics:datazone_get_data_source]{get_data_source} \tab Gets an Amazon DataZone data source\cr
#'  \link[paws.analytics:datazone_get_data_source_run]{get_data_source_run} \tab Gets an Amazon DataZone data source run\cr
#'  \link[paws.analytics:datazone_get_domain]{get_domain} \tab Gets an Amazon DataZone domain\cr
#'  \link[paws.analytics:datazone_get_domain_unit]{get_domain_unit} \tab Gets the details of the specified domain unit\cr
#'  \link[paws.analytics:datazone_get_environment]{get_environment} \tab Gets an Amazon DataZone environment\cr
#'  \link[paws.analytics:datazone_get_environment_action]{get_environment_action} \tab Gets the specified environment action\cr
#'  \link[paws.analytics:datazone_get_environment_blueprint]{get_environment_blueprint} \tab Gets an Amazon DataZone blueprint\cr
#'  \link[paws.analytics:datazone_get_environment_blueprint_configuration]{get_environment_blueprint_configuration} \tab Gets the blueprint configuration in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_environment_credentials]{get_environment_credentials} \tab Gets the credentials of an environment in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_environment_profile]{get_environment_profile} \tab Gets an evinronment profile in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_form_type]{get_form_type} \tab Gets a metadata form type in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_glossary]{get_glossary} \tab Gets a business glossary in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_glossary_term]{get_glossary_term} \tab Gets a business glossary term in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_group_profile]{get_group_profile} \tab Gets a group profile in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_iam_portal_login_url]{get_iam_portal_login_url} \tab Gets the data portal URL for the specified Amazon DataZone domain\cr
#'  \link[paws.analytics:datazone_get_job_run]{get_job_run} \tab The details of the job run\cr
#'  \link[paws.analytics:datazone_get_lineage_event]{get_lineage_event} \tab Describes the lineage event\cr
#'  \link[paws.analytics:datazone_get_lineage_node]{get_lineage_node} \tab Gets the data lineage node\cr
#'  \link[paws.analytics:datazone_get_listing]{get_listing} \tab Gets a listing (a record of an asset at a given time)\cr
#'  \link[paws.analytics:datazone_get_metadata_generation_run]{get_metadata_generation_run} \tab Gets a metadata generation run in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_project]{get_project} \tab Gets a project in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_project_profile]{get_project_profile} \tab The details of the project profile\cr
#'  \link[paws.analytics:datazone_get_rule]{get_rule} \tab Gets the details of a rule in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_subscription]{get_subscription} \tab Gets a subscription in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_subscription_grant]{get_subscription_grant} \tab Gets the subscription grant in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_subscription_request_details]{get_subscription_request_details} \tab Gets the details of the specified subscription request\cr
#'  \link[paws.analytics:datazone_get_subscription_target]{get_subscription_target} \tab Gets the subscription target in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_get_time_series_data_point]{get_time_series_data_point} \tab Gets the existing data point for the asset\cr
#'  \link[paws.analytics:datazone_get_user_profile]{get_user_profile} \tab Gets a user profile in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_list_asset_filters]{list_asset_filters} \tab Lists asset filters\cr
#'  \link[paws.analytics:datazone_list_asset_revisions]{list_asset_revisions} \tab Lists the revisions for the asset\cr
#'  \link[paws.analytics:datazone_list_connections]{list_connections} \tab Lists connections\cr
#'  \link[paws.analytics:datazone_list_data_product_revisions]{list_data_product_revisions} \tab Lists data product revisions\cr
#'  \link[paws.analytics:datazone_list_data_source_run_activities]{list_data_source_run_activities} \tab Lists data source run activities\cr
#'  \link[paws.analytics:datazone_list_data_source_runs]{list_data_source_runs} \tab Lists data source runs in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_list_data_sources]{list_data_sources} \tab Lists data sources in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_list_domains]{list_domains} \tab Lists Amazon DataZone domains\cr
#'  \link[paws.analytics:datazone_list_domain_units_for_parent]{list_domain_units_for_parent} \tab Lists child domain units for the specified parent domain unit\cr
#'  \link[paws.analytics:datazone_list_entity_owners]{list_entity_owners} \tab Lists the entity (domain units) owners\cr
#'  \link[paws.analytics:datazone_list_environment_actions]{list_environment_actions} \tab Lists existing environment actions\cr
#'  \link[paws.analytics:datazone_list_environment_blueprint_configurations]{list_environment_blueprint_configurations} \tab Lists blueprint configurations for a Amazon DataZone environment\cr
#'  \link[paws.analytics:datazone_list_environment_blueprints]{list_environment_blueprints} \tab Lists blueprints in an Amazon DataZone environment\cr
#'  \link[paws.analytics:datazone_list_environment_profiles]{list_environment_profiles} \tab Lists Amazon DataZone environment profiles\cr
#'  \link[paws.analytics:datazone_list_environments]{list_environments} \tab Lists Amazon DataZone environments\cr
#'  \link[paws.analytics:datazone_list_job_runs]{list_job_runs} \tab Lists job runs\cr
#'  \link[paws.analytics:datazone_list_lineage_events]{list_lineage_events} \tab Lists lineage events\cr
#'  \link[paws.analytics:datazone_list_lineage_node_history]{list_lineage_node_history} \tab Lists the history of the specified data lineage node\cr
#'  \link[paws.analytics:datazone_list_metadata_generation_runs]{list_metadata_generation_runs} \tab Lists all metadata generation runs\cr
#'  \link[paws.analytics:datazone_list_notifications]{list_notifications} \tab Lists all Amazon DataZone notifications\cr
#'  \link[paws.analytics:datazone_list_policy_grants]{list_policy_grants} \tab Lists policy grants\cr
#'  \link[paws.analytics:datazone_list_project_memberships]{list_project_memberships} \tab Lists all members of the specified project\cr
#'  \link[paws.analytics:datazone_list_project_profiles]{list_project_profiles} \tab Lists project profiles\cr
#'  \link[paws.analytics:datazone_list_projects]{list_projects} \tab Lists Amazon DataZone projects\cr
#'  \link[paws.analytics:datazone_list_rules]{list_rules} \tab Lists existing rules\cr
#'  \link[paws.analytics:datazone_list_subscription_grants]{list_subscription_grants} \tab Lists subscription grants\cr
#'  \link[paws.analytics:datazone_list_subscription_requests]{list_subscription_requests} \tab Lists Amazon DataZone subscription requests\cr
#'  \link[paws.analytics:datazone_list_subscriptions]{list_subscriptions} \tab Lists subscriptions in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_list_subscription_targets]{list_subscription_targets} \tab Lists subscription targets in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags for the specified resource in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_list_time_series_data_points]{list_time_series_data_points} \tab Lists time series data points\cr
#'  \link[paws.analytics:datazone_post_lineage_event]{post_lineage_event} \tab Posts a data lineage event\cr
#'  \link[paws.analytics:datazone_post_time_series_data_points]{post_time_series_data_points} \tab Posts time series data points to Amazon DataZone for the specified asset\cr
#'  \link[paws.analytics:datazone_put_environment_blueprint_configuration]{put_environment_blueprint_configuration} \tab Writes the configuration for the specified environment blueprint in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_reject_predictions]{reject_predictions} \tab Rejects automatically generated business-friendly metadata for your Amazon DataZone assets\cr
#'  \link[paws.analytics:datazone_reject_subscription_request]{reject_subscription_request} \tab Rejects the specified subscription request\cr
#'  \link[paws.analytics:datazone_remove_entity_owner]{remove_entity_owner} \tab Removes an owner from an entity\cr
#'  \link[paws.analytics:datazone_remove_policy_grant]{remove_policy_grant} \tab Removes a policy grant\cr
#'  \link[paws.analytics:datazone_revoke_subscription]{revoke_subscription} \tab Revokes a specified subscription in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_search]{search} \tab Searches for assets in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_search_group_profiles]{search_group_profiles} \tab Searches group profiles in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_search_listings]{search_listings} \tab Searches listings (records of an asset at a given time) in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_search_types]{search_types} \tab Searches for types in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_search_user_profiles]{search_user_profiles} \tab Searches user profiles in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_start_data_source_run]{start_data_source_run} \tab Start the run of the specified data source in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_start_metadata_generation_run]{start_metadata_generation_run} \tab Starts the metadata generation run\cr
#'  \link[paws.analytics:datazone_tag_resource]{tag_resource} \tab Tags a resource in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_untag_resource]{untag_resource} \tab Untags a resource in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_asset_filter]{update_asset_filter} \tab Updates an asset filter\cr
#'  \link[paws.analytics:datazone_update_connection]{update_connection} \tab Updates a connection\cr
#'  \link[paws.analytics:datazone_update_data_source]{update_data_source} \tab Updates the specified data source in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_domain]{update_domain} \tab Updates a Amazon DataZone domain\cr
#'  \link[paws.analytics:datazone_update_domain_unit]{update_domain_unit} \tab Updates the domain unit\cr
#'  \link[paws.analytics:datazone_update_environment]{update_environment} \tab Updates the specified environment in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_environment_action]{update_environment_action} \tab Updates an environment action\cr
#'  \link[paws.analytics:datazone_update_environment_profile]{update_environment_profile} \tab Updates the specified environment profile in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_glossary]{update_glossary} \tab Updates the business glossary in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_glossary_term]{update_glossary_term} \tab Updates a business glossary term in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_group_profile]{update_group_profile} \tab Updates the specified group profile in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_project]{update_project} \tab Updates the specified project in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_project_profile]{update_project_profile} \tab Updates a project profile\cr
#'  \link[paws.analytics:datazone_update_rule]{update_rule} \tab Updates a rule\cr
#'  \link[paws.analytics:datazone_update_subscription_grant_status]{update_subscription_grant_status} \tab Updates the status of the specified subscription grant status in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_subscription_request]{update_subscription_request} \tab Updates a specified subscription request in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_subscription_target]{update_subscription_target} \tab Updates the specified subscription target in Amazon DataZone\cr
#'  \link[paws.analytics:datazone_update_user_profile]{update_user_profile} \tab Updates the specified user profile in Amazon DataZone
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname datazone
#' @export
datazone <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::datazone(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Elasticsearch Service
#'
#' @description
#' Amazon Elasticsearch Configuration Service
#' 
#' Use the Amazon Elasticsearch Configuration API to create, configure, and
#' manage Elasticsearch domains.
#' 
#' For sample code that uses the Configuration API, see the [Amazon
#' Elasticsearch Service Developer
#' Guide](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/configuration-samples.html).
#' The guide also contains [sample code for sending signed HTTP requests to
#' the Elasticsearch
#' APIs](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/).
#' 
#' The endpoint for configuration service requests is region-specific:
#' es.*region*.amazonaws.com. For example, es.us-east-1.amazonaws.com. For
#' a current list of supported regions and endpoints, see <a
#' href="https://docs.aws.amazon.com/general/latest/gr/rande.html#elasticsearch-service-regions"
#' target="_blank">Regions and Endpoints</a>.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- elasticsearchservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- elasticsearchservice()
#' svc$accept_inbound_cross_cluster_search_connection(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:elasticsearchservice_accept_inbound_cross_cluster_search_connection]{accept_inbound_cross_cluster_search_connection} \tab Allows the destination domain owner to accept an inbound cross-cluster search connection request\cr
#'  \link[paws.analytics:elasticsearchservice_add_tags]{add_tags} \tab Attaches tags to an existing Elasticsearch domain\cr
#'  \link[paws.analytics:elasticsearchservice_associate_package]{associate_package} \tab Associates a package with an Amazon ES domain\cr
#'  \link[paws.analytics:elasticsearchservice_authorize_vpc_endpoint_access]{authorize_vpc_endpoint_access} \tab Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint\cr
#'  \link[paws.analytics:elasticsearchservice_cancel_domain_config_change]{cancel_domain_config_change} \tab Cancels a pending configuration change on an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:elasticsearchservice_cancel_elasticsearch_service_software_update]{cancel_elasticsearch_service_software_update} \tab Cancels a scheduled service software update for an Amazon ES domain\cr
#'  \link[paws.analytics:elasticsearchservice_create_elasticsearch_domain]{create_elasticsearch_domain} \tab Creates a new Elasticsearch domain\cr
#'  \link[paws.analytics:elasticsearchservice_create_outbound_cross_cluster_search_connection]{create_outbound_cross_cluster_search_connection} \tab Creates a new cross-cluster search connection from a source domain to a destination domain\cr
#'  \link[paws.analytics:elasticsearchservice_create_package]{create_package} \tab Create a package for use with Amazon ES domains\cr
#'  \link[paws.analytics:elasticsearchservice_create_vpc_endpoint]{create_vpc_endpoint} \tab Creates an Amazon OpenSearch Service-managed VPC endpoint\cr
#'  \link[paws.analytics:elasticsearchservice_delete_elasticsearch_domain]{delete_elasticsearch_domain} \tab Permanently deletes the specified Elasticsearch domain and all of its data\cr
#'  \link[paws.analytics:elasticsearchservice_delete_elasticsearch_service_role]{delete_elasticsearch_service_role} \tab Deletes the service-linked role that Elasticsearch Service uses to manage and maintain VPC domains\cr
#'  \link[paws.analytics:elasticsearchservice_delete_inbound_cross_cluster_search_connection]{delete_inbound_cross_cluster_search_connection} \tab Allows the destination domain owner to delete an existing inbound cross-cluster search connection\cr
#'  \link[paws.analytics:elasticsearchservice_delete_outbound_cross_cluster_search_connection]{delete_outbound_cross_cluster_search_connection} \tab Allows the source domain owner to delete an existing outbound cross-cluster search connection\cr
#'  \link[paws.analytics:elasticsearchservice_delete_package]{delete_package} \tab Delete the package\cr
#'  \link[paws.analytics:elasticsearchservice_delete_vpc_endpoint]{delete_vpc_endpoint} \tab Deletes an Amazon OpenSearch Service-managed interface VPC endpoint\cr
#'  \link[paws.analytics:elasticsearchservice_describe_domain_auto_tunes]{describe_domain_auto_tunes} \tab Provides scheduled Auto-Tune action details for the Elasticsearch domain, such as Auto-Tune action type, description, severity, and scheduled date\cr
#'  \link[paws.analytics:elasticsearchservice_describe_domain_change_progress]{describe_domain_change_progress} \tab Returns information about the current blue/green deployment happening on a domain, including a change ID, status, and progress stages\cr
#'  \link[paws.analytics:elasticsearchservice_describe_elasticsearch_domain]{describe_elasticsearch_domain} \tab Returns domain configuration information about the specified Elasticsearch domain, including the domain ID, domain endpoint, and domain ARN\cr
#'  \link[paws.analytics:elasticsearchservice_describe_elasticsearch_domain_config]{describe_elasticsearch_domain_config} \tab Provides cluster configuration information about the specified Elasticsearch domain, such as the state, creation date, update version, and update date for cluster options\cr
#'  \link[paws.analytics:elasticsearchservice_describe_elasticsearch_domains]{describe_elasticsearch_domains} \tab Returns domain configuration information about the specified Elasticsearch domains, including the domain ID, domain endpoint, and domain ARN\cr
#'  \link[paws.analytics:elasticsearchservice_describe_elasticsearch_instance_type_limits]{describe_elasticsearch_instance_type_limits} \tab Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion\cr
#'  \link[paws.analytics:elasticsearchservice_describe_inbound_cross_cluster_search_connections]{describe_inbound_cross_cluster_search_connections} \tab Lists all the inbound cross-cluster search connections for a destination domain\cr
#'  \link[paws.analytics:elasticsearchservice_describe_outbound_cross_cluster_search_connections]{describe_outbound_cross_cluster_search_connections} \tab Lists all the outbound cross-cluster search connections for a source domain\cr
#'  \link[paws.analytics:elasticsearchservice_describe_packages]{describe_packages} \tab Describes all packages available to Amazon ES\cr
#'  \link[paws.analytics:elasticsearchservice_describe_reserved_elasticsearch_instance_offerings]{describe_reserved_elasticsearch_instance_offerings} \tab Lists available reserved Elasticsearch instance offerings\cr
#'  \link[paws.analytics:elasticsearchservice_describe_reserved_elasticsearch_instances]{describe_reserved_elasticsearch_instances} \tab Returns information about reserved Elasticsearch instances for this account\cr
#'  \link[paws.analytics:elasticsearchservice_describe_vpc_endpoints]{describe_vpc_endpoints} \tab Describes one or more Amazon OpenSearch Service-managed VPC endpoints\cr
#'  \link[paws.analytics:elasticsearchservice_dissociate_package]{dissociate_package} \tab Dissociates a package from the Amazon ES domain\cr
#'  \link[paws.analytics:elasticsearchservice_get_compatible_elasticsearch_versions]{get_compatible_elasticsearch_versions} \tab Returns a list of upgrade compatible Elastisearch versions\cr
#'  \link[paws.analytics:elasticsearchservice_get_package_version_history]{get_package_version_history} \tab Returns a list of versions of the package, along with their creation time and commit message\cr
#'  \link[paws.analytics:elasticsearchservice_get_upgrade_history]{get_upgrade_history} \tab Retrieves the complete history of the last 10 upgrades that were performed on the domain\cr
#'  \link[paws.analytics:elasticsearchservice_get_upgrade_status]{get_upgrade_status} \tab Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain\cr
#'  \link[paws.analytics:elasticsearchservice_list_domain_names]{list_domain_names} \tab Returns the name of all Elasticsearch domains owned by the current user's account\cr
#'  \link[paws.analytics:elasticsearchservice_list_domains_for_package]{list_domains_for_package} \tab Lists all Amazon ES domains associated with the package\cr
#'  \link[paws.analytics:elasticsearchservice_list_elasticsearch_instance_types]{list_elasticsearch_instance_types} \tab List all Elasticsearch instance types that are supported for given ElasticsearchVersion\cr
#'  \link[paws.analytics:elasticsearchservice_list_elasticsearch_versions]{list_elasticsearch_versions} \tab List all supported Elasticsearch versions\cr
#'  \link[paws.analytics:elasticsearchservice_list_packages_for_domain]{list_packages_for_domain} \tab Lists all packages associated with the Amazon ES domain\cr
#'  \link[paws.analytics:elasticsearchservice_list_tags]{list_tags} \tab Returns all tags for the given Elasticsearch domain\cr
#'  \link[paws.analytics:elasticsearchservice_list_vpc_endpoint_access]{list_vpc_endpoint_access} \tab Retrieves information about each principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint\cr
#'  \link[paws.analytics:elasticsearchservice_list_vpc_endpoints]{list_vpc_endpoints} \tab Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current account and Region\cr
#'  \link[paws.analytics:elasticsearchservice_list_vpc_endpoints_for_domain]{list_vpc_endpoints_for_domain} \tab Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain\cr
#'  \link[paws.analytics:elasticsearchservice_purchase_reserved_elasticsearch_instance_offering]{purchase_reserved_elasticsearch_instance_offering} \tab Allows you to purchase reserved Elasticsearch instances\cr
#'  \link[paws.analytics:elasticsearchservice_reject_inbound_cross_cluster_search_connection]{reject_inbound_cross_cluster_search_connection} \tab Allows the destination domain owner to reject an inbound cross-cluster search connection request\cr
#'  \link[paws.analytics:elasticsearchservice_remove_tags]{remove_tags} \tab Removes the specified set of tags from the specified Elasticsearch domain\cr
#'  \link[paws.analytics:elasticsearchservice_revoke_vpc_endpoint_access]{revoke_vpc_endpoint_access} \tab Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint\cr
#'  \link[paws.analytics:elasticsearchservice_start_elasticsearch_service_software_update]{start_elasticsearch_service_software_update} \tab Schedules a service software update for an Amazon ES domain\cr
#'  \link[paws.analytics:elasticsearchservice_update_elasticsearch_domain_config]{update_elasticsearch_domain_config} \tab Modifies the cluster configuration of the specified Elasticsearch domain, setting as setting the instance type and the number of instances\cr
#'  \link[paws.analytics:elasticsearchservice_update_package]{update_package} \tab Updates a package for use with Amazon ES domains\cr
#'  \link[paws.analytics:elasticsearchservice_update_vpc_endpoint]{update_vpc_endpoint} \tab Modifies an Amazon OpenSearch Service-managed interface VPC endpoint\cr
#'  \link[paws.analytics:elasticsearchservice_upgrade_elasticsearch_domain]{upgrade_elasticsearch_domain} \tab Allows you to either upgrade your domain or perform an Upgrade eligibility check to a compatible Elasticsearch version
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname elasticsearchservice
#' @export
elasticsearchservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::elasticsearchservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon EMR
#'
#' @description
#' Amazon EMR is a web service that makes it easier to process large
#' amounts of data efficiently. Amazon EMR uses Hadoop processing combined
#' with several Amazon Web Services services to do tasks such as web
#' indexing, data mining, log file analysis, machine learning, scientific
#' simulation, and data warehouse management.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- emr(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- emr()
#' svc$add_instance_fleet(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:emr_add_instance_fleet]{add_instance_fleet} \tab Adds an instance fleet to a running cluster\cr
#'  \link[paws.analytics:emr_add_instance_groups]{add_instance_groups} \tab Adds one or more instance groups to a running cluster\cr
#'  \link[paws.analytics:emr_add_job_flow_steps]{add_job_flow_steps} \tab AddJobFlowSteps adds new steps to a running cluster\cr
#'  \link[paws.analytics:emr_add_tags]{add_tags} \tab Adds tags to an Amazon EMR resource, such as a cluster or an Amazon EMR Studio\cr
#'  \link[paws.analytics:emr_cancel_steps]{cancel_steps} \tab Cancels a pending step or steps in a running cluster\cr
#'  \link[paws.analytics:emr_create_security_configuration]{create_security_configuration} \tab Creates a security configuration, which is stored in the service and can be specified when a cluster is created\cr
#'  \link[paws.analytics:emr_create_studio]{create_studio} \tab Creates a new Amazon EMR Studio\cr
#'  \link[paws.analytics:emr_create_studio_session_mapping]{create_studio_session_mapping} \tab Maps a user or group to the Amazon EMR Studio specified by StudioId, and applies a session policy to refine Studio permissions for that user or group\cr
#'  \link[paws.analytics:emr_delete_security_configuration]{delete_security_configuration} \tab Deletes a security configuration\cr
#'  \link[paws.analytics:emr_delete_studio]{delete_studio} \tab Removes an Amazon EMR Studio from the Studio metadata store\cr
#'  \link[paws.analytics:emr_delete_studio_session_mapping]{delete_studio_session_mapping} \tab Removes a user or group from an Amazon EMR Studio\cr
#'  \link[paws.analytics:emr_describe_cluster]{describe_cluster} \tab Provides cluster-level details including status, hardware and software configuration, VPC settings, and so on\cr
#'  \link[paws.analytics:emr_describe_job_flows]{describe_job_flows} \tab This API is no longer supported and will eventually be removed\cr
#'  \link[paws.analytics:emr_describe_notebook_execution]{describe_notebook_execution} \tab Provides details of a notebook execution\cr
#'  \link[paws.analytics:emr_describe_release_label]{describe_release_label} \tab Provides Amazon EMR release label details, such as the releases available the Region where the API request is run, and the available applications for a specific Amazon EMR release label\cr
#'  \link[paws.analytics:emr_describe_security_configuration]{describe_security_configuration} \tab Provides the details of a security configuration by returning the configuration JSON\cr
#'  \link[paws.analytics:emr_describe_step]{describe_step} \tab Provides more detail about the cluster step\cr
#'  \link[paws.analytics:emr_describe_studio]{describe_studio} \tab Returns details for the specified Amazon EMR Studio including ID, Name, VPC, Studio access URL, and so on\cr
#'  \link[paws.analytics:emr_get_auto_termination_policy]{get_auto_termination_policy} \tab Returns the auto-termination policy for an Amazon EMR cluster\cr
#'  \link[paws.analytics:emr_get_block_public_access_configuration]{get_block_public_access_configuration} \tab Returns the Amazon EMR block public access configuration for your Amazon Web Services account in the current Region\cr
#'  \link[paws.analytics:emr_get_cluster_session_credentials]{get_cluster_session_credentials} \tab Provides temporary, HTTP basic credentials that are associated with a given runtime IAM role and used by a cluster with fine-grained access control activated\cr
#'  \link[paws.analytics:emr_get_managed_scaling_policy]{get_managed_scaling_policy} \tab Fetches the attached managed scaling policy for an Amazon EMR cluster\cr
#'  \link[paws.analytics:emr_get_studio_session_mapping]{get_studio_session_mapping} \tab Fetches mapping details for the specified Amazon EMR Studio and identity (user or group)\cr
#'  \link[paws.analytics:emr_list_bootstrap_actions]{list_bootstrap_actions} \tab Provides information about the bootstrap actions associated with a cluster\cr
#'  \link[paws.analytics:emr_list_clusters]{list_clusters} \tab Provides the status of all clusters visible to this Amazon Web Services account\cr
#'  \link[paws.analytics:emr_list_instance_fleets]{list_instance_fleets} \tab Lists all available details about the instance fleets in a cluster\cr
#'  \link[paws.analytics:emr_list_instance_groups]{list_instance_groups} \tab Provides all available details about the instance groups in a cluster\cr
#'  \link[paws.analytics:emr_list_instances]{list_instances} \tab Provides information for all active Amazon EC2 instances and Amazon EC2 instances terminated in the last 30 days, up to a maximum of 2,000\cr
#'  \link[paws.analytics:emr_list_notebook_executions]{list_notebook_executions} \tab Provides summaries of all notebook executions\cr
#'  \link[paws.analytics:emr_list_release_labels]{list_release_labels} \tab Retrieves release labels of Amazon EMR services in the Region where the API is called\cr
#'  \link[paws.analytics:emr_list_security_configurations]{list_security_configurations} \tab Lists all the security configurations visible to this account, providing their creation dates and times, and their names\cr
#'  \link[paws.analytics:emr_list_steps]{list_steps} \tab Provides a list of steps for the cluster in reverse order unless you specify stepIds with the request or filter by StepStates\cr
#'  \link[paws.analytics:emr_list_studios]{list_studios} \tab Returns a list of all Amazon EMR Studios associated with the Amazon Web Services account\cr
#'  \link[paws.analytics:emr_list_studio_session_mappings]{list_studio_session_mappings} \tab Returns a list of all user or group session mappings for the Amazon EMR Studio specified by StudioId\cr
#'  \link[paws.analytics:emr_list_supported_instance_types]{list_supported_instance_types} \tab A list of the instance types that Amazon EMR supports\cr
#'  \link[paws.analytics:emr_modify_cluster]{modify_cluster} \tab Modifies the number of steps that can be executed concurrently for the cluster specified using ClusterID\cr
#'  \link[paws.analytics:emr_modify_instance_fleet]{modify_instance_fleet} \tab Modifies the target On-Demand and target Spot capacities for the instance fleet with the specified InstanceFleetID within the cluster specified using ClusterID\cr
#'  \link[paws.analytics:emr_modify_instance_groups]{modify_instance_groups} \tab ModifyInstanceGroups modifies the number of nodes and configuration settings of an instance group\cr
#'  \link[paws.analytics:emr_put_auto_scaling_policy]{put_auto_scaling_policy} \tab Creates or updates an automatic scaling policy for a core instance group or task instance group in an Amazon EMR cluster\cr
#'  \link[paws.analytics:emr_put_auto_termination_policy]{put_auto_termination_policy} \tab Auto-termination is supported in Amazon EMR releases 5\cr
#'  \link[paws.analytics:emr_put_block_public_access_configuration]{put_block_public_access_configuration} \tab Creates or updates an Amazon EMR block public access configuration for your Amazon Web Services account in the current Region\cr
#'  \link[paws.analytics:emr_put_managed_scaling_policy]{put_managed_scaling_policy} \tab Creates or updates a managed scaling policy for an Amazon EMR cluster\cr
#'  \link[paws.analytics:emr_remove_auto_scaling_policy]{remove_auto_scaling_policy} \tab Removes an automatic scaling policy from a specified instance group within an Amazon EMR cluster\cr
#'  \link[paws.analytics:emr_remove_auto_termination_policy]{remove_auto_termination_policy} \tab Removes an auto-termination policy from an Amazon EMR cluster\cr
#'  \link[paws.analytics:emr_remove_managed_scaling_policy]{remove_managed_scaling_policy} \tab Removes a managed scaling policy from a specified Amazon EMR cluster\cr
#'  \link[paws.analytics:emr_remove_tags]{remove_tags} \tab Removes tags from an Amazon EMR resource, such as a cluster or Amazon EMR Studio\cr
#'  \link[paws.analytics:emr_run_job_flow]{run_job_flow} \tab RunJobFlow creates and starts running a new cluster (job flow)\cr
#'  \link[paws.analytics:emr_set_keep_job_flow_alive_when_no_steps]{set_keep_job_flow_alive_when_no_steps} \tab You can use the SetKeepJobFlowAliveWhenNoSteps to configure a cluster (job flow) to terminate after the step execution, i\cr
#'  \link[paws.analytics:emr_set_termination_protection]{set_termination_protection} \tab SetTerminationProtection locks a cluster (job flow) so the Amazon EC2 instances in the cluster cannot be terminated by user intervention, an API call, or in the event of a job-flow error\cr
#'  \link[paws.analytics:emr_set_unhealthy_node_replacement]{set_unhealthy_node_replacement} \tab Specify whether to enable unhealthy node replacement, which lets Amazon EMR gracefully replace core nodes on a cluster if any nodes become unhealthy\cr
#'  \link[paws.analytics:emr_set_visible_to_all_users]{set_visible_to_all_users} \tab The SetVisibleToAllUsers parameter is no longer supported\cr
#'  \link[paws.analytics:emr_start_notebook_execution]{start_notebook_execution} \tab Starts a notebook execution\cr
#'  \link[paws.analytics:emr_stop_notebook_execution]{stop_notebook_execution} \tab Stops a notebook execution\cr
#'  \link[paws.analytics:emr_terminate_job_flows]{terminate_job_flows} \tab TerminateJobFlows shuts a list of clusters (job flows) down\cr
#'  \link[paws.analytics:emr_update_studio]{update_studio} \tab Updates an Amazon EMR Studio configuration, including attributes such as name, description, and subnets\cr
#'  \link[paws.analytics:emr_update_studio_session_mapping]{update_studio_session_mapping} \tab Updates the session policy attached to the user or group for the specified Amazon EMR Studio
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname emr
#' @export
emr <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::emr(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS EntityResolution
#'
#' @description
#' Welcome to the *Entity Resolution API Reference*.
#' 
#' Entity Resolution is an Amazon Web Services service that provides
#' pre-configured entity resolution capabilities that enable developers and
#' analysts at advertising and marketing companies to build an accurate and
#' complete view of their consumers.
#' 
#' With Entity Resolution, you can match source records containing consumer
#' identifiers, such as name, email address, and phone number. This is true
#' even when these records have incomplete or conflicting identifiers. For
#' example, Entity Resolution can effectively match a source record from a
#' customer relationship management (CRM) system with a source record from
#' a marketing system containing campaign information.
#' 
#' To learn more about Entity Resolution concepts, procedures, and best
#' practices, see the [Entity Resolution User
#' Guide](https://docs.aws.amazon.com/entityresolution/latest/userguide/what-is-service.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- entityresolution(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- entityresolution()
#' svc$add_policy_statement(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:entityresolution_add_policy_statement]{add_policy_statement} \tab Adds a policy statement object\cr
#'  \link[paws.analytics:entityresolution_batch_delete_unique_id]{batch_delete_unique_id} \tab Deletes multiple unique IDs in a matching workflow\cr
#'  \link[paws.analytics:entityresolution_create_id_mapping_workflow]{create_id_mapping_workflow} \tab Creates an IdMappingWorkflow object which stores the configuration of the data processing job to be run\cr
#'  \link[paws.analytics:entityresolution_create_id_namespace]{create_id_namespace} \tab Creates an ID namespace object which will help customers provide metadata explaining their dataset and how to use it\cr
#'  \link[paws.analytics:entityresolution_create_matching_workflow]{create_matching_workflow} \tab Creates a MatchingWorkflow object which stores the configuration of the data processing job to be run\cr
#'  \link[paws.analytics:entityresolution_create_schema_mapping]{create_schema_mapping} \tab Creates a schema mapping, which defines the schema of the input customer records table\cr
#'  \link[paws.analytics:entityresolution_delete_id_mapping_workflow]{delete_id_mapping_workflow} \tab Deletes the IdMappingWorkflow with a given name\cr
#'  \link[paws.analytics:entityresolution_delete_id_namespace]{delete_id_namespace} \tab Deletes the IdNamespace with a given name\cr
#'  \link[paws.analytics:entityresolution_delete_matching_workflow]{delete_matching_workflow} \tab Deletes the MatchingWorkflow with a given name\cr
#'  \link[paws.analytics:entityresolution_delete_policy_statement]{delete_policy_statement} \tab Deletes the policy statement\cr
#'  \link[paws.analytics:entityresolution_delete_schema_mapping]{delete_schema_mapping} \tab Deletes the SchemaMapping with a given name\cr
#'  \link[paws.analytics:entityresolution_get_id_mapping_job]{get_id_mapping_job} \tab Gets the status, metrics, and errors (if there are any) that are associated with a job\cr
#'  \link[paws.analytics:entityresolution_get_id_mapping_workflow]{get_id_mapping_workflow} \tab Returns the IdMappingWorkflow with a given name, if it exists\cr
#'  \link[paws.analytics:entityresolution_get_id_namespace]{get_id_namespace} \tab Returns the IdNamespace with a given name, if it exists\cr
#'  \link[paws.analytics:entityresolution_get_match_id]{get_match_id} \tab Returns the corresponding Match ID of a customer record if the record has been processed\cr
#'  \link[paws.analytics:entityresolution_get_matching_job]{get_matching_job} \tab Gets the status, metrics, and errors (if there are any) that are associated with a job\cr
#'  \link[paws.analytics:entityresolution_get_matching_workflow]{get_matching_workflow} \tab Returns the MatchingWorkflow with a given name, if it exists\cr
#'  \link[paws.analytics:entityresolution_get_policy]{get_policy} \tab Returns the resource-based policy\cr
#'  \link[paws.analytics:entityresolution_get_provider_service]{get_provider_service} \tab Returns the ProviderService of a given name\cr
#'  \link[paws.analytics:entityresolution_get_schema_mapping]{get_schema_mapping} \tab Returns the SchemaMapping of a given name\cr
#'  \link[paws.analytics:entityresolution_list_id_mapping_jobs]{list_id_mapping_jobs} \tab Lists all ID mapping jobs for a given workflow\cr
#'  \link[paws.analytics:entityresolution_list_id_mapping_workflows]{list_id_mapping_workflows} \tab Returns a list of all the IdMappingWorkflows that have been created for an Amazon Web Services account\cr
#'  \link[paws.analytics:entityresolution_list_id_namespaces]{list_id_namespaces} \tab Returns a list of all ID namespaces\cr
#'  \link[paws.analytics:entityresolution_list_matching_jobs]{list_matching_jobs} \tab Lists all jobs for a given workflow\cr
#'  \link[paws.analytics:entityresolution_list_matching_workflows]{list_matching_workflows} \tab Returns a list of all the MatchingWorkflows that have been created for an Amazon Web Services account\cr
#'  \link[paws.analytics:entityresolution_list_provider_services]{list_provider_services} \tab Returns a list of all the ProviderServices that are available in this Amazon Web Services Region\cr
#'  \link[paws.analytics:entityresolution_list_schema_mappings]{list_schema_mappings} \tab Returns a list of all the SchemaMappings that have been created for an Amazon Web Services account\cr
#'  \link[paws.analytics:entityresolution_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with an Entity Resolution resource\cr
#'  \link[paws.analytics:entityresolution_put_policy]{put_policy} \tab Updates the resource-based policy\cr
#'  \link[paws.analytics:entityresolution_start_id_mapping_job]{start_id_mapping_job} \tab Starts the IdMappingJob of a workflow\cr
#'  \link[paws.analytics:entityresolution_start_matching_job]{start_matching_job} \tab Starts the MatchingJob of a workflow\cr
#'  \link[paws.analytics:entityresolution_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified Entity Resolution resource\cr
#'  \link[paws.analytics:entityresolution_untag_resource]{untag_resource} \tab Removes one or more tags from the specified Entity Resolution resource\cr
#'  \link[paws.analytics:entityresolution_update_id_mapping_workflow]{update_id_mapping_workflow} \tab Updates an existing IdMappingWorkflow\cr
#'  \link[paws.analytics:entityresolution_update_id_namespace]{update_id_namespace} \tab Updates an existing ID namespace\cr
#'  \link[paws.analytics:entityresolution_update_matching_workflow]{update_matching_workflow} \tab Updates an existing MatchingWorkflow\cr
#'  \link[paws.analytics:entityresolution_update_schema_mapping]{update_schema_mapping} \tab Updates a schema mapping
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname entityresolution
#' @export
entityresolution <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::entityresolution(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Kinesis Firehose
#'
#' @description
#' Amazon Data Firehose
#' 
#' Amazon Data Firehose was previously known as Amazon Kinesis Data
#' Firehose.
#' 
#' Amazon Data Firehose is a fully managed service that delivers real-time
#' streaming data to destinations such as Amazon Simple Storage Service
#' (Amazon S3), Amazon OpenSearch Service, Amazon Redshift, Splunk, and
#' various other supported destinations.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- firehose(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- firehose()
#' svc$create_delivery_stream(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:firehose_create_delivery_stream]{create_delivery_stream} \tab Creates a Firehose stream\cr
#'  \link[paws.analytics:firehose_delete_delivery_stream]{delete_delivery_stream} \tab Deletes a Firehose stream and its data\cr
#'  \link[paws.analytics:firehose_describe_delivery_stream]{describe_delivery_stream} \tab Describes the specified Firehose stream and its status\cr
#'  \link[paws.analytics:firehose_list_delivery_streams]{list_delivery_streams} \tab Lists your Firehose streams in alphabetical order of their names\cr
#'  \link[paws.analytics:firehose_list_tags_for_delivery_stream]{list_tags_for_delivery_stream} \tab Lists the tags for the specified Firehose stream\cr
#'  \link[paws.analytics:firehose_put_record]{put_record} \tab Writes a single data record into an Firehose stream\cr
#'  \link[paws.analytics:firehose_put_record_batch]{put_record_batch} \tab Writes multiple data records into a Firehose stream in a single call, which can achieve higher throughput per producer than when writing single records\cr
#'  \link[paws.analytics:firehose_start_delivery_stream_encryption]{start_delivery_stream_encryption} \tab Enables server-side encryption (SSE) for the Firehose stream\cr
#'  \link[paws.analytics:firehose_stop_delivery_stream_encryption]{stop_delivery_stream_encryption} \tab Disables server-side encryption (SSE) for the Firehose stream\cr
#'  \link[paws.analytics:firehose_tag_delivery_stream]{tag_delivery_stream} \tab Adds or updates tags for the specified Firehose stream\cr
#'  \link[paws.analytics:firehose_untag_delivery_stream]{untag_delivery_stream} \tab Removes tags from the specified Firehose stream\cr
#'  \link[paws.analytics:firehose_update_destination]{update_destination} \tab Updates the specified destination of the specified Firehose stream
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname firehose
#' @export
firehose <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::firehose(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Glue
#'
#' @description
#' Glue
#' 
#' Defines the public endpoint for the Glue service.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- glue(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- glue()
#' svc$batch_create_partition(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:glue_batch_create_partition]{batch_create_partition} \tab Creates one or more partitions in a batch operation\cr
#'  \link[paws.analytics:glue_batch_delete_connection]{batch_delete_connection} \tab Deletes a list of connection definitions from the Data Catalog\cr
#'  \link[paws.analytics:glue_batch_delete_partition]{batch_delete_partition} \tab Deletes one or more partitions in a batch operation\cr
#'  \link[paws.analytics:glue_batch_delete_table]{batch_delete_table} \tab Deletes multiple tables at once\cr
#'  \link[paws.analytics:glue_batch_delete_table_version]{batch_delete_table_version} \tab Deletes a specified batch of versions of a table\cr
#'  \link[paws.analytics:glue_batch_get_blueprints]{batch_get_blueprints} \tab Retrieves information about a list of blueprints\cr
#'  \link[paws.analytics:glue_batch_get_crawlers]{batch_get_crawlers} \tab Returns a list of resource metadata for a given list of crawler names\cr
#'  \link[paws.analytics:glue_batch_get_custom_entity_types]{batch_get_custom_entity_types} \tab Retrieves the details for the custom patterns specified by a list of names\cr
#'  \link[paws.analytics:glue_batch_get_data_quality_result]{batch_get_data_quality_result} \tab Retrieves a list of data quality results for the specified result IDs\cr
#'  \link[paws.analytics:glue_batch_get_dev_endpoints]{batch_get_dev_endpoints} \tab Returns a list of resource metadata for a given list of development endpoint names\cr
#'  \link[paws.analytics:glue_batch_get_jobs]{batch_get_jobs} \tab Returns a list of resource metadata for a given list of job names\cr
#'  \link[paws.analytics:glue_batch_get_partition]{batch_get_partition} \tab Retrieves partitions in a batch request\cr
#'  \link[paws.analytics:glue_batch_get_table_optimizer]{batch_get_table_optimizer} \tab Returns the configuration for the specified table optimizers\cr
#'  \link[paws.analytics:glue_batch_get_triggers]{batch_get_triggers} \tab Returns a list of resource metadata for a given list of trigger names\cr
#'  \link[paws.analytics:glue_batch_get_workflows]{batch_get_workflows} \tab Returns a list of resource metadata for a given list of workflow names\cr
#'  \link[paws.analytics:glue_batch_put_data_quality_statistic_annotation]{batch_put_data_quality_statistic_annotation} \tab Annotate datapoints over time for a specific data quality statistic\cr
#'  \link[paws.analytics:glue_batch_stop_job_run]{batch_stop_job_run} \tab Stops one or more job runs for a specified job definition\cr
#'  \link[paws.analytics:glue_batch_update_partition]{batch_update_partition} \tab Updates one or more partitions in a batch operation\cr
#'  \link[paws.analytics:glue_cancel_data_quality_rule_recommendation_run]{cancel_data_quality_rule_recommendation_run} \tab Cancels the specified recommendation run that was being used to generate rules\cr
#'  \link[paws.analytics:glue_cancel_data_quality_ruleset_evaluation_run]{cancel_data_quality_ruleset_evaluation_run} \tab Cancels a run where a ruleset is being evaluated against a data source\cr
#'  \link[paws.analytics:glue_cancel_ml_task_run]{cancel_ml_task_run} \tab Cancels (stops) a task run\cr
#'  \link[paws.analytics:glue_cancel_statement]{cancel_statement} \tab Cancels the statement\cr
#'  \link[paws.analytics:glue_check_schema_version_validity]{check_schema_version_validity} \tab Validates the supplied schema\cr
#'  \link[paws.analytics:glue_create_blueprint]{create_blueprint} \tab Registers a blueprint with Glue\cr
#'  \link[paws.analytics:glue_create_catalog]{create_catalog} \tab Creates a new catalog in the Glue Data Catalog\cr
#'  \link[paws.analytics:glue_create_classifier]{create_classifier} \tab Creates a classifier in the user's account\cr
#'  \link[paws.analytics:glue_create_column_statistics_task_settings]{create_column_statistics_task_settings} \tab Creates settings for a column statistics task\cr
#'  \link[paws.analytics:glue_create_connection]{create_connection} \tab Creates a connection definition in the Data Catalog\cr
#'  \link[paws.analytics:glue_create_crawler]{create_crawler} \tab Creates a new crawler with specified targets, role, configuration, and optional schedule\cr
#'  \link[paws.analytics:glue_create_custom_entity_type]{create_custom_entity_type} \tab Creates a custom pattern that is used to detect sensitive data across the columns and rows of your structured data\cr
#'  \link[paws.analytics:glue_create_database]{create_database} \tab Creates a new database in a Data Catalog\cr
#'  \link[paws.analytics:glue_create_data_quality_ruleset]{create_data_quality_ruleset} \tab Creates a data quality ruleset with DQDL rules applied to a specified Glue table\cr
#'  \link[paws.analytics:glue_create_dev_endpoint]{create_dev_endpoint} \tab Creates a new development endpoint\cr
#'  \link[paws.analytics:glue_create_integration]{create_integration} \tab Creates a Zero-ETL integration in the caller's account between two resources with Amazon Resource Names (ARNs): the SourceArn and TargetArn\cr
#'  \link[paws.analytics:glue_create_integration_resource_property]{create_integration_resource_property} \tab This API can be used for setting up the ResourceProperty of the Glue connection (for the source) or Glue database ARN (for the target)\cr
#'  \link[paws.analytics:glue_create_integration_table_properties]{create_integration_table_properties} \tab This API is used to provide optional override properties for the the tables that need to be replicated\cr
#'  \link[paws.analytics:glue_create_job]{create_job} \tab Creates a new job definition\cr
#'  \link[paws.analytics:glue_create_ml_transform]{create_ml_transform} \tab Creates an Glue machine learning transform\cr
#'  \link[paws.analytics:glue_create_partition]{create_partition} \tab Creates a new partition\cr
#'  \link[paws.analytics:glue_create_partition_index]{create_partition_index} \tab Creates a specified partition index in an existing table\cr
#'  \link[paws.analytics:glue_create_registry]{create_registry} \tab Creates a new registry which may be used to hold a collection of schemas\cr
#'  \link[paws.analytics:glue_create_schema]{create_schema} \tab Creates a new schema set and registers the schema definition\cr
#'  \link[paws.analytics:glue_create_script]{create_script} \tab Transforms a directed acyclic graph (DAG) into code\cr
#'  \link[paws.analytics:glue_create_security_configuration]{create_security_configuration} \tab Creates a new security configuration\cr
#'  \link[paws.analytics:glue_create_session]{create_session} \tab Creates a new session\cr
#'  \link[paws.analytics:glue_create_table]{create_table} \tab Creates a new table definition in the Data Catalog\cr
#'  \link[paws.analytics:glue_create_table_optimizer]{create_table_optimizer} \tab Creates a new table optimizer for a specific function\cr
#'  \link[paws.analytics:glue_create_trigger]{create_trigger} \tab Creates a new trigger\cr
#'  \link[paws.analytics:glue_create_usage_profile]{create_usage_profile} \tab Creates an Glue usage profile\cr
#'  \link[paws.analytics:glue_create_user_defined_function]{create_user_defined_function} \tab Creates a new function definition in the Data Catalog\cr
#'  \link[paws.analytics:glue_create_workflow]{create_workflow} \tab Creates a new workflow\cr
#'  \link[paws.analytics:glue_delete_blueprint]{delete_blueprint} \tab Deletes an existing blueprint\cr
#'  \link[paws.analytics:glue_delete_catalog]{delete_catalog} \tab Removes the specified catalog from the Glue Data Catalog\cr
#'  \link[paws.analytics:glue_delete_classifier]{delete_classifier} \tab Removes a classifier from the Data Catalog\cr
#'  \link[paws.analytics:glue_delete_column_statistics_for_partition]{delete_column_statistics_for_partition} \tab Delete the partition column statistics of a column\cr
#'  \link[paws.analytics:glue_delete_column_statistics_for_table]{delete_column_statistics_for_table} \tab Retrieves table statistics of columns\cr
#'  \link[paws.analytics:glue_delete_column_statistics_task_settings]{delete_column_statistics_task_settings} \tab Deletes settings for a column statistics task\cr
#'  \link[paws.analytics:glue_delete_connection]{delete_connection} \tab Deletes a connection from the Data Catalog\cr
#'  \link[paws.analytics:glue_delete_crawler]{delete_crawler} \tab Removes a specified crawler from the Glue Data Catalog, unless the crawler state is RUNNING\cr
#'  \link[paws.analytics:glue_delete_custom_entity_type]{delete_custom_entity_type} \tab Deletes a custom pattern by specifying its name\cr
#'  \link[paws.analytics:glue_delete_database]{delete_database} \tab Removes a specified database from a Data Catalog\cr
#'  \link[paws.analytics:glue_delete_data_quality_ruleset]{delete_data_quality_ruleset} \tab Deletes a data quality ruleset\cr
#'  \link[paws.analytics:glue_delete_dev_endpoint]{delete_dev_endpoint} \tab Deletes a specified development endpoint\cr
#'  \link[paws.analytics:glue_delete_integration]{delete_integration} \tab Deletes the specified Zero-ETL integration\cr
#'  \link[paws.analytics:glue_delete_integration_table_properties]{delete_integration_table_properties} \tab Deletes the table properties that have been created for the tables that need to be replicated\cr
#'  \link[paws.analytics:glue_delete_job]{delete_job} \tab Deletes a specified job definition\cr
#'  \link[paws.analytics:glue_delete_ml_transform]{delete_ml_transform} \tab Deletes an Glue machine learning transform\cr
#'  \link[paws.analytics:glue_delete_partition]{delete_partition} \tab Deletes a specified partition\cr
#'  \link[paws.analytics:glue_delete_partition_index]{delete_partition_index} \tab Deletes a specified partition index from an existing table\cr
#'  \link[paws.analytics:glue_delete_registry]{delete_registry} \tab Delete the entire registry including schema and all of its versions\cr
#'  \link[paws.analytics:glue_delete_resource_policy]{delete_resource_policy} \tab Deletes a specified policy\cr
#'  \link[paws.analytics:glue_delete_schema]{delete_schema} \tab Deletes the entire schema set, including the schema set and all of its versions\cr
#'  \link[paws.analytics:glue_delete_schema_versions]{delete_schema_versions} \tab Remove versions from the specified schema\cr
#'  \link[paws.analytics:glue_delete_security_configuration]{delete_security_configuration} \tab Deletes a specified security configuration\cr
#'  \link[paws.analytics:glue_delete_session]{delete_session} \tab Deletes the session\cr
#'  \link[paws.analytics:glue_delete_table]{delete_table} \tab Removes a table definition from the Data Catalog\cr
#'  \link[paws.analytics:glue_delete_table_optimizer]{delete_table_optimizer} \tab Deletes an optimizer and all associated metadata for a table\cr
#'  \link[paws.analytics:glue_delete_table_version]{delete_table_version} \tab Deletes a specified version of a table\cr
#'  \link[paws.analytics:glue_delete_trigger]{delete_trigger} \tab Deletes a specified trigger\cr
#'  \link[paws.analytics:glue_delete_usage_profile]{delete_usage_profile} \tab Deletes the Glue specified usage profile\cr
#'  \link[paws.analytics:glue_delete_user_defined_function]{delete_user_defined_function} \tab Deletes an existing function definition from the Data Catalog\cr
#'  \link[paws.analytics:glue_delete_workflow]{delete_workflow} \tab Deletes a workflow\cr
#'  \link[paws.analytics:glue_describe_connection_type]{describe_connection_type} \tab The DescribeConnectionType API provides full details of the supported options for a given connection type in Glue\cr
#'  \link[paws.analytics:glue_describe_entity]{describe_entity} \tab Provides details regarding the entity used with the connection type, with a description of the data model for each field in the selected entity\cr
#'  \link[paws.analytics:glue_describe_inbound_integrations]{describe_inbound_integrations} \tab Returns a list of inbound integrations for the specified integration\cr
#'  \link[paws.analytics:glue_describe_integrations]{describe_integrations} \tab The API is used to retrieve a list of integrations\cr
#'  \link[paws.analytics:glue_get_blueprint]{get_blueprint} \tab Retrieves the details of a blueprint\cr
#'  \link[paws.analytics:glue_get_blueprint_run]{get_blueprint_run} \tab Retrieves the details of a blueprint run\cr
#'  \link[paws.analytics:glue_get_blueprint_runs]{get_blueprint_runs} \tab Retrieves the details of blueprint runs for a specified blueprint\cr
#'  \link[paws.analytics:glue_get_catalog]{get_catalog} \tab The name of the Catalog to retrieve\cr
#'  \link[paws.analytics:glue_get_catalog_import_status]{get_catalog_import_status} \tab Retrieves the status of a migration operation\cr
#'  \link[paws.analytics:glue_get_catalogs]{get_catalogs} \tab Retrieves all catalogs defined in a catalog in the Glue Data Catalog\cr
#'  \link[paws.analytics:glue_get_classifier]{get_classifier} \tab Retrieve a classifier by name\cr
#'  \link[paws.analytics:glue_get_classifiers]{get_classifiers} \tab Lists all classifier objects in the Data Catalog\cr
#'  \link[paws.analytics:glue_get_column_statistics_for_partition]{get_column_statistics_for_partition} \tab Retrieves partition statistics of columns\cr
#'  \link[paws.analytics:glue_get_column_statistics_for_table]{get_column_statistics_for_table} \tab Retrieves table statistics of columns\cr
#'  \link[paws.analytics:glue_get_column_statistics_task_run]{get_column_statistics_task_run} \tab Get the associated metadata/information for a task run, given a task run ID\cr
#'  \link[paws.analytics:glue_get_column_statistics_task_runs]{get_column_statistics_task_runs} \tab Retrieves information about all runs associated with the specified table\cr
#'  \link[paws.analytics:glue_get_column_statistics_task_settings]{get_column_statistics_task_settings} \tab Gets settings for a column statistics task\cr
#'  \link[paws.analytics:glue_get_connection]{get_connection} \tab Retrieves a connection definition from the Data Catalog\cr
#'  \link[paws.analytics:glue_get_connections]{get_connections} \tab Retrieves a list of connection definitions from the Data Catalog\cr
#'  \link[paws.analytics:glue_get_crawler]{get_crawler} \tab Retrieves metadata for a specified crawler\cr
#'  \link[paws.analytics:glue_get_crawler_metrics]{get_crawler_metrics} \tab Retrieves metrics about specified crawlers\cr
#'  \link[paws.analytics:glue_get_crawlers]{get_crawlers} \tab Retrieves metadata for all crawlers defined in the customer account\cr
#'  \link[paws.analytics:glue_get_custom_entity_type]{get_custom_entity_type} \tab Retrieves the details of a custom pattern by specifying its name\cr
#'  \link[paws.analytics:glue_get_database]{get_database} \tab Retrieves the definition of a specified database\cr
#'  \link[paws.analytics:glue_get_databases]{get_databases} \tab Retrieves all databases defined in a given Data Catalog\cr
#'  \link[paws.analytics:glue_get_data_catalog_encryption_settings]{get_data_catalog_encryption_settings} \tab Retrieves the security configuration for a specified catalog\cr
#'  \link[paws.analytics:glue_get_dataflow_graph]{get_dataflow_graph} \tab Transforms a Python script into a directed acyclic graph (DAG)\cr
#'  \link[paws.analytics:glue_get_data_quality_model]{get_data_quality_model} \tab Retrieve the training status of the model along with more information (CompletedOn, StartedOn, FailureReason)\cr
#'  \link[paws.analytics:glue_get_data_quality_model_result]{get_data_quality_model_result} \tab Retrieve a statistic's predictions for a given Profile ID\cr
#'  \link[paws.analytics:glue_get_data_quality_result]{get_data_quality_result} \tab Retrieves the result of a data quality rule evaluation\cr
#'  \link[paws.analytics:glue_get_data_quality_rule_recommendation_run]{get_data_quality_rule_recommendation_run} \tab Gets the specified recommendation run that was used to generate rules\cr
#'  \link[paws.analytics:glue_get_data_quality_ruleset]{get_data_quality_ruleset} \tab Returns an existing ruleset by identifier or name\cr
#'  \link[paws.analytics:glue_get_data_quality_ruleset_evaluation_run]{get_data_quality_ruleset_evaluation_run} \tab Retrieves a specific run where a ruleset is evaluated against a data source\cr
#'  \link[paws.analytics:glue_get_dev_endpoint]{get_dev_endpoint} \tab Retrieves information about a specified development endpoint\cr
#'  \link[paws.analytics:glue_get_dev_endpoints]{get_dev_endpoints} \tab Retrieves all the development endpoints in this Amazon Web Services account\cr
#'  \link[paws.analytics:glue_get_entity_records]{get_entity_records} \tab This API is used to query preview data from a given connection type or from a native Amazon S3 based Glue Data Catalog\cr
#'  \link[paws.analytics:glue_get_integration_resource_property]{get_integration_resource_property} \tab This API is used for fetching the ResourceProperty of the Glue connection (for the source) or Glue database ARN (for the target)\cr
#'  \link[paws.analytics:glue_get_integration_table_properties]{get_integration_table_properties} \tab This API is used to retrieve optional override properties for the tables that need to be replicated\cr
#'  \link[paws.analytics:glue_get_job]{get_job} \tab Retrieves an existing job definition\cr
#'  \link[paws.analytics:glue_get_job_bookmark]{get_job_bookmark} \tab Returns information on a job bookmark entry\cr
#'  \link[paws.analytics:glue_get_job_run]{get_job_run} \tab Retrieves the metadata for a given job run\cr
#'  \link[paws.analytics:glue_get_job_runs]{get_job_runs} \tab Retrieves metadata for all runs of a given job definition\cr
#'  \link[paws.analytics:glue_get_jobs]{get_jobs} \tab Retrieves all current job definitions\cr
#'  \link[paws.analytics:glue_get_mapping]{get_mapping} \tab Creates mappings\cr
#'  \link[paws.analytics:glue_get_ml_task_run]{get_ml_task_run} \tab Gets details for a specific task run on a machine learning transform\cr
#'  \link[paws.analytics:glue_get_ml_task_runs]{get_ml_task_runs} \tab Gets a list of runs for a machine learning transform\cr
#'  \link[paws.analytics:glue_get_ml_transform]{get_ml_transform} \tab Gets an Glue machine learning transform artifact and all its corresponding metadata\cr
#'  \link[paws.analytics:glue_get_ml_transforms]{get_ml_transforms} \tab Gets a sortable, filterable list of existing Glue machine learning transforms\cr
#'  \link[paws.analytics:glue_get_partition]{get_partition} \tab Retrieves information about a specified partition\cr
#'  \link[paws.analytics:glue_get_partition_indexes]{get_partition_indexes} \tab Retrieves the partition indexes associated with a table\cr
#'  \link[paws.analytics:glue_get_partitions]{get_partitions} \tab Retrieves information about the partitions in a table\cr
#'  \link[paws.analytics:glue_get_plan]{get_plan} \tab Gets code to perform a specified mapping\cr
#'  \link[paws.analytics:glue_get_registry]{get_registry} \tab Describes the specified registry in detail\cr
#'  \link[paws.analytics:glue_get_resource_policies]{get_resource_policies} \tab Retrieves the resource policies set on individual resources by Resource Access Manager during cross-account permission grants\cr
#'  \link[paws.analytics:glue_get_resource_policy]{get_resource_policy} \tab Retrieves a specified resource policy\cr
#'  \link[paws.analytics:glue_get_schema]{get_schema} \tab Describes the specified schema in detail\cr
#'  \link[paws.analytics:glue_get_schema_by_definition]{get_schema_by_definition} \tab Retrieves a schema by the SchemaDefinition\cr
#'  \link[paws.analytics:glue_get_schema_version]{get_schema_version} \tab Get the specified schema by its unique ID assigned when a version of the schema is created or registered\cr
#'  \link[paws.analytics:glue_get_schema_versions_diff]{get_schema_versions_diff} \tab Fetches the schema version difference in the specified difference type between two stored schema versions in the Schema Registry\cr
#'  \link[paws.analytics:glue_get_security_configuration]{get_security_configuration} \tab Retrieves a specified security configuration\cr
#'  \link[paws.analytics:glue_get_security_configurations]{get_security_configurations} \tab Retrieves a list of all security configurations\cr
#'  \link[paws.analytics:glue_get_session]{get_session} \tab Retrieves the session\cr
#'  \link[paws.analytics:glue_get_statement]{get_statement} \tab Retrieves the statement\cr
#'  \link[paws.analytics:glue_get_table]{get_table} \tab Retrieves the Table definition in a Data Catalog for a specified table\cr
#'  \link[paws.analytics:glue_get_table_optimizer]{get_table_optimizer} \tab Returns the configuration of all optimizers associated with a specified table\cr
#'  \link[paws.analytics:glue_get_tables]{get_tables} \tab Retrieves the definitions of some or all of the tables in a given Database\cr
#'  \link[paws.analytics:glue_get_table_version]{get_table_version} \tab Retrieves a specified version of a table\cr
#'  \link[paws.analytics:glue_get_table_versions]{get_table_versions} \tab Retrieves a list of strings that identify available versions of a specified table\cr
#'  \link[paws.analytics:glue_get_tags]{get_tags} \tab Retrieves a list of tags associated with a resource\cr
#'  \link[paws.analytics:glue_get_trigger]{get_trigger} \tab Retrieves the definition of a trigger\cr
#'  \link[paws.analytics:glue_get_triggers]{get_triggers} \tab Gets all the triggers associated with a job\cr
#'  \link[paws.analytics:glue_get_unfiltered_partition_metadata]{get_unfiltered_partition_metadata} \tab Retrieves partition metadata from the Data Catalog that contains unfiltered metadata\cr
#'  \link[paws.analytics:glue_get_unfiltered_partitions_metadata]{get_unfiltered_partitions_metadata} \tab Retrieves partition metadata from the Data Catalog that contains unfiltered metadata\cr
#'  \link[paws.analytics:glue_get_unfiltered_table_metadata]{get_unfiltered_table_metadata} \tab Allows a third-party analytical engine to retrieve unfiltered table metadata from the Data Catalog\cr
#'  \link[paws.analytics:glue_get_usage_profile]{get_usage_profile} \tab Retrieves information about the specified Glue usage profile\cr
#'  \link[paws.analytics:glue_get_user_defined_function]{get_user_defined_function} \tab Retrieves a specified function definition from the Data Catalog\cr
#'  \link[paws.analytics:glue_get_user_defined_functions]{get_user_defined_functions} \tab Retrieves multiple function definitions from the Data Catalog\cr
#'  \link[paws.analytics:glue_get_workflow]{get_workflow} \tab Retrieves resource metadata for a workflow\cr
#'  \link[paws.analytics:glue_get_workflow_run]{get_workflow_run} \tab Retrieves the metadata for a given workflow run\cr
#'  \link[paws.analytics:glue_get_workflow_run_properties]{get_workflow_run_properties} \tab Retrieves the workflow run properties which were set during the run\cr
#'  \link[paws.analytics:glue_get_workflow_runs]{get_workflow_runs} \tab Retrieves metadata for all runs of a given workflow\cr
#'  \link[paws.analytics:glue_import_catalog_to_glue]{import_catalog_to_glue} \tab Imports an existing Amazon Athena Data Catalog to Glue\cr
#'  \link[paws.analytics:glue_list_blueprints]{list_blueprints} \tab Lists all the blueprint names in an account\cr
#'  \link[paws.analytics:glue_list_column_statistics_task_runs]{list_column_statistics_task_runs} \tab List all task runs for a particular account\cr
#'  \link[paws.analytics:glue_list_connection_types]{list_connection_types} \tab The ListConnectionTypes API provides a discovery mechanism to learn available connection types in Glue\cr
#'  \link[paws.analytics:glue_list_crawlers]{list_crawlers} \tab Retrieves the names of all crawler resources in this Amazon Web Services account, or the resources with the specified tag\cr
#'  \link[paws.analytics:glue_list_crawls]{list_crawls} \tab Returns all the crawls of a specified crawler\cr
#'  \link[paws.analytics:glue_list_custom_entity_types]{list_custom_entity_types} \tab Lists all the custom patterns that have been created\cr
#'  \link[paws.analytics:glue_list_data_quality_results]{list_data_quality_results} \tab Returns all data quality execution results for your account\cr
#'  \link[paws.analytics:glue_list_data_quality_rule_recommendation_runs]{list_data_quality_rule_recommendation_runs} \tab Lists the recommendation runs meeting the filter criteria\cr
#'  \link[paws.analytics:glue_list_data_quality_ruleset_evaluation_runs]{list_data_quality_ruleset_evaluation_runs} \tab Lists all the runs meeting the filter criteria, where a ruleset is evaluated against a data source\cr
#'  \link[paws.analytics:glue_list_data_quality_rulesets]{list_data_quality_rulesets} \tab Returns a paginated list of rulesets for the specified list of Glue tables\cr
#'  \link[paws.analytics:glue_list_data_quality_statistic_annotations]{list_data_quality_statistic_annotations} \tab Retrieve annotations for a data quality statistic\cr
#'  \link[paws.analytics:glue_list_data_quality_statistics]{list_data_quality_statistics} \tab Retrieves a list of data quality statistics\cr
#'  \link[paws.analytics:glue_list_dev_endpoints]{list_dev_endpoints} \tab Retrieves the names of all DevEndpoint resources in this Amazon Web Services account, or the resources with the specified tag\cr
#'  \link[paws.analytics:glue_list_entities]{list_entities} \tab Returns the available entities supported by the connection type\cr
#'  \link[paws.analytics:glue_list_jobs]{list_jobs} \tab Retrieves the names of all job resources in this Amazon Web Services account, or the resources with the specified tag\cr
#'  \link[paws.analytics:glue_list_ml_transforms]{list_ml_transforms} \tab Retrieves a sortable, filterable list of existing Glue machine learning transforms in this Amazon Web Services account, or the resources with the specified tag\cr
#'  \link[paws.analytics:glue_list_registries]{list_registries} \tab Returns a list of registries that you have created, with minimal registry information\cr
#'  \link[paws.analytics:glue_list_schemas]{list_schemas} \tab Returns a list of schemas with minimal details\cr
#'  \link[paws.analytics:glue_list_schema_versions]{list_schema_versions} \tab Returns a list of schema versions that you have created, with minimal information\cr
#'  \link[paws.analytics:glue_list_sessions]{list_sessions} \tab Retrieve a list of sessions\cr
#'  \link[paws.analytics:glue_list_statements]{list_statements} \tab Lists statements for the session\cr
#'  \link[paws.analytics:glue_list_table_optimizer_runs]{list_table_optimizer_runs} \tab Lists the history of previous optimizer runs for a specific table\cr
#'  \link[paws.analytics:glue_list_triggers]{list_triggers} \tab Retrieves the names of all trigger resources in this Amazon Web Services account, or the resources with the specified tag\cr
#'  \link[paws.analytics:glue_list_usage_profiles]{list_usage_profiles} \tab List all the Glue usage profiles\cr
#'  \link[paws.analytics:glue_list_workflows]{list_workflows} \tab Lists names of workflows created in the account\cr
#'  \link[paws.analytics:glue_modify_integration]{modify_integration} \tab Modifies a Zero-ETL integration in the caller's account\cr
#'  \link[paws.analytics:glue_put_data_catalog_encryption_settings]{put_data_catalog_encryption_settings} \tab Sets the security configuration for a specified catalog\cr
#'  \link[paws.analytics:glue_put_data_quality_profile_annotation]{put_data_quality_profile_annotation} \tab Annotate all datapoints for a Profile\cr
#'  \link[paws.analytics:glue_put_resource_policy]{put_resource_policy} \tab Sets the Data Catalog resource policy for access control\cr
#'  \link[paws.analytics:glue_put_schema_version_metadata]{put_schema_version_metadata} \tab Puts the metadata key value pair for a specified schema version ID\cr
#'  \link[paws.analytics:glue_put_workflow_run_properties]{put_workflow_run_properties} \tab Puts the specified workflow run properties for the given workflow run\cr
#'  \link[paws.analytics:glue_query_schema_version_metadata]{query_schema_version_metadata} \tab Queries for the schema version metadata information\cr
#'  \link[paws.analytics:glue_register_schema_version]{register_schema_version} \tab Adds a new version to the existing schema\cr
#'  \link[paws.analytics:glue_remove_schema_version_metadata]{remove_schema_version_metadata} \tab Removes a key value pair from the schema version metadata for the specified schema version ID\cr
#'  \link[paws.analytics:glue_reset_job_bookmark]{reset_job_bookmark} \tab Resets a bookmark entry\cr
#'  \link[paws.analytics:glue_resume_workflow_run]{resume_workflow_run} \tab Restarts selected nodes of a previous partially completed workflow run and resumes the workflow run\cr
#'  \link[paws.analytics:glue_run_statement]{run_statement} \tab Executes the statement\cr
#'  \link[paws.analytics:glue_search_tables]{search_tables} \tab Searches a set of tables based on properties in the table metadata as well as on the parent database\cr
#'  \link[paws.analytics:glue_start_blueprint_run]{start_blueprint_run} \tab Starts a new run of the specified blueprint\cr
#'  \link[paws.analytics:glue_start_column_statistics_task_run]{start_column_statistics_task_run} \tab Starts a column statistics task run, for a specified table and columns\cr
#'  \link[paws.analytics:glue_start_column_statistics_task_run_schedule]{start_column_statistics_task_run_schedule} \tab Starts a column statistics task run schedule\cr
#'  \link[paws.analytics:glue_start_crawler]{start_crawler} \tab Starts a crawl using the specified crawler, regardless of what is scheduled\cr
#'  \link[paws.analytics:glue_start_crawler_schedule]{start_crawler_schedule} \tab Changes the schedule state of the specified crawler to SCHEDULED, unless the crawler is already running or the schedule state is already SCHEDULED\cr
#'  \link[paws.analytics:glue_start_data_quality_rule_recommendation_run]{start_data_quality_rule_recommendation_run} \tab Starts a recommendation run that is used to generate rules when you don't know what rules to write\cr
#'  \link[paws.analytics:glue_start_data_quality_ruleset_evaluation_run]{start_data_quality_ruleset_evaluation_run} \tab Once you have a ruleset definition (either recommended or your own), you call this operation to evaluate the ruleset against a data source (Glue table)\cr
#'  \link[paws.analytics:glue_start_export_labels_task_run]{start_export_labels_task_run} \tab Begins an asynchronous task to export all labeled data for a particular transform\cr
#'  \link[paws.analytics:glue_start_import_labels_task_run]{start_import_labels_task_run} \tab Enables you to provide additional labels (examples of truth) to be used to teach the machine learning transform and improve its quality\cr
#'  \link[paws.analytics:glue_start_job_run]{start_job_run} \tab Starts a job run using a job definition\cr
#'  \link[paws.analytics:glue_start_ml_evaluation_task_run]{start_ml_evaluation_task_run} \tab Starts a task to estimate the quality of the transform\cr
#'  \link[paws.analytics:glue_start_ml_labeling_set_generation_task_run]{start_ml_labeling_set_generation_task_run} \tab Starts the active learning workflow for your machine learning transform to improve the transform's quality by generating label sets and adding labels\cr
#'  \link[paws.analytics:glue_start_trigger]{start_trigger} \tab Starts an existing trigger\cr
#'  \link[paws.analytics:glue_start_workflow_run]{start_workflow_run} \tab Starts a new run of the specified workflow\cr
#'  \link[paws.analytics:glue_stop_column_statistics_task_run]{stop_column_statistics_task_run} \tab Stops a task run for the specified table\cr
#'  \link[paws.analytics:glue_stop_column_statistics_task_run_schedule]{stop_column_statistics_task_run_schedule} \tab Stops a column statistics task run schedule\cr
#'  \link[paws.analytics:glue_stop_crawler]{stop_crawler} \tab If the specified crawler is running, stops the crawl\cr
#'  \link[paws.analytics:glue_stop_crawler_schedule]{stop_crawler_schedule} \tab Sets the schedule state of the specified crawler to NOT_SCHEDULED, but does not stop the crawler if it is already running\cr
#'  \link[paws.analytics:glue_stop_session]{stop_session} \tab Stops the session\cr
#'  \link[paws.analytics:glue_stop_trigger]{stop_trigger} \tab Stops a specified trigger\cr
#'  \link[paws.analytics:glue_stop_workflow_run]{stop_workflow_run} \tab Stops the execution of the specified workflow run\cr
#'  \link[paws.analytics:glue_tag_resource]{tag_resource} \tab Adds tags to a resource\cr
#'  \link[paws.analytics:glue_test_connection]{test_connection} \tab Tests a connection to a service to validate the service credentials that you provide\cr
#'  \link[paws.analytics:glue_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.analytics:glue_update_blueprint]{update_blueprint} \tab Updates a registered blueprint\cr
#'  \link[paws.analytics:glue_update_catalog]{update_catalog} \tab Updates an existing catalog's properties in the Glue Data Catalog\cr
#'  \link[paws.analytics:glue_update_classifier]{update_classifier} \tab Modifies an existing classifier (a GrokClassifier, an XMLClassifier, a JsonClassifier, or a CsvClassifier, depending on which field is present)\cr
#'  \link[paws.analytics:glue_update_column_statistics_for_partition]{update_column_statistics_for_partition} \tab Creates or updates partition statistics of columns\cr
#'  \link[paws.analytics:glue_update_column_statistics_for_table]{update_column_statistics_for_table} \tab Creates or updates table statistics of columns\cr
#'  \link[paws.analytics:glue_update_column_statistics_task_settings]{update_column_statistics_task_settings} \tab Updates settings for a column statistics task\cr
#'  \link[paws.analytics:glue_update_connection]{update_connection} \tab Updates a connection definition in the Data Catalog\cr
#'  \link[paws.analytics:glue_update_crawler]{update_crawler} \tab Updates a crawler\cr
#'  \link[paws.analytics:glue_update_crawler_schedule]{update_crawler_schedule} \tab Updates the schedule of a crawler using a cron expression\cr
#'  \link[paws.analytics:glue_update_database]{update_database} \tab Updates an existing database definition in a Data Catalog\cr
#'  \link[paws.analytics:glue_update_data_quality_ruleset]{update_data_quality_ruleset} \tab Updates the specified data quality ruleset\cr
#'  \link[paws.analytics:glue_update_dev_endpoint]{update_dev_endpoint} \tab Updates a specified development endpoint\cr
#'  \link[paws.analytics:glue_update_integration_resource_property]{update_integration_resource_property} \tab This API can be used for updating the ResourceProperty of the Glue connection (for the source) or Glue database ARN (for the target)\cr
#'  \link[paws.analytics:glue_update_integration_table_properties]{update_integration_table_properties} \tab This API is used to provide optional override properties for the tables that need to be replicated\cr
#'  \link[paws.analytics:glue_update_job]{update_job} \tab Updates an existing job definition\cr
#'  \link[paws.analytics:glue_update_job_from_source_control]{update_job_from_source_control} \tab Synchronizes a job from the source control repository\cr
#'  \link[paws.analytics:glue_update_ml_transform]{update_ml_transform} \tab Updates an existing machine learning transform\cr
#'  \link[paws.analytics:glue_update_partition]{update_partition} \tab Updates a partition\cr
#'  \link[paws.analytics:glue_update_registry]{update_registry} \tab Updates an existing registry which is used to hold a collection of schemas\cr
#'  \link[paws.analytics:glue_update_schema]{update_schema} \tab Updates the description, compatibility setting, or version checkpoint for a schema set\cr
#'  \link[paws.analytics:glue_update_source_control_from_job]{update_source_control_from_job} \tab Synchronizes a job to the source control repository\cr
#'  \link[paws.analytics:glue_update_table]{update_table} \tab Updates a metadata table in the Data Catalog\cr
#'  \link[paws.analytics:glue_update_table_optimizer]{update_table_optimizer} \tab Updates the configuration for an existing table optimizer\cr
#'  \link[paws.analytics:glue_update_trigger]{update_trigger} \tab Updates a trigger definition\cr
#'  \link[paws.analytics:glue_update_usage_profile]{update_usage_profile} \tab Update an Glue usage profile\cr
#'  \link[paws.analytics:glue_update_user_defined_function]{update_user_defined_function} \tab Updates an existing function definition in the Data Catalog\cr
#'  \link[paws.analytics:glue_update_workflow]{update_workflow} \tab Updates an existing workflow
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname glue
#' @export
glue <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::glue(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Glue DataBrew
#'
#' @description
#' Glue DataBrew is a visual, cloud-scale data-preparation service.
#' DataBrew simplifies data preparation tasks, targeting data issues that
#' are hard to spot and time-consuming to fix. DataBrew empowers users of
#' all technical levels to visualize the data and perform one-click data
#' transformations, with no coding required.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- gluedatabrew(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- gluedatabrew()
#' svc$batch_delete_recipe_version(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:gluedatabrew_batch_delete_recipe_version]{batch_delete_recipe_version} \tab Deletes one or more versions of a recipe at a time\cr
#'  \link[paws.analytics:gluedatabrew_create_dataset]{create_dataset} \tab Creates a new DataBrew dataset\cr
#'  \link[paws.analytics:gluedatabrew_create_profile_job]{create_profile_job} \tab Creates a new job to analyze a dataset and create its data profile\cr
#'  \link[paws.analytics:gluedatabrew_create_project]{create_project} \tab Creates a new DataBrew project\cr
#'  \link[paws.analytics:gluedatabrew_create_recipe]{create_recipe} \tab Creates a new DataBrew recipe\cr
#'  \link[paws.analytics:gluedatabrew_create_recipe_job]{create_recipe_job} \tab Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe\cr
#'  \link[paws.analytics:gluedatabrew_create_ruleset]{create_ruleset} \tab Creates a new ruleset that can be used in a profile job to validate the data quality of a dataset\cr
#'  \link[paws.analytics:gluedatabrew_create_schedule]{create_schedule} \tab Creates a new schedule for one or more DataBrew jobs\cr
#'  \link[paws.analytics:gluedatabrew_delete_dataset]{delete_dataset} \tab Deletes a dataset from DataBrew\cr
#'  \link[paws.analytics:gluedatabrew_delete_job]{delete_job} \tab Deletes the specified DataBrew job\cr
#'  \link[paws.analytics:gluedatabrew_delete_project]{delete_project} \tab Deletes an existing DataBrew project\cr
#'  \link[paws.analytics:gluedatabrew_delete_recipe_version]{delete_recipe_version} \tab Deletes a single version of a DataBrew recipe\cr
#'  \link[paws.analytics:gluedatabrew_delete_ruleset]{delete_ruleset} \tab Deletes a ruleset\cr
#'  \link[paws.analytics:gluedatabrew_delete_schedule]{delete_schedule} \tab Deletes the specified DataBrew schedule\cr
#'  \link[paws.analytics:gluedatabrew_describe_dataset]{describe_dataset} \tab Returns the definition of a specific DataBrew dataset\cr
#'  \link[paws.analytics:gluedatabrew_describe_job]{describe_job} \tab Returns the definition of a specific DataBrew job\cr
#'  \link[paws.analytics:gluedatabrew_describe_job_run]{describe_job_run} \tab Represents one run of a DataBrew job\cr
#'  \link[paws.analytics:gluedatabrew_describe_project]{describe_project} \tab Returns the definition of a specific DataBrew project\cr
#'  \link[paws.analytics:gluedatabrew_describe_recipe]{describe_recipe} \tab Returns the definition of a specific DataBrew recipe corresponding to a particular version\cr
#'  \link[paws.analytics:gluedatabrew_describe_ruleset]{describe_ruleset} \tab Retrieves detailed information about the ruleset\cr
#'  \link[paws.analytics:gluedatabrew_describe_schedule]{describe_schedule} \tab Returns the definition of a specific DataBrew schedule\cr
#'  \link[paws.analytics:gluedatabrew_list_datasets]{list_datasets} \tab Lists all of the DataBrew datasets\cr
#'  \link[paws.analytics:gluedatabrew_list_job_runs]{list_job_runs} \tab Lists all of the previous runs of a particular DataBrew job\cr
#'  \link[paws.analytics:gluedatabrew_list_jobs]{list_jobs} \tab Lists all of the DataBrew jobs that are defined\cr
#'  \link[paws.analytics:gluedatabrew_list_projects]{list_projects} \tab Lists all of the DataBrew projects that are defined\cr
#'  \link[paws.analytics:gluedatabrew_list_recipes]{list_recipes} \tab Lists all of the DataBrew recipes that are defined\cr
#'  \link[paws.analytics:gluedatabrew_list_recipe_versions]{list_recipe_versions} \tab Lists the versions of a particular DataBrew recipe, except for LATEST_WORKING\cr
#'  \link[paws.analytics:gluedatabrew_list_rulesets]{list_rulesets} \tab List all rulesets available in the current account or rulesets associated with a specific resource (dataset)\cr
#'  \link[paws.analytics:gluedatabrew_list_schedules]{list_schedules} \tab Lists the DataBrew schedules that are defined\cr
#'  \link[paws.analytics:gluedatabrew_list_tags_for_resource]{list_tags_for_resource} \tab Lists all the tags for a DataBrew resource\cr
#'  \link[paws.analytics:gluedatabrew_publish_recipe]{publish_recipe} \tab Publishes a new version of a DataBrew recipe\cr
#'  \link[paws.analytics:gluedatabrew_send_project_session_action]{send_project_session_action} \tab Performs a recipe step within an interactive DataBrew session that's currently open\cr
#'  \link[paws.analytics:gluedatabrew_start_job_run]{start_job_run} \tab Runs a DataBrew job\cr
#'  \link[paws.analytics:gluedatabrew_start_project_session]{start_project_session} \tab Creates an interactive session, enabling you to manipulate data in a DataBrew project\cr
#'  \link[paws.analytics:gluedatabrew_stop_job_run]{stop_job_run} \tab Stops a particular run of a job\cr
#'  \link[paws.analytics:gluedatabrew_tag_resource]{tag_resource} \tab Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe, job, or schedule\cr
#'  \link[paws.analytics:gluedatabrew_untag_resource]{untag_resource} \tab Removes metadata tags from a DataBrew resource\cr
#'  \link[paws.analytics:gluedatabrew_update_dataset]{update_dataset} \tab Modifies the definition of an existing DataBrew dataset\cr
#'  \link[paws.analytics:gluedatabrew_update_profile_job]{update_profile_job} \tab Modifies the definition of an existing profile job\cr
#'  \link[paws.analytics:gluedatabrew_update_project]{update_project} \tab Modifies the definition of an existing DataBrew project\cr
#'  \link[paws.analytics:gluedatabrew_update_recipe]{update_recipe} \tab Modifies the definition of the LATEST_WORKING version of a DataBrew recipe\cr
#'  \link[paws.analytics:gluedatabrew_update_recipe_job]{update_recipe_job} \tab Modifies the definition of an existing DataBrew recipe job\cr
#'  \link[paws.analytics:gluedatabrew_update_ruleset]{update_ruleset} \tab Updates specified ruleset\cr
#'  \link[paws.analytics:gluedatabrew_update_schedule]{update_schedule} \tab Modifies the definition of an existing DataBrew schedule
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname gluedatabrew
#' @export
gluedatabrew <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::gluedatabrew(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon HealthLake
#'
#' @description
#' AWS HealthLake is a HIPAA eligibile service that allows customers to
#' store, transform, query, and analyze their FHIR-formatted data in a
#' consistent fashion in the cloud.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- healthlake(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- healthlake()
#' svc$create_fhir_datastore(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:healthlake_create_fhir_datastore]{create_fhir_datastore} \tab Creates a data store that can ingest and export FHIR formatted data\cr
#'  \link[paws.analytics:healthlake_delete_fhir_datastore]{delete_fhir_datastore} \tab Deletes a data store\cr
#'  \link[paws.analytics:healthlake_describe_fhir_datastore]{describe_fhir_datastore} \tab Gets the properties associated with the FHIR data store, including the data store ID, data store ARN, data store name, data store status, when the data store was created, data store type version, and the data store's endpoint\cr
#'  \link[paws.analytics:healthlake_describe_fhir_export_job]{describe_fhir_export_job} \tab Displays the properties of a FHIR export job, including the ID, ARN, name, and the status of the job\cr
#'  \link[paws.analytics:healthlake_describe_fhir_import_job]{describe_fhir_import_job} \tab Displays the properties of a FHIR import job, including the ID, ARN, name, and the status of the job\cr
#'  \link[paws.analytics:healthlake_list_fhir_datastores]{list_fhir_datastores} \tab Lists all FHIR data stores that are in the user’s account, regardless of data store status\cr
#'  \link[paws.analytics:healthlake_list_fhir_export_jobs]{list_fhir_export_jobs} \tab Lists all FHIR export jobs associated with an account and their statuses\cr
#'  \link[paws.analytics:healthlake_list_fhir_import_jobs]{list_fhir_import_jobs} \tab Lists all FHIR import jobs associated with an account and their statuses\cr
#'  \link[paws.analytics:healthlake_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of all existing tags associated with a data store\cr
#'  \link[paws.analytics:healthlake_start_fhir_export_job]{start_fhir_export_job} \tab Begins a FHIR export job\cr
#'  \link[paws.analytics:healthlake_start_fhir_import_job]{start_fhir_import_job} \tab Begins a FHIR Import job\cr
#'  \link[paws.analytics:healthlake_tag_resource]{tag_resource} \tab Adds a user specified key and value tag to a data store\cr
#'  \link[paws.analytics:healthlake_untag_resource]{untag_resource} \tab Removes tags from a data store
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname healthlake
#' @export
healthlake <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::healthlake(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Interactive Video Service
#'
#' @description
#' **Introduction**
#' 
#' The Amazon Interactive Video Service (IVS) API is REST compatible, using
#' a standard HTTP API and an Amazon Web Services EventBridge event stream
#' for responses. JSON is used for both requests and responses, including
#' errors.
#' 
#' The API is an Amazon Web Services regional service. For a list of
#' supported regions and Amazon IVS HTTPS service endpoints, see the
#' [Amazon IVS
#' page](https://docs.aws.amazon.com/general/latest/gr/ivs.html) in the
#' *Amazon Web Services General Reference*.
#' 
#' *All API request parameters and URLs are case sensitive. *
#' 
#' For a summary of notable documentation changes in each release, see
#' [Document
#' History](https://docs.aws.amazon.com/ivs/latest/LowLatencyUserGuide/doc-history.html).
#' 
#' **Allowed Header Values**
#' 
#' -   ` Accept: ` application/json
#' 
#' -   ` Accept-Encoding: ` gzip, deflate
#' 
#' -   ` Content-Type: `application/json
#' 
#' **Key Concepts**
#' 
#' -   **Channel** — Stores configuration data related to your live stream.
#'     You first create a channel and then use the channel’s stream key to
#'     start your live stream.
#' 
#' -   **Stream key** — An identifier assigned by Amazon IVS when you
#'     create a channel, which is then used to authorize streaming. *Treat
#'     the stream key like a secret, since it allows anyone to stream to
#'     the channel.*
#' 
#' -   **Playback key pair** — Video playback may be restricted using
#'     playback-authorization tokens, which use public-key encryption. A
#'     playback key pair is the public-private pair of keys used to sign
#'     and validate the playback-authorization token.
#' 
#' -   **Recording configuration** — Stores configuration related to
#'     recording a live stream and where to store the recorded content.
#'     Multiple channels can reference the same recording configuration.
#' 
#' -   **Playback restriction policy** — Restricts playback by countries
#'     and/or origin sites.
#' 
#' For more information about your IVS live stream, also see [Getting
#' Started with IVS Low-Latency
#' Streaming](https://docs.aws.amazon.com/ivs/latest/LowLatencyUserGuide/getting-started.html).
#' 
#' **Tagging**
#' 
#' A *tag* is a metadata label that you assign to an Amazon Web Services
#' resource. A tag comprises a *key* and a *value*, both set by you. For
#' example, you might set a tag as `topic:nature` to label a particular
#' video category. See [Best practices and
#' strategies](https://docs.aws.amazon.com/tag-editor/latest/userguide/best-practices-and-strats.html)
#' in *Tagging Amazon Web Services Resources and Tag Editor* for details,
#' including restrictions that apply to tags and "Tag naming limits and
#' requirements"; Amazon IVS has no service-specific constraints beyond
#' what is documented there.
#' 
#' Tags can help you identify and organize your Amazon Web Services
#' resources. For example, you can use the same tag for different resources
#' to indicate that they are related. You can also use tags to manage
#' access (see [Access
#' Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html)).
#' 
#' The Amazon IVS API has these tag-related operations:
#' `tag_resource`,
#' `untag_resource`, and
#' `list_tags_for_resource`. The following
#' resources support tagging: Channels, Stream Keys, Playback Key Pairs,
#' and Recording Configurations.
#' 
#' At most 50 tags can be applied to a resource.
#' 
#' **Authentication versus Authorization**
#' 
#' Note the differences between these concepts:
#' 
#' -   *Authentication* is about verifying identity. You need to be
#'     authenticated to sign Amazon IVS API requests.
#' 
#' -   *Authorization* is about granting permissions. Your IAM roles need
#'     to have permissions for Amazon IVS API requests. In addition,
#'     authorization is needed to view [Amazon IVS private
#'     channels](https://docs.aws.amazon.com/ivs/latest/LowLatencyUserGuide/private-channels.html).
#'     (Private channels are channels that are enabled for "playback
#'     authorization.")
#' 
#' **Authentication**
#' 
#' All Amazon IVS API requests must be authenticated with a signature. The
#' Amazon Web Services Command-Line Interface (CLI) and Amazon IVS Player
#' SDKs take care of signing the underlying API calls for you. However, if
#' your application calls the Amazon IVS API directly, it’s your
#' responsibility to sign the requests.
#' 
#' You generate a signature using valid Amazon Web Services credentials
#' that have permission to perform the requested action. For example, you
#' must sign PutMetadata requests with a signature generated from a user
#' account that has the `ivs:PutMetadata` permission.
#' 
#' For more information:
#' 
#' -   Authentication and generating signatures — See [Authenticating
#'     Requests (Amazon Web Services Signature Version
#'     4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html)
#'     in the *Amazon Web Services General Reference*.
#' 
#' -   Managing Amazon IVS permissions — See [Identity and Access
#'     Management](https://docs.aws.amazon.com/ivs/latest/LowLatencyUserGuide/security-iam.html)
#'     on the Security page of the *Amazon IVS User Guide*.
#' 
#' **Amazon Resource Names (ARNs)**
#' 
#' ARNs uniquely identify AWS resources. An ARN is required when you need
#' to specify a resource unambiguously across all of AWS, such as in IAM
#' policies and API calls. For more information, see [Amazon Resource
#' Names](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html)
#' in the *AWS General Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ivs(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ivs()
#' svc$batch_get_channel(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:ivs_batch_get_channel]{batch_get_channel} \tab Performs GetChannel on multiple ARNs simultaneously\cr
#'  \link[paws.analytics:ivs_batch_get_stream_key]{batch_get_stream_key} \tab Performs GetStreamKey on multiple ARNs simultaneously\cr
#'  \link[paws.analytics:ivs_batch_start_viewer_session_revocation]{batch_start_viewer_session_revocation} \tab Performs StartViewerSessionRevocation on multiple channel ARN and viewer ID pairs simultaneously\cr
#'  \link[paws.analytics:ivs_create_channel]{create_channel} \tab Creates a new channel and an associated stream key to start streaming\cr
#'  \link[paws.analytics:ivs_create_playback_restriction_policy]{create_playback_restriction_policy} \tab Creates a new playback restriction policy, for constraining playback by countries and/or origins\cr
#'  \link[paws.analytics:ivs_create_recording_configuration]{create_recording_configuration} \tab Creates a new recording configuration, used to enable recording to Amazon S3\cr
#'  \link[paws.analytics:ivs_create_stream_key]{create_stream_key} \tab Creates a stream key, used to initiate a stream, for the specified channel ARN\cr
#'  \link[paws.analytics:ivs_delete_channel]{delete_channel} \tab Deletes the specified channel and its associated stream keys\cr
#'  \link[paws.analytics:ivs_delete_playback_key_pair]{delete_playback_key_pair} \tab Deletes a specified authorization key pair\cr
#'  \link[paws.analytics:ivs_delete_playback_restriction_policy]{delete_playback_restriction_policy} \tab Deletes the specified playback restriction policy\cr
#'  \link[paws.analytics:ivs_delete_recording_configuration]{delete_recording_configuration} \tab Deletes the recording configuration for the specified ARN\cr
#'  \link[paws.analytics:ivs_delete_stream_key]{delete_stream_key} \tab Deletes the stream key for the specified ARN, so it can no longer be used to stream\cr
#'  \link[paws.analytics:ivs_get_channel]{get_channel} \tab Gets the channel configuration for the specified channel ARN\cr
#'  \link[paws.analytics:ivs_get_playback_key_pair]{get_playback_key_pair} \tab Gets a specified playback authorization key pair and returns the arn and fingerprint\cr
#'  \link[paws.analytics:ivs_get_playback_restriction_policy]{get_playback_restriction_policy} \tab Gets the specified playback restriction policy\cr
#'  \link[paws.analytics:ivs_get_recording_configuration]{get_recording_configuration} \tab Gets the recording configuration for the specified ARN\cr
#'  \link[paws.analytics:ivs_get_stream]{get_stream} \tab Gets information about the active (live) stream on a specified channel\cr
#'  \link[paws.analytics:ivs_get_stream_key]{get_stream_key} \tab Gets stream-key information for a specified ARN\cr
#'  \link[paws.analytics:ivs_get_stream_session]{get_stream_session} \tab Gets metadata on a specified stream\cr
#'  \link[paws.analytics:ivs_import_playback_key_pair]{import_playback_key_pair} \tab Imports the public portion of a new key pair and returns its arn and fingerprint\cr
#'  \link[paws.analytics:ivs_list_channels]{list_channels} \tab Gets summary information about all channels in your account, in the Amazon Web Services region where the API request is processed\cr
#'  \link[paws.analytics:ivs_list_playback_key_pairs]{list_playback_key_pairs} \tab Gets summary information about playback key pairs\cr
#'  \link[paws.analytics:ivs_list_playback_restriction_policies]{list_playback_restriction_policies} \tab Gets summary information about playback restriction policies\cr
#'  \link[paws.analytics:ivs_list_recording_configurations]{list_recording_configurations} \tab Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed\cr
#'  \link[paws.analytics:ivs_list_stream_keys]{list_stream_keys} \tab Gets summary information about stream keys for the specified channel\cr
#'  \link[paws.analytics:ivs_list_streams]{list_streams} \tab Gets summary information about live streams in your account, in the Amazon Web Services region where the API request is processed\cr
#'  \link[paws.analytics:ivs_list_stream_sessions]{list_stream_sessions} \tab Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed\cr
#'  \link[paws.analytics:ivs_list_tags_for_resource]{list_tags_for_resource} \tab Gets information about Amazon Web Services tags for the specified ARN\cr
#'  \link[paws.analytics:ivs_put_metadata]{put_metadata} \tab Inserts metadata into the active stream of the specified channel\cr
#'  \link[paws.analytics:ivs_start_viewer_session_revocation]{start_viewer_session_revocation} \tab Starts the process of revoking the viewer session associated with a specified channel ARN and viewer ID\cr
#'  \link[paws.analytics:ivs_stop_stream]{stop_stream} \tab Disconnects the incoming RTMPS stream for the specified channel\cr
#'  \link[paws.analytics:ivs_tag_resource]{tag_resource} \tab Adds or updates tags for the Amazon Web Services resource with the specified ARN\cr
#'  \link[paws.analytics:ivs_untag_resource]{untag_resource} \tab Removes tags from the resource with the specified ARN\cr
#'  \link[paws.analytics:ivs_update_channel]{update_channel} \tab Updates a channel's configuration\cr
#'  \link[paws.analytics:ivs_update_playback_restriction_policy]{update_playback_restriction_policy} \tab Updates a specified playback restriction policy
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ivs
#' @export
ivs <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::ivs(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Interactive Video Service RealTime
#'
#' @description
#' The Amazon Interactive Video Service (IVS) real-time API is REST
#' compatible, using a standard HTTP API and an AWS EventBridge event
#' stream for responses. JSON is used for both requests and responses,
#' including errors.
#' 
#' **Key Concepts**
#' 
#' -   **Stage** — A virtual space where participants can exchange video in
#'     real time.
#' 
#' -   **Participant token** — A token that authenticates a participant
#'     when they join a stage.
#' 
#' -   **Participant object** — Represents participants (people) in the
#'     stage and contains information about them. When a token is created,
#'     it includes a participant ID; when a participant uses that token to
#'     join a stage, the participant is associated with that participant
#'     ID. There is a 1:1 mapping between participant tokens and
#'     participants.
#' 
#' For server-side composition:
#' 
#' -   **Composition process** — Composites participants of a stage into a
#'     single video and forwards it to a set of outputs (e.g., IVS
#'     channels). Composition operations support this process.
#' 
#' -   **Composition** — Controls the look of the outputs, including how
#'     participants are positioned in the video.
#' 
#' For more information about your IVS live stream, also see [Getting
#' Started with Amazon IVS Real-Time
#' Streaming](https://docs.aws.amazon.com/ivs/latest/RealTimeUserGuide/getting-started.html).
#' 
#' **Tagging**
#' 
#' A *tag* is a metadata label that you assign to an AWS resource. A tag
#' comprises a *key* and a *value*, both set by you. For example, you might
#' set a tag as `topic:nature` to label a particular video category. See
#' [Best practices and
#' strategies](https://docs.aws.amazon.com/tag-editor/latest/userguide/best-practices-and-strats.html)
#' in *Tagging AWS Resources and Tag Editor* for details, including
#' restrictions that apply to tags and "Tag naming limits and
#' requirements"; Amazon IVS stages has no service-specific constraints
#' beyond what is documented there.
#' 
#' Tags can help you identify and organize your AWS resources. For example,
#' you can use the same tag for different resources to indicate that they
#' are related. You can also use tags to manage access (see [Access
#' Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html)).
#' 
#' The Amazon IVS real-time API has these tag-related operations:
#' `tag_resource`,
#' `untag_resource`, and
#' `list_tags_for_resource`. The
#' following resource supports tagging: Stage.
#' 
#' At most 50 tags can be applied to a resource.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ivsrealtime(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ivsrealtime()
#' svc$create_encoder_configuration(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:ivsrealtime_create_encoder_configuration]{create_encoder_configuration} \tab Creates an EncoderConfiguration object\cr
#'  \link[paws.analytics:ivsrealtime_create_ingest_configuration]{create_ingest_configuration} \tab Creates a new IngestConfiguration resource, used to specify the ingest protocol for a stage\cr
#'  \link[paws.analytics:ivsrealtime_create_participant_token]{create_participant_token} \tab Creates an additional token for a specified stage\cr
#'  \link[paws.analytics:ivsrealtime_create_stage]{create_stage} \tab Creates a new stage (and optionally participant tokens)\cr
#'  \link[paws.analytics:ivsrealtime_create_storage_configuration]{create_storage_configuration} \tab Creates a new storage configuration, used to enable recording to Amazon S3\cr
#'  \link[paws.analytics:ivsrealtime_delete_encoder_configuration]{delete_encoder_configuration} \tab Deletes an EncoderConfiguration resource\cr
#'  \link[paws.analytics:ivsrealtime_delete_ingest_configuration]{delete_ingest_configuration} \tab Deletes a specified IngestConfiguration, so it can no longer be used to broadcast\cr
#'  \link[paws.analytics:ivsrealtime_delete_public_key]{delete_public_key} \tab Deletes the specified public key used to sign stage participant tokens\cr
#'  \link[paws.analytics:ivsrealtime_delete_stage]{delete_stage} \tab Shuts down and deletes the specified stage (disconnecting all participants)\cr
#'  \link[paws.analytics:ivsrealtime_delete_storage_configuration]{delete_storage_configuration} \tab Deletes the storage configuration for the specified ARN\cr
#'  \link[paws.analytics:ivsrealtime_disconnect_participant]{disconnect_participant} \tab Disconnects a specified participant from a specified stage\cr
#'  \link[paws.analytics:ivsrealtime_get_composition]{get_composition} \tab Get information about the specified Composition resource\cr
#'  \link[paws.analytics:ivsrealtime_get_encoder_configuration]{get_encoder_configuration} \tab Gets information about the specified EncoderConfiguration resource\cr
#'  \link[paws.analytics:ivsrealtime_get_ingest_configuration]{get_ingest_configuration} \tab Gets information about the specified IngestConfiguration\cr
#'  \link[paws.analytics:ivsrealtime_get_participant]{get_participant} \tab Gets information about the specified participant token\cr
#'  \link[paws.analytics:ivsrealtime_get_public_key]{get_public_key} \tab Gets information for the specified public key\cr
#'  \link[paws.analytics:ivsrealtime_get_stage]{get_stage} \tab Gets information for the specified stage\cr
#'  \link[paws.analytics:ivsrealtime_get_stage_session]{get_stage_session} \tab Gets information for the specified stage session\cr
#'  \link[paws.analytics:ivsrealtime_get_storage_configuration]{get_storage_configuration} \tab Gets the storage configuration for the specified ARN\cr
#'  \link[paws.analytics:ivsrealtime_import_public_key]{import_public_key} \tab Import a public key to be used for signing stage participant tokens\cr
#'  \link[paws.analytics:ivsrealtime_list_compositions]{list_compositions} \tab Gets summary information about all Compositions in your account, in the AWS region where the API request is processed\cr
#'  \link[paws.analytics:ivsrealtime_list_encoder_configurations]{list_encoder_configurations} \tab Gets summary information about all EncoderConfigurations in your account, in the AWS region where the API request is processed\cr
#'  \link[paws.analytics:ivsrealtime_list_ingest_configurations]{list_ingest_configurations} \tab Lists all IngestConfigurations in your account, in the AWS region where the API request is processed\cr
#'  \link[paws.analytics:ivsrealtime_list_participant_events]{list_participant_events} \tab Lists events for a specified participant that occurred during a specified stage session\cr
#'  \link[paws.analytics:ivsrealtime_list_participants]{list_participants} \tab Lists all participants in a specified stage session\cr
#'  \link[paws.analytics:ivsrealtime_list_public_keys]{list_public_keys} \tab Gets summary information about all public keys in your account, in the AWS region where the API request is processed\cr
#'  \link[paws.analytics:ivsrealtime_list_stages]{list_stages} \tab Gets summary information about all stages in your account, in the AWS region where the API request is processed\cr
#'  \link[paws.analytics:ivsrealtime_list_stage_sessions]{list_stage_sessions} \tab Gets all sessions for a specified stage\cr
#'  \link[paws.analytics:ivsrealtime_list_storage_configurations]{list_storage_configurations} \tab Gets summary information about all storage configurations in your account, in the AWS region where the API request is processed\cr
#'  \link[paws.analytics:ivsrealtime_list_tags_for_resource]{list_tags_for_resource} \tab Gets information about AWS tags for the specified ARN\cr
#'  \link[paws.analytics:ivsrealtime_start_composition]{start_composition} \tab Starts a Composition from a stage based on the configuration provided in the request\cr
#'  \link[paws.analytics:ivsrealtime_stop_composition]{stop_composition} \tab Stops and deletes a Composition resource\cr
#'  \link[paws.analytics:ivsrealtime_tag_resource]{tag_resource} \tab Adds or updates tags for the AWS resource with the specified ARN\cr
#'  \link[paws.analytics:ivsrealtime_untag_resource]{untag_resource} \tab Removes tags from the resource with the specified ARN\cr
#'  \link[paws.analytics:ivsrealtime_update_ingest_configuration]{update_ingest_configuration} \tab Updates a specified IngestConfiguration\cr
#'  \link[paws.analytics:ivsrealtime_update_stage]{update_stage} \tab Updates a stage’s configuration
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ivsrealtime
#' @export
ivsrealtime <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::ivsrealtime(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Managed Streaming for Kafka
#'
#' @description
#' The operations for managing an Amazon MSK cluster.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- kafka(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- kafka()
#' svc$batch_associate_scram_secret(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:kafka_batch_associate_scram_secret]{batch_associate_scram_secret} \tab Associates one or more Scram Secrets with an Amazon MSK cluster\cr
#'  \link[paws.analytics:kafka_batch_disassociate_scram_secret]{batch_disassociate_scram_secret} \tab Disassociates one or more Scram Secrets from an Amazon MSK cluster\cr
#'  \link[paws.analytics:kafka_create_cluster]{create_cluster} \tab Creates a new MSK cluster\cr
#'  \link[paws.analytics:kafka_create_cluster_v2]{create_cluster_v2} \tab Creates a new MSK cluster\cr
#'  \link[paws.analytics:kafka_create_configuration]{create_configuration} \tab Creates a new MSK configuration\cr
#'  \link[paws.analytics:kafka_create_replicator]{create_replicator} \tab Creates the replicator\cr
#'  \link[paws.analytics:kafka_create_vpc_connection]{create_vpc_connection} \tab Creates a new MSK VPC connection\cr
#'  \link[paws.analytics:kafka_delete_cluster]{delete_cluster} \tab Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request\cr
#'  \link[paws.analytics:kafka_delete_cluster_policy]{delete_cluster_policy} \tab Deletes the MSK cluster policy specified by the Amazon Resource Name (ARN) in the request\cr
#'  \link[paws.analytics:kafka_delete_configuration]{delete_configuration} \tab Deletes an MSK Configuration\cr
#'  \link[paws.analytics:kafka_delete_replicator]{delete_replicator} \tab Deletes a replicator\cr
#'  \link[paws.analytics:kafka_delete_vpc_connection]{delete_vpc_connection} \tab Deletes a MSK VPC connection\cr
#'  \link[paws.analytics:kafka_describe_cluster]{describe_cluster} \tab Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request\cr
#'  \link[paws.analytics:kafka_describe_cluster_operation]{describe_cluster_operation} \tab Returns a description of the cluster operation specified by the ARN\cr
#'  \link[paws.analytics:kafka_describe_cluster_operation_v2]{describe_cluster_operation_v2} \tab Returns a description of the cluster operation specified by the ARN\cr
#'  \link[paws.analytics:kafka_describe_cluster_v2]{describe_cluster_v2} \tab Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request\cr
#'  \link[paws.analytics:kafka_describe_configuration]{describe_configuration} \tab Returns a description of this MSK configuration\cr
#'  \link[paws.analytics:kafka_describe_configuration_revision]{describe_configuration_revision} \tab Returns a description of this revision of the configuration\cr
#'  \link[paws.analytics:kafka_describe_replicator]{describe_replicator} \tab Describes a replicator\cr
#'  \link[paws.analytics:kafka_describe_vpc_connection]{describe_vpc_connection} \tab Returns a description of this MSK VPC connection\cr
#'  \link[paws.analytics:kafka_get_bootstrap_brokers]{get_bootstrap_brokers} \tab A list of brokers that a client application can use to bootstrap\cr
#'  \link[paws.analytics:kafka_get_cluster_policy]{get_cluster_policy} \tab Get the MSK cluster policy specified by the Amazon Resource Name (ARN) in the request\cr
#'  \link[paws.analytics:kafka_get_compatible_kafka_versions]{get_compatible_kafka_versions} \tab Gets the Apache Kafka versions to which you can update the MSK cluster\cr
#'  \link[paws.analytics:kafka_list_client_vpc_connections]{list_client_vpc_connections} \tab Returns a list of all the VPC connections in this Region\cr
#'  \link[paws.analytics:kafka_list_cluster_operations]{list_cluster_operations} \tab Returns a list of all the operations that have been performed on the specified MSK cluster\cr
#'  \link[paws.analytics:kafka_list_cluster_operations_v2]{list_cluster_operations_v2} \tab Returns a list of all the operations that have been performed on the specified MSK cluster\cr
#'  \link[paws.analytics:kafka_list_clusters]{list_clusters} \tab Returns a list of all the MSK clusters in the current Region\cr
#'  \link[paws.analytics:kafka_list_clusters_v2]{list_clusters_v2} \tab Returns a list of all the MSK clusters in the current Region\cr
#'  \link[paws.analytics:kafka_list_configuration_revisions]{list_configuration_revisions} \tab Returns a list of all the MSK configurations in this Region\cr
#'  \link[paws.analytics:kafka_list_configurations]{list_configurations} \tab Returns a list of all the MSK configurations in this Region\cr
#'  \link[paws.analytics:kafka_list_kafka_versions]{list_kafka_versions} \tab Returns a list of Apache Kafka versions\cr
#'  \link[paws.analytics:kafka_list_nodes]{list_nodes} \tab Returns a list of the broker nodes in the cluster\cr
#'  \link[paws.analytics:kafka_list_replicators]{list_replicators} \tab Lists the replicators\cr
#'  \link[paws.analytics:kafka_list_scram_secrets]{list_scram_secrets} \tab Returns a list of the Scram Secrets associated with an Amazon MSK cluster\cr
#'  \link[paws.analytics:kafka_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of the tags associated with the specified resource\cr
#'  \link[paws.analytics:kafka_list_vpc_connections]{list_vpc_connections} \tab Returns a list of all the VPC connections in this Region\cr
#'  \link[paws.analytics:kafka_put_cluster_policy]{put_cluster_policy} \tab Creates or updates the MSK cluster policy specified by the cluster Amazon Resource Name (ARN) in the request\cr
#'  \link[paws.analytics:kafka_reboot_broker]{reboot_broker} \tab Reboots brokers\cr
#'  \link[paws.analytics:kafka_reject_client_vpc_connection]{reject_client_vpc_connection} \tab Returns empty response\cr
#'  \link[paws.analytics:kafka_tag_resource]{tag_resource} \tab Adds tags to the specified MSK resource\cr
#'  \link[paws.analytics:kafka_untag_resource]{untag_resource} \tab Removes the tags associated with the keys that are provided in the query\cr
#'  \link[paws.analytics:kafka_update_broker_count]{update_broker_count} \tab Updates the number of broker nodes in the cluster\cr
#'  \link[paws.analytics:kafka_update_broker_storage]{update_broker_storage} \tab Updates the EBS storage associated with MSK brokers\cr
#'  \link[paws.analytics:kafka_update_broker_type]{update_broker_type} \tab Updates EC2 instance type\cr
#'  \link[paws.analytics:kafka_update_cluster_configuration]{update_cluster_configuration} \tab Updates the cluster with the configuration that is specified in the request body\cr
#'  \link[paws.analytics:kafka_update_cluster_kafka_version]{update_cluster_kafka_version} \tab Updates the Apache Kafka version for the cluster\cr
#'  \link[paws.analytics:kafka_update_configuration]{update_configuration} \tab Updates an MSK configuration\cr
#'  \link[paws.analytics:kafka_update_connectivity]{update_connectivity} \tab Updates the cluster's connectivity configuration\cr
#'  \link[paws.analytics:kafka_update_monitoring]{update_monitoring} \tab Updates the monitoring settings for the cluster\cr
#'  \link[paws.analytics:kafka_update_replication_info]{update_replication_info} \tab Updates replication info of a replicator\cr
#'  \link[paws.analytics:kafka_update_security]{update_security} \tab Updates the security settings for the cluster\cr
#'  \link[paws.analytics:kafka_update_storage]{update_storage} \tab Updates cluster broker volume size (or) sets cluster storage mode to TIERED
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname kafka
#' @export
kafka <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::kafka(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Managed Streaming for Kafka Connect
#'
#' 
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- kafkaconnect(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- kafkaconnect()
#' svc$create_connector(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:kafkaconnect_create_connector]{create_connector} \tab Creates a connector using the specified properties\cr
#'  \link[paws.analytics:kafkaconnect_create_custom_plugin]{create_custom_plugin} \tab Creates a custom plugin using the specified properties\cr
#'  \link[paws.analytics:kafkaconnect_create_worker_configuration]{create_worker_configuration} \tab Creates a worker configuration using the specified properties\cr
#'  \link[paws.analytics:kafkaconnect_delete_connector]{delete_connector} \tab Deletes the specified connector\cr
#'  \link[paws.analytics:kafkaconnect_delete_custom_plugin]{delete_custom_plugin} \tab Deletes a custom plugin\cr
#'  \link[paws.analytics:kafkaconnect_delete_worker_configuration]{delete_worker_configuration} \tab Deletes the specified worker configuration\cr
#'  \link[paws.analytics:kafkaconnect_describe_connector]{describe_connector} \tab Returns summary information about the connector\cr
#'  \link[paws.analytics:kafkaconnect_describe_connector_operation]{describe_connector_operation} \tab Returns information about the specified connector's operations\cr
#'  \link[paws.analytics:kafkaconnect_describe_custom_plugin]{describe_custom_plugin} \tab A summary description of the custom plugin\cr
#'  \link[paws.analytics:kafkaconnect_describe_worker_configuration]{describe_worker_configuration} \tab Returns information about a worker configuration\cr
#'  \link[paws.analytics:kafkaconnect_list_connector_operations]{list_connector_operations} \tab Lists information about a connector's operation(s)\cr
#'  \link[paws.analytics:kafkaconnect_list_connectors]{list_connectors} \tab Returns a list of all the connectors in this account and Region\cr
#'  \link[paws.analytics:kafkaconnect_list_custom_plugins]{list_custom_plugins} \tab Returns a list of all of the custom plugins in this account and Region\cr
#'  \link[paws.analytics:kafkaconnect_list_tags_for_resource]{list_tags_for_resource} \tab Lists all the tags attached to the specified resource\cr
#'  \link[paws.analytics:kafkaconnect_list_worker_configurations]{list_worker_configurations} \tab Returns a list of all of the worker configurations in this account and Region\cr
#'  \link[paws.analytics:kafkaconnect_tag_resource]{tag_resource} \tab Attaches tags to the specified resource\cr
#'  \link[paws.analytics:kafkaconnect_untag_resource]{untag_resource} \tab Removes tags from the specified resource\cr
#'  \link[paws.analytics:kafkaconnect_update_connector]{update_connector} \tab Updates the specified connector
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname kafkaconnect
#' @export
kafkaconnect <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::kafkaconnect(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWSKendraFrontendService
#'
#' @description
#' Amazon Kendra is a service for indexing large document sets.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- kendra(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- kendra()
#' svc$associate_entities_to_experience(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:kendra_associate_entities_to_experience]{associate_entities_to_experience} \tab Grants users or groups in your IAM Identity Center identity source access to your Amazon Kendra experience\cr
#'  \link[paws.analytics:kendra_associate_personas_to_entities]{associate_personas_to_entities} \tab Defines the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience\cr
#'  \link[paws.analytics:kendra_batch_delete_document]{batch_delete_document} \tab Removes one or more documents from an index\cr
#'  \link[paws.analytics:kendra_batch_delete_featured_results_set]{batch_delete_featured_results_set} \tab Removes one or more sets of featured results\cr
#'  \link[paws.analytics:kendra_batch_get_document_status]{batch_get_document_status} \tab Returns the indexing status for one or more documents submitted with the BatchPutDocument API\cr
#'  \link[paws.analytics:kendra_batch_put_document]{batch_put_document} \tab Adds one or more documents to an index\cr
#'  \link[paws.analytics:kendra_clear_query_suggestions]{clear_query_suggestions} \tab Clears existing query suggestions from an index\cr
#'  \link[paws.analytics:kendra_create_access_control_configuration]{create_access_control_configuration} \tab Creates an access configuration for your documents\cr
#'  \link[paws.analytics:kendra_create_data_source]{create_data_source} \tab Creates a data source connector that you want to use with an Amazon Kendra index\cr
#'  \link[paws.analytics:kendra_create_experience]{create_experience} \tab Creates an Amazon Kendra experience such as a search application\cr
#'  \link[paws.analytics:kendra_create_faq]{create_faq} \tab Creates a set of frequently ask questions (FAQs) using a specified FAQ file stored in an Amazon S3 bucket\cr
#'  \link[paws.analytics:kendra_create_featured_results_set]{create_featured_results_set} \tab Creates a set of featured results to display at the top of the search results page\cr
#'  \link[paws.analytics:kendra_create_index]{create_index} \tab Creates an Amazon Kendra index\cr
#'  \link[paws.analytics:kendra_create_query_suggestions_block_list]{create_query_suggestions_block_list} \tab Creates a block list to exlcude certain queries from suggestions\cr
#'  \link[paws.analytics:kendra_create_thesaurus]{create_thesaurus} \tab Creates a thesaurus for an index\cr
#'  \link[paws.analytics:kendra_delete_access_control_configuration]{delete_access_control_configuration} \tab Deletes an access control configuration that you created for your documents in an index\cr
#'  \link[paws.analytics:kendra_delete_data_source]{delete_data_source} \tab Deletes an Amazon Kendra data source connector\cr
#'  \link[paws.analytics:kendra_delete_experience]{delete_experience} \tab Deletes your Amazon Kendra experience such as a search application\cr
#'  \link[paws.analytics:kendra_delete_faq]{delete_faq} \tab Removes a FAQ from an index\cr
#'  \link[paws.analytics:kendra_delete_index]{delete_index} \tab Deletes an Amazon Kendra index\cr
#'  \link[paws.analytics:kendra_delete_principal_mapping]{delete_principal_mapping} \tab Deletes a group so that all users that belong to the group can no longer access documents only available to that group\cr
#'  \link[paws.analytics:kendra_delete_query_suggestions_block_list]{delete_query_suggestions_block_list} \tab Deletes a block list used for query suggestions for an index\cr
#'  \link[paws.analytics:kendra_delete_thesaurus]{delete_thesaurus} \tab Deletes an Amazon Kendra thesaurus\cr
#'  \link[paws.analytics:kendra_describe_access_control_configuration]{describe_access_control_configuration} \tab Gets information about an access control configuration that you created for your documents in an index\cr
#'  \link[paws.analytics:kendra_describe_data_source]{describe_data_source} \tab Gets information about an Amazon Kendra data source connector\cr
#'  \link[paws.analytics:kendra_describe_experience]{describe_experience} \tab Gets information about your Amazon Kendra experience such as a search application\cr
#'  \link[paws.analytics:kendra_describe_faq]{describe_faq} \tab Gets information about a FAQ\cr
#'  \link[paws.analytics:kendra_describe_featured_results_set]{describe_featured_results_set} \tab Gets information about a set of featured results\cr
#'  \link[paws.analytics:kendra_describe_index]{describe_index} \tab Gets information about an Amazon Kendra index\cr
#'  \link[paws.analytics:kendra_describe_principal_mapping]{describe_principal_mapping} \tab Describes the processing of PUT and DELETE actions for mapping users to their groups\cr
#'  \link[paws.analytics:kendra_describe_query_suggestions_block_list]{describe_query_suggestions_block_list} \tab Gets information about a block list used for query suggestions for an index\cr
#'  \link[paws.analytics:kendra_describe_query_suggestions_config]{describe_query_suggestions_config} \tab Gets information on the settings of query suggestions for an index\cr
#'  \link[paws.analytics:kendra_describe_thesaurus]{describe_thesaurus} \tab Gets information about an Amazon Kendra thesaurus\cr
#'  \link[paws.analytics:kendra_disassociate_entities_from_experience]{disassociate_entities_from_experience} \tab Prevents users or groups in your IAM Identity Center identity source from accessing your Amazon Kendra experience\cr
#'  \link[paws.analytics:kendra_disassociate_personas_from_entities]{disassociate_personas_from_entities} \tab Removes the specific permissions of users or groups in your IAM Identity Center identity source with access to your Amazon Kendra experience\cr
#'  \link[paws.analytics:kendra_get_query_suggestions]{get_query_suggestions} \tab Fetches the queries that are suggested to your users\cr
#'  \link[paws.analytics:kendra_get_snapshots]{get_snapshots} \tab Retrieves search metrics data\cr
#'  \link[paws.analytics:kendra_list_access_control_configurations]{list_access_control_configurations} \tab Lists one or more access control configurations for an index\cr
#'  \link[paws.analytics:kendra_list_data_sources]{list_data_sources} \tab Lists the data source connectors that you have created\cr
#'  \link[paws.analytics:kendra_list_data_source_sync_jobs]{list_data_source_sync_jobs} \tab Gets statistics about synchronizing a data source connector\cr
#'  \link[paws.analytics:kendra_list_entity_personas]{list_entity_personas} \tab Lists specific permissions of users and groups with access to your Amazon Kendra experience\cr
#'  \link[paws.analytics:kendra_list_experience_entities]{list_experience_entities} \tab Lists users or groups in your IAM Identity Center identity source that are granted access to your Amazon Kendra experience\cr
#'  \link[paws.analytics:kendra_list_experiences]{list_experiences} \tab Lists one or more Amazon Kendra experiences\cr
#'  \link[paws.analytics:kendra_list_faqs]{list_faqs} \tab Gets a list of FAQs associated with an index\cr
#'  \link[paws.analytics:kendra_list_featured_results_sets]{list_featured_results_sets} \tab Lists all your sets of featured results for a given index\cr
#'  \link[paws.analytics:kendra_list_groups_older_than_ordering_id]{list_groups_older_than_ordering_id} \tab Provides a list of groups that are mapped to users before a given ordering or timestamp identifier\cr
#'  \link[paws.analytics:kendra_list_indices]{list_indices} \tab Lists the Amazon Kendra indexes that you created\cr
#'  \link[paws.analytics:kendra_list_query_suggestions_block_lists]{list_query_suggestions_block_lists} \tab Lists the block lists used for query suggestions for an index\cr
#'  \link[paws.analytics:kendra_list_tags_for_resource]{list_tags_for_resource} \tab Gets a list of tags associated with a resource\cr
#'  \link[paws.analytics:kendra_list_thesauri]{list_thesauri} \tab Lists the thesauri for an index\cr
#'  \link[paws.analytics:kendra_put_principal_mapping]{put_principal_mapping} \tab Maps users to their groups so that you only need to provide the user ID when you issue the query\cr
#'  \link[paws.analytics:kendra_query]{query} \tab Searches an index given an input query\cr
#'  \link[paws.analytics:kendra_retrieve]{retrieve} \tab Retrieves relevant passages or text excerpts given an input query\cr
#'  \link[paws.analytics:kendra_start_data_source_sync_job]{start_data_source_sync_job} \tab Starts a synchronization job for a data source connector\cr
#'  \link[paws.analytics:kendra_stop_data_source_sync_job]{stop_data_source_sync_job} \tab Stops a synchronization job that is currently running\cr
#'  \link[paws.analytics:kendra_submit_feedback]{submit_feedback} \tab Enables you to provide feedback to Amazon Kendra to improve the performance of your index\cr
#'  \link[paws.analytics:kendra_tag_resource]{tag_resource} \tab Adds the specified tag to the specified index, FAQ, data source, or other resource\cr
#'  \link[paws.analytics:kendra_untag_resource]{untag_resource} \tab Removes a tag from an index, FAQ, data source, or other resource\cr
#'  \link[paws.analytics:kendra_update_access_control_configuration]{update_access_control_configuration} \tab Updates an access control configuration for your documents in an index\cr
#'  \link[paws.analytics:kendra_update_data_source]{update_data_source} \tab Updates an Amazon Kendra data source connector\cr
#'  \link[paws.analytics:kendra_update_experience]{update_experience} \tab Updates your Amazon Kendra experience such as a search application\cr
#'  \link[paws.analytics:kendra_update_featured_results_set]{update_featured_results_set} \tab Updates a set of featured results\cr
#'  \link[paws.analytics:kendra_update_index]{update_index} \tab Updates an Amazon Kendra index\cr
#'  \link[paws.analytics:kendra_update_query_suggestions_block_list]{update_query_suggestions_block_list} \tab Updates a block list used for query suggestions for an index\cr
#'  \link[paws.analytics:kendra_update_query_suggestions_config]{update_query_suggestions_config} \tab Updates the settings of query suggestions for an index\cr
#'  \link[paws.analytics:kendra_update_thesaurus]{update_thesaurus} \tab Updates a thesaurus for an index
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname kendra
#' @export
kendra <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::kendra(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Kendra Intelligent Ranking
#'
#' @description
#' Amazon Kendra Intelligent Ranking uses Amazon Kendra semantic search
#' capabilities to intelligently re-rank a search service's results.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- kendraranking(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- kendraranking()
#' svc$create_rescore_execution_plan(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:kendraranking_create_rescore_execution_plan]{create_rescore_execution_plan} \tab Creates a rescore execution plan\cr
#'  \link[paws.analytics:kendraranking_delete_rescore_execution_plan]{delete_rescore_execution_plan} \tab Deletes a rescore execution plan\cr
#'  \link[paws.analytics:kendraranking_describe_rescore_execution_plan]{describe_rescore_execution_plan} \tab Gets information about a rescore execution plan\cr
#'  \link[paws.analytics:kendraranking_list_rescore_execution_plans]{list_rescore_execution_plans} \tab Lists your rescore execution plans\cr
#'  \link[paws.analytics:kendraranking_list_tags_for_resource]{list_tags_for_resource} \tab Gets a list of tags associated with a specified resource\cr
#'  \link[paws.analytics:kendraranking_rescore]{rescore} \tab Rescores or re-ranks search results from a search service such as OpenSearch (self managed)\cr
#'  \link[paws.analytics:kendraranking_tag_resource]{tag_resource} \tab Adds a specified tag to a specified rescore execution plan\cr
#'  \link[paws.analytics:kendraranking_untag_resource]{untag_resource} \tab Removes a tag from a rescore execution plan\cr
#'  \link[paws.analytics:kendraranking_update_rescore_execution_plan]{update_rescore_execution_plan} \tab Updates a rescore execution plan
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname kendraranking
#' @export
kendraranking <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::kendraranking(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Kinesis
#'
#' @description
#' Amazon Kinesis Data Streams Service API Reference
#' 
#' Amazon Kinesis Data Streams is a managed service that scales elastically
#' for real-time processing of streaming big data.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- kinesis(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- kinesis()
#' svc$add_tags_to_stream(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:kinesis_add_tags_to_stream]{add_tags_to_stream} \tab Adds or updates tags for the specified Kinesis data stream\cr
#'  \link[paws.analytics:kinesis_create_stream]{create_stream} \tab Creates a Kinesis data stream\cr
#'  \link[paws.analytics:kinesis_decrease_stream_retention_period]{decrease_stream_retention_period} \tab Decreases the Kinesis data stream's retention period, which is the length of time data records are accessible after they are added to the stream\cr
#'  \link[paws.analytics:kinesis_delete_resource_policy]{delete_resource_policy} \tab Delete a policy for the specified data stream or consumer\cr
#'  \link[paws.analytics:kinesis_delete_stream]{delete_stream} \tab Deletes a Kinesis data stream and all its shards and data\cr
#'  \link[paws.analytics:kinesis_deregister_stream_consumer]{deregister_stream_consumer} \tab To deregister a consumer, provide its ARN\cr
#'  \link[paws.analytics:kinesis_describe_limits]{describe_limits} \tab Describes the shard limits and usage for the account\cr
#'  \link[paws.analytics:kinesis_describe_stream]{describe_stream} \tab Describes the specified Kinesis data stream\cr
#'  \link[paws.analytics:kinesis_describe_stream_consumer]{describe_stream_consumer} \tab To get the description of a registered consumer, provide the ARN of the consumer\cr
#'  \link[paws.analytics:kinesis_describe_stream_summary]{describe_stream_summary} \tab Provides a summarized description of the specified Kinesis data stream without the shard list\cr
#'  \link[paws.analytics:kinesis_disable_enhanced_monitoring]{disable_enhanced_monitoring} \tab Disables enhanced monitoring\cr
#'  \link[paws.analytics:kinesis_enable_enhanced_monitoring]{enable_enhanced_monitoring} \tab Enables enhanced Kinesis data stream monitoring for shard-level metrics\cr
#'  \link[paws.analytics:kinesis_get_records]{get_records} \tab Gets data records from a Kinesis data stream's shard\cr
#'  \link[paws.analytics:kinesis_get_resource_policy]{get_resource_policy} \tab Returns a policy attached to the specified data stream or consumer\cr
#'  \link[paws.analytics:kinesis_get_shard_iterator]{get_shard_iterator} \tab Gets an Amazon Kinesis shard iterator\cr
#'  \link[paws.analytics:kinesis_increase_stream_retention_period]{increase_stream_retention_period} \tab Increases the Kinesis data stream's retention period, which is the length of time data records are accessible after they are added to the stream\cr
#'  \link[paws.analytics:kinesis_list_shards]{list_shards} \tab Lists the shards in a stream and provides information about each shard\cr
#'  \link[paws.analytics:kinesis_list_stream_consumers]{list_stream_consumers} \tab Lists the consumers registered to receive data from a stream using enhanced fan-out, and provides information about each consumer\cr
#'  \link[paws.analytics:kinesis_list_streams]{list_streams} \tab Lists your Kinesis data streams\cr
#'  \link[paws.analytics:kinesis_list_tags_for_stream]{list_tags_for_stream} \tab Lists the tags for the specified Kinesis data stream\cr
#'  \link[paws.analytics:kinesis_merge_shards]{merge_shards} \tab Merges two adjacent shards in a Kinesis data stream and combines them into a single shard to reduce the stream's capacity to ingest and transport data\cr
#'  \link[paws.analytics:kinesis_put_record]{put_record} \tab Writes a single data record into an Amazon Kinesis data stream\cr
#'  \link[paws.analytics:kinesis_put_records]{put_records} \tab Writes multiple data records into a Kinesis data stream in a single call (also referred to as a PutRecords request)\cr
#'  \link[paws.analytics:kinesis_put_resource_policy]{put_resource_policy} \tab Attaches a resource-based policy to a data stream or registered consumer\cr
#'  \link[paws.analytics:kinesis_register_stream_consumer]{register_stream_consumer} \tab Registers a consumer with a Kinesis data stream\cr
#'  \link[paws.analytics:kinesis_remove_tags_from_stream]{remove_tags_from_stream} \tab Removes tags from the specified Kinesis data stream\cr
#'  \link[paws.analytics:kinesis_split_shard]{split_shard} \tab Splits a shard into two new shards in the Kinesis data stream, to increase the stream's capacity to ingest and transport data\cr
#'  \link[paws.analytics:kinesis_start_stream_encryption]{start_stream_encryption} \tab Enables or updates server-side encryption using an Amazon Web Services KMS key for a specified stream\cr
#'  \link[paws.analytics:kinesis_stop_stream_encryption]{stop_stream_encryption} \tab Disables server-side encryption for a specified stream\cr
#'  \link[paws.analytics:kinesis_subscribe_to_shard]{subscribe_to_shard} \tab This operation establishes an HTTP/2 connection between the consumer you specify in the ConsumerARN parameter and the shard you specify in the ShardId parameter\cr
#'  \link[paws.analytics:kinesis_update_shard_count]{update_shard_count} \tab Updates the shard count of the specified stream to the specified number of shards\cr
#'  \link[paws.analytics:kinesis_update_stream_mode]{update_stream_mode} \tab Updates the capacity mode of the data stream
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname kinesis
#' @export
kinesis <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::kinesis(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Kinesis Analytics
#'
#' @description
#' **Overview**
#' 
#' This documentation is for version 1 of the Amazon Kinesis Data Analytics
#' API, which only supports SQL applications. Version 2 of the API supports
#' SQL and Java applications. For more information about version 2, see
#' Amazon Kinesis Data Analytics API V2 Documentation.
#' 
#' This is the *Amazon Kinesis Analytics v1 API Reference*. The Amazon
#' Kinesis Analytics Developer Guide provides additional information.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- kinesisanalytics(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- kinesisanalytics()
#' svc$add_application_cloud_watch_logging_option(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:kinesisanalytics_add_application_cloud_watch_logging_option]{add_application_cloud_watch_logging_option} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_add_application_input]{add_application_input} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_add_application_input_processing_configuration]{add_application_input_processing_configuration} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_add_application_output]{add_application_output} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_add_application_reference_data_source]{add_application_reference_data_source} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_create_application]{create_application} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_delete_application]{delete_application} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_delete_application_cloud_watch_logging_option]{delete_application_cloud_watch_logging_option} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_delete_application_input_processing_configuration]{delete_application_input_processing_configuration} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_delete_application_output]{delete_application_output} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_delete_application_reference_data_source]{delete_application_reference_data_source} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_describe_application]{describe_application} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_discover_input_schema]{discover_input_schema} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_list_applications]{list_applications} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves the list of key-value tags assigned to the application\cr
#'  \link[paws.analytics:kinesisanalytics_start_application]{start_application} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_stop_application]{stop_application} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications\cr
#'  \link[paws.analytics:kinesisanalytics_tag_resource]{tag_resource} \tab Adds one or more key-value tags to a Kinesis Analytics application\cr
#'  \link[paws.analytics:kinesisanalytics_untag_resource]{untag_resource} \tab Removes one or more tags from a Kinesis Analytics application\cr
#'  \link[paws.analytics:kinesisanalytics_update_application]{update_application} \tab This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname kinesisanalytics
#' @export
kinesisanalytics <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::kinesisanalytics(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Kinesis Analytics
#'
#' @description
#' Amazon Managed Service for Apache Flink was previously known as Amazon
#' Kinesis Data Analytics for Apache Flink.
#' 
#' Amazon Managed Service for Apache Flink is a fully managed service that
#' you can use to process and analyze streaming data using Java, Python,
#' SQL, or Scala. The service enables you to quickly author and run Java,
#' SQL, or Scala code against streaming sources to perform time series
#' analytics, feed real-time dashboards, and create real-time metrics.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- kinesisanalyticsv2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- kinesisanalyticsv2()
#' svc$add_application_cloud_watch_logging_option(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:kinesisanalyticsv2_add_application_cloud_watch_logging_option]{add_application_cloud_watch_logging_option} \tab Adds an Amazon CloudWatch log stream to monitor application configuration errors\cr
#'  \link[paws.analytics:kinesisanalyticsv2_add_application_input]{add_application_input} \tab Adds a streaming source to your SQL-based Kinesis Data Analytics application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_add_application_input_processing_configuration]{add_application_input_processing_configuration} \tab Adds an InputProcessingConfiguration to a SQL-based Kinesis Data Analytics application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_add_application_output]{add_application_output} \tab Adds an external destination to your SQL-based Kinesis Data Analytics application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_add_application_reference_data_source]{add_application_reference_data_source} \tab Adds a reference data source to an existing SQL-based Kinesis Data Analytics application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_add_application_vpc_configuration]{add_application_vpc_configuration} \tab Adds a Virtual Private Cloud (VPC) configuration to the application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_create_application]{create_application} \tab Creates a Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_create_application_presigned_url]{create_application_presigned_url} \tab Creates and returns a URL that you can use to connect to an application's extension\cr
#'  \link[paws.analytics:kinesisanalyticsv2_create_application_snapshot]{create_application_snapshot} \tab Creates a snapshot of the application's state data\cr
#'  \link[paws.analytics:kinesisanalyticsv2_delete_application]{delete_application} \tab Deletes the specified application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_delete_application_cloud_watch_logging_option]{delete_application_cloud_watch_logging_option} \tab Deletes an Amazon CloudWatch log stream from an SQL-based Kinesis Data Analytics application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_delete_application_input_processing_configuration]{delete_application_input_processing_configuration} \tab Deletes an InputProcessingConfiguration from an input\cr
#'  \link[paws.analytics:kinesisanalyticsv2_delete_application_output]{delete_application_output} \tab Deletes the output destination configuration from your SQL-based Kinesis Data Analytics application's configuration\cr
#'  \link[paws.analytics:kinesisanalyticsv2_delete_application_reference_data_source]{delete_application_reference_data_source} \tab Deletes a reference data source configuration from the specified SQL-based Kinesis Data Analytics application's configuration\cr
#'  \link[paws.analytics:kinesisanalyticsv2_delete_application_snapshot]{delete_application_snapshot} \tab Deletes a snapshot of application state\cr
#'  \link[paws.analytics:kinesisanalyticsv2_delete_application_vpc_configuration]{delete_application_vpc_configuration} \tab Removes a VPC configuration from a Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_describe_application]{describe_application} \tab Returns information about a specific Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_describe_application_operation]{describe_application_operation} \tab Returns information about a specific operation performed on a Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_describe_application_snapshot]{describe_application_snapshot} \tab Returns information about a snapshot of application state data\cr
#'  \link[paws.analytics:kinesisanalyticsv2_describe_application_version]{describe_application_version} \tab Provides a detailed description of a specified version of the application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_discover_input_schema]{discover_input_schema} \tab Infers a schema for a SQL-based Kinesis Data Analytics application by evaluating sample records on the specified streaming source (Kinesis data stream or Kinesis Data Firehose delivery stream) or Amazon S3 object\cr
#'  \link[paws.analytics:kinesisanalyticsv2_list_application_operations]{list_application_operations} \tab Lists information about operations performed on a Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_list_applications]{list_applications} \tab Returns a list of Managed Service for Apache Flink applications in your account\cr
#'  \link[paws.analytics:kinesisanalyticsv2_list_application_snapshots]{list_application_snapshots} \tab Lists information about the current application snapshots\cr
#'  \link[paws.analytics:kinesisanalyticsv2_list_application_versions]{list_application_versions} \tab Lists all the versions for the specified application, including versions that were rolled back\cr
#'  \link[paws.analytics:kinesisanalyticsv2_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves the list of key-value tags assigned to the application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_rollback_application]{rollback_application} \tab Reverts the application to the previous running version\cr
#'  \link[paws.analytics:kinesisanalyticsv2_start_application]{start_application} \tab Starts the specified Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_stop_application]{stop_application} \tab Stops the application from processing data\cr
#'  \link[paws.analytics:kinesisanalyticsv2_tag_resource]{tag_resource} \tab Adds one or more key-value tags to a Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_untag_resource]{untag_resource} \tab Removes one or more tags from a Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_update_application]{update_application} \tab Updates an existing Managed Service for Apache Flink application\cr
#'  \link[paws.analytics:kinesisanalyticsv2_update_application_maintenance_configuration]{update_application_maintenance_configuration} \tab Updates the maintenance configuration of the Managed Service for Apache Flink application
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname kinesisanalyticsv2
#' @export
kinesisanalyticsv2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::kinesisanalyticsv2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Mechanical Turk
#'
#' @description
#' Amazon Mechanical Turk API Reference
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- mturk(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- mturk()
#' svc$accept_qualification_request(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:mturk_accept_qualification_request]{accept_qualification_request} \tab The AcceptQualificationRequest operation approves a Worker's request for a Qualification\cr
#'  \link[paws.analytics:mturk_approve_assignment]{approve_assignment} \tab The ApproveAssignment operation approves the results of a completed assignment\cr
#'  \link[paws.analytics:mturk_associate_qualification_with_worker]{associate_qualification_with_worker} \tab The AssociateQualificationWithWorker operation gives a Worker a Qualification\cr
#'  \link[paws.analytics:mturk_create_additional_assignments_for_hit]{create_additional_assignments_for_hit} \tab The CreateAdditionalAssignmentsForHIT operation increases the maximum number of assignments of an existing HIT\cr
#'  \link[paws.analytics:mturk_create_hit]{create_hit} \tab The CreateHIT operation creates a new Human Intelligence Task (HIT)\cr
#'  \link[paws.analytics:mturk_create_hit_type]{create_hit_type} \tab The CreateHITType operation creates a new HIT type\cr
#'  \link[paws.analytics:mturk_create_hit_with_hit_type]{create_hit_with_hit_type} \tab The CreateHITWithHITType operation creates a new Human Intelligence Task (HIT) using an existing HITTypeID generated by the CreateHITType operation\cr
#'  \link[paws.analytics:mturk_create_qualification_type]{create_qualification_type} \tab The CreateQualificationType operation creates a new Qualification type, which is represented by a QualificationType data structure\cr
#'  \link[paws.analytics:mturk_create_worker_block]{create_worker_block} \tab The CreateWorkerBlock operation allows you to prevent a Worker from working on your HITs\cr
#'  \link[paws.analytics:mturk_delete_hit]{delete_hit} \tab The DeleteHIT operation is used to delete HIT that is no longer needed\cr
#'  \link[paws.analytics:mturk_delete_qualification_type]{delete_qualification_type} \tab The DeleteQualificationType deletes a Qualification type and deletes any HIT types that are associated with the Qualification type\cr
#'  \link[paws.analytics:mturk_delete_worker_block]{delete_worker_block} \tab The DeleteWorkerBlock operation allows you to reinstate a blocked Worker to work on your HITs\cr
#'  \link[paws.analytics:mturk_disassociate_qualification_from_worker]{disassociate_qualification_from_worker} \tab The DisassociateQualificationFromWorker revokes a previously granted Qualification from a user\cr
#'  \link[paws.analytics:mturk_get_account_balance]{get_account_balance} \tab The GetAccountBalance operation retrieves the Prepaid HITs balance in your Amazon Mechanical Turk account if you are a Prepaid Requester\cr
#'  \link[paws.analytics:mturk_get_assignment]{get_assignment} \tab The GetAssignment operation retrieves the details of the specified Assignment\cr
#'  \link[paws.analytics:mturk_get_file_upload_url]{get_file_upload_url} \tab The GetFileUploadURL operation generates and returns a temporary URL\cr
#'  \link[paws.analytics:mturk_get_hit]{get_hit} \tab The GetHIT operation retrieves the details of the specified HIT\cr
#'  \link[paws.analytics:mturk_get_qualification_score]{get_qualification_score} \tab The GetQualificationScore operation returns the value of a Worker's Qualification for a given Qualification type\cr
#'  \link[paws.analytics:mturk_get_qualification_type]{get_qualification_type} \tab The GetQualificationTypeoperation retrieves information about a Qualification type using its ID\cr
#'  \link[paws.analytics:mturk_list_assignments_for_hit]{list_assignments_for_hit} \tab The ListAssignmentsForHIT operation retrieves completed assignments for a HIT\cr
#'  \link[paws.analytics:mturk_list_bonus_payments]{list_bonus_payments} \tab The ListBonusPayments operation retrieves the amounts of bonuses you have paid to Workers for a given HIT or assignment\cr
#'  \link[paws.analytics:mturk_list_hi_ts]{list_hi_ts} \tab The ListHITs operation returns all of a Requester's HITs\cr
#'  \link[paws.analytics:mturk_list_hi_ts_for_qualification_type]{list_hi_ts_for_qualification_type} \tab The ListHITsForQualificationType operation returns the HITs that use the given Qualification type for a Qualification requirement\cr
#'  \link[paws.analytics:mturk_list_qualification_requests]{list_qualification_requests} \tab The ListQualificationRequests operation retrieves requests for Qualifications of a particular Qualification type\cr
#'  \link[paws.analytics:mturk_list_qualification_types]{list_qualification_types} \tab The ListQualificationTypes operation returns a list of Qualification types, filtered by an optional search term\cr
#'  \link[paws.analytics:mturk_list_reviewable_hi_ts]{list_reviewable_hi_ts} \tab The ListReviewableHITs operation retrieves the HITs with Status equal to Reviewable or Status equal to Reviewing that belong to the Requester calling the operation\cr
#'  \link[paws.analytics:mturk_list_review_policy_results_for_hit]{list_review_policy_results_for_hit} \tab The ListReviewPolicyResultsForHIT operation retrieves the computed results and the actions taken in the course of executing your Review Policies for a given HIT\cr
#'  \link[paws.analytics:mturk_list_worker_blocks]{list_worker_blocks} \tab The ListWorkersBlocks operation retrieves a list of Workers who are blocked from working on your HITs\cr
#'  \link[paws.analytics:mturk_list_workers_with_qualification_type]{list_workers_with_qualification_type} \tab The ListWorkersWithQualificationType operation returns all of the Workers that have been associated with a given Qualification type\cr
#'  \link[paws.analytics:mturk_notify_workers]{notify_workers} \tab The NotifyWorkers operation sends an email to one or more Workers that you specify with the Worker ID\cr
#'  \link[paws.analytics:mturk_reject_assignment]{reject_assignment} \tab The RejectAssignment operation rejects the results of a completed assignment\cr
#'  \link[paws.analytics:mturk_reject_qualification_request]{reject_qualification_request} \tab The RejectQualificationRequest operation rejects a user's request for a Qualification\cr
#'  \link[paws.analytics:mturk_send_bonus]{send_bonus} \tab The SendBonus operation issues a payment of money from your account to a Worker\cr
#'  \link[paws.analytics:mturk_send_test_event_notification]{send_test_event_notification} \tab The SendTestEventNotification operation causes Amazon Mechanical Turk to send a notification message as if a HIT event occurred, according to the provided notification specification\cr
#'  \link[paws.analytics:mturk_update_expiration_for_hit]{update_expiration_for_hit} \tab The UpdateExpirationForHIT operation allows you update the expiration time of a HIT\cr
#'  \link[paws.analytics:mturk_update_hit_review_status]{update_hit_review_status} \tab The UpdateHITReviewStatus operation updates the status of a HIT\cr
#'  \link[paws.analytics:mturk_update_hit_type_of_hit]{update_hit_type_of_hit} \tab The UpdateHITTypeOfHIT operation allows you to change the HITType properties of a HIT\cr
#'  \link[paws.analytics:mturk_update_notification_settings]{update_notification_settings} \tab The UpdateNotificationSettings operation creates, updates, disables or re-enables notifications for a HIT type\cr
#'  \link[paws.analytics:mturk_update_qualification_type]{update_qualification_type} \tab The UpdateQualificationType operation modifies the attributes of an existing Qualification type, which is represented by a QualificationType data structure
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname mturk
#' @export
mturk <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::mturk(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon OpenSearch Service
#'
#' @description
#' Use the Amazon OpenSearch Service configuration API to create,
#' configure, and manage OpenSearch Service domains. The endpoint for
#' configuration service requests is Region specific:
#' es.*region*.amazonaws.com. For example, es.us-east-1.amazonaws.com. For
#' a current list of supported Regions and endpoints, see [Amazon Web
#' Services service
#' endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#service-regions).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- opensearchservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- opensearchservice()
#' svc$accept_inbound_connection(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:opensearchservice_accept_inbound_connection]{accept_inbound_connection} \tab Allows the destination Amazon OpenSearch Service domain owner to accept an inbound cross-cluster search connection request\cr
#'  \link[paws.analytics:opensearchservice_add_data_source]{add_data_source} \tab Creates a new direct-query data source to the specified domain\cr
#'  \link[paws.analytics:opensearchservice_add_direct_query_data_source]{add_direct_query_data_source} \tab Adds a new data source in Amazon OpenSearch Service so that you can perform direct queries on external data\cr
#'  \link[paws.analytics:opensearchservice_add_tags]{add_tags} \tab Attaches tags to an existing Amazon OpenSearch Service domain, data source, or application\cr
#'  \link[paws.analytics:opensearchservice_associate_package]{associate_package} \tab Associates a package with an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_associate_packages]{associate_packages} \tab Operation in the Amazon OpenSearch Service API for associating multiple packages with a domain simultaneously\cr
#'  \link[paws.analytics:opensearchservice_authorize_vpc_endpoint_access]{authorize_vpc_endpoint_access} \tab Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint\cr
#'  \link[paws.analytics:opensearchservice_cancel_domain_config_change]{cancel_domain_config_change} \tab Cancels a pending configuration change on an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_cancel_service_software_update]{cancel_service_software_update} \tab Cancels a scheduled service software update for an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_create_application]{create_application} \tab Creates an OpenSearch Application\cr
#'  \link[paws.analytics:opensearchservice_create_domain]{create_domain} \tab Creates an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_create_outbound_connection]{create_outbound_connection} \tab Creates a new cross-cluster search connection from a source Amazon OpenSearch Service domain to a destination domain\cr
#'  \link[paws.analytics:opensearchservice_create_package]{create_package} \tab Creates a package for use with Amazon OpenSearch Service domains\cr
#'  \link[paws.analytics:opensearchservice_create_vpc_endpoint]{create_vpc_endpoint} \tab Creates an Amazon OpenSearch Service-managed VPC endpoint\cr
#'  \link[paws.analytics:opensearchservice_delete_application]{delete_application} \tab Deletes an existing OpenSearch Application\cr
#'  \link[paws.analytics:opensearchservice_delete_data_source]{delete_data_source} \tab Deletes a direct-query data source\cr
#'  \link[paws.analytics:opensearchservice_delete_direct_query_data_source]{delete_direct_query_data_source} \tab Deletes a previously configured direct query data source from Amazon OpenSearch Service\cr
#'  \link[paws.analytics:opensearchservice_delete_domain]{delete_domain} \tab Deletes an Amazon OpenSearch Service domain and all of its data\cr
#'  \link[paws.analytics:opensearchservice_delete_inbound_connection]{delete_inbound_connection} \tab Allows the destination Amazon OpenSearch Service domain owner to delete an existing inbound cross-cluster search connection\cr
#'  \link[paws.analytics:opensearchservice_delete_outbound_connection]{delete_outbound_connection} \tab Allows the source Amazon OpenSearch Service domain owner to delete an existing outbound cross-cluster search connection\cr
#'  \link[paws.analytics:opensearchservice_delete_package]{delete_package} \tab Deletes an Amazon OpenSearch Service package\cr
#'  \link[paws.analytics:opensearchservice_delete_vpc_endpoint]{delete_vpc_endpoint} \tab Deletes an Amazon OpenSearch Service-managed interface VPC endpoint\cr
#'  \link[paws.analytics:opensearchservice_describe_domain]{describe_domain} \tab Describes the domain configuration for the specified Amazon OpenSearch Service domain, including the domain ID, domain service endpoint, and domain ARN\cr
#'  \link[paws.analytics:opensearchservice_describe_domain_auto_tunes]{describe_domain_auto_tunes} \tab Returns the list of optimizations that Auto-Tune has made to an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_describe_domain_change_progress]{describe_domain_change_progress} \tab Returns information about the current blue/green deployment happening on an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_describe_domain_config]{describe_domain_config} \tab Returns the configuration of an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_describe_domain_health]{describe_domain_health} \tab Returns information about domain and node health, the standby Availability Zone, number of nodes per Availability Zone, and shard count per node\cr
#'  \link[paws.analytics:opensearchservice_describe_domain_nodes]{describe_domain_nodes} \tab Returns information about domain and nodes, including data nodes, master nodes, ultrawarm nodes, Availability Zone(s), standby nodes, node configurations, and node states\cr
#'  \link[paws.analytics:opensearchservice_describe_domains]{describe_domains} \tab Returns domain configuration information about the specified Amazon OpenSearch Service domains\cr
#'  \link[paws.analytics:opensearchservice_describe_dry_run_progress]{describe_dry_run_progress} \tab Describes the progress of a pre-update dry run analysis on an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_describe_inbound_connections]{describe_inbound_connections} \tab Lists all the inbound cross-cluster search connections for a destination (remote) Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_describe_instance_type_limits]{describe_instance_type_limits} \tab Describes the instance count, storage, and master node limits for a given OpenSearch or Elasticsearch version and instance type\cr
#'  \link[paws.analytics:opensearchservice_describe_outbound_connections]{describe_outbound_connections} \tab Lists all the outbound cross-cluster connections for a local (source) Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_describe_packages]{describe_packages} \tab Describes all packages available to OpenSearch Service\cr
#'  \link[paws.analytics:opensearchservice_describe_reserved_instance_offerings]{describe_reserved_instance_offerings} \tab Describes the available Amazon OpenSearch Service Reserved Instance offerings for a given Region\cr
#'  \link[paws.analytics:opensearchservice_describe_reserved_instances]{describe_reserved_instances} \tab Describes the Amazon OpenSearch Service instances that you have reserved in a given Region\cr
#'  \link[paws.analytics:opensearchservice_describe_vpc_endpoints]{describe_vpc_endpoints} \tab Describes one or more Amazon OpenSearch Service-managed VPC endpoints\cr
#'  \link[paws.analytics:opensearchservice_dissociate_package]{dissociate_package} \tab Removes a package from the specified Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_dissociate_packages]{dissociate_packages} \tab Dissociates multiple packages from a domain simulatneously\cr
#'  \link[paws.analytics:opensearchservice_get_application]{get_application} \tab Check the configuration and status of an existing OpenSearch Application\cr
#'  \link[paws.analytics:opensearchservice_get_compatible_versions]{get_compatible_versions} \tab Returns a map of OpenSearch or Elasticsearch versions and the versions you can upgrade them to\cr
#'  \link[paws.analytics:opensearchservice_get_data_source]{get_data_source} \tab Retrieves information about a direct query data source\cr
#'  \link[paws.analytics:opensearchservice_get_direct_query_data_source]{get_direct_query_data_source} \tab Returns detailed configuration information for a specific direct query data source in Amazon OpenSearch Service\cr
#'  \link[paws.analytics:opensearchservice_get_domain_maintenance_status]{get_domain_maintenance_status} \tab The status of the maintenance action\cr
#'  \link[paws.analytics:opensearchservice_get_package_version_history]{get_package_version_history} \tab Returns a list of Amazon OpenSearch Service package versions, along with their creation time, commit message, and plugin properties (if the package is a zip plugin package)\cr
#'  \link[paws.analytics:opensearchservice_get_upgrade_history]{get_upgrade_history} \tab Retrieves the complete history of the last 10 upgrades performed on an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_get_upgrade_status]{get_upgrade_status} \tab Returns the most recent status of the last upgrade or upgrade eligibility check performed on an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_list_applications]{list_applications} \tab List all OpenSearch Applications under your account\cr
#'  \link[paws.analytics:opensearchservice_list_data_sources]{list_data_sources} \tab Lists direct-query data sources for a specific domain\cr
#'  \link[paws.analytics:opensearchservice_list_direct_query_data_sources]{list_direct_query_data_sources} \tab Lists an inventory of all the direct query data sources that you have configured within Amazon OpenSearch Service\cr
#'  \link[paws.analytics:opensearchservice_list_domain_maintenances]{list_domain_maintenances} \tab A list of maintenance actions for the domain\cr
#'  \link[paws.analytics:opensearchservice_list_domain_names]{list_domain_names} \tab Returns the names of all Amazon OpenSearch Service domains owned by the current user in the active Region\cr
#'  \link[paws.analytics:opensearchservice_list_domains_for_package]{list_domains_for_package} \tab Lists all Amazon OpenSearch Service domains associated with a given package\cr
#'  \link[paws.analytics:opensearchservice_list_instance_type_details]{list_instance_type_details} \tab Lists all instance types and available features for a given OpenSearch or Elasticsearch version\cr
#'  \link[paws.analytics:opensearchservice_list_packages_for_domain]{list_packages_for_domain} \tab Lists all packages associated with an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_list_scheduled_actions]{list_scheduled_actions} \tab Retrieves a list of configuration changes that are scheduled for a domain\cr
#'  \link[paws.analytics:opensearchservice_list_tags]{list_tags} \tab Returns all resource tags for an Amazon OpenSearch Service domain, data source, or application\cr
#'  \link[paws.analytics:opensearchservice_list_versions]{list_versions} \tab Lists all versions of OpenSearch and Elasticsearch that Amazon OpenSearch Service supports\cr
#'  \link[paws.analytics:opensearchservice_list_vpc_endpoint_access]{list_vpc_endpoint_access} \tab Retrieves information about each Amazon Web Services principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint\cr
#'  \link[paws.analytics:opensearchservice_list_vpc_endpoints]{list_vpc_endpoints} \tab Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current Amazon Web Services account and Region\cr
#'  \link[paws.analytics:opensearchservice_list_vpc_endpoints_for_domain]{list_vpc_endpoints_for_domain} \tab Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain\cr
#'  \link[paws.analytics:opensearchservice_purchase_reserved_instance_offering]{purchase_reserved_instance_offering} \tab Allows you to purchase Amazon OpenSearch Service Reserved Instances\cr
#'  \link[paws.analytics:opensearchservice_reject_inbound_connection]{reject_inbound_connection} \tab Allows the remote Amazon OpenSearch Service domain owner to reject an inbound cross-cluster connection request\cr
#'  \link[paws.analytics:opensearchservice_remove_tags]{remove_tags} \tab Removes the specified set of tags from an Amazon OpenSearch Service domain, data source, or application\cr
#'  \link[paws.analytics:opensearchservice_revoke_vpc_endpoint_access]{revoke_vpc_endpoint_access} \tab Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint\cr
#'  \link[paws.analytics:opensearchservice_start_domain_maintenance]{start_domain_maintenance} \tab Starts the node maintenance process on the data node\cr
#'  \link[paws.analytics:opensearchservice_start_service_software_update]{start_service_software_update} \tab Schedules a service software update for an Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_update_application]{update_application} \tab Update the OpenSearch Application\cr
#'  \link[paws.analytics:opensearchservice_update_data_source]{update_data_source} \tab Updates a direct-query data source\cr
#'  \link[paws.analytics:opensearchservice_update_direct_query_data_source]{update_direct_query_data_source} \tab Updates the configuration or properties of an existing direct query data source in Amazon OpenSearch Service\cr
#'  \link[paws.analytics:opensearchservice_update_domain_config]{update_domain_config} \tab Modifies the cluster configuration of the specified Amazon OpenSearch Service domain\cr
#'  \link[paws.analytics:opensearchservice_update_package]{update_package} \tab Updates a package for use with Amazon OpenSearch Service domains\cr
#'  \link[paws.analytics:opensearchservice_update_package_scope]{update_package_scope} \tab Updates the scope of a package\cr
#'  \link[paws.analytics:opensearchservice_update_scheduled_action]{update_scheduled_action} \tab Reschedules a planned domain configuration change for a later time\cr
#'  \link[paws.analytics:opensearchservice_update_vpc_endpoint]{update_vpc_endpoint} \tab Modifies an Amazon OpenSearch Service-managed interface VPC endpoint\cr
#'  \link[paws.analytics:opensearchservice_upgrade_domain]{upgrade_domain} \tab Allows you to either upgrade your Amazon OpenSearch Service domain or perform an upgrade eligibility check to a compatible version of OpenSearch or Elasticsearch
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname opensearchservice
#' @export
opensearchservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::opensearchservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' OpenSearch Service Serverless
#'
#' @description
#' Use the Amazon OpenSearch Serverless API to create, configure, and
#' manage OpenSearch Serverless collections and security policies.
#' 
#' OpenSearch Serverless is an on-demand, pre-provisioned serverless
#' configuration for Amazon OpenSearch Service. OpenSearch Serverless
#' removes the operational complexities of provisioning, configuring, and
#' tuning your OpenSearch clusters. It enables you to easily search and
#' analyze petabytes of data without having to worry about the underlying
#' infrastructure and data management.
#' 
#' To learn more about OpenSearch Serverless, see [What is Amazon
#' OpenSearch
#' Serverless?](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-overview.html)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- opensearchserviceserverless(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- opensearchserviceserverless()
#' svc$batch_get_collection(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:opensearchserviceserverless_batch_get_collection]{batch_get_collection} \tab Returns attributes for one or more collections, including the collection endpoint and the OpenSearch Dashboards endpoint\cr
#'  \link[paws.analytics:opensearchserviceserverless_batch_get_effective_lifecycle_policy]{batch_get_effective_lifecycle_policy} \tab Returns a list of successful and failed retrievals for the OpenSearch Serverless indexes\cr
#'  \link[paws.analytics:opensearchserviceserverless_batch_get_lifecycle_policy]{batch_get_lifecycle_policy} \tab Returns one or more configured OpenSearch Serverless lifecycle policies\cr
#'  \link[paws.analytics:opensearchserviceserverless_batch_get_vpc_endpoint]{batch_get_vpc_endpoint} \tab Returns attributes for one or more VPC endpoints associated with the current account\cr
#'  \link[paws.analytics:opensearchserviceserverless_create_access_policy]{create_access_policy} \tab Creates a data access policy for OpenSearch Serverless\cr
#'  \link[paws.analytics:opensearchserviceserverless_create_collection]{create_collection} \tab Creates a new OpenSearch Serverless collection\cr
#'  \link[paws.analytics:opensearchserviceserverless_create_lifecycle_policy]{create_lifecycle_policy} \tab Creates a lifecyle policy to be applied to OpenSearch Serverless indexes\cr
#'  \link[paws.analytics:opensearchserviceserverless_create_security_config]{create_security_config} \tab Specifies a security configuration for OpenSearch Serverless\cr
#'  \link[paws.analytics:opensearchserviceserverless_create_security_policy]{create_security_policy} \tab Creates a security policy to be used by one or more OpenSearch Serverless collections\cr
#'  \link[paws.analytics:opensearchserviceserverless_create_vpc_endpoint]{create_vpc_endpoint} \tab Creates an OpenSearch Serverless-managed interface VPC endpoint\cr
#'  \link[paws.analytics:opensearchserviceserverless_delete_access_policy]{delete_access_policy} \tab Deletes an OpenSearch Serverless access policy\cr
#'  \link[paws.analytics:opensearchserviceserverless_delete_collection]{delete_collection} \tab Deletes an OpenSearch Serverless collection\cr
#'  \link[paws.analytics:opensearchserviceserverless_delete_lifecycle_policy]{delete_lifecycle_policy} \tab Deletes an OpenSearch Serverless lifecycle policy\cr
#'  \link[paws.analytics:opensearchserviceserverless_delete_security_config]{delete_security_config} \tab Deletes a security configuration for OpenSearch Serverless\cr
#'  \link[paws.analytics:opensearchserviceserverless_delete_security_policy]{delete_security_policy} \tab Deletes an OpenSearch Serverless security policy\cr
#'  \link[paws.analytics:opensearchserviceserverless_delete_vpc_endpoint]{delete_vpc_endpoint} \tab Deletes an OpenSearch Serverless-managed interface endpoint\cr
#'  \link[paws.analytics:opensearchserviceserverless_get_access_policy]{get_access_policy} \tab Returns an OpenSearch Serverless access policy\cr
#'  \link[paws.analytics:opensearchserviceserverless_get_account_settings]{get_account_settings} \tab Returns account-level settings related to OpenSearch Serverless\cr
#'  \link[paws.analytics:opensearchserviceserverless_get_policies_stats]{get_policies_stats} \tab Returns statistical information about your OpenSearch Serverless access policies, security configurations, and security policies\cr
#'  \link[paws.analytics:opensearchserviceserverless_get_security_config]{get_security_config} \tab Returns information about an OpenSearch Serverless security configuration\cr
#'  \link[paws.analytics:opensearchserviceserverless_get_security_policy]{get_security_policy} \tab Returns information about a configured OpenSearch Serverless security policy\cr
#'  \link[paws.analytics:opensearchserviceserverless_list_access_policies]{list_access_policies} \tab Returns information about a list of OpenSearch Serverless access policies\cr
#'  \link[paws.analytics:opensearchserviceserverless_list_collections]{list_collections} \tab Lists all OpenSearch Serverless collections\cr
#'  \link[paws.analytics:opensearchserviceserverless_list_lifecycle_policies]{list_lifecycle_policies} \tab Returns a list of OpenSearch Serverless lifecycle policies\cr
#'  \link[paws.analytics:opensearchserviceserverless_list_security_configs]{list_security_configs} \tab Returns information about configured OpenSearch Serverless security configurations\cr
#'  \link[paws.analytics:opensearchserviceserverless_list_security_policies]{list_security_policies} \tab Returns information about configured OpenSearch Serverless security policies\cr
#'  \link[paws.analytics:opensearchserviceserverless_list_tags_for_resource]{list_tags_for_resource} \tab Returns the tags for an OpenSearch Serverless resource\cr
#'  \link[paws.analytics:opensearchserviceserverless_list_vpc_endpoints]{list_vpc_endpoints} \tab Returns the OpenSearch Serverless-managed interface VPC endpoints associated with the current account\cr
#'  \link[paws.analytics:opensearchserviceserverless_tag_resource]{tag_resource} \tab Associates tags with an OpenSearch Serverless resource\cr
#'  \link[paws.analytics:opensearchserviceserverless_untag_resource]{untag_resource} \tab Removes a tag or set of tags from an OpenSearch Serverless resource\cr
#'  \link[paws.analytics:opensearchserviceserverless_update_access_policy]{update_access_policy} \tab Updates an OpenSearch Serverless access policy\cr
#'  \link[paws.analytics:opensearchserviceserverless_update_account_settings]{update_account_settings} \tab Update the OpenSearch Serverless settings for the current Amazon Web Services account\cr
#'  \link[paws.analytics:opensearchserviceserverless_update_collection]{update_collection} \tab Updates an OpenSearch Serverless collection\cr
#'  \link[paws.analytics:opensearchserviceserverless_update_lifecycle_policy]{update_lifecycle_policy} \tab Updates an OpenSearch Serverless access policy\cr
#'  \link[paws.analytics:opensearchserviceserverless_update_security_config]{update_security_config} \tab Updates a security configuration for OpenSearch Serverless\cr
#'  \link[paws.analytics:opensearchserviceserverless_update_security_policy]{update_security_policy} \tab Updates an OpenSearch Serverless security policy\cr
#'  \link[paws.analytics:opensearchserviceserverless_update_vpc_endpoint]{update_vpc_endpoint} \tab Updates an OpenSearch Serverless-managed interface endpoint
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname opensearchserviceserverless
#' @export
opensearchserviceserverless <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::opensearchserviceserverless(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon OpenSearch Ingestion
#'
#' @description
#' Use the Amazon OpenSearch Ingestion API to create and manage ingestion
#' pipelines. OpenSearch Ingestion is a fully managed data collector that
#' delivers real-time log and trace data to OpenSearch Service domains. For
#' more information, see [Getting data into your cluster using OpenSearch
#' Ingestion](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ingestion.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- opensearchingestion(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- opensearchingestion()
#' svc$create_pipeline(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:opensearchingestion_create_pipeline]{create_pipeline} \tab Creates an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_delete_pipeline]{delete_pipeline} \tab Deletes an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_get_pipeline]{get_pipeline} \tab Retrieves information about an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_get_pipeline_blueprint]{get_pipeline_blueprint} \tab Retrieves information about a specific blueprint for OpenSearch Ingestion\cr
#'  \link[paws.analytics:opensearchingestion_get_pipeline_change_progress]{get_pipeline_change_progress} \tab Returns progress information for the current change happening on an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_list_pipeline_blueprints]{list_pipeline_blueprints} \tab Retrieves a list of all available blueprints for Data Prepper\cr
#'  \link[paws.analytics:opensearchingestion_list_pipelines]{list_pipelines} \tab Lists all OpenSearch Ingestion pipelines in the current Amazon Web Services account and Region\cr
#'  \link[paws.analytics:opensearchingestion_list_tags_for_resource]{list_tags_for_resource} \tab Lists all resource tags associated with an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_start_pipeline]{start_pipeline} \tab Starts an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_stop_pipeline]{stop_pipeline} \tab Stops an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_tag_resource]{tag_resource} \tab Tags an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_untag_resource]{untag_resource} \tab Removes one or more tags from an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_update_pipeline]{update_pipeline} \tab Updates an OpenSearch Ingestion pipeline\cr
#'  \link[paws.analytics:opensearchingestion_validate_pipeline]{validate_pipeline} \tab Checks whether an OpenSearch Ingestion pipeline configuration is valid prior to creation
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname opensearchingestion
#' @export
opensearchingestion <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::opensearchingestion(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon QuickSight
#'
#' @description
#' Amazon QuickSight API Reference
#' 
#' Amazon QuickSight is a fully managed, serverless business intelligence
#' service for the Amazon Web Services Cloud that makes it easy to extend
#' data and insights to every user in your organization. This API reference
#' contains documentation for a programming interface that you can use to
#' manage Amazon QuickSight.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- quicksight(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- quicksight()
#' svc$batch_create_topic_reviewed_answer(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.analytics:quicksight_batch_create_topic_reviewed_answer]{batch_create_topic_reviewed_answer} \tab Creates new reviewed answers for a Q Topic\cr
#'  \link[paws.analytics:quicksight_batch_delete_topic_reviewed_answer]{batch_delete_topic_reviewed_answer} \tab Deletes reviewed answers for Q Topic\cr
#'  \link[paws.analytics:quicksight_cancel_ingestion]{cancel_ingestion} \tab Cancels an ongoing ingestion of data into SPICE\cr
#'  \link[paws.analytics:quicksight_create_account_customization]{create_account_customization} \tab Creates Amazon QuickSight customizations for the current Amazon Web Services Region\cr
#'  \link[paws.analytics:quicksight_create_account_subscription]{create_account_subscription} \tab Creates an Amazon QuickSight account, or subscribes to Amazon QuickSight Q\cr
#'  \link[paws.analytics:quicksight_create_analysis]{create_analysis} \tab Creates an analysis in Amazon QuickSight\cr
#'  \link[paws.analytics:quicksight_create_brand]{create_brand} \tab Creates an Amazon QuickSight brand\cr
#'  \link[paws.analytics:quicksight_create_custom_permissions]{create_custom_permissions} \tab Creates a custom permissions profile\cr
#'  \link[paws.analytics:quicksight_create_dashboard]{create_dashboard} \tab Creates a dashboard from either a template or directly with a DashboardDefinition\cr
#'  \link[paws.analytics:quicksight_create_data_set]{create_data_set} \tab Creates a dataset\cr
#'  \link[paws.analytics:quicksight_create_data_source]{create_data_source} \tab Creates a data source\cr
#'  \link[paws.analytics:quicksight_create_folder]{create_folder} \tab Creates an empty shared folder\cr
#'  \link[paws.analytics:quicksight_create_folder_membership]{create_folder_membership} \tab Adds an asset, such as a dashboard, analysis, or dataset into a folder\cr
#'  \link[paws.analytics:quicksight_create_group]{create_group} \tab Use the CreateGroup operation to create a group in Amazon QuickSight\cr
#'  \link[paws.analytics:quicksight_create_group_membership]{create_group_membership} \tab Adds an Amazon QuickSight user to an Amazon QuickSight group\cr
#'  \link[paws.analytics:quicksight_create_iam_policy_assignment]{create_iam_policy_assignment} \tab Creates an assignment with one specified IAM policy, identified by its Amazon Resource Name (ARN)\cr
#'  \link[paws.analytics:quicksight_create_ingestion]{create_ingestion} \tab Creates and starts a new SPICE ingestion for a dataset\cr
#'  \link[paws.analytics:quicksight_create_namespace]{create_namespace} \tab (Enterprise edition only) Creates a new namespace for you to use with Amazon QuickSight\cr
#'  \link[paws.analytics:quicksight_create_refresh_schedule]{create_refresh_schedule} \tab Creates a refresh schedule for a dataset\cr
#'  \link[paws.analytics:quicksight_create_role_membership]{create_role_membership} \tab Use CreateRoleMembership to add an existing Amazon QuickSight group to an existing role\cr
#'  \link[paws.analytics:quicksight_create_template]{create_template} \tab Creates a template either from a TemplateDefinition or from an existing Amazon QuickSight analysis or template\cr
#'  \link[paws.analytics:quicksight_create_template_alias]{create_template_alias} \tab Creates a template alias for a template\cr
#'  \link[paws.analytics:quicksight_create_theme]{create_theme} \tab Creates a theme\cr
#'  \link[paws.analytics:quicksight_create_theme_alias]{create_theme_alias} \tab Creates a theme alias for a theme\cr
#'  \link[paws.analytics:quicksight_create_topic]{create_topic} \tab Creates a new Q topic\cr
#'  \link[paws.analytics:quicksight_create_topic_refresh_schedule]{create_topic_refresh_schedule} \tab Creates a topic refresh schedule\cr
#'  \link[paws.analytics:quicksight_create_vpc_connection]{create_vpc_connection} \tab Creates a new VPC connection\cr
#'  \link[paws.analytics:quicksight_delete_account_customization]{delete_account_customization} \tab Deletes all Amazon QuickSight customizations in this Amazon Web Services Region for the specified Amazon Web Services account and Amazon QuickSight namespace\cr
#'  \link[paws.analytics:quicksight_delete_account_subscription]{delete_account_subscription} \tab Use the DeleteAccountSubscription operation to delete an Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_delete_analysis]{delete_analysis} \tab Deletes an analysis from Amazon QuickSight\cr
#'  \link[paws.analytics:quicksight_delete_brand]{delete_brand} \tab Deletes an Amazon QuickSight brand\cr
#'  \link[paws.analytics:quicksight_delete_brand_assignment]{delete_brand_assignment} \tab Deletes a brand assignment\cr
#'  \link[paws.analytics:quicksight_delete_custom_permissions]{delete_custom_permissions} \tab Deletes a custom permissions profile\cr
#'  \link[paws.analytics:quicksight_delete_dashboard]{delete_dashboard} \tab Deletes a dashboard\cr
#'  \link[paws.analytics:quicksight_delete_data_set]{delete_data_set} \tab Deletes a dataset\cr
#'  \link[paws.analytics:quicksight_delete_data_set_refresh_properties]{delete_data_set_refresh_properties} \tab Deletes the dataset refresh properties of the dataset\cr
#'  \link[paws.analytics:quicksight_delete_data_source]{delete_data_source} \tab Deletes the data source permanently\cr
#'  \link[paws.analytics:quicksight_delete_default_q_business_application]{delete_default_q_business_application} \tab Deletes a linked Amazon Q Business application from an Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_delete_folder]{delete_folder} \tab Deletes an empty folder\cr
#'  \link[paws.analytics:quicksight_delete_folder_membership]{delete_folder_membership} \tab Removes an asset, such as a dashboard, analysis, or dataset, from a folder\cr
#'  \link[paws.analytics:quicksight_delete_group]{delete_group} \tab Removes a user group from Amazon QuickSight\cr
#'  \link[paws.analytics:quicksight_delete_group_membership]{delete_group_membership} \tab Removes a user from a group so that the user is no longer a member of the group\cr
#'  \link[paws.analytics:quicksight_delete_iam_policy_assignment]{delete_iam_policy_assignment} \tab Deletes an existing IAM policy assignment\cr
#'  \link[paws.analytics:quicksight_delete_identity_propagation_config]{delete_identity_propagation_config} \tab Deletes all access scopes and authorized targets that are associated with a service from the Amazon QuickSight IAM Identity Center application\cr
#'  \link[paws.analytics:quicksight_delete_namespace]{delete_namespace} \tab Deletes a namespace and the users and groups that are associated with the namespace\cr
#'  \link[paws.analytics:quicksight_delete_refresh_schedule]{delete_refresh_schedule} \tab Deletes a refresh schedule from a dataset\cr
#'  \link[paws.analytics:quicksight_delete_role_custom_permission]{delete_role_custom_permission} \tab Removes custom permissions from the role\cr
#'  \link[paws.analytics:quicksight_delete_role_membership]{delete_role_membership} \tab Removes a group from a role\cr
#'  \link[paws.analytics:quicksight_delete_template]{delete_template} \tab Deletes a template\cr
#'  \link[paws.analytics:quicksight_delete_template_alias]{delete_template_alias} \tab Deletes the item that the specified template alias points to\cr
#'  \link[paws.analytics:quicksight_delete_theme]{delete_theme} \tab Deletes a theme\cr
#'  \link[paws.analytics:quicksight_delete_theme_alias]{delete_theme_alias} \tab Deletes the version of the theme that the specified theme alias points to\cr
#'  \link[paws.analytics:quicksight_delete_topic]{delete_topic} \tab Deletes a topic\cr
#'  \link[paws.analytics:quicksight_delete_topic_refresh_schedule]{delete_topic_refresh_schedule} \tab Deletes a topic refresh schedule\cr
#'  \link[paws.analytics:quicksight_delete_user]{delete_user} \tab Deletes the Amazon QuickSight user that is associated with the identity of the IAM user or role that's making the call\cr
#'  \link[paws.analytics:quicksight_delete_user_by_principal_id]{delete_user_by_principal_id} \tab Deletes a user identified by its principal ID\cr
#'  \link[paws.analytics:quicksight_delete_user_custom_permission]{delete_user_custom_permission} \tab Deletes a custom permissions profile from a user\cr
#'  \link[paws.analytics:quicksight_delete_vpc_connection]{delete_vpc_connection} \tab Deletes a VPC connection\cr
#'  \link[paws.analytics:quicksight_describe_account_customization]{describe_account_customization} \tab Describes the customizations associated with the provided Amazon Web Services account and Amazon Amazon QuickSight namespace in an Amazon Web Services Region\cr
#'  \link[paws.analytics:quicksight_describe_account_settings]{describe_account_settings} \tab Describes the settings that were used when your Amazon QuickSight subscription was first created in this Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_describe_account_subscription]{describe_account_subscription} \tab Use the DescribeAccountSubscription operation to receive a description of an Amazon QuickSight account's subscription\cr
#'  \link[paws.analytics:quicksight_describe_analysis]{describe_analysis} \tab Provides a summary of the metadata for an analysis\cr
#'  \link[paws.analytics:quicksight_describe_analysis_definition]{describe_analysis_definition} \tab Provides a detailed description of the definition of an analysis\cr
#'  \link[paws.analytics:quicksight_describe_analysis_permissions]{describe_analysis_permissions} \tab Provides the read and write permissions for an analysis\cr
#'  \link[paws.analytics:quicksight_describe_asset_bundle_export_job]{describe_asset_bundle_export_job} \tab Describes an existing export job\cr
#'  \link[paws.analytics:quicksight_describe_asset_bundle_import_job]{describe_asset_bundle_import_job} \tab Describes an existing import job\cr
#'  \link[paws.analytics:quicksight_describe_brand]{describe_brand} \tab Describes a brand\cr
#'  \link[paws.analytics:quicksight_describe_brand_assignment]{describe_brand_assignment} \tab Describes a brand assignment\cr
#'  \link[paws.analytics:quicksight_describe_brand_published_version]{describe_brand_published_version} \tab Describes the published version of the brand\cr
#'  \link[paws.analytics:quicksight_describe_custom_permissions]{describe_custom_permissions} \tab Describes a custom permissions profile\cr
#'  \link[paws.analytics:quicksight_describe_dashboard]{describe_dashboard} \tab Provides a summary for a dashboard\cr
#'  \link[paws.analytics:quicksight_describe_dashboard_definition]{describe_dashboard_definition} \tab Provides a detailed description of the definition of a dashboard\cr
#'  \link[paws.analytics:quicksight_describe_dashboard_permissions]{describe_dashboard_permissions} \tab Describes read and write permissions for a dashboard\cr
#'  \link[paws.analytics:quicksight_describe_dashboard_snapshot_job]{describe_dashboard_snapshot_job} \tab Describes an existing snapshot job\cr
#'  \link[paws.analytics:quicksight_describe_dashboard_snapshot_job_result]{describe_dashboard_snapshot_job_result} \tab Describes the result of an existing snapshot job that has finished running\cr
#'  \link[paws.analytics:quicksight_describe_dashboards_qa_configuration]{describe_dashboards_qa_configuration} \tab Describes an existing dashboard QA configuration\cr
#'  \link[paws.analytics:quicksight_describe_data_set]{describe_data_set} \tab Describes a dataset\cr
#'  \link[paws.analytics:quicksight_describe_data_set_permissions]{describe_data_set_permissions} \tab Describes the permissions on a dataset\cr
#'  \link[paws.analytics:quicksight_describe_data_set_refresh_properties]{describe_data_set_refresh_properties} \tab Describes the refresh properties of a dataset\cr
#'  \link[paws.analytics:quicksight_describe_data_source]{describe_data_source} \tab Describes a data source\cr
#'  \link[paws.analytics:quicksight_describe_data_source_permissions]{describe_data_source_permissions} \tab Describes the resource permissions for a data source\cr
#'  \link[paws.analytics:quicksight_describe_default_q_business_application]{describe_default_q_business_application} \tab Describes a Amazon Q Business application that is linked to an Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_describe_folder]{describe_folder} \tab Describes a folder\cr
#'  \link[paws.analytics:quicksight_describe_folder_permissions]{describe_folder_permissions} \tab Describes permissions for a folder\cr
#'  \link[paws.analytics:quicksight_describe_folder_resolved_permissions]{describe_folder_resolved_permissions} \tab Describes the folder resolved permissions\cr
#'  \link[paws.analytics:quicksight_describe_group]{describe_group} \tab Returns an Amazon QuickSight group's description and Amazon Resource Name (ARN)\cr
#'  \link[paws.analytics:quicksight_describe_group_membership]{describe_group_membership} \tab Use the DescribeGroupMembership operation to determine if a user is a member of the specified group\cr
#'  \link[paws.analytics:quicksight_describe_iam_policy_assignment]{describe_iam_policy_assignment} \tab Describes an existing IAM policy assignment, as specified by the assignment name\cr
#'  \link[paws.analytics:quicksight_describe_ingestion]{describe_ingestion} \tab Describes a SPICE ingestion\cr
#'  \link[paws.analytics:quicksight_describe_ip_restriction]{describe_ip_restriction} \tab Provides a summary and status of IP rules\cr
#'  \link[paws.analytics:quicksight_describe_key_registration]{describe_key_registration} \tab Describes all customer managed key registrations in a Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_describe_namespace]{describe_namespace} \tab Describes the current namespace\cr
#'  \link[paws.analytics:quicksight_describe_q_personalization_configuration]{describe_q_personalization_configuration} \tab Describes a personalization configuration\cr
#'  \link[paws.analytics:quicksight_describe_quick_sight_q_search_configuration]{describe_quick_sight_q_search_configuration} \tab Describes the state of a Amazon QuickSight Q Search configuration\cr
#'  \link[paws.analytics:quicksight_describe_refresh_schedule]{describe_refresh_schedule} \tab Provides a summary of a refresh schedule\cr
#'  \link[paws.analytics:quicksight_describe_role_custom_permission]{describe_role_custom_permission} \tab Describes all custom permissions that are mapped to a role\cr
#'  \link[paws.analytics:quicksight_describe_template]{describe_template} \tab Describes a template's metadata\cr
#'  \link[paws.analytics:quicksight_describe_template_alias]{describe_template_alias} \tab Describes the template alias for a template\cr
#'  \link[paws.analytics:quicksight_describe_template_definition]{describe_template_definition} \tab Provides a detailed description of the definition of a template\cr
#'  \link[paws.analytics:quicksight_describe_template_permissions]{describe_template_permissions} \tab Describes read and write permissions on a template\cr
#'  \link[paws.analytics:quicksight_describe_theme]{describe_theme} \tab Describes a theme\cr
#'  \link[paws.analytics:quicksight_describe_theme_alias]{describe_theme_alias} \tab Describes the alias for a theme\cr
#'  \link[paws.analytics:quicksight_describe_theme_permissions]{describe_theme_permissions} \tab Describes the read and write permissions for a theme\cr
#'  \link[paws.analytics:quicksight_describe_topic]{describe_topic} \tab Describes a topic\cr
#'  \link[paws.analytics:quicksight_describe_topic_permissions]{describe_topic_permissions} \tab Describes the permissions of a topic\cr
#'  \link[paws.analytics:quicksight_describe_topic_refresh]{describe_topic_refresh} \tab Describes the status of a topic refresh\cr
#'  \link[paws.analytics:quicksight_describe_topic_refresh_schedule]{describe_topic_refresh_schedule} \tab Deletes a topic refresh schedule\cr
#'  \link[paws.analytics:quicksight_describe_user]{describe_user} \tab Returns information about a user, given the user name\cr
#'  \link[paws.analytics:quicksight_describe_vpc_connection]{describe_vpc_connection} \tab Describes a VPC connection\cr
#'  \link[paws.analytics:quicksight_generate_embed_url_for_anonymous_user]{generate_embed_url_for_anonymous_user} \tab Generates an embed URL that you can use to embed an Amazon QuickSight dashboard or visual in your website, without having to register any reader users\cr
#'  \link[paws.analytics:quicksight_generate_embed_url_for_registered_user]{generate_embed_url_for_registered_user} \tab Generates an embed URL that you can use to embed an Amazon QuickSight experience in your website\cr
#'  \link[paws.analytics:quicksight_generate_embed_url_for_registered_user_with_identity]{generate_embed_url_for_registered_user_with_identity} \tab Generates an embed URL that you can use to embed an Amazon QuickSight experience in your website\cr
#'  \link[paws.analytics:quicksight_get_dashboard_embed_url]{get_dashboard_embed_url} \tab Generates a temporary session URL and authorization code(bearer token) that you can use to embed an Amazon QuickSight read-only dashboard in your website or application\cr
#'  \link[paws.analytics:quicksight_get_session_embed_url]{get_session_embed_url} \tab Generates a session URL and authorization code that you can use to embed the Amazon Amazon QuickSight console in your web server code\cr
#'  \link[paws.analytics:quicksight_list_analyses]{list_analyses} \tab Lists Amazon QuickSight analyses that exist in the specified Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_list_asset_bundle_export_jobs]{list_asset_bundle_export_jobs} \tab Lists all asset bundle export jobs that have been taken place in the last 14 days\cr
#'  \link[paws.analytics:quicksight_list_asset_bundle_import_jobs]{list_asset_bundle_import_jobs} \tab Lists all asset bundle import jobs that have taken place in the last 14 days\cr
#'  \link[paws.analytics:quicksight_list_brands]{list_brands} \tab Lists all brands in an Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_list_custom_permissions]{list_custom_permissions} \tab Returns a list of all the custom permissions profiles\cr
#'  \link[paws.analytics:quicksight_list_dashboards]{list_dashboards} \tab Lists dashboards in an Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_list_dashboard_versions]{list_dashboard_versions} \tab Lists all the versions of the dashboards in the Amazon QuickSight subscription\cr
#'  \link[paws.analytics:quicksight_list_data_sets]{list_data_sets} \tab Lists all of the datasets belonging to the current Amazon Web Services account in an Amazon Web Services Region\cr
#'  \link[paws.analytics:quicksight_list_data_sources]{list_data_sources} \tab Lists data sources in current Amazon Web Services Region that belong to this Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_list_folder_members]{list_folder_members} \tab List all assets (DASHBOARD, ANALYSIS, and DATASET) in a folder\cr
#'  \link[paws.analytics:quicksight_list_folders]{list_folders} \tab Lists all folders in an account\cr
#'  \link[paws.analytics:quicksight_list_folders_for_resource]{list_folders_for_resource} \tab List all folders that a resource is a member of\cr
#'  \link[paws.analytics:quicksight_list_group_memberships]{list_group_memberships} \tab Lists member users in a group\cr
#'  \link[paws.analytics:quicksight_list_groups]{list_groups} \tab Lists all user groups in Amazon QuickSight\cr
#'  \link[paws.analytics:quicksight_list_iam_policy_assignments]{list_iam_policy_assignments} \tab Lists the IAM policy assignments in the current Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_list_iam_policy_assignments_for_user]{list_iam_policy_assignments_for_user} \tab Lists all of the IAM policy assignments, including the Amazon Resource Names (ARNs), for the IAM policies assigned to the specified user and group, or groups that the user belongs to\cr
#'  \link[paws.analytics:quicksight_list_identity_propagation_configs]{list_identity_propagation_configs} \tab Lists all services and authorized targets that the Amazon QuickSight IAM Identity Center application can access\cr
#'  \link[paws.analytics:quicksight_list_ingestions]{list_ingestions} \tab Lists the history of SPICE ingestions for a dataset\cr
#'  \link[paws.analytics:quicksight_list_namespaces]{list_namespaces} \tab Lists the namespaces for the specified Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_list_refresh_schedules]{list_refresh_schedules} \tab Lists the refresh schedules of a dataset\cr
#'  \link[paws.analytics:quicksight_list_role_memberships]{list_role_memberships} \tab Lists all groups that are associated with a role\cr
#'  \link[paws.analytics:quicksight_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags assigned to a resource\cr
#'  \link[paws.analytics:quicksight_list_template_aliases]{list_template_aliases} \tab Lists all the aliases of a template\cr
#'  \link[paws.analytics:quicksight_list_templates]{list_templates} \tab Lists all the templates in the current Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_list_template_versions]{list_template_versions} \tab Lists all the versions of the templates in the current Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_list_theme_aliases]{list_theme_aliases} \tab Lists all the aliases of a theme\cr
#'  \link[paws.analytics:quicksight_list_themes]{list_themes} \tab Lists all the themes in the current Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_list_theme_versions]{list_theme_versions} \tab Lists all the versions of the themes in the current Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_list_topic_refresh_schedules]{list_topic_refresh_schedules} \tab Lists all of the refresh schedules for a topic\cr
#'  \link[paws.analytics:quicksight_list_topic_reviewed_answers]{list_topic_reviewed_answers} \tab Lists all reviewed answers for a Q Topic\cr
#'  \link[paws.analytics:quicksight_list_topics]{list_topics} \tab Lists all of the topics within an account\cr
#'  \link[paws.analytics:quicksight_list_user_groups]{list_user_groups} \tab Lists the Amazon QuickSight groups that an Amazon QuickSight user is a member of\cr
#'  \link[paws.analytics:quicksight_list_users]{list_users} \tab Returns a list of all of the Amazon QuickSight users belonging to this account\cr
#'  \link[paws.analytics:quicksight_list_vpc_connections]{list_vpc_connections} \tab Lists all of the VPC connections in the current set Amazon Web Services Region of an Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_predict_qa_results]{predict_qa_results} \tab Predicts existing visuals or generates new visuals to answer a given query\cr
#'  \link[paws.analytics:quicksight_put_data_set_refresh_properties]{put_data_set_refresh_properties} \tab Creates or updates the dataset refresh properties for the dataset\cr
#'  \link[paws.analytics:quicksight_register_user]{register_user} \tab Creates an Amazon QuickSight user whose identity is associated with the Identity and Access Management (IAM) identity or role specified in the request\cr
#'  \link[paws.analytics:quicksight_restore_analysis]{restore_analysis} \tab Restores an analysis\cr
#'  \link[paws.analytics:quicksight_search_analyses]{search_analyses} \tab Searches for analyses that belong to the user specified in the filter\cr
#'  \link[paws.analytics:quicksight_search_dashboards]{search_dashboards} \tab Searches for dashboards that belong to a user\cr
#'  \link[paws.analytics:quicksight_search_data_sets]{search_data_sets} \tab Use the SearchDataSets operation to search for datasets that belong to an account\cr
#'  \link[paws.analytics:quicksight_search_data_sources]{search_data_sources} \tab Use the SearchDataSources operation to search for data sources that belong to an account\cr
#'  \link[paws.analytics:quicksight_search_folders]{search_folders} \tab Searches the subfolders in a folder\cr
#'  \link[paws.analytics:quicksight_search_groups]{search_groups} \tab Use the SearchGroups operation to search groups in a specified Amazon QuickSight namespace using the supplied filters\cr
#'  \link[paws.analytics:quicksight_search_topics]{search_topics} \tab Searches for any Q topic that exists in an Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_start_asset_bundle_export_job]{start_asset_bundle_export_job} \tab Starts an Asset Bundle export job\cr
#'  \link[paws.analytics:quicksight_start_asset_bundle_import_job]{start_asset_bundle_import_job} \tab Starts an Asset Bundle import job\cr
#'  \link[paws.analytics:quicksight_start_dashboard_snapshot_job]{start_dashboard_snapshot_job} \tab Starts an asynchronous job that generates a snapshot of a dashboard's output\cr
#'  \link[paws.analytics:quicksight_start_dashboard_snapshot_job_schedule]{start_dashboard_snapshot_job_schedule} \tab Starts an asynchronous job that runs an existing dashboard schedule and sends the dashboard snapshot through email\cr
#'  \link[paws.analytics:quicksight_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified Amazon QuickSight resource\cr
#'  \link[paws.analytics:quicksight_untag_resource]{untag_resource} \tab Removes a tag or tags from a resource\cr
#'  \link[paws.analytics:quicksight_update_account_customization]{update_account_customization} \tab Updates Amazon QuickSight customizations for the current Amazon Web Services Region\cr
#'  \link[paws.analytics:quicksight_update_account_settings]{update_account_settings} \tab Updates the Amazon QuickSight settings in your Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_update_analysis]{update_analysis} \tab Updates an analysis in Amazon QuickSight\cr
#'  \link[paws.analytics:quicksight_update_analysis_permissions]{update_analysis_permissions} \tab Updates the read and write permissions for an analysis\cr
#'  \link[paws.analytics:quicksight_update_application_with_token_exchange_grant]{update_application_with_token_exchange_grant} \tab Updates an Amazon QuickSight application with a token exchange grant\cr
#'  \link[paws.analytics:quicksight_update_brand]{update_brand} \tab Updates a brand\cr
#'  \link[paws.analytics:quicksight_update_brand_assignment]{update_brand_assignment} \tab Updates a brand assignment\cr
#'  \link[paws.analytics:quicksight_update_brand_published_version]{update_brand_published_version} \tab Updates the published version of a brand\cr
#'  \link[paws.analytics:quicksight_update_custom_permissions]{update_custom_permissions} \tab Updates a custom permissions profile\cr
#'  \link[paws.analytics:quicksight_update_dashboard]{update_dashboard} \tab Updates a dashboard in an Amazon Web Services account\cr
#'  \link[paws.analytics:quicksight_update_dashboard_links]{update_dashboard_links} \tab Updates the linked analyses on a dashboard\cr
#'  \link[paws.analytics:quicksight_update_dashboard_permissions]{update_dashboard_permissions} \tab Updates read and write permissions on a dashboard\cr
#'  \link[paws.analytics:quicksight_update_dashboard_published_version]{update_dashboard_published_version} \tab Updates the published version of a dashboard\cr
#'  \link[paws.analytics:quicksight_update_dashboards_qa_configuration]{update_dashboards_qa_configuration} \tab Updates a Dashboard QA configuration\cr
#'  \link[paws.analytics:quicksight_update_data_set]{update_data_set} \tab Updates a dataset\cr
#'  \link[paws.analytics:quicksight_update_data_set_permissions]{update_data_set_permissions} \tab Updates the permissions on a dataset\cr
#'  \link[paws.analytics:quicksight_update_data_source]{update_data_source} \tab Updates a data source\cr
#'  \link[paws.analytics:quicksight_update_data_source_permissions]{update_data_source_permissions} \tab Updates the permissions to a data source\cr
#'  \link[paws.analytics:quicksight_update_default_q_business_application]{update_default_q_business_application} \tab Updates a Amazon Q Business application that is linked to a Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_update_folder]{update_folder} \tab Updates the name of a folder\cr
#'  \link[paws.analytics:quicksight_update_folder_permissions]{update_folder_permissions} \tab Updates permissions of a folder\cr
#'  \link[paws.analytics:quicksight_update_group]{update_group} \tab Changes a group description\cr
#'  \link[paws.analytics:quicksight_update_iam_policy_assignment]{update_iam_policy_assignment} \tab Updates an existing IAM policy assignment\cr
#'  \link[paws.analytics:quicksight_update_identity_propagation_config]{update_identity_propagation_config} \tab Adds or updates services and authorized targets to configure what the Amazon QuickSight IAM Identity Center application can access\cr
#'  \link[paws.analytics:quicksight_update_ip_restriction]{update_ip_restriction} \tab Updates the content and status of IP rules\cr
#'  \link[paws.analytics:quicksight_update_key_registration]{update_key_registration} \tab Updates a customer managed key in a Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_update_public_sharing_settings]{update_public_sharing_settings} \tab Use the UpdatePublicSharingSettings operation to turn on or turn off the public sharing settings of an Amazon QuickSight dashboard\cr
#'  \link[paws.analytics:quicksight_update_q_personalization_configuration]{update_q_personalization_configuration} \tab Updates a personalization configuration\cr
#'  \link[paws.analytics:quicksight_update_quick_sight_q_search_configuration]{update_quick_sight_q_search_configuration} \tab Updates the state of a Amazon QuickSight Q Search configuration\cr
#'  \link[paws.analytics:quicksight_update_refresh_schedule]{update_refresh_schedule} \tab Updates a refresh schedule for a dataset\cr
#'  \link[paws.analytics:quicksight_update_role_custom_permission]{update_role_custom_permission} \tab Updates the custom permissions that are associated with a role\cr
#'  \link[paws.analytics:quicksight_update_spice_capacity_configuration]{update_spice_capacity_configuration} \tab Updates the SPICE capacity configuration for a Amazon QuickSight account\cr
#'  \link[paws.analytics:quicksight_update_template]{update_template} \tab Updates a template from an existing Amazon QuickSight analysis or another template\cr
#'  \link[paws.analytics:quicksight_update_template_alias]{update_template_alias} \tab Updates the template alias of a template\cr
#'  \link[paws.analytics:quicksight_update_template_permissions]{update_template_permissions} \tab Updates the resource permissions for a template\cr
#'  \link[paws.analytics:quicksight_update_theme]{update_theme} \tab Updates a theme\cr
#'  \link[paws.analytics:quicksight_update_theme_alias]{update_theme_alias} \tab Updates an alias of a theme\cr
#'  \link[paws.analytics:quicksight_update_theme_permissions]{update_theme_permissions} \tab Updates the resource permissions for a theme\cr
#'  \link[paws.analytics:quicksight_update_topic]{update_topic} \tab Updates a topic\cr
#'  \link[paws.analytics:quicksight_update_topic_permissions]{update_topic_permissions} \tab Updates the permissions of a topic\cr
#'  \link[paws.analytics:quicksight_update_topic_refresh_schedule]{update_topic_refresh_schedule} \tab Updates a topic refresh schedule\cr
#'  \link[paws.analytics:quicksight_update_user]{update_user} \tab Updates an Amazon QuickSight user\cr
#'  \link[paws.analytics:quicksight_update_user_custom_permission]{update_user_custom_permission} \tab Updates a custom permissions profile for a user\cr
#'  \link[paws.analytics:quicksight_update_vpc_connection]{update_vpc_connection} \tab Updates a VPC connection
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname quicksight
#' @export
quicksight <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.analytics::quicksight(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Access Analyzer
#'
#' @description
#' Identity and Access Management Access Analyzer helps you to set, verify,
#' and refine your IAM policies by providing a suite of capabilities. Its
#' features include findings for external and unused access, basic and
#' custom policy checks for validating policies, and policy generation to
#' generate fine-grained policies. To start using IAM Access Analyzer to
#' identify external or unused access, you first need to create an
#' analyzer.
#' 
#' **External access analyzers** help identify potential risks of accessing
#' resources by enabling you to identify any resource policies that grant
#' access to an external principal. It does this by using logic-based
#' reasoning to analyze resource-based policies in your Amazon Web Services
#' environment. An external principal can be another Amazon Web Services
#' account, a root user, an IAM user or role, a federated user, an Amazon
#' Web Services service, or an anonymous user. You can also use IAM Access
#' Analyzer to preview public and cross-account access to your resources
#' before deploying permissions changes.
#' 
#' **Unused access analyzers** help identify potential identity access
#' risks by enabling you to identify unused IAM roles, unused access keys,
#' unused console passwords, and IAM principals with unused service and
#' action-level permissions.
#' 
#' Beyond findings, IAM Access Analyzer provides basic and custom policy
#' checks to validate IAM policies before deploying permissions changes.
#' You can use policy generation to refine permissions by attaching a
#' policy generated using access activity logged in CloudTrail logs.
#' 
#' This guide describes the IAM Access Analyzer operations that you can
#' call programmatically. For general information about IAM Access
#' Analyzer, see [Identity and Access Management Access
#' Analyzer](https://docs.aws.amazon.com/IAM/latest/UserGuide/what-is-access-analyzer.html)
#' in the **IAM User Guide**.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- accessanalyzer(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- accessanalyzer()
#' svc$apply_archive_rule(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:accessanalyzer_apply_archive_rule]{apply_archive_rule} \tab Retroactively applies the archive rule to existing findings that meet the archive rule criteria\cr
#'  \link[paws.security.identity:accessanalyzer_cancel_policy_generation]{cancel_policy_generation} \tab Cancels the requested policy generation\cr
#'  \link[paws.security.identity:accessanalyzer_check_access_not_granted]{check_access_not_granted} \tab Checks whether the specified access isn't allowed by a policy\cr
#'  \link[paws.security.identity:accessanalyzer_check_no_new_access]{check_no_new_access} \tab Checks whether new access is allowed for an updated policy when compared to the existing policy\cr
#'  \link[paws.security.identity:accessanalyzer_check_no_public_access]{check_no_public_access} \tab Checks whether a resource policy can grant public access to the specified resource type\cr
#'  \link[paws.security.identity:accessanalyzer_create_access_preview]{create_access_preview} \tab Creates an access preview that allows you to preview IAM Access Analyzer findings for your resource before deploying resource permissions\cr
#'  \link[paws.security.identity:accessanalyzer_create_analyzer]{create_analyzer} \tab Creates an analyzer for your account\cr
#'  \link[paws.security.identity:accessanalyzer_create_archive_rule]{create_archive_rule} \tab Creates an archive rule for the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_delete_analyzer]{delete_analyzer} \tab Deletes the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_delete_archive_rule]{delete_archive_rule} \tab Deletes the specified archive rule\cr
#'  \link[paws.security.identity:accessanalyzer_generate_finding_recommendation]{generate_finding_recommendation} \tab Creates a recommendation for an unused permissions finding\cr
#'  \link[paws.security.identity:accessanalyzer_get_access_preview]{get_access_preview} \tab Retrieves information about an access preview for the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_get_analyzed_resource]{get_analyzed_resource} \tab Retrieves information about a resource that was analyzed\cr
#'  \link[paws.security.identity:accessanalyzer_get_analyzer]{get_analyzer} \tab Retrieves information about the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_get_archive_rule]{get_archive_rule} \tab Retrieves information about an archive rule\cr
#'  \link[paws.security.identity:accessanalyzer_get_finding]{get_finding} \tab Retrieves information about the specified finding\cr
#'  \link[paws.security.identity:accessanalyzer_get_finding_recommendation]{get_finding_recommendation} \tab Retrieves information about a finding recommendation for the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_get_findings_statistics]{get_findings_statistics} \tab Retrieves a list of aggregated finding statistics for an external access or unused access analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_get_finding_v2]{get_finding_v2} \tab Retrieves information about the specified finding\cr
#'  \link[paws.security.identity:accessanalyzer_get_generated_policy]{get_generated_policy} \tab Retrieves the policy that was generated using StartPolicyGeneration\cr
#'  \link[paws.security.identity:accessanalyzer_list_access_preview_findings]{list_access_preview_findings} \tab Retrieves a list of access preview findings generated by the specified access preview\cr
#'  \link[paws.security.identity:accessanalyzer_list_access_previews]{list_access_previews} \tab Retrieves a list of access previews for the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_list_analyzed_resources]{list_analyzed_resources} \tab Retrieves a list of resources of the specified type that have been analyzed by the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_list_analyzers]{list_analyzers} \tab Retrieves a list of analyzers\cr
#'  \link[paws.security.identity:accessanalyzer_list_archive_rules]{list_archive_rules} \tab Retrieves a list of archive rules created for the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_list_findings]{list_findings} \tab Retrieves a list of findings generated by the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_list_findings_v2]{list_findings_v2} \tab Retrieves a list of findings generated by the specified analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_list_policy_generations]{list_policy_generations} \tab Lists all of the policy generations requested in the last seven days\cr
#'  \link[paws.security.identity:accessanalyzer_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves a list of tags applied to the specified resource\cr
#'  \link[paws.security.identity:accessanalyzer_start_policy_generation]{start_policy_generation} \tab Starts the policy generation request\cr
#'  \link[paws.security.identity:accessanalyzer_start_resource_scan]{start_resource_scan} \tab Immediately starts a scan of the policies applied to the specified resource\cr
#'  \link[paws.security.identity:accessanalyzer_tag_resource]{tag_resource} \tab Adds a tag to the specified resource\cr
#'  \link[paws.security.identity:accessanalyzer_untag_resource]{untag_resource} \tab Removes a tag from the specified resource\cr
#'  \link[paws.security.identity:accessanalyzer_update_analyzer]{update_analyzer} \tab Modifies the configuration of an existing analyzer\cr
#'  \link[paws.security.identity:accessanalyzer_update_archive_rule]{update_archive_rule} \tab Updates the criteria and values for the specified archive rule\cr
#'  \link[paws.security.identity:accessanalyzer_update_findings]{update_findings} \tab Updates the status for the specified findings\cr
#'  \link[paws.security.identity:accessanalyzer_validate_policy]{validate_policy} \tab Requests the validation of a policy and returns a list of findings
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname accessanalyzer
#' @export
accessanalyzer <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::accessanalyzer(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Account
#'
#' @description
#' Operations for Amazon Web Services Account Management
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- account(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- account()
#' svc$accept_primary_email_update(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:account_accept_primary_email_update]{accept_primary_email_update} \tab Accepts the request that originated from StartPrimaryEmailUpdate to update the primary email address (also known as the root user email address) for the specified account\cr
#'  \link[paws.security.identity:account_delete_alternate_contact]{delete_alternate_contact} \tab Deletes the specified alternate contact from an Amazon Web Services account\cr
#'  \link[paws.security.identity:account_disable_region]{disable_region} \tab Disables (opts-out) a particular Region for an account\cr
#'  \link[paws.security.identity:account_enable_region]{enable_region} \tab Enables (opts-in) a particular Region for an account\cr
#'  \link[paws.security.identity:account_get_alternate_contact]{get_alternate_contact} \tab Retrieves the specified alternate contact attached to an Amazon Web Services account\cr
#'  \link[paws.security.identity:account_get_contact_information]{get_contact_information} \tab Retrieves the primary contact information of an Amazon Web Services account\cr
#'  \link[paws.security.identity:account_get_primary_email]{get_primary_email} \tab Retrieves the primary email address for the specified account\cr
#'  \link[paws.security.identity:account_get_region_opt_status]{get_region_opt_status} \tab Retrieves the opt-in status of a particular Region\cr
#'  \link[paws.security.identity:account_list_regions]{list_regions} \tab Lists all the Regions for a given account and their respective opt-in statuses\cr
#'  \link[paws.security.identity:account_put_alternate_contact]{put_alternate_contact} \tab Modifies the specified alternate contact attached to an Amazon Web Services account\cr
#'  \link[paws.security.identity:account_put_contact_information]{put_contact_information} \tab Updates the primary contact information of an Amazon Web Services account\cr
#'  \link[paws.security.identity:account_start_primary_email_update]{start_primary_email_update} \tab Starts the process to update the primary email address for the specified account
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname account
#' @export
account <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::account(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Certificate Manager
#'
#' @description
#' Certificate Manager
#' 
#' You can use Certificate Manager (ACM) to manage SSL/TLS certificates for
#' your Amazon Web Services-based websites and applications. For more
#' information about using ACM, see the [Certificate Manager User
#' Guide](https://docs.aws.amazon.com/acm/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- acm(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- acm()
#' svc$add_tags_to_certificate(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:acm_add_tags_to_certificate]{add_tags_to_certificate} \tab Adds one or more tags to an ACM certificate\cr
#'  \link[paws.security.identity:acm_delete_certificate]{delete_certificate} \tab Deletes a certificate and its associated private key\cr
#'  \link[paws.security.identity:acm_describe_certificate]{describe_certificate} \tab Returns detailed metadata about the specified ACM certificate\cr
#'  \link[paws.security.identity:acm_export_certificate]{export_certificate} \tab Exports a private certificate issued by a private certificate authority (CA) for use anywhere\cr
#'  \link[paws.security.identity:acm_get_account_configuration]{get_account_configuration} \tab Returns the account configuration options associated with an Amazon Web Services account\cr
#'  \link[paws.security.identity:acm_get_certificate]{get_certificate} \tab Retrieves a certificate and its certificate chain\cr
#'  \link[paws.security.identity:acm_import_certificate]{import_certificate} \tab Imports a certificate into Certificate Manager (ACM) to use with services that are integrated with ACM\cr
#'  \link[paws.security.identity:acm_list_certificates]{list_certificates} \tab Retrieves a list of certificate ARNs and domain names\cr
#'  \link[paws.security.identity:acm_list_tags_for_certificate]{list_tags_for_certificate} \tab Lists the tags that have been applied to the ACM certificate\cr
#'  \link[paws.security.identity:acm_put_account_configuration]{put_account_configuration} \tab Adds or modifies account-level configurations in ACM\cr
#'  \link[paws.security.identity:acm_remove_tags_from_certificate]{remove_tags_from_certificate} \tab Remove one or more tags from an ACM certificate\cr
#'  \link[paws.security.identity:acm_renew_certificate]{renew_certificate} \tab Renews an eligible ACM certificate\cr
#'  \link[paws.security.identity:acm_request_certificate]{request_certificate} \tab Requests an ACM certificate for use with other Amazon Web Services services\cr
#'  \link[paws.security.identity:acm_resend_validation_email]{resend_validation_email} \tab Resends the email that requests domain ownership validation\cr
#'  \link[paws.security.identity:acm_update_certificate_options]{update_certificate_options} \tab Updates a certificate
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname acm
#' @export
acm <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::acm(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Certificate Manager Private Certificate Authority
#'
#' @description
#' This is the *Amazon Web Services Private Certificate Authority API
#' Reference*. It provides descriptions, syntax, and usage examples for
#' each of the actions and data types involved in creating and managing a
#' private certificate authority (CA) for your organization.
#' 
#' The documentation for each action shows the API request parameters and
#' the JSON response. Alternatively, you can use one of the Amazon Web
#' Services SDKs to access an API that is tailored to the programming
#' language or platform that you prefer. For more information, see [Amazon
#' Web Services SDKs](https://aws.amazon.com/developer/tools/#SDKs).
#' 
#' Each Amazon Web Services Private CA API operation has a quota that
#' determines the number of times the operation can be called per second.
#' Amazon Web Services Private CA throttles API requests at different rates
#' depending on the operation. Throttling means that Amazon Web Services
#' Private CA rejects an otherwise valid request because the request
#' exceeds the operation's quota for the number of requests per second.
#' When a request is throttled, Amazon Web Services Private CA returns a
#' [ThrottlingException](https://docs.aws.amazon.com/privateca/latest/APIReference/CommonErrors.html)
#' error. Amazon Web Services Private CA does not guarantee a minimum
#' request rate for APIs.
#' 
#' To see an up-to-date list of your Amazon Web Services Private CA quotas,
#' or to request a quota increase, log into your Amazon Web Services
#' account and visit the Service Quotas console.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- acmpca(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- acmpca()
#' svc$create_certificate_authority(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:acmpca_create_certificate_authority]{create_certificate_authority} \tab Creates a root or subordinate private certificate authority (CA)\cr
#'  \link[paws.security.identity:acmpca_create_certificate_authority_audit_report]{create_certificate_authority_audit_report} \tab Creates an audit report that lists every time that your CA private key is used to issue a certificate\cr
#'  \link[paws.security.identity:acmpca_create_permission]{create_permission} \tab Grants one or more permissions on a private CA to the Certificate Manager (ACM) service principal (acm\cr
#'  \link[paws.security.identity:acmpca_delete_certificate_authority]{delete_certificate_authority} \tab Deletes a private certificate authority (CA)\cr
#'  \link[paws.security.identity:acmpca_delete_permission]{delete_permission} \tab Revokes permissions on a private CA granted to the Certificate Manager (ACM) service principal (acm\cr
#'  \link[paws.security.identity:acmpca_delete_policy]{delete_policy} \tab Deletes the resource-based policy attached to a private CA\cr
#'  \link[paws.security.identity:acmpca_describe_certificate_authority]{describe_certificate_authority} \tab Lists information about your private certificate authority (CA) or one that has been shared with you\cr
#'  \link[paws.security.identity:acmpca_describe_certificate_authority_audit_report]{describe_certificate_authority_audit_report} \tab Lists information about a specific audit report created by calling the CreateCertificateAuthorityAuditReport action\cr
#'  \link[paws.security.identity:acmpca_get_certificate]{get_certificate} \tab Retrieves a certificate from your private CA or one that has been shared with you\cr
#'  \link[paws.security.identity:acmpca_get_certificate_authority_certificate]{get_certificate_authority_certificate} \tab Retrieves the certificate and certificate chain for your private certificate authority (CA) or one that has been shared with you\cr
#'  \link[paws.security.identity:acmpca_get_certificate_authority_csr]{get_certificate_authority_csr} \tab Retrieves the certificate signing request (CSR) for your private certificate authority (CA)\cr
#'  \link[paws.security.identity:acmpca_get_policy]{get_policy} \tab Retrieves the resource-based policy attached to a private CA\cr
#'  \link[paws.security.identity:acmpca_import_certificate_authority_certificate]{import_certificate_authority_certificate} \tab Imports a signed private CA certificate into Amazon Web Services Private CA\cr
#'  \link[paws.security.identity:acmpca_issue_certificate]{issue_certificate} \tab Uses your private certificate authority (CA), or one that has been shared with you, to issue a client certificate\cr
#'  \link[paws.security.identity:acmpca_list_certificate_authorities]{list_certificate_authorities} \tab Lists the private certificate authorities that you created by using the CreateCertificateAuthority action\cr
#'  \link[paws.security.identity:acmpca_list_permissions]{list_permissions} \tab List all permissions on a private CA, if any, granted to the Certificate Manager (ACM) service principal (acm\cr
#'  \link[paws.security.identity:acmpca_list_tags]{list_tags} \tab Lists the tags, if any, that are associated with your private CA or one that has been shared with you\cr
#'  \link[paws.security.identity:acmpca_put_policy]{put_policy} \tab Attaches a resource-based policy to a private CA\cr
#'  \link[paws.security.identity:acmpca_restore_certificate_authority]{restore_certificate_authority} \tab Restores a certificate authority (CA) that is in the DELETED state\cr
#'  \link[paws.security.identity:acmpca_revoke_certificate]{revoke_certificate} \tab Revokes a certificate that was issued inside Amazon Web Services Private CA\cr
#'  \link[paws.security.identity:acmpca_tag_certificate_authority]{tag_certificate_authority} \tab Adds one or more tags to your private CA\cr
#'  \link[paws.security.identity:acmpca_untag_certificate_authority]{untag_certificate_authority} \tab Remove one or more tags from your private CA\cr
#'  \link[paws.security.identity:acmpca_update_certificate_authority]{update_certificate_authority} \tab Updates the status or configuration of a private certificate authority (CA)
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname acmpca
#' @export
acmpca <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::acmpca(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Clean Rooms ML
#'
#' @description
#' Welcome to the *Amazon Web Services Clean Rooms ML API Reference*.
#' 
#' Amazon Web Services Clean Rooms ML provides a privacy-enhancing method
#' for two parties to identify similar users in their data without the need
#' to share their data with each other. The first party brings the training
#' data to Clean Rooms so that they can create and configure an audience
#' model (lookalike model) and associate it with a collaboration. The
#' second party then brings their seed data to Clean Rooms and generates an
#' audience (lookalike segment) that resembles the training data.
#' 
#' To learn more about Amazon Web Services Clean Rooms ML concepts,
#' procedures, and best practices, see the [Clean Rooms User
#' Guide](https://docs.aws.amazon.com/clean-rooms/latest/userguide/machine-learning.html).
#' 
#' To learn more about SQL commands, functions, and conditions supported in
#' Clean Rooms, see the [Clean Rooms SQL
#' Reference](https://docs.aws.amazon.com/clean-rooms/latest/sql-reference/sql-reference.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cleanroomsml(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cleanroomsml()
#' svc$cancel_trained_model(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:cleanroomsml_cancel_trained_model]{cancel_trained_model} \tab Submits a request to cancel the trained model job\cr
#'  \link[paws.security.identity:cleanroomsml_cancel_trained_model_inference_job]{cancel_trained_model_inference_job} \tab Submits a request to cancel a trained model inference job\cr
#'  \link[paws.security.identity:cleanroomsml_create_audience_model]{create_audience_model} \tab Defines the information necessary to create an audience model\cr
#'  \link[paws.security.identity:cleanroomsml_create_configured_audience_model]{create_configured_audience_model} \tab Defines the information necessary to create a configured audience model\cr
#'  \link[paws.security.identity:cleanroomsml_create_configured_model_algorithm]{create_configured_model_algorithm} \tab Creates a configured model algorithm using a container image stored in an ECR repository\cr
#'  \link[paws.security.identity:cleanroomsml_create_configured_model_algorithm_association]{create_configured_model_algorithm_association} \tab Associates a configured model algorithm to a collaboration for use by any member of the collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_create_ml_input_channel]{create_ml_input_channel} \tab Provides the information to create an ML input channel\cr
#'  \link[paws.security.identity:cleanroomsml_create_trained_model]{create_trained_model} \tab Creates a trained model from an associated configured model algorithm using data from any member of the collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_create_training_dataset]{create_training_dataset} \tab Defines the information necessary to create a training dataset\cr
#'  \link[paws.security.identity:cleanroomsml_delete_audience_generation_job]{delete_audience_generation_job} \tab Deletes the specified audience generation job, and removes all data associated with the job\cr
#'  \link[paws.security.identity:cleanroomsml_delete_audience_model]{delete_audience_model} \tab Specifies an audience model that you want to delete\cr
#'  \link[paws.security.identity:cleanroomsml_delete_configured_audience_model]{delete_configured_audience_model} \tab Deletes the specified configured audience model\cr
#'  \link[paws.security.identity:cleanroomsml_delete_configured_audience_model_policy]{delete_configured_audience_model_policy} \tab Deletes the specified configured audience model policy\cr
#'  \link[paws.security.identity:cleanroomsml_delete_configured_model_algorithm]{delete_configured_model_algorithm} \tab Deletes a configured model algorithm\cr
#'  \link[paws.security.identity:cleanroomsml_delete_configured_model_algorithm_association]{delete_configured_model_algorithm_association} \tab Deletes a configured model algorithm association\cr
#'  \link[paws.security.identity:cleanroomsml_delete_ml_configuration]{delete_ml_configuration} \tab Deletes a ML modeling configuration\cr
#'  \link[paws.security.identity:cleanroomsml_delete_ml_input_channel_data]{delete_ml_input_channel_data} \tab Provides the information necessary to delete an ML input channel\cr
#'  \link[paws.security.identity:cleanroomsml_delete_trained_model_output]{delete_trained_model_output} \tab Deletes the output of a trained model\cr
#'  \link[paws.security.identity:cleanroomsml_delete_training_dataset]{delete_training_dataset} \tab Specifies a training dataset that you want to delete\cr
#'  \link[paws.security.identity:cleanroomsml_get_audience_generation_job]{get_audience_generation_job} \tab Returns information about an audience generation job\cr
#'  \link[paws.security.identity:cleanroomsml_get_audience_model]{get_audience_model} \tab Returns information about an audience model\cr
#'  \link[paws.security.identity:cleanroomsml_get_collaboration_configured_model_algorithm_association]{get_collaboration_configured_model_algorithm_association} \tab Returns information about the configured model algorithm association in a collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_get_collaboration_ml_input_channel]{get_collaboration_ml_input_channel} \tab Returns information about a specific ML input channel in a collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_get_collaboration_trained_model]{get_collaboration_trained_model} \tab Returns information about a trained model in a collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_get_configured_audience_model]{get_configured_audience_model} \tab Returns information about a specified configured audience model\cr
#'  \link[paws.security.identity:cleanroomsml_get_configured_audience_model_policy]{get_configured_audience_model_policy} \tab Returns information about a configured audience model policy\cr
#'  \link[paws.security.identity:cleanroomsml_get_configured_model_algorithm]{get_configured_model_algorithm} \tab Returns information about a configured model algorithm\cr
#'  \link[paws.security.identity:cleanroomsml_get_configured_model_algorithm_association]{get_configured_model_algorithm_association} \tab Returns information about a configured model algorithm association\cr
#'  \link[paws.security.identity:cleanroomsml_get_ml_configuration]{get_ml_configuration} \tab Returns information about a specific ML configuration\cr
#'  \link[paws.security.identity:cleanroomsml_get_ml_input_channel]{get_ml_input_channel} \tab Returns information about an ML input channel\cr
#'  \link[paws.security.identity:cleanroomsml_get_trained_model]{get_trained_model} \tab Returns information about a trained model\cr
#'  \link[paws.security.identity:cleanroomsml_get_trained_model_inference_job]{get_trained_model_inference_job} \tab Returns information about a trained model inference job\cr
#'  \link[paws.security.identity:cleanroomsml_get_training_dataset]{get_training_dataset} \tab Returns information about a training dataset\cr
#'  \link[paws.security.identity:cleanroomsml_list_audience_export_jobs]{list_audience_export_jobs} \tab Returns a list of the audience export jobs\cr
#'  \link[paws.security.identity:cleanroomsml_list_audience_generation_jobs]{list_audience_generation_jobs} \tab Returns a list of audience generation jobs\cr
#'  \link[paws.security.identity:cleanroomsml_list_audience_models]{list_audience_models} \tab Returns a list of audience models\cr
#'  \link[paws.security.identity:cleanroomsml_list_collaboration_configured_model_algorithm_associations]{list_collaboration_configured_model_algorithm_associations} \tab Returns a list of the configured model algorithm associations in a collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_list_collaboration_ml_input_channels]{list_collaboration_ml_input_channels} \tab Returns a list of the ML input channels in a collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_list_collaboration_trained_model_export_jobs]{list_collaboration_trained_model_export_jobs} \tab Returns a list of the export jobs for a trained model in a collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_list_collaboration_trained_model_inference_jobs]{list_collaboration_trained_model_inference_jobs} \tab Returns a list of trained model inference jobs in a specified collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_list_collaboration_trained_models]{list_collaboration_trained_models} \tab Returns a list of the trained models in a collaboration\cr
#'  \link[paws.security.identity:cleanroomsml_list_configured_audience_models]{list_configured_audience_models} \tab Returns a list of the configured audience models\cr
#'  \link[paws.security.identity:cleanroomsml_list_configured_model_algorithm_associations]{list_configured_model_algorithm_associations} \tab Returns a list of configured model algorithm associations\cr
#'  \link[paws.security.identity:cleanroomsml_list_configured_model_algorithms]{list_configured_model_algorithms} \tab Returns a list of configured model algorithms\cr
#'  \link[paws.security.identity:cleanroomsml_list_ml_input_channels]{list_ml_input_channels} \tab Returns a list of ML input channels\cr
#'  \link[paws.security.identity:cleanroomsml_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags for a provided resource\cr
#'  \link[paws.security.identity:cleanroomsml_list_trained_model_inference_jobs]{list_trained_model_inference_jobs} \tab Returns a list of trained model inference jobs that match the request parameters\cr
#'  \link[paws.security.identity:cleanroomsml_list_trained_models]{list_trained_models} \tab Returns a list of trained models\cr
#'  \link[paws.security.identity:cleanroomsml_list_training_datasets]{list_training_datasets} \tab Returns a list of training datasets\cr
#'  \link[paws.security.identity:cleanroomsml_put_configured_audience_model_policy]{put_configured_audience_model_policy} \tab Create or update the resource policy for a configured audience model\cr
#'  \link[paws.security.identity:cleanroomsml_put_ml_configuration]{put_ml_configuration} \tab Assigns information about an ML configuration\cr
#'  \link[paws.security.identity:cleanroomsml_start_audience_export_job]{start_audience_export_job} \tab Export an audience of a specified size after you have generated an audience\cr
#'  \link[paws.security.identity:cleanroomsml_start_audience_generation_job]{start_audience_generation_job} \tab Information necessary to start the audience generation job\cr
#'  \link[paws.security.identity:cleanroomsml_start_trained_model_export_job]{start_trained_model_export_job} \tab Provides the information necessary to start a trained model export job\cr
#'  \link[paws.security.identity:cleanroomsml_start_trained_model_inference_job]{start_trained_model_inference_job} \tab Defines the information necessary to begin a trained model inference job\cr
#'  \link[paws.security.identity:cleanroomsml_tag_resource]{tag_resource} \tab Adds metadata tags to a specified resource\cr
#'  \link[paws.security.identity:cleanroomsml_untag_resource]{untag_resource} \tab Removes metadata tags from a specified resource\cr
#'  \link[paws.security.identity:cleanroomsml_update_configured_audience_model]{update_configured_audience_model} \tab Provides the information necessary to update a configured audience model
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cleanroomsml
#' @export
cleanroomsml <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::cleanroomsml(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudDirectory
#'
#' @description
#' Amazon Cloud Directory
#' 
#' Amazon Cloud Directory is a component of the AWS Directory Service that
#' simplifies the development and management of cloud-scale web, mobile,
#' and IoT applications. This guide describes the Cloud Directory
#' operations that you can call programmatically and includes detailed
#' information on data types and errors. For information about Cloud
#' Directory features, see [AWS Directory
#' Service](https://aws.amazon.com/directoryservice/) and the [Amazon Cloud
#' Directory Developer
#' Guide](https://docs.aws.amazon.com/clouddirectory/latest/developerguide/what_is_cloud_directory.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- clouddirectory(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- clouddirectory()
#' svc$add_facet_to_object(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:clouddirectory_add_facet_to_object]{add_facet_to_object} \tab Adds a new Facet to an object\cr
#'  \link[paws.security.identity:clouddirectory_apply_schema]{apply_schema} \tab Copies the input published schema, at the specified version, into the Directory with the same name and version as that of the published schema\cr
#'  \link[paws.security.identity:clouddirectory_attach_object]{attach_object} \tab Attaches an existing object to another object\cr
#'  \link[paws.security.identity:clouddirectory_attach_policy]{attach_policy} \tab Attaches a policy object to a regular object\cr
#'  \link[paws.security.identity:clouddirectory_attach_to_index]{attach_to_index} \tab Attaches the specified object to the specified index\cr
#'  \link[paws.security.identity:clouddirectory_attach_typed_link]{attach_typed_link} \tab Attaches a typed link to a specified source and target object\cr
#'  \link[paws.security.identity:clouddirectory_batch_read]{batch_read} \tab Performs all the read operations in a batch\cr
#'  \link[paws.security.identity:clouddirectory_batch_write]{batch_write} \tab Performs all the write operations in a batch\cr
#'  \link[paws.security.identity:clouddirectory_create_directory]{create_directory} \tab Creates a Directory by copying the published schema into the directory\cr
#'  \link[paws.security.identity:clouddirectory_create_facet]{create_facet} \tab Creates a new Facet in a schema\cr
#'  \link[paws.security.identity:clouddirectory_create_index]{create_index} \tab Creates an index object\cr
#'  \link[paws.security.identity:clouddirectory_create_object]{create_object} \tab Creates an object in a Directory\cr
#'  \link[paws.security.identity:clouddirectory_create_schema]{create_schema} \tab Creates a new schema in a development state\cr
#'  \link[paws.security.identity:clouddirectory_create_typed_link_facet]{create_typed_link_facet} \tab Creates a TypedLinkFacet\cr
#'  \link[paws.security.identity:clouddirectory_delete_directory]{delete_directory} \tab Deletes a directory\cr
#'  \link[paws.security.identity:clouddirectory_delete_facet]{delete_facet} \tab Deletes a given Facet\cr
#'  \link[paws.security.identity:clouddirectory_delete_object]{delete_object} \tab Deletes an object and its associated attributes\cr
#'  \link[paws.security.identity:clouddirectory_delete_schema]{delete_schema} \tab Deletes a given schema\cr
#'  \link[paws.security.identity:clouddirectory_delete_typed_link_facet]{delete_typed_link_facet} \tab Deletes a TypedLinkFacet\cr
#'  \link[paws.security.identity:clouddirectory_detach_from_index]{detach_from_index} \tab Detaches the specified object from the specified index\cr
#'  \link[paws.security.identity:clouddirectory_detach_object]{detach_object} \tab Detaches a given object from the parent object\cr
#'  \link[paws.security.identity:clouddirectory_detach_policy]{detach_policy} \tab Detaches a policy from an object\cr
#'  \link[paws.security.identity:clouddirectory_detach_typed_link]{detach_typed_link} \tab Detaches a typed link from a specified source and target object\cr
#'  \link[paws.security.identity:clouddirectory_disable_directory]{disable_directory} \tab Disables the specified directory\cr
#'  \link[paws.security.identity:clouddirectory_enable_directory]{enable_directory} \tab Enables the specified directory\cr
#'  \link[paws.security.identity:clouddirectory_get_applied_schema_version]{get_applied_schema_version} \tab Returns current applied schema version ARN, including the minor version in use\cr
#'  \link[paws.security.identity:clouddirectory_get_directory]{get_directory} \tab Retrieves metadata about a directory\cr
#'  \link[paws.security.identity:clouddirectory_get_facet]{get_facet} \tab Gets details of the Facet, such as facet name, attributes, Rules, or ObjectType\cr
#'  \link[paws.security.identity:clouddirectory_get_link_attributes]{get_link_attributes} \tab Retrieves attributes that are associated with a typed link\cr
#'  \link[paws.security.identity:clouddirectory_get_object_attributes]{get_object_attributes} \tab Retrieves attributes within a facet that are associated with an object\cr
#'  \link[paws.security.identity:clouddirectory_get_object_information]{get_object_information} \tab Retrieves metadata about an object\cr
#'  \link[paws.security.identity:clouddirectory_get_schema_as_json]{get_schema_as_json} \tab Retrieves a JSON representation of the schema\cr
#'  \link[paws.security.identity:clouddirectory_get_typed_link_facet_information]{get_typed_link_facet_information} \tab Returns the identity attribute order for a specific TypedLinkFacet\cr
#'  \link[paws.security.identity:clouddirectory_list_applied_schema_arns]{list_applied_schema_arns} \tab Lists schema major versions applied to a directory\cr
#'  \link[paws.security.identity:clouddirectory_list_attached_indices]{list_attached_indices} \tab Lists indices attached to the specified object\cr
#'  \link[paws.security.identity:clouddirectory_list_development_schema_arns]{list_development_schema_arns} \tab Retrieves each Amazon Resource Name (ARN) of schemas in the development state\cr
#'  \link[paws.security.identity:clouddirectory_list_directories]{list_directories} \tab Lists directories created within an account\cr
#'  \link[paws.security.identity:clouddirectory_list_facet_attributes]{list_facet_attributes} \tab Retrieves attributes attached to the facet\cr
#'  \link[paws.security.identity:clouddirectory_list_facet_names]{list_facet_names} \tab Retrieves the names of facets that exist in a schema\cr
#'  \link[paws.security.identity:clouddirectory_list_incoming_typed_links]{list_incoming_typed_links} \tab Returns a paginated list of all the incoming TypedLinkSpecifier information for an object\cr
#'  \link[paws.security.identity:clouddirectory_list_index]{list_index} \tab Lists objects attached to the specified index\cr
#'  \link[paws.security.identity:clouddirectory_list_managed_schema_arns]{list_managed_schema_arns} \tab Lists the major version families of each managed schema\cr
#'  \link[paws.security.identity:clouddirectory_list_object_attributes]{list_object_attributes} \tab Lists all attributes that are associated with an object\cr
#'  \link[paws.security.identity:clouddirectory_list_object_children]{list_object_children} \tab Returns a paginated list of child objects that are associated with a given object\cr
#'  \link[paws.security.identity:clouddirectory_list_object_parent_paths]{list_object_parent_paths} \tab Retrieves all available parent paths for any object type such as node, leaf node, policy node, and index node objects\cr
#'  \link[paws.security.identity:clouddirectory_list_object_parents]{list_object_parents} \tab Lists parent objects that are associated with a given object in pagination fashion\cr
#'  \link[paws.security.identity:clouddirectory_list_object_policies]{list_object_policies} \tab Returns policies attached to an object in pagination fashion\cr
#'  \link[paws.security.identity:clouddirectory_list_outgoing_typed_links]{list_outgoing_typed_links} \tab Returns a paginated list of all the outgoing TypedLinkSpecifier information for an object\cr
#'  \link[paws.security.identity:clouddirectory_list_policy_attachments]{list_policy_attachments} \tab Returns all of the ObjectIdentifiers to which a given policy is attached\cr
#'  \link[paws.security.identity:clouddirectory_list_published_schema_arns]{list_published_schema_arns} \tab Lists the major version families of each published schema\cr
#'  \link[paws.security.identity:clouddirectory_list_tags_for_resource]{list_tags_for_resource} \tab Returns tags for a resource\cr
#'  \link[paws.security.identity:clouddirectory_list_typed_link_facet_attributes]{list_typed_link_facet_attributes} \tab Returns a paginated list of all attribute definitions for a particular TypedLinkFacet\cr
#'  \link[paws.security.identity:clouddirectory_list_typed_link_facet_names]{list_typed_link_facet_names} \tab Returns a paginated list of TypedLink facet names for a particular schema\cr
#'  \link[paws.security.identity:clouddirectory_lookup_policy]{lookup_policy} \tab Lists all policies from the root of the Directory to the object specified\cr
#'  \link[paws.security.identity:clouddirectory_publish_schema]{publish_schema} \tab Publishes a development schema with a major version and a recommended minor version\cr
#'  \link[paws.security.identity:clouddirectory_put_schema_from_json]{put_schema_from_json} \tab Allows a schema to be updated using JSON upload\cr
#'  \link[paws.security.identity:clouddirectory_remove_facet_from_object]{remove_facet_from_object} \tab Removes the specified facet from the specified object\cr
#'  \link[paws.security.identity:clouddirectory_tag_resource]{tag_resource} \tab An API operation for adding tags to a resource\cr
#'  \link[paws.security.identity:clouddirectory_untag_resource]{untag_resource} \tab An API operation for removing tags from a resource\cr
#'  \link[paws.security.identity:clouddirectory_update_facet]{update_facet} \tab Does the following:\cr
#'  \link[paws.security.identity:clouddirectory_update_link_attributes]{update_link_attributes} \tab Updates a given typed link’s attributes\cr
#'  \link[paws.security.identity:clouddirectory_update_object_attributes]{update_object_attributes} \tab Updates a given object's attributes\cr
#'  \link[paws.security.identity:clouddirectory_update_schema]{update_schema} \tab Updates the schema name with a new name\cr
#'  \link[paws.security.identity:clouddirectory_update_typed_link_facet]{update_typed_link_facet} \tab Updates a TypedLinkFacet\cr
#'  \link[paws.security.identity:clouddirectory_upgrade_applied_schema]{upgrade_applied_schema} \tab Upgrades a single directory in-place using the PublishedSchemaArn with schema updates found in MinorVersion\cr
#'  \link[paws.security.identity:clouddirectory_upgrade_published_schema]{upgrade_published_schema} \tab Upgrades a published schema under a new minor version revision using the current contents of DevelopmentSchemaArn
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname clouddirectory
#' @export
clouddirectory <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::clouddirectory(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon CloudHSM
#'
#' @description
#' AWS CloudHSM Service
#' 
#' This is documentation for **AWS CloudHSM Classic**. For more
#' information, see [AWS CloudHSM Classic
#' FAQs](https://aws.amazon.com/cloudhsm/faqs/), the AWS CloudHSM Classic
#' User Guide, and the [AWS CloudHSM Classic API
#' Reference](https://docs.aws.amazon.com/cloudhsm/classic/APIReference/).
#' 
#' **For information about the current version of AWS CloudHSM**, see [AWS
#' CloudHSM](https://aws.amazon.com/cloudhsm/), the [AWS CloudHSM User
#' Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/), and the
#' [AWS CloudHSM API
#' Reference](https://docs.aws.amazon.com/cloudhsm/latest/APIReference/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudhsm(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudhsm()
#' svc$add_tags_to_resource(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:cloudhsm_add_tags_to_resource]{add_tags_to_resource} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_create_hapg]{create_hapg} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_create_hsm]{create_hsm} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_create_luna_client]{create_luna_client} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_delete_hapg]{delete_hapg} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_delete_hsm]{delete_hsm} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_delete_luna_client]{delete_luna_client} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_describe_hapg]{describe_hapg} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_describe_hsm]{describe_hsm} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_describe_luna_client]{describe_luna_client} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_get_config]{get_config} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_list_available_zones]{list_available_zones} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_list_hapgs]{list_hapgs} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_list_hsms]{list_hsms} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_list_luna_clients]{list_luna_clients} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_list_tags_for_resource]{list_tags_for_resource} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_modify_hapg]{modify_hapg} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_modify_hsm]{modify_hsm} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_modify_luna_client]{modify_luna_client} \tab This is documentation for AWS CloudHSM Classic\cr
#'  \link[paws.security.identity:cloudhsm_remove_tags_from_resource]{remove_tags_from_resource} \tab This is documentation for AWS CloudHSM Classic
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudhsm
#' @export
cloudhsm <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::cloudhsm(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS CloudHSM V2
#'
#' @description
#' For more information about CloudHSM, see
#' [CloudHSM](https://aws.amazon.com/cloudhsm/) and the [CloudHSM User
#' Guide](https://docs.aws.amazon.com/cloudhsm/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cloudhsmv2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cloudhsmv2()
#' svc$copy_backup_to_region(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:cloudhsmv2_copy_backup_to_region]{copy_backup_to_region} \tab Copy an CloudHSM cluster backup to a different region\cr
#'  \link[paws.security.identity:cloudhsmv2_create_cluster]{create_cluster} \tab Creates a new CloudHSM cluster\cr
#'  \link[paws.security.identity:cloudhsmv2_create_hsm]{create_hsm} \tab Creates a new hardware security module (HSM) in the specified CloudHSM cluster\cr
#'  \link[paws.security.identity:cloudhsmv2_delete_backup]{delete_backup} \tab Deletes a specified CloudHSM backup\cr
#'  \link[paws.security.identity:cloudhsmv2_delete_cluster]{delete_cluster} \tab Deletes the specified CloudHSM cluster\cr
#'  \link[paws.security.identity:cloudhsmv2_delete_hsm]{delete_hsm} \tab Deletes the specified HSM\cr
#'  \link[paws.security.identity:cloudhsmv2_delete_resource_policy]{delete_resource_policy} \tab Deletes an CloudHSM resource policy\cr
#'  \link[paws.security.identity:cloudhsmv2_describe_backups]{describe_backups} \tab Gets information about backups of CloudHSM clusters\cr
#'  \link[paws.security.identity:cloudhsmv2_describe_clusters]{describe_clusters} \tab Gets information about CloudHSM clusters\cr
#'  \link[paws.security.identity:cloudhsmv2_get_resource_policy]{get_resource_policy} \tab Retrieves the resource policy document attached to a given resource\cr
#'  \link[paws.security.identity:cloudhsmv2_initialize_cluster]{initialize_cluster} \tab Claims an CloudHSM cluster by submitting the cluster certificate issued by your issuing certificate authority (CA) and the CA's root certificate\cr
#'  \link[paws.security.identity:cloudhsmv2_list_tags]{list_tags} \tab Gets a list of tags for the specified CloudHSM cluster\cr
#'  \link[paws.security.identity:cloudhsmv2_modify_backup_attributes]{modify_backup_attributes} \tab Modifies attributes for CloudHSM backup\cr
#'  \link[paws.security.identity:cloudhsmv2_modify_cluster]{modify_cluster} \tab Modifies CloudHSM cluster\cr
#'  \link[paws.security.identity:cloudhsmv2_put_resource_policy]{put_resource_policy} \tab Creates or updates an CloudHSM resource policy\cr
#'  \link[paws.security.identity:cloudhsmv2_restore_backup]{restore_backup} \tab Restores a specified CloudHSM backup that is in the PENDING_DELETION state\cr
#'  \link[paws.security.identity:cloudhsmv2_tag_resource]{tag_resource} \tab Adds or overwrites one or more tags for the specified CloudHSM cluster\cr
#'  \link[paws.security.identity:cloudhsmv2_untag_resource]{untag_resource} \tab Removes the specified tag or tags from the specified CloudHSM cluster
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cloudhsmv2
#' @export
cloudhsmv2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::cloudhsmv2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Cognito Identity
#'
#' @description
#' Amazon Cognito Federated Identities
#' 
#' Amazon Cognito Federated Identities is a web service that delivers
#' scoped temporary credentials to mobile devices and other untrusted
#' environments. It uniquely identifies a device and supplies the user with
#' a consistent identity over the lifetime of an application.
#' 
#' Using Amazon Cognito Federated Identities, you can enable authentication
#' with one or more third-party identity providers (Facebook, Google, or
#' Login with Amazon) or an Amazon Cognito user pool, and you can also
#' choose to support unauthenticated access from your app. Cognito delivers
#' a unique identifier for each user and acts as an OpenID token provider
#' trusted by AWS Security Token Service (STS) to access temporary,
#' limited-privilege AWS credentials.
#' 
#' For a description of the authentication flow from the Amazon Cognito
#' Developer Guide see [Authentication
#' Flow](https://docs.aws.amazon.com/cognito/latest/developerguide/authentication-flow.html).
#' 
#' For more information see [Amazon Cognito Federated
#' Identities](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-identity.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cognitoidentity(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cognitoidentity()
#' svc$create_identity_pool(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:cognitoidentity_create_identity_pool]{create_identity_pool} \tab Creates a new identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_delete_identities]{delete_identities} \tab Deletes identities from an identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_delete_identity_pool]{delete_identity_pool} \tab Deletes an identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_describe_identity]{describe_identity} \tab Returns metadata related to the given identity, including when the identity was created and any associated linked logins\cr
#'  \link[paws.security.identity:cognitoidentity_describe_identity_pool]{describe_identity_pool} \tab Gets details about a particular identity pool, including the pool name, ID description, creation date, and current number of users\cr
#'  \link[paws.security.identity:cognitoidentity_get_credentials_for_identity]{get_credentials_for_identity} \tab Returns credentials for the provided identity ID\cr
#'  \link[paws.security.identity:cognitoidentity_get_id]{get_id} \tab Generates (or retrieves) a Cognito ID\cr
#'  \link[paws.security.identity:cognitoidentity_get_identity_pool_roles]{get_identity_pool_roles} \tab Gets the roles for an identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_get_open_id_token]{get_open_id_token} \tab Gets an OpenID token, using a known Cognito ID\cr
#'  \link[paws.security.identity:cognitoidentity_get_open_id_token_for_developer_identity]{get_open_id_token_for_developer_identity} \tab Registers (or retrieves) a Cognito IdentityId and an OpenID Connect token for a user authenticated by your backend authentication process\cr
#'  \link[paws.security.identity:cognitoidentity_get_principal_tag_attribute_map]{get_principal_tag_attribute_map} \tab Use GetPrincipalTagAttributeMap to list all mappings between PrincipalTags and user attributes\cr
#'  \link[paws.security.identity:cognitoidentity_list_identities]{list_identities} \tab Lists the identities in an identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_list_identity_pools]{list_identity_pools} \tab Lists all of the Cognito identity pools registered for your account\cr
#'  \link[paws.security.identity:cognitoidentity_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that are assigned to an Amazon Cognito identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_lookup_developer_identity]{lookup_developer_identity} \tab Retrieves the IdentityID associated with a DeveloperUserIdentifier or the list of DeveloperUserIdentifier values associated with an IdentityId for an existing identity\cr
#'  \link[paws.security.identity:cognitoidentity_merge_developer_identities]{merge_developer_identities} \tab Merges two users having different IdentityIds, existing in the same identity pool, and identified by the same developer provider\cr
#'  \link[paws.security.identity:cognitoidentity_set_identity_pool_roles]{set_identity_pool_roles} \tab Sets the roles for an identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_set_principal_tag_attribute_map]{set_principal_tag_attribute_map} \tab You can use this operation to use default (username and clientID) attribute or custom attribute mappings\cr
#'  \link[paws.security.identity:cognitoidentity_tag_resource]{tag_resource} \tab Assigns a set of tags to the specified Amazon Cognito identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_unlink_developer_identity]{unlink_developer_identity} \tab Unlinks a DeveloperUserIdentifier from an existing identity\cr
#'  \link[paws.security.identity:cognitoidentity_unlink_identity]{unlink_identity} \tab Unlinks a federated identity from an existing account\cr
#'  \link[paws.security.identity:cognitoidentity_untag_resource]{untag_resource} \tab Removes the specified tags from the specified Amazon Cognito identity pool\cr
#'  \link[paws.security.identity:cognitoidentity_update_identity_pool]{update_identity_pool} \tab Updates an identity pool
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cognitoidentity
#' @export
cognitoidentity <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::cognitoidentity(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Cognito Identity Provider
#'
#' @description
#' With the Amazon Cognito user pools API, you can configure user pools and
#' authenticate users. To authenticate users from third-party identity
#' providers (IdPs) in this API, you can [link IdP users to native user
#' profiles](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-identity-federation-consolidate-users.html).
#' Learn more about the authentication and authorization of federated users
#' at [Adding user pool sign-in through a third
#' party](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-identity-federation.html)
#' and in the [User pool federation endpoints and hosted UI
#' reference](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-userpools-server-contract-reference.html).
#' 
#' This API reference provides detailed information about API operations
#' and object types in Amazon Cognito.
#' 
#' Along with resource management operations, the Amazon Cognito user pools
#' API includes classes of operations and authorization models for
#' client-side and server-side authentication of users. You can interact
#' with operations in the Amazon Cognito user pools API as any of the
#' following subjects.
#' 
#' 1.  An administrator who wants to configure user pools, app clients,
#'     users, groups, or other user pool functions.
#' 
#' 2.  A server-side app, like a web application, that wants to use its
#'     Amazon Web Services privileges to manage, authenticate, or authorize
#'     a user.
#' 
#' 3.  A client-side app, like a mobile app, that wants to make
#'     unauthenticated requests to manage, authenticate, or authorize a
#'     user.
#' 
#' For more information, see [Using the Amazon Cognito user pools API and
#' user pool
#' endpoints](https://docs.aws.amazon.com/cognito/latest/developerguide/authentication-flows-public-server-side.html)
#' in the *Amazon Cognito Developer Guide*.
#' 
#' With your Amazon Web Services SDK, you can build the logic to support
#' operational flows in every use case for this API. You can also make
#' direct REST API requests to [Amazon Cognito user pools service
#' endpoints](https://docs.aws.amazon.com/general/latest/gr/cognito_identity.html#cognito_identity_your_user_pools_region).
#' The following links can get you started with the
#' `CognitoIdentityProvider` client in other supported Amazon Web Services
#' SDKs.
#' 
#' -   [Amazon Web Services Command Line
#'     Interface](https://docs.aws.amazon.com/cli/latest/reference/cognito-idp/#cli-aws-cognito-idp)
#' 
#' -   [Amazon Web Services SDK for
#'     .NET](https://docs.aws.amazon.com/sdkfornet/v3/apidocs/items/CognitoIdentityProvider/TCognitoIdentityProviderClient.html)
#' 
#' -   [Amazon Web Services SDK for
#'     C++](https://sdk.amazonaws.com/cpp/api/LATEST/aws-cpp-sdk-cognito-idp/html/class_aws_1_1_cognito_identity_provider_1_1_cognito_identity_provider_client.html)
#' 
#' -   [Amazon Web Services SDK for
#'     Go](https://docs.aws.amazon.com/sdk-for-go/api/service/cognitoidentityprovider/#CognitoIdentityProvider)
#' 
#' -   [Amazon Web Services SDK for Java
#'     V2](https://sdk.amazonaws.com/java/api/latest/software/amazon/awssdk/services/cognitoidentityprovider/CognitoIdentityProviderClient.html)
#' 
#' -   [Amazon Web Services SDK for
#'     JavaScript](https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/AWS/CognitoIdentityServiceProvider.html)
#' 
#' -   [Amazon Web Services SDK for PHP
#'     V3](https://docs.aws.amazon.com/aws-sdk-php/v3/api/api-cognito-idp-2016-04-18.html)
#' 
#' -   [Amazon Web Services SDK for
#'     Python](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-idp.html)
#' 
#' -   [Amazon Web Services SDK for Ruby
#'     V3](https://docs.aws.amazon.com/sdk-for-ruby/v3/api/Aws/CognitoIdentityProvider/Client.html)
#' 
#' -   [Amazon Web Services SDK for
#'     Kotlin](https://sdk.amazonaws.com/kotlin/api/latest/cognitoidentityprovider/aws.sdk.kotlin.services.cognitoidentityprovider/-cognito-identity-provider-client/index.html)
#' 
#' To get started with an Amazon Web Services SDK, see [Tools to Build on
#' Amazon Web Services](https://aws.amazon.com/developer/tools/). For
#' example actions and scenarios, see [Code examples for Amazon Cognito
#' Identity Provider using Amazon Web Services
#' SDKs](https://docs.aws.amazon.com/cognito/latest/developerguide/service_code_examples_cognito-identity-provider.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cognitoidentityprovider(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cognitoidentityprovider()
#' svc$add_custom_attributes(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:cognitoidentityprovider_add_custom_attributes]{add_custom_attributes} \tab Adds additional user attributes to the user pool schema\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_add_user_to_group]{admin_add_user_to_group} \tab Adds a user to a group\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_confirm_sign_up]{admin_confirm_sign_up} \tab Confirms user sign-up as an administrator\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_create_user]{admin_create_user} \tab Creates a new user in the specified user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_delete_user]{admin_delete_user} \tab Deletes a user profile in your user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_delete_user_attributes]{admin_delete_user_attributes} \tab Deletes attribute values from a user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_disable_provider_for_user]{admin_disable_provider_for_user} \tab Prevents the user from signing in with the specified external (SAML or social) identity provider (IdP)\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_disable_user]{admin_disable_user} \tab Deactivates a user profile and revokes all access tokens for the user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_enable_user]{admin_enable_user} \tab Activate sign-in for a user profile that previously had sign-in access disabled\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_forget_device]{admin_forget_device} \tab Forgets, or deletes, a remembered device from a user's profile\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_get_device]{admin_get_device} \tab Given the device key, returns details for a user' device\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_get_user]{admin_get_user} \tab Given the username, returns details about a user profile in a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_initiate_auth]{admin_initiate_auth} \tab Starts sign-in for applications with a server-side component, for example a traditional web application\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_link_provider_for_user]{admin_link_provider_for_user} \tab Links an existing user account in a user pool (DestinationUser) to an identity from an external IdP (SourceUser) based on a specified attribute name and value from the external IdP\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_list_devices]{admin_list_devices} \tab Lists a user's registered devices\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_list_groups_for_user]{admin_list_groups_for_user} \tab Lists the groups that a user belongs to\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_list_user_auth_events]{admin_list_user_auth_events} \tab Requests a history of user activity and any risks detected as part of Amazon Cognito threat protection\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_remove_user_from_group]{admin_remove_user_from_group} \tab Given a username and a group name\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_reset_user_password]{admin_reset_user_password} \tab Resets the specified user's password in a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_respond_to_auth_challenge]{admin_respond_to_auth_challenge} \tab Some API operations in a user pool generate a challenge, like a prompt for an MFA code, for device authentication that bypasses MFA, or for a custom authentication challenge\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_set_user_mfa_preference]{admin_set_user_mfa_preference} \tab Sets the user's multi-factor authentication (MFA) preference, including which MFA options are activated, and if any are preferred\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_set_user_password]{admin_set_user_password} \tab Sets the specified user's password in a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_set_user_settings]{admin_set_user_settings} \tab This action is no longer supported\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_update_auth_event_feedback]{admin_update_auth_event_feedback} \tab Provides feedback for an authentication event indicating if it was from a valid user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_update_device_status]{admin_update_device_status} \tab Updates the status of a user's device so that it is marked as remembered or not remembered for the purpose of device authentication\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_update_user_attributes]{admin_update_user_attributes} \tab This action might generate an SMS text message\cr
#'  \link[paws.security.identity:cognitoidentityprovider_admin_user_global_sign_out]{admin_user_global_sign_out} \tab Invalidates the identity, access, and refresh tokens that Amazon Cognito issued to a user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_associate_software_token]{associate_software_token} \tab Begins setup of time-based one-time password (TOTP) multi-factor authentication (MFA) for a user, with a unique private key that Amazon Cognito generates and returns in the API response\cr
#'  \link[paws.security.identity:cognitoidentityprovider_change_password]{change_password} \tab Changes the password for a specified user in a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_complete_web_authn_registration]{complete_web_authn_registration} \tab Completes registration of a passkey authenticator for the current user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_confirm_device]{confirm_device} \tab Confirms a device that a user wants to remember\cr
#'  \link[paws.security.identity:cognitoidentityprovider_confirm_forgot_password]{confirm_forgot_password} \tab This public API operation accepts a confirmation code that Amazon Cognito sent to a user and accepts a new password for that user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_confirm_sign_up]{confirm_sign_up} \tab This public API operation submits a code that Amazon Cognito sent to your user when they signed up in your user pool via the SignUp API operation\cr
#'  \link[paws.security.identity:cognitoidentityprovider_create_group]{create_group} \tab Creates a new group in the specified user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_create_identity_provider]{create_identity_provider} \tab Adds a configuration and trust relationship between a third-party identity provider (IdP) and a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_create_managed_login_branding]{create_managed_login_branding} \tab Creates a new set of branding settings for a user pool style and associates it with an app client\cr
#'  \link[paws.security.identity:cognitoidentityprovider_create_resource_server]{create_resource_server} \tab Creates a new OAuth2\cr
#'  \link[paws.security.identity:cognitoidentityprovider_create_user_import_job]{create_user_import_job} \tab Creates a user import job\cr
#'  \link[paws.security.identity:cognitoidentityprovider_create_user_pool]{create_user_pool} \tab This action might generate an SMS text message\cr
#'  \link[paws.security.identity:cognitoidentityprovider_create_user_pool_client]{create_user_pool_client} \tab Creates an app client in a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_create_user_pool_domain]{create_user_pool_domain} \tab A user pool domain hosts managed login, an authorization server and web server for authentication in your application\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_group]{delete_group} \tab Deletes a group from the specified user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_identity_provider]{delete_identity_provider} \tab Deletes a user pool identity provider (IdP)\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_managed_login_branding]{delete_managed_login_branding} \tab Deletes a managed login branding style\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_resource_server]{delete_resource_server} \tab Deletes a resource server\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_user]{delete_user} \tab Self-deletes a user profile\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_user_attributes]{delete_user_attributes} \tab Self-deletes attributes for a user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_user_pool]{delete_user_pool} \tab Deletes a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_user_pool_client]{delete_user_pool_client} \tab Deletes a user pool app client\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_user_pool_domain]{delete_user_pool_domain} \tab Given a user pool ID and domain identifier, deletes a user pool domain\cr
#'  \link[paws.security.identity:cognitoidentityprovider_delete_web_authn_credential]{delete_web_authn_credential} \tab Deletes a registered passkey, or webauthN, authenticator for the currently signed-in user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_identity_provider]{describe_identity_provider} \tab Given a user pool ID and identity provider (IdP) name, returns details about the IdP\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_managed_login_branding]{describe_managed_login_branding} \tab Given the ID of a managed login branding style, returns detailed information about the style\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_managed_login_branding_by_client]{describe_managed_login_branding_by_client} \tab Given the ID of a user pool app client, returns detailed information about the style assigned to the app client\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_resource_server]{describe_resource_server} \tab Describes a resource server\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_risk_configuration]{describe_risk_configuration} \tab Given an app client or user pool ID where threat protection is configured, describes the risk configuration\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_user_import_job]{describe_user_import_job} \tab Describes a user import job\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_user_pool]{describe_user_pool} \tab Given a user pool ID, returns configuration information\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_user_pool_client]{describe_user_pool_client} \tab Given an app client ID, returns configuration information\cr
#'  \link[paws.security.identity:cognitoidentityprovider_describe_user_pool_domain]{describe_user_pool_domain} \tab Given a user pool domain name, returns information about the domain configuration\cr
#'  \link[paws.security.identity:cognitoidentityprovider_forget_device]{forget_device} \tab Forgets the specified device\cr
#'  \link[paws.security.identity:cognitoidentityprovider_forgot_password]{forgot_password} \tab Calling this API causes a message to be sent to the end user with a confirmation code that is required to change the user's password\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_csv_header]{get_csv_header} \tab Gets the header information for the comma-separated value (CSV) file to be used as input for the user import job\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_device]{get_device} \tab Gets the device\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_group]{get_group} \tab Gets a group\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_identity_provider_by_identifier]{get_identity_provider_by_identifier} \tab Gets the specified IdP\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_log_delivery_configuration]{get_log_delivery_configuration} \tab Gets the logging configuration of a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_signing_certificate]{get_signing_certificate} \tab This method takes a user pool ID, and returns the signing certificate\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_ui_customization]{get_ui_customization} \tab Gets the user interface (UI) Customization information for a particular app client's app UI, if any such information exists for the client\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_user]{get_user} \tab Gets the user attributes and metadata for a user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_user_attribute_verification_code]{get_user_attribute_verification_code} \tab Generates a user attribute verification code for the specified attribute name\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_user_auth_factors]{get_user_auth_factors} \tab Lists the authentication options for the currently signed-in user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_get_user_pool_mfa_config]{get_user_pool_mfa_config} \tab Gets the user pool multi-factor authentication (MFA) configuration\cr
#'  \link[paws.security.identity:cognitoidentityprovider_global_sign_out]{global_sign_out} \tab Invalidates the identity, access, and refresh tokens that Amazon Cognito issued to a user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_initiate_auth]{initiate_auth} \tab Initiates sign-in for a user in the Amazon Cognito user directory\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_devices]{list_devices} \tab Lists the sign-in devices that Amazon Cognito has registered to the current user\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_groups]{list_groups} \tab Lists the groups associated with a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_identity_providers]{list_identity_providers} \tab Lists information about all IdPs for a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_resource_servers]{list_resource_servers} \tab Lists the resource servers for a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that are assigned to an Amazon Cognito user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_user_import_jobs]{list_user_import_jobs} \tab Lists user import jobs for a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_user_pool_clients]{list_user_pool_clients} \tab Lists the clients that have been created for the specified user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_user_pools]{list_user_pools} \tab Lists the user pools associated with an Amazon Web Services account\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_users]{list_users} \tab Lists users and their basic details in a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_users_in_group]{list_users_in_group} \tab Lists the users in the specified group\cr
#'  \link[paws.security.identity:cognitoidentityprovider_list_web_authn_credentials]{list_web_authn_credentials} \tab Generates a list of the current user's registered passkey, or webauthN, credentials\cr
#'  \link[paws.security.identity:cognitoidentityprovider_resend_confirmation_code]{resend_confirmation_code} \tab Resends the confirmation (for confirmation of registration) to a specific user in the user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_respond_to_auth_challenge]{respond_to_auth_challenge} \tab Some API operations in a user pool generate a challenge, like a prompt for an MFA code, for device authentication that bypasses MFA, or for a custom authentication challenge\cr
#'  \link[paws.security.identity:cognitoidentityprovider_revoke_token]{revoke_token} \tab Revokes all of the access tokens generated by, and at the same time as, the specified refresh token\cr
#'  \link[paws.security.identity:cognitoidentityprovider_set_log_delivery_configuration]{set_log_delivery_configuration} \tab Sets up or modifies the logging configuration of a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_set_risk_configuration]{set_risk_configuration} \tab Configures actions on detected risks\cr
#'  \link[paws.security.identity:cognitoidentityprovider_set_ui_customization]{set_ui_customization} \tab Sets the user interface (UI) customization information for a user pool's built-in app UI\cr
#'  \link[paws.security.identity:cognitoidentityprovider_set_user_mfa_preference]{set_user_mfa_preference} \tab Set the user's multi-factor authentication (MFA) method preference, including which MFA factors are activated and if any are preferred\cr
#'  \link[paws.security.identity:cognitoidentityprovider_set_user_pool_mfa_config]{set_user_pool_mfa_config} \tab Sets the user pool multi-factor authentication (MFA) and passkey configuration\cr
#'  \link[paws.security.identity:cognitoidentityprovider_set_user_settings]{set_user_settings} \tab This action is no longer supported\cr
#'  \link[paws.security.identity:cognitoidentityprovider_sign_up]{sign_up} \tab Registers the user in the specified user pool and creates a user name, password, and user attributes\cr
#'  \link[paws.security.identity:cognitoidentityprovider_start_user_import_job]{start_user_import_job} \tab Starts the user import\cr
#'  \link[paws.security.identity:cognitoidentityprovider_start_web_authn_registration]{start_web_authn_registration} \tab Requests credential creation options from your user pool for registration of a passkey authenticator\cr
#'  \link[paws.security.identity:cognitoidentityprovider_stop_user_import_job]{stop_user_import_job} \tab Stops the user import job\cr
#'  \link[paws.security.identity:cognitoidentityprovider_tag_resource]{tag_resource} \tab Assigns a set of tags to an Amazon Cognito user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_untag_resource]{untag_resource} \tab Removes the specified tags from an Amazon Cognito user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_auth_event_feedback]{update_auth_event_feedback} \tab Provides the feedback for an authentication event, whether it was from a valid user or not\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_device_status]{update_device_status} \tab Updates the device status\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_group]{update_group} \tab Updates the specified group with the specified attributes\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_identity_provider]{update_identity_provider} \tab Updates IdP information for a user pool\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_managed_login_branding]{update_managed_login_branding} \tab Configures the branding settings for a user pool style\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_resource_server]{update_resource_server} \tab Updates the name and scopes of resource server\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_user_attributes]{update_user_attributes} \tab With this operation, your users can update one or more of their attributes with their own credentials\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_user_pool]{update_user_pool} \tab This action might generate an SMS text message\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_user_pool_client]{update_user_pool_client} \tab Updates the specified user pool app client with the specified attributes\cr
#'  \link[paws.security.identity:cognitoidentityprovider_update_user_pool_domain]{update_user_pool_domain} \tab A user pool domain hosts managed login, an authorization server and web server for authentication in your application\cr
#'  \link[paws.security.identity:cognitoidentityprovider_verify_software_token]{verify_software_token} \tab Use this API to register a user's entered time-based one-time password (TOTP) code and mark the user's software token MFA status as "verified" if successful\cr
#'  \link[paws.security.identity:cognitoidentityprovider_verify_user_attribute]{verify_user_attribute} \tab Verifies the specified user attributes in the user pool
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cognitoidentityprovider
#' @export
cognitoidentityprovider <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::cognitoidentityprovider(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Cognito Sync
#'
#' @description
#' Amazon Cognito Sync provides an AWS service and client library that
#' enable cross-device syncing of application-related user data. High-level
#' client libraries are available for both iOS and Android. You can use
#' these libraries to persist data locally so that it's available even if
#' the device is offline. Developer credentials don't need to be stored on
#' the mobile device to access the service. You can use Amazon Cognito to
#' obtain a normalized user ID and credentials. User data is persisted in a
#' dataset that can store up to 1 MB of key-value pairs, and you can have
#' up to 20 datasets per user identity.
#' 
#' With Amazon Cognito Sync, the data stored for each identity is
#' accessible only to credentials assigned to that identity. In order to
#' use the Cognito Sync service, you need to make API calls using
#' credentials retrieved with [Amazon Cognito Identity
#' service](https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/Welcome.html).
#' 
#' If you want to use Cognito Sync in an Android or iOS application, you
#' will probably want to make API calls via the AWS Mobile SDK. To learn
#' more, see the [Developer Guide for
#' Android](https://docs.amplify.aws/android/) and the [Developer Guide for
#' iOS](https://docs.amplify.aws/swift/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- cognitosync(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- cognitosync()
#' svc$bulk_publish(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:cognitosync_bulk_publish]{bulk_publish} \tab Initiates a bulk publish of all existing datasets for an Identity Pool to the configured stream\cr
#'  \link[paws.security.identity:cognitosync_delete_dataset]{delete_dataset} \tab Deletes the specific dataset\cr
#'  \link[paws.security.identity:cognitosync_describe_dataset]{describe_dataset} \tab Gets meta data about a dataset by identity and dataset name\cr
#'  \link[paws.security.identity:cognitosync_describe_identity_pool_usage]{describe_identity_pool_usage} \tab Gets usage details (for example, data storage) about a particular identity pool\cr
#'  \link[paws.security.identity:cognitosync_describe_identity_usage]{describe_identity_usage} \tab Gets usage information for an identity, including number of datasets and data usage\cr
#'  \link[paws.security.identity:cognitosync_get_bulk_publish_details]{get_bulk_publish_details} \tab Get the status of the last BulkPublish operation for an identity pool\cr
#'  \link[paws.security.identity:cognitosync_get_cognito_events]{get_cognito_events} \tab Gets the events and the corresponding Lambda functions associated with an identity pool\cr
#'  \link[paws.security.identity:cognitosync_get_identity_pool_configuration]{get_identity_pool_configuration} \tab Gets the configuration settings of an identity pool\cr
#'  \link[paws.security.identity:cognitosync_list_datasets]{list_datasets} \tab Lists datasets for an identity\cr
#'  \link[paws.security.identity:cognitosync_list_identity_pool_usage]{list_identity_pool_usage} \tab Gets a list of identity pools registered with Cognito\cr
#'  \link[paws.security.identity:cognitosync_list_records]{list_records} \tab Gets paginated records, optionally changed after a particular sync count for a dataset and identity\cr
#'  \link[paws.security.identity:cognitosync_register_device]{register_device} \tab Registers a device to receive push sync notifications\cr
#'  \link[paws.security.identity:cognitosync_set_cognito_events]{set_cognito_events} \tab Sets the AWS Lambda function for a given event type for an identity pool\cr
#'  \link[paws.security.identity:cognitosync_set_identity_pool_configuration]{set_identity_pool_configuration} \tab Sets the necessary configuration for push sync\cr
#'  \link[paws.security.identity:cognitosync_subscribe_to_dataset]{subscribe_to_dataset} \tab Subscribes to receive notifications when a dataset is modified by another device\cr
#'  \link[paws.security.identity:cognitosync_unsubscribe_from_dataset]{unsubscribe_from_dataset} \tab Unsubscribes from receiving notifications when a dataset is modified by another device\cr
#'  \link[paws.security.identity:cognitosync_update_records]{update_records} \tab Posts updates to records and adds and deletes records for a dataset and user
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname cognitosync
#' @export
cognitosync <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::cognitosync(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Detective
#'
#' @description
#' Detective uses machine learning and purpose-built visualizations to help
#' you to analyze and investigate security issues across your Amazon Web
#' Services (Amazon Web Services) workloads. Detective automatically
#' extracts time-based events such as login attempts, API calls, and
#' network traffic from CloudTrail and Amazon Virtual Private Cloud (Amazon
#' VPC) flow logs. It also extracts findings detected by Amazon GuardDuty.
#' 
#' The Detective API primarily supports the creation and management of
#' behavior graphs. A behavior graph contains the extracted data from a set
#' of member accounts, and is created and managed by an administrator
#' account.
#' 
#' To add a member account to the behavior graph, the administrator account
#' sends an invitation to the account. When the account accepts the
#' invitation, it becomes a member account in the behavior graph.
#' 
#' Detective is also integrated with Organizations. The organization
#' management account designates the Detective administrator account for
#' the organization. That account becomes the administrator account for the
#' organization behavior graph. The Detective administrator account is also
#' the delegated administrator account for Detective in Organizations.
#' 
#' The Detective administrator account can enable any organization account
#' as a member account in the organization behavior graph. The organization
#' accounts do not receive invitations. The Detective administrator account
#' can also invite other accounts to the organization behavior graph.
#' 
#' Every behavior graph is specific to a Region. You can only use the API
#' to manage behavior graphs that belong to the Region that is associated
#' with the currently selected endpoint.
#' 
#' The administrator account for a behavior graph can use the Detective API
#' to do the following:
#' 
#' -   Enable and disable Detective. Enabling Detective creates a new
#'     behavior graph.
#' 
#' -   View the list of member accounts in a behavior graph.
#' 
#' -   Add member accounts to a behavior graph.
#' 
#' -   Remove member accounts from a behavior graph.
#' 
#' -   Apply tags to a behavior graph.
#' 
#' The organization management account can use the Detective API to select
#' the delegated administrator for Detective.
#' 
#' The Detective administrator account for an organization can use the
#' Detective API to do the following:
#' 
#' -   Perform all of the functions of an administrator account.
#' 
#' -   Determine whether to automatically enable new organization accounts
#'     as member accounts in the organization behavior graph.
#' 
#' An invited member account can use the Detective API to do the following:
#' 
#' -   View the list of behavior graphs that they are invited to.
#' 
#' -   Accept an invitation to contribute to a behavior graph.
#' 
#' -   Decline an invitation to contribute to a behavior graph.
#' 
#' -   Remove their account from a behavior graph.
#' 
#' All API actions are logged as CloudTrail events. See [Logging Detective
#' API Calls with
#' CloudTrail](https://docs.aws.amazon.com/detective/latest/userguide/logging-using-cloudtrail.html).
#' 
#' We replaced the term "master account" with the term "administrator
#' account". An administrator account is used to centrally manage multiple
#' accounts. In the case of Detective, the administrator account manages
#' the accounts in their behavior graph.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- detective(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- detective()
#' svc$accept_invitation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:detective_accept_invitation]{accept_invitation} \tab Accepts an invitation for the member account to contribute data to a behavior graph\cr
#'  \link[paws.security.identity:detective_batch_get_graph_member_datasources]{batch_get_graph_member_datasources} \tab Gets data source package information for the behavior graph\cr
#'  \link[paws.security.identity:detective_batch_get_membership_datasources]{batch_get_membership_datasources} \tab Gets information on the data source package history for an account\cr
#'  \link[paws.security.identity:detective_create_graph]{create_graph} \tab Creates a new behavior graph for the calling account, and sets that account as the administrator account\cr
#'  \link[paws.security.identity:detective_create_members]{create_members} \tab CreateMembers is used to send invitations to accounts\cr
#'  \link[paws.security.identity:detective_delete_graph]{delete_graph} \tab Disables the specified behavior graph and queues it to be deleted\cr
#'  \link[paws.security.identity:detective_delete_members]{delete_members} \tab Removes the specified member accounts from the behavior graph\cr
#'  \link[paws.security.identity:detective_describe_organization_configuration]{describe_organization_configuration} \tab Returns information about the configuration for the organization behavior graph\cr
#'  \link[paws.security.identity:detective_disable_organization_admin_account]{disable_organization_admin_account} \tab Removes the Detective administrator account in the current Region\cr
#'  \link[paws.security.identity:detective_disassociate_membership]{disassociate_membership} \tab Removes the member account from the specified behavior graph\cr
#'  \link[paws.security.identity:detective_enable_organization_admin_account]{enable_organization_admin_account} \tab Designates the Detective administrator account for the organization in the current Region\cr
#'  \link[paws.security.identity:detective_get_investigation]{get_investigation} \tab Detective investigations lets you investigate IAM users and IAM roles using indicators of compromise\cr
#'  \link[paws.security.identity:detective_get_members]{get_members} \tab Returns the membership details for specified member accounts for a behavior graph\cr
#'  \link[paws.security.identity:detective_list_datasource_packages]{list_datasource_packages} \tab Lists data source packages in the behavior graph\cr
#'  \link[paws.security.identity:detective_list_graphs]{list_graphs} \tab Returns the list of behavior graphs that the calling account is an administrator account of\cr
#'  \link[paws.security.identity:detective_list_indicators]{list_indicators} \tab Gets the indicators from an investigation\cr
#'  \link[paws.security.identity:detective_list_investigations]{list_investigations} \tab Detective investigations lets you investigate IAM users and IAM roles using indicators of compromise\cr
#'  \link[paws.security.identity:detective_list_invitations]{list_invitations} \tab Retrieves the list of open and accepted behavior graph invitations for the member account\cr
#'  \link[paws.security.identity:detective_list_members]{list_members} \tab Retrieves the list of member accounts for a behavior graph\cr
#'  \link[paws.security.identity:detective_list_organization_admin_accounts]{list_organization_admin_accounts} \tab Returns information about the Detective administrator account for an organization\cr
#'  \link[paws.security.identity:detective_list_tags_for_resource]{list_tags_for_resource} \tab Returns the tag values that are assigned to a behavior graph\cr
#'  \link[paws.security.identity:detective_reject_invitation]{reject_invitation} \tab Rejects an invitation to contribute the account data to a behavior graph\cr
#'  \link[paws.security.identity:detective_start_investigation]{start_investigation} \tab Detective investigations lets you investigate IAM users and IAM roles using indicators of compromise\cr
#'  \link[paws.security.identity:detective_start_monitoring_member]{start_monitoring_member} \tab Sends a request to enable data ingest for a member account that has a status of ACCEPTED_BUT_DISABLED\cr
#'  \link[paws.security.identity:detective_tag_resource]{tag_resource} \tab Applies tag values to a behavior graph\cr
#'  \link[paws.security.identity:detective_untag_resource]{untag_resource} \tab Removes tags from a behavior graph\cr
#'  \link[paws.security.identity:detective_update_datasource_packages]{update_datasource_packages} \tab Starts a data source package for the Detective behavior graph\cr
#'  \link[paws.security.identity:detective_update_investigation_state]{update_investigation_state} \tab Updates the state of an investigation\cr
#'  \link[paws.security.identity:detective_update_organization_configuration]{update_organization_configuration} \tab Updates the configuration for the Organizations integration in the current Region
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname detective
#' @export
detective <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::detective(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Directory Service
#'
#' @description
#' Directory Service
#' 
#' Directory Service is a web service that makes it easy for you to setup
#' and run directories in the Amazon Web Services cloud, or connect your
#' Amazon Web Services resources with an existing self-managed Microsoft
#' Active Directory. This guide provides detailed information about
#' Directory Service operations, data types, parameters, and errors. For
#' information about Directory Services features, see [Directory
#' Service](https://aws.amazon.com/directoryservice/) and the [Directory
#' Service Administration
#' Guide](https://docs.aws.amazon.com/directoryservice/latest/admin-guide/what_is.html).
#' 
#' Amazon Web Services provides SDKs that consist of libraries and sample
#' code for various programming languages and platforms (Java, Ruby, .Net,
#' iOS, Android, etc.). The SDKs provide a convenient way to create
#' programmatic access to Directory Service and other Amazon Web Services
#' services. For more information about the Amazon Web Services SDKs,
#' including how to download and install them, see [Tools for Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- directoryservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- directoryservice()
#' svc$accept_shared_directory(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:directoryservice_accept_shared_directory]{accept_shared_directory} \tab Accepts a directory sharing request that was sent from the directory owner account\cr
#'  \link[paws.security.identity:directoryservice_add_ip_routes]{add_ip_routes} \tab If the DNS server for your self-managed domain uses a publicly addressable IP address, you must add a CIDR address block to correctly route traffic to and from your Microsoft AD on Amazon Web Services\cr
#'  \link[paws.security.identity:directoryservice_add_region]{add_region} \tab Adds two domain controllers in the specified Region for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_add_tags_to_resource]{add_tags_to_resource} \tab Adds or overwrites one or more tags for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_cancel_schema_extension]{cancel_schema_extension} \tab Cancels an in-progress schema extension to a Microsoft AD directory\cr
#'  \link[paws.security.identity:directoryservice_connect_directory]{connect_directory} \tab Creates an AD Connector to connect to a self-managed directory\cr
#'  \link[paws.security.identity:directoryservice_create_alias]{create_alias} \tab Creates an alias for a directory and assigns the alias to the directory\cr
#'  \link[paws.security.identity:directoryservice_create_computer]{create_computer} \tab Creates an Active Directory computer object in the specified directory\cr
#'  \link[paws.security.identity:directoryservice_create_conditional_forwarder]{create_conditional_forwarder} \tab Creates a conditional forwarder associated with your Amazon Web Services directory\cr
#'  \link[paws.security.identity:directoryservice_create_directory]{create_directory} \tab Creates a Simple AD directory\cr
#'  \link[paws.security.identity:directoryservice_create_log_subscription]{create_log_subscription} \tab Creates a subscription to forward real-time Directory Service domain controller security logs to the specified Amazon CloudWatch log group in your Amazon Web Services account\cr
#'  \link[paws.security.identity:directoryservice_create_microsoft_ad]{create_microsoft_ad} \tab Creates a Microsoft AD directory in the Amazon Web Services Cloud\cr
#'  \link[paws.security.identity:directoryservice_create_snapshot]{create_snapshot} \tab Creates a snapshot of a Simple AD or Microsoft AD directory in the Amazon Web Services cloud\cr
#'  \link[paws.security.identity:directoryservice_create_trust]{create_trust} \tab Directory Service for Microsoft Active Directory allows you to configure trust relationships\cr
#'  \link[paws.security.identity:directoryservice_delete_conditional_forwarder]{delete_conditional_forwarder} \tab Deletes a conditional forwarder that has been set up for your Amazon Web Services directory\cr
#'  \link[paws.security.identity:directoryservice_delete_directory]{delete_directory} \tab Deletes an Directory Service directory\cr
#'  \link[paws.security.identity:directoryservice_delete_log_subscription]{delete_log_subscription} \tab Deletes the specified log subscription\cr
#'  \link[paws.security.identity:directoryservice_delete_snapshot]{delete_snapshot} \tab Deletes a directory snapshot\cr
#'  \link[paws.security.identity:directoryservice_delete_trust]{delete_trust} \tab Deletes an existing trust relationship between your Managed Microsoft AD directory and an external domain\cr
#'  \link[paws.security.identity:directoryservice_deregister_certificate]{deregister_certificate} \tab Deletes from the system the certificate that was registered for secure LDAP or client certificate authentication\cr
#'  \link[paws.security.identity:directoryservice_deregister_event_topic]{deregister_event_topic} \tab Removes the specified directory as a publisher to the specified Amazon SNS topic\cr
#'  \link[paws.security.identity:directoryservice_describe_certificate]{describe_certificate} \tab Displays information about the certificate registered for secure LDAP or client certificate authentication\cr
#'  \link[paws.security.identity:directoryservice_describe_client_authentication_settings]{describe_client_authentication_settings} \tab Retrieves information about the type of client authentication for the specified directory, if the type is specified\cr
#'  \link[paws.security.identity:directoryservice_describe_conditional_forwarders]{describe_conditional_forwarders} \tab Obtains information about the conditional forwarders for this account\cr
#'  \link[paws.security.identity:directoryservice_describe_directories]{describe_directories} \tab Obtains information about the directories that belong to this account\cr
#'  \link[paws.security.identity:directoryservice_describe_directory_data_access]{describe_directory_data_access} \tab Obtains status of directory data access enablement through the Directory Service Data API for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_describe_domain_controllers]{describe_domain_controllers} \tab Provides information about any domain controllers in your directory\cr
#'  \link[paws.security.identity:directoryservice_describe_event_topics]{describe_event_topics} \tab Obtains information about which Amazon SNS topics receive status messages from the specified directory\cr
#'  \link[paws.security.identity:directoryservice_describe_ldaps_settings]{describe_ldaps_settings} \tab Describes the status of LDAP security for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_describe_regions]{describe_regions} \tab Provides information about the Regions that are configured for multi-Region replication\cr
#'  \link[paws.security.identity:directoryservice_describe_settings]{describe_settings} \tab Retrieves information about the configurable settings for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_describe_shared_directories]{describe_shared_directories} \tab Returns the shared directories in your account\cr
#'  \link[paws.security.identity:directoryservice_describe_snapshots]{describe_snapshots} \tab Obtains information about the directory snapshots that belong to this account\cr
#'  \link[paws.security.identity:directoryservice_describe_trusts]{describe_trusts} \tab Obtains information about the trust relationships for this account\cr
#'  \link[paws.security.identity:directoryservice_describe_update_directory]{describe_update_directory} \tab Describes the updates of a directory for a particular update type\cr
#'  \link[paws.security.identity:directoryservice_disable_client_authentication]{disable_client_authentication} \tab Disables alternative client authentication methods for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_disable_directory_data_access]{disable_directory_data_access} \tab Deactivates access to directory data via the Directory Service Data API for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_disable_ldaps]{disable_ldaps} \tab Deactivates LDAP secure calls for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_disable_radius]{disable_radius} \tab Disables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory\cr
#'  \link[paws.security.identity:directoryservice_disable_sso]{disable_sso} \tab Disables single-sign on for a directory\cr
#'  \link[paws.security.identity:directoryservice_enable_client_authentication]{enable_client_authentication} \tab Enables alternative client authentication methods for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_enable_directory_data_access]{enable_directory_data_access} \tab Enables access to directory data via the Directory Service Data API for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_enable_ldaps]{enable_ldaps} \tab Activates the switch for the specific directory to always use LDAP secure calls\cr
#'  \link[paws.security.identity:directoryservice_enable_radius]{enable_radius} \tab Enables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector or Microsoft AD directory\cr
#'  \link[paws.security.identity:directoryservice_enable_sso]{enable_sso} \tab Enables single sign-on for a directory\cr
#'  \link[paws.security.identity:directoryservice_get_directory_limits]{get_directory_limits} \tab Obtains directory limit information for the current Region\cr
#'  \link[paws.security.identity:directoryservice_get_snapshot_limits]{get_snapshot_limits} \tab Obtains the manual snapshot limits for a directory\cr
#'  \link[paws.security.identity:directoryservice_list_certificates]{list_certificates} \tab For the specified directory, lists all the certificates registered for a secure LDAP or client certificate authentication\cr
#'  \link[paws.security.identity:directoryservice_list_ip_routes]{list_ip_routes} \tab Lists the address blocks that you have added to a directory\cr
#'  \link[paws.security.identity:directoryservice_list_log_subscriptions]{list_log_subscriptions} \tab Lists the active log subscriptions for the Amazon Web Services account\cr
#'  \link[paws.security.identity:directoryservice_list_schema_extensions]{list_schema_extensions} \tab Lists all schema extensions applied to a Microsoft AD Directory\cr
#'  \link[paws.security.identity:directoryservice_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags on a directory\cr
#'  \link[paws.security.identity:directoryservice_register_certificate]{register_certificate} \tab Registers a certificate for a secure LDAP or client certificate authentication\cr
#'  \link[paws.security.identity:directoryservice_register_event_topic]{register_event_topic} \tab Associates a directory with an Amazon SNS topic\cr
#'  \link[paws.security.identity:directoryservice_reject_shared_directory]{reject_shared_directory} \tab Rejects a directory sharing request that was sent from the directory owner account\cr
#'  \link[paws.security.identity:directoryservice_remove_ip_routes]{remove_ip_routes} \tab Removes IP address blocks from a directory\cr
#'  \link[paws.security.identity:directoryservice_remove_region]{remove_region} \tab Stops all replication and removes the domain controllers from the specified Region\cr
#'  \link[paws.security.identity:directoryservice_remove_tags_from_resource]{remove_tags_from_resource} \tab Removes tags from a directory\cr
#'  \link[paws.security.identity:directoryservice_reset_user_password]{reset_user_password} \tab Resets the password for any user in your Managed Microsoft AD or Simple AD directory\cr
#'  \link[paws.security.identity:directoryservice_restore_from_snapshot]{restore_from_snapshot} \tab Restores a directory using an existing directory snapshot\cr
#'  \link[paws.security.identity:directoryservice_share_directory]{share_directory} \tab Shares a specified directory (DirectoryId) in your Amazon Web Services account (directory owner) with another Amazon Web Services account (directory consumer)\cr
#'  \link[paws.security.identity:directoryservice_start_schema_extension]{start_schema_extension} \tab Applies a schema extension to a Microsoft AD directory\cr
#'  \link[paws.security.identity:directoryservice_unshare_directory]{unshare_directory} \tab Stops the directory sharing between the directory owner and consumer accounts\cr
#'  \link[paws.security.identity:directoryservice_update_conditional_forwarder]{update_conditional_forwarder} \tab Updates a conditional forwarder that has been set up for your Amazon Web Services directory\cr
#'  \link[paws.security.identity:directoryservice_update_directory_setup]{update_directory_setup} \tab Updates the directory for a particular update type\cr
#'  \link[paws.security.identity:directoryservice_update_number_of_domain_controllers]{update_number_of_domain_controllers} \tab Adds or removes domain controllers to or from the directory\cr
#'  \link[paws.security.identity:directoryservice_update_radius]{update_radius} \tab Updates the Remote Authentication Dial In User Service (RADIUS) server information for an AD Connector or Microsoft AD directory\cr
#'  \link[paws.security.identity:directoryservice_update_settings]{update_settings} \tab Updates the configurable settings for the specified directory\cr
#'  \link[paws.security.identity:directoryservice_update_trust]{update_trust} \tab Updates the trust that has been set up between your Managed Microsoft AD directory and an self-managed Active Directory\cr
#'  \link[paws.security.identity:directoryservice_verify_trust]{verify_trust} \tab Directory Service for Microsoft Active Directory allows you to configure and verify trust relationships
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname directoryservice
#' @export
directoryservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::directoryservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Firewall Management Service
#'
#' @description
#' This is the *Firewall Manager API Reference*. This guide is for
#' developers who need detailed information about the Firewall Manager API
#' actions, data types, and errors. For detailed information about Firewall
#' Manager features, see the [Firewall Manager Developer
#' Guide](https://docs.aws.amazon.com/waf/latest/developerguide/fms-chapter.html).
#' 
#' Some API actions require explicit resource permissions. For information,
#' see the developer guide topic [Service roles for Firewall
#' Manager](https://docs.aws.amazon.com/waf/latest/developerguide/fms-security_iam_service-with-iam.html#fms-security_iam_service-with-iam-roles-service).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- fms(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- fms()
#' svc$associate_admin_account(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:fms_associate_admin_account]{associate_admin_account} \tab Sets a Firewall Manager default administrator account\cr
#'  \link[paws.security.identity:fms_associate_third_party_firewall]{associate_third_party_firewall} \tab Sets the Firewall Manager policy administrator as a tenant administrator of a third-party firewall service\cr
#'  \link[paws.security.identity:fms_batch_associate_resource]{batch_associate_resource} \tab Associate resources to a Firewall Manager resource set\cr
#'  \link[paws.security.identity:fms_batch_disassociate_resource]{batch_disassociate_resource} \tab Disassociates resources from a Firewall Manager resource set\cr
#'  \link[paws.security.identity:fms_delete_apps_list]{delete_apps_list} \tab Permanently deletes an Firewall Manager applications list\cr
#'  \link[paws.security.identity:fms_delete_notification_channel]{delete_notification_channel} \tab Deletes an Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs\cr
#'  \link[paws.security.identity:fms_delete_policy]{delete_policy} \tab Permanently deletes an Firewall Manager policy\cr
#'  \link[paws.security.identity:fms_delete_protocols_list]{delete_protocols_list} \tab Permanently deletes an Firewall Manager protocols list\cr
#'  \link[paws.security.identity:fms_delete_resource_set]{delete_resource_set} \tab Deletes the specified ResourceSet\cr
#'  \link[paws.security.identity:fms_disassociate_admin_account]{disassociate_admin_account} \tab Disassociates an Firewall Manager administrator account\cr
#'  \link[paws.security.identity:fms_disassociate_third_party_firewall]{disassociate_third_party_firewall} \tab Disassociates a Firewall Manager policy administrator from a third-party firewall tenant\cr
#'  \link[paws.security.identity:fms_get_admin_account]{get_admin_account} \tab Returns the Organizations account that is associated with Firewall Manager as the Firewall Manager default administrator\cr
#'  \link[paws.security.identity:fms_get_admin_scope]{get_admin_scope} \tab Returns information about the specified account's administrative scope\cr
#'  \link[paws.security.identity:fms_get_apps_list]{get_apps_list} \tab Returns information about the specified Firewall Manager applications list\cr
#'  \link[paws.security.identity:fms_get_compliance_detail]{get_compliance_detail} \tab Returns detailed compliance information about the specified member account\cr
#'  \link[paws.security.identity:fms_get_notification_channel]{get_notification_channel} \tab Information about the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs\cr
#'  \link[paws.security.identity:fms_get_policy]{get_policy} \tab Returns information about the specified Firewall Manager policy\cr
#'  \link[paws.security.identity:fms_get_protection_status]{get_protection_status} \tab If you created a Shield Advanced policy, returns policy-level attack summary information in the event of a potential DDoS attack\cr
#'  \link[paws.security.identity:fms_get_protocols_list]{get_protocols_list} \tab Returns information about the specified Firewall Manager protocols list\cr
#'  \link[paws.security.identity:fms_get_resource_set]{get_resource_set} \tab Gets information about a specific resource set\cr
#'  \link[paws.security.identity:fms_get_third_party_firewall_association_status]{get_third_party_firewall_association_status} \tab The onboarding status of a Firewall Manager admin account to third-party firewall vendor tenant\cr
#'  \link[paws.security.identity:fms_get_violation_details]{get_violation_details} \tab Retrieves violations for a resource based on the specified Firewall Manager policy and Amazon Web Services account\cr
#'  \link[paws.security.identity:fms_list_admin_accounts_for_organization]{list_admin_accounts_for_organization} \tab Returns a AdminAccounts object that lists the Firewall Manager administrators within the organization that are onboarded to Firewall Manager by AssociateAdminAccount\cr
#'  \link[paws.security.identity:fms_list_admins_managing_account]{list_admins_managing_account} \tab Lists the accounts that are managing the specified Organizations member account\cr
#'  \link[paws.security.identity:fms_list_apps_lists]{list_apps_lists} \tab Returns an array of AppsListDataSummary objects\cr
#'  \link[paws.security.identity:fms_list_compliance_status]{list_compliance_status} \tab Returns an array of PolicyComplianceStatus objects\cr
#'  \link[paws.security.identity:fms_list_discovered_resources]{list_discovered_resources} \tab Returns an array of resources in the organization's accounts that are available to be associated with a resource set\cr
#'  \link[paws.security.identity:fms_list_member_accounts]{list_member_accounts} \tab Returns a MemberAccounts object that lists the member accounts in the administrator's Amazon Web Services organization\cr
#'  \link[paws.security.identity:fms_list_policies]{list_policies} \tab Returns an array of PolicySummary objects\cr
#'  \link[paws.security.identity:fms_list_protocols_lists]{list_protocols_lists} \tab Returns an array of ProtocolsListDataSummary objects\cr
#'  \link[paws.security.identity:fms_list_resource_set_resources]{list_resource_set_resources} \tab Returns an array of resources that are currently associated to a resource set\cr
#'  \link[paws.security.identity:fms_list_resource_sets]{list_resource_sets} \tab Returns an array of ResourceSetSummary objects\cr
#'  \link[paws.security.identity:fms_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves the list of tags for the specified Amazon Web Services resource\cr
#'  \link[paws.security.identity:fms_list_third_party_firewall_firewall_policies]{list_third_party_firewall_firewall_policies} \tab Retrieves a list of all of the third-party firewall policies that are associated with the third-party firewall administrator's account\cr
#'  \link[paws.security.identity:fms_put_admin_account]{put_admin_account} \tab Creates or updates an Firewall Manager administrator account\cr
#'  \link[paws.security.identity:fms_put_apps_list]{put_apps_list} \tab Creates an Firewall Manager applications list\cr
#'  \link[paws.security.identity:fms_put_notification_channel]{put_notification_channel} \tab Designates the IAM role and Amazon Simple Notification Service (SNS) topic that Firewall Manager uses to record SNS logs\cr
#'  \link[paws.security.identity:fms_put_policy]{put_policy} \tab Creates an Firewall Manager policy\cr
#'  \link[paws.security.identity:fms_put_protocols_list]{put_protocols_list} \tab Creates an Firewall Manager protocols list\cr
#'  \link[paws.security.identity:fms_put_resource_set]{put_resource_set} \tab Creates the resource set\cr
#'  \link[paws.security.identity:fms_tag_resource]{tag_resource} \tab Adds one or more tags to an Amazon Web Services resource\cr
#'  \link[paws.security.identity:fms_untag_resource]{untag_resource} \tab Removes one or more tags from an Amazon Web Services resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname fms
#' @export
fms <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::fms(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon GuardDuty
#'
#' @description
#' Amazon GuardDuty is a continuous security monitoring service that
#' analyzes and processes the following foundational data sources - VPC
#' flow logs, Amazon Web Services CloudTrail management event logs,
#' CloudTrail S3 data event logs, EKS audit logs, DNS logs, Amazon EBS
#' volume data, runtime activity belonging to container workloads, such as
#' Amazon EKS, Amazon ECS (including Amazon Web Services Fargate), and
#' Amazon EC2 instances. It uses threat intelligence feeds, such as lists
#' of malicious IPs and domains, and machine learning to identify
#' unexpected, potentially unauthorized, and malicious activity within your
#' Amazon Web Services environment. This can include issues like
#' escalations of privileges, uses of exposed credentials, or communication
#' with malicious IPs, domains, or presence of malware on your Amazon EC2
#' instances and container workloads. For example, GuardDuty can detect
#' compromised EC2 instances and container workloads serving malware, or
#' mining bitcoin.
#' 
#' GuardDuty also monitors Amazon Web Services account access behavior for
#' signs of compromise, such as unauthorized infrastructure deployments
#' like EC2 instances deployed in a Region that has never been used, or
#' unusual API calls like a password policy change to reduce password
#' strength.
#' 
#' GuardDuty informs you about the status of your Amazon Web Services
#' environment by producing security findings that you can view in the
#' GuardDuty console or through Amazon EventBridge. For more information,
#' see the *\href{https://docs.aws.amazon.com/guardduty/latest/ug/what-is-guardduty.html}{Amazon GuardDuty User Guide}* .
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- guardduty(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- guardduty()
#' svc$accept_administrator_invitation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:guardduty_accept_administrator_invitation]{accept_administrator_invitation} \tab Accepts the invitation to be a member account and get monitored by a GuardDuty administrator account that sent the invitation\cr
#'  \link[paws.security.identity:guardduty_accept_invitation]{accept_invitation} \tab Accepts the invitation to be monitored by a GuardDuty administrator account\cr
#'  \link[paws.security.identity:guardduty_archive_findings]{archive_findings} \tab Archives GuardDuty findings that are specified by the list of finding IDs\cr
#'  \link[paws.security.identity:guardduty_create_detector]{create_detector} \tab Creates a single GuardDuty detector\cr
#'  \link[paws.security.identity:guardduty_create_filter]{create_filter} \tab Creates a filter using the specified finding criteria\cr
#'  \link[paws.security.identity:guardduty_create_ip_set]{create_ip_set} \tab Creates a new IPSet, which is called a trusted IP list in the console user interface\cr
#'  \link[paws.security.identity:guardduty_create_malware_protection_plan]{create_malware_protection_plan} \tab Creates a new Malware Protection plan for the protected resource\cr
#'  \link[paws.security.identity:guardduty_create_members]{create_members} \tab Creates member accounts of the current Amazon Web Services account by specifying a list of Amazon Web Services account IDs\cr
#'  \link[paws.security.identity:guardduty_create_publishing_destination]{create_publishing_destination} \tab Creates a publishing destination where you can export your GuardDuty findings\cr
#'  \link[paws.security.identity:guardduty_create_sample_findings]{create_sample_findings} \tab Generates sample findings of types specified by the list of finding types\cr
#'  \link[paws.security.identity:guardduty_create_threat_intel_set]{create_threat_intel_set} \tab Creates a new ThreatIntelSet\cr
#'  \link[paws.security.identity:guardduty_decline_invitations]{decline_invitations} \tab Declines invitations sent to the current member account by Amazon Web Services accounts specified by their account IDs\cr
#'  \link[paws.security.identity:guardduty_delete_detector]{delete_detector} \tab Deletes an Amazon GuardDuty detector that is specified by the detector ID\cr
#'  \link[paws.security.identity:guardduty_delete_filter]{delete_filter} \tab Deletes the filter specified by the filter name\cr
#'  \link[paws.security.identity:guardduty_delete_invitations]{delete_invitations} \tab Deletes invitations sent to the current member account by Amazon Web Services accounts specified by their account IDs\cr
#'  \link[paws.security.identity:guardduty_delete_ip_set]{delete_ip_set} \tab Deletes the IPSet specified by the ipSetId\cr
#'  \link[paws.security.identity:guardduty_delete_malware_protection_plan]{delete_malware_protection_plan} \tab Deletes the Malware Protection plan ID associated with the Malware Protection plan resource\cr
#'  \link[paws.security.identity:guardduty_delete_members]{delete_members} \tab Deletes GuardDuty member accounts (to the current GuardDuty administrator account) specified by the account IDs\cr
#'  \link[paws.security.identity:guardduty_delete_publishing_destination]{delete_publishing_destination} \tab Deletes the publishing definition with the specified destinationId\cr
#'  \link[paws.security.identity:guardduty_delete_threat_intel_set]{delete_threat_intel_set} \tab Deletes the ThreatIntelSet specified by the ThreatIntelSet ID\cr
#'  \link[paws.security.identity:guardduty_describe_malware_scans]{describe_malware_scans} \tab Returns a list of malware scans\cr
#'  \link[paws.security.identity:guardduty_describe_organization_configuration]{describe_organization_configuration} \tab Returns information about the account selected as the delegated administrator for GuardDuty\cr
#'  \link[paws.security.identity:guardduty_describe_publishing_destination]{describe_publishing_destination} \tab Returns information about the publishing destination specified by the provided destinationId\cr
#'  \link[paws.security.identity:guardduty_disable_organization_admin_account]{disable_organization_admin_account} \tab Removes the existing GuardDuty delegated administrator of the organization\cr
#'  \link[paws.security.identity:guardduty_disassociate_from_administrator_account]{disassociate_from_administrator_account} \tab Disassociates the current GuardDuty member account from its administrator account\cr
#'  \link[paws.security.identity:guardduty_disassociate_from_master_account]{disassociate_from_master_account} \tab Disassociates the current GuardDuty member account from its administrator account\cr
#'  \link[paws.security.identity:guardduty_disassociate_members]{disassociate_members} \tab Disassociates GuardDuty member accounts (from the current administrator account) specified by the account IDs\cr
#'  \link[paws.security.identity:guardduty_enable_organization_admin_account]{enable_organization_admin_account} \tab Designates an Amazon Web Services account within the organization as your GuardDuty delegated administrator\cr
#'  \link[paws.security.identity:guardduty_get_administrator_account]{get_administrator_account} \tab Provides the details of the GuardDuty administrator account associated with the current GuardDuty member account\cr
#'  \link[paws.security.identity:guardduty_get_coverage_statistics]{get_coverage_statistics} \tab Retrieves aggregated statistics for your account\cr
#'  \link[paws.security.identity:guardduty_get_detector]{get_detector} \tab Retrieves a GuardDuty detector specified by the detectorId\cr
#'  \link[paws.security.identity:guardduty_get_filter]{get_filter} \tab Returns the details of the filter specified by the filter name\cr
#'  \link[paws.security.identity:guardduty_get_findings]{get_findings} \tab Describes Amazon GuardDuty findings specified by finding IDs\cr
#'  \link[paws.security.identity:guardduty_get_findings_statistics]{get_findings_statistics} \tab Lists GuardDuty findings statistics for the specified detector ID\cr
#'  \link[paws.security.identity:guardduty_get_invitations_count]{get_invitations_count} \tab Returns the count of all GuardDuty membership invitations that were sent to the current member account except the currently accepted invitation\cr
#'  \link[paws.security.identity:guardduty_get_ip_set]{get_ip_set} \tab Retrieves the IPSet specified by the ipSetId\cr
#'  \link[paws.security.identity:guardduty_get_malware_protection_plan]{get_malware_protection_plan} \tab Retrieves the Malware Protection plan details associated with a Malware Protection plan ID\cr
#'  \link[paws.security.identity:guardduty_get_malware_scan_settings]{get_malware_scan_settings} \tab Returns the details of the malware scan settings\cr
#'  \link[paws.security.identity:guardduty_get_master_account]{get_master_account} \tab Provides the details for the GuardDuty administrator account associated with the current GuardDuty member account\cr
#'  \link[paws.security.identity:guardduty_get_member_detectors]{get_member_detectors} \tab Describes which data sources are enabled for the member account's detector\cr
#'  \link[paws.security.identity:guardduty_get_members]{get_members} \tab Retrieves GuardDuty member accounts (of the current GuardDuty administrator account) specified by the account IDs\cr
#'  \link[paws.security.identity:guardduty_get_organization_statistics]{get_organization_statistics} \tab Retrieves how many active member accounts have each feature enabled within GuardDuty\cr
#'  \link[paws.security.identity:guardduty_get_remaining_free_trial_days]{get_remaining_free_trial_days} \tab Provides the number of days left for each data source used in the free trial period\cr
#'  \link[paws.security.identity:guardduty_get_threat_intel_set]{get_threat_intel_set} \tab Retrieves the ThreatIntelSet that is specified by the ThreatIntelSet ID\cr
#'  \link[paws.security.identity:guardduty_get_usage_statistics]{get_usage_statistics} \tab Lists Amazon GuardDuty usage statistics over the last 30 days for the specified detector ID\cr
#'  \link[paws.security.identity:guardduty_invite_members]{invite_members} \tab Invites Amazon Web Services accounts to become members of an organization administered by the Amazon Web Services account that invokes this API\cr
#'  \link[paws.security.identity:guardduty_list_coverage]{list_coverage} \tab Lists coverage details for your GuardDuty account\cr
#'  \link[paws.security.identity:guardduty_list_detectors]{list_detectors} \tab Lists detectorIds of all the existing Amazon GuardDuty detector resources\cr
#'  \link[paws.security.identity:guardduty_list_filters]{list_filters} \tab Returns a paginated list of the current filters\cr
#'  \link[paws.security.identity:guardduty_list_findings]{list_findings} \tab Lists GuardDuty findings for the specified detector ID\cr
#'  \link[paws.security.identity:guardduty_list_invitations]{list_invitations} \tab Lists all GuardDuty membership invitations that were sent to the current Amazon Web Services account\cr
#'  \link[paws.security.identity:guardduty_list_ip_sets]{list_ip_sets} \tab Lists the IPSets of the GuardDuty service specified by the detector ID\cr
#'  \link[paws.security.identity:guardduty_list_malware_protection_plans]{list_malware_protection_plans} \tab Lists the Malware Protection plan IDs associated with the protected resources in your Amazon Web Services account\cr
#'  \link[paws.security.identity:guardduty_list_members]{list_members} \tab Lists details about all member accounts for the current GuardDuty administrator account\cr
#'  \link[paws.security.identity:guardduty_list_organization_admin_accounts]{list_organization_admin_accounts} \tab Lists the accounts designated as GuardDuty delegated administrators\cr
#'  \link[paws.security.identity:guardduty_list_publishing_destinations]{list_publishing_destinations} \tab Returns a list of publishing destinations associated with the specified detectorId\cr
#'  \link[paws.security.identity:guardduty_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags for a resource\cr
#'  \link[paws.security.identity:guardduty_list_threat_intel_sets]{list_threat_intel_sets} \tab Lists the ThreatIntelSets of the GuardDuty service specified by the detector ID\cr
#'  \link[paws.security.identity:guardduty_start_malware_scan]{start_malware_scan} \tab Initiates the malware scan\cr
#'  \link[paws.security.identity:guardduty_start_monitoring_members]{start_monitoring_members} \tab Turns on GuardDuty monitoring of the specified member accounts\cr
#'  \link[paws.security.identity:guardduty_stop_monitoring_members]{stop_monitoring_members} \tab Stops GuardDuty monitoring for the specified member accounts\cr
#'  \link[paws.security.identity:guardduty_tag_resource]{tag_resource} \tab Adds tags to a resource\cr
#'  \link[paws.security.identity:guardduty_unarchive_findings]{unarchive_findings} \tab Unarchives GuardDuty findings specified by the findingIds\cr
#'  \link[paws.security.identity:guardduty_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.security.identity:guardduty_update_detector]{update_detector} \tab Updates the GuardDuty detector specified by the detector ID\cr
#'  \link[paws.security.identity:guardduty_update_filter]{update_filter} \tab Updates the filter specified by the filter name\cr
#'  \link[paws.security.identity:guardduty_update_findings_feedback]{update_findings_feedback} \tab Marks the specified GuardDuty findings as useful or not useful\cr
#'  \link[paws.security.identity:guardduty_update_ip_set]{update_ip_set} \tab Updates the IPSet specified by the IPSet ID\cr
#'  \link[paws.security.identity:guardduty_update_malware_protection_plan]{update_malware_protection_plan} \tab Updates an existing Malware Protection plan resource\cr
#'  \link[paws.security.identity:guardduty_update_malware_scan_settings]{update_malware_scan_settings} \tab Updates the malware scan settings\cr
#'  \link[paws.security.identity:guardduty_update_member_detectors]{update_member_detectors} \tab Contains information on member accounts to be updated\cr
#'  \link[paws.security.identity:guardduty_update_organization_configuration]{update_organization_configuration} \tab Configures the delegated administrator account with the provided values\cr
#'  \link[paws.security.identity:guardduty_update_publishing_destination]{update_publishing_destination} \tab Updates information about the publishing destination specified by the destinationId\cr
#'  \link[paws.security.identity:guardduty_update_threat_intel_set]{update_threat_intel_set} \tab Updates the ThreatIntelSet specified by the ThreatIntelSet ID
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname guardduty
#' @export
guardduty <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::guardduty(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Identity and Access Management
#'
#' @description
#' Identity and Access Management
#' 
#' Identity and Access Management (IAM) is a web service for securely
#' controlling access to Amazon Web Services services. With IAM, you can
#' centrally manage users, security credentials such as access keys, and
#' permissions that control which Amazon Web Services resources users and
#' applications can access. For more information about IAM, see [Identity
#' and Access Management (IAM)](https://aws.amazon.com/iam/) and the
#' [Identity and Access Management User
#' Guide](https://docs.aws.amazon.com/IAM/latest/UserGuide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- iam(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- iam()
#' # The following add-client-id-to-open-id-connect-provider command adds the
#' # client ID my-application-ID to the OIDC provider named
#' # server.example.com:
#' svc$add_client_id_to_open_id_connect_provider(
#'   ClientID = "my-application-ID",
#'   OpenIDConnectProviderArn = "arn:aws:iam::123456789012:oidc-provider/server.example.com"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:iam_add_client_id_to_open_id_connect_provider]{add_client_id_to_open_id_connect_provider} \tab Adds a new client ID (also known as audience) to the list of client IDs already registered for the specified IAM OpenID Connect (OIDC) provider resource\cr
#'  \link[paws.security.identity:iam_add_role_to_instance_profile]{add_role_to_instance_profile} \tab Adds the specified IAM role to the specified instance profile\cr
#'  \link[paws.security.identity:iam_add_user_to_group]{add_user_to_group} \tab Adds the specified user to the specified group\cr
#'  \link[paws.security.identity:iam_attach_group_policy]{attach_group_policy} \tab Attaches the specified managed policy to the specified IAM group\cr
#'  \link[paws.security.identity:iam_attach_role_policy]{attach_role_policy} \tab Attaches the specified managed policy to the specified IAM role\cr
#'  \link[paws.security.identity:iam_attach_user_policy]{attach_user_policy} \tab Attaches the specified managed policy to the specified user\cr
#'  \link[paws.security.identity:iam_change_password]{change_password} \tab Changes the password of the IAM user who is calling this operation\cr
#'  \link[paws.security.identity:iam_create_access_key]{create_access_key} \tab Creates a new Amazon Web Services secret access key and corresponding Amazon Web Services access key ID for the specified user\cr
#'  \link[paws.security.identity:iam_create_account_alias]{create_account_alias} \tab Creates an alias for your Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_create_group]{create_group} \tab Creates a new group\cr
#'  \link[paws.security.identity:iam_create_instance_profile]{create_instance_profile} \tab Creates a new instance profile\cr
#'  \link[paws.security.identity:iam_create_login_profile]{create_login_profile} \tab Creates a password for the specified IAM user\cr
#'  \link[paws.security.identity:iam_create_open_id_connect_provider]{create_open_id_connect_provider} \tab Creates an IAM entity to describe an identity provider (IdP) that supports OpenID Connect (OIDC)\cr
#'  \link[paws.security.identity:iam_create_policy]{create_policy} \tab Creates a new managed policy for your Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_create_policy_version]{create_policy_version} \tab Creates a new version of the specified managed policy\cr
#'  \link[paws.security.identity:iam_create_role]{create_role} \tab Creates a new role for your Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_create_saml_provider]{create_saml_provider} \tab Creates an IAM resource that describes an identity provider (IdP) that supports SAML 2\cr
#'  \link[paws.security.identity:iam_create_service_linked_role]{create_service_linked_role} \tab Creates an IAM role that is linked to a specific Amazon Web Services service\cr
#'  \link[paws.security.identity:iam_create_service_specific_credential]{create_service_specific_credential} \tab Generates a set of credentials consisting of a user name and password that can be used to access the service specified in the request\cr
#'  \link[paws.security.identity:iam_create_user]{create_user} \tab Creates a new IAM user for your Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_create_virtual_mfa_device]{create_virtual_mfa_device} \tab Creates a new virtual MFA device for the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_deactivate_mfa_device]{deactivate_mfa_device} \tab Deactivates the specified MFA device and removes it from association with the user name for which it was originally enabled\cr
#'  \link[paws.security.identity:iam_delete_access_key]{delete_access_key} \tab Deletes the access key pair associated with the specified IAM user\cr
#'  \link[paws.security.identity:iam_delete_account_alias]{delete_account_alias} \tab Deletes the specified Amazon Web Services account alias\cr
#'  \link[paws.security.identity:iam_delete_account_password_policy]{delete_account_password_policy} \tab Deletes the password policy for the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_delete_group]{delete_group} \tab Deletes the specified IAM group\cr
#'  \link[paws.security.identity:iam_delete_group_policy]{delete_group_policy} \tab Deletes the specified inline policy that is embedded in the specified IAM group\cr
#'  \link[paws.security.identity:iam_delete_instance_profile]{delete_instance_profile} \tab Deletes the specified instance profile\cr
#'  \link[paws.security.identity:iam_delete_login_profile]{delete_login_profile} \tab Deletes the password for the specified IAM user, For more information, see Managing passwords for IAM users\cr
#'  \link[paws.security.identity:iam_delete_open_id_connect_provider]{delete_open_id_connect_provider} \tab Deletes an OpenID Connect identity provider (IdP) resource object in IAM\cr
#'  \link[paws.security.identity:iam_delete_policy]{delete_policy} \tab Deletes the specified managed policy\cr
#'  \link[paws.security.identity:iam_delete_policy_version]{delete_policy_version} \tab Deletes the specified version from the specified managed policy\cr
#'  \link[paws.security.identity:iam_delete_role]{delete_role} \tab Deletes the specified role\cr
#'  \link[paws.security.identity:iam_delete_role_permissions_boundary]{delete_role_permissions_boundary} \tab Deletes the permissions boundary for the specified IAM role\cr
#'  \link[paws.security.identity:iam_delete_role_policy]{delete_role_policy} \tab Deletes the specified inline policy that is embedded in the specified IAM role\cr
#'  \link[paws.security.identity:iam_delete_saml_provider]{delete_saml_provider} \tab Deletes a SAML provider resource in IAM\cr
#'  \link[paws.security.identity:iam_delete_server_certificate]{delete_server_certificate} \tab Deletes the specified server certificate\cr
#'  \link[paws.security.identity:iam_delete_service_linked_role]{delete_service_linked_role} \tab Submits a service-linked role deletion request and returns a DeletionTaskId, which you can use to check the status of the deletion\cr
#'  \link[paws.security.identity:iam_delete_service_specific_credential]{delete_service_specific_credential} \tab Deletes the specified service-specific credential\cr
#'  \link[paws.security.identity:iam_delete_signing_certificate]{delete_signing_certificate} \tab Deletes a signing certificate associated with the specified IAM user\cr
#'  \link[paws.security.identity:iam_delete_ssh_public_key]{delete_ssh_public_key} \tab Deletes the specified SSH public key\cr
#'  \link[paws.security.identity:iam_delete_user]{delete_user} \tab Deletes the specified IAM user\cr
#'  \link[paws.security.identity:iam_delete_user_permissions_boundary]{delete_user_permissions_boundary} \tab Deletes the permissions boundary for the specified IAM user\cr
#'  \link[paws.security.identity:iam_delete_user_policy]{delete_user_policy} \tab Deletes the specified inline policy that is embedded in the specified IAM user\cr
#'  \link[paws.security.identity:iam_delete_virtual_mfa_device]{delete_virtual_mfa_device} \tab Deletes a virtual MFA device\cr
#'  \link[paws.security.identity:iam_detach_group_policy]{detach_group_policy} \tab Removes the specified managed policy from the specified IAM group\cr
#'  \link[paws.security.identity:iam_detach_role_policy]{detach_role_policy} \tab Removes the specified managed policy from the specified role\cr
#'  \link[paws.security.identity:iam_detach_user_policy]{detach_user_policy} \tab Removes the specified managed policy from the specified user\cr
#'  \link[paws.security.identity:iam_disable_organizations_root_credentials_management]{disable_organizations_root_credentials_management} \tab Disables the management of privileged root user credentials across member accounts in your organization\cr
#'  \link[paws.security.identity:iam_disable_organizations_root_sessions]{disable_organizations_root_sessions} \tab Disables root user sessions for privileged tasks across member accounts in your organization\cr
#'  \link[paws.security.identity:iam_enable_mfa_device]{enable_mfa_device} \tab Enables the specified MFA device and associates it with the specified IAM user\cr
#'  \link[paws.security.identity:iam_enable_organizations_root_credentials_management]{enable_organizations_root_credentials_management} \tab Enables the management of privileged root user credentials across member accounts in your organization\cr
#'  \link[paws.security.identity:iam_enable_organizations_root_sessions]{enable_organizations_root_sessions} \tab Allows the management account or delegated administrator to perform privileged tasks on member accounts in your organization\cr
#'  \link[paws.security.identity:iam_generate_credential_report]{generate_credential_report} \tab Generates a credential report for the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_generate_organizations_access_report]{generate_organizations_access_report} \tab Generates a report for service last accessed data for Organizations\cr
#'  \link[paws.security.identity:iam_generate_service_last_accessed_details]{generate_service_last_accessed_details} \tab Generates a report that includes details about when an IAM resource (user, group, role, or policy) was last used in an attempt to access Amazon Web Services services\cr
#'  \link[paws.security.identity:iam_get_access_key_last_used]{get_access_key_last_used} \tab Retrieves information about when the specified access key was last used\cr
#'  \link[paws.security.identity:iam_get_account_authorization_details]{get_account_authorization_details} \tab Retrieves information about all IAM users, groups, roles, and policies in your Amazon Web Services account, including their relationships to one another\cr
#'  \link[paws.security.identity:iam_get_account_password_policy]{get_account_password_policy} \tab Retrieves the password policy for the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_get_account_summary]{get_account_summary} \tab Retrieves information about IAM entity usage and IAM quotas in the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_get_context_keys_for_custom_policy]{get_context_keys_for_custom_policy} \tab Gets a list of all of the context keys referenced in the input policies\cr
#'  \link[paws.security.identity:iam_get_context_keys_for_principal_policy]{get_context_keys_for_principal_policy} \tab Gets a list of all of the context keys referenced in all the IAM policies that are attached to the specified IAM entity\cr
#'  \link[paws.security.identity:iam_get_credential_report]{get_credential_report} \tab Retrieves a credential report for the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_get_group]{get_group} \tab Returns a list of IAM users that are in the specified IAM group\cr
#'  \link[paws.security.identity:iam_get_group_policy]{get_group_policy} \tab Retrieves the specified inline policy document that is embedded in the specified IAM group\cr
#'  \link[paws.security.identity:iam_get_instance_profile]{get_instance_profile} \tab Retrieves information about the specified instance profile, including the instance profile's path, GUID, ARN, and role\cr
#'  \link[paws.security.identity:iam_get_login_profile]{get_login_profile} \tab Retrieves the user name for the specified IAM user\cr
#'  \link[paws.security.identity:iam_get_mfa_device]{get_mfa_device} \tab Retrieves information about an MFA device for a specified user\cr
#'  \link[paws.security.identity:iam_get_open_id_connect_provider]{get_open_id_connect_provider} \tab Returns information about the specified OpenID Connect (OIDC) provider resource object in IAM\cr
#'  \link[paws.security.identity:iam_get_organizations_access_report]{get_organizations_access_report} \tab Retrieves the service last accessed data report for Organizations that was previously generated using the GenerateOrganizationsAccessReport operation\cr
#'  \link[paws.security.identity:iam_get_policy]{get_policy} \tab Retrieves information about the specified managed policy, including the policy's default version and the total number of IAM users, groups, and roles to which the policy is attached\cr
#'  \link[paws.security.identity:iam_get_policy_version]{get_policy_version} \tab Retrieves information about the specified version of the specified managed policy, including the policy document\cr
#'  \link[paws.security.identity:iam_get_role]{get_role} \tab Retrieves information about the specified role, including the role's path, GUID, ARN, and the role's trust policy that grants permission to assume the role\cr
#'  \link[paws.security.identity:iam_get_role_policy]{get_role_policy} \tab Retrieves the specified inline policy document that is embedded with the specified IAM role\cr
#'  \link[paws.security.identity:iam_get_saml_provider]{get_saml_provider} \tab Returns the SAML provider metadocument that was uploaded when the IAM SAML provider resource object was created or updated\cr
#'  \link[paws.security.identity:iam_get_server_certificate]{get_server_certificate} \tab Retrieves information about the specified server certificate stored in IAM\cr
#'  \link[paws.security.identity:iam_get_service_last_accessed_details]{get_service_last_accessed_details} \tab Retrieves a service last accessed report that was created using the GenerateServiceLastAccessedDetails operation\cr
#'  \link[paws.security.identity:iam_get_service_last_accessed_details_with_entities]{get_service_last_accessed_details_with_entities} \tab After you generate a group or policy report using the GenerateServiceLastAccessedDetails operation, you can use the JobId parameter in GetServiceLastAccessedDetailsWithEntities\cr
#'  \link[paws.security.identity:iam_get_service_linked_role_deletion_status]{get_service_linked_role_deletion_status} \tab Retrieves the status of your service-linked role deletion\cr
#'  \link[paws.security.identity:iam_get_ssh_public_key]{get_ssh_public_key} \tab Retrieves the specified SSH public key, including metadata about the key\cr
#'  \link[paws.security.identity:iam_get_user]{get_user} \tab Retrieves information about the specified IAM user, including the user's creation date, path, unique ID, and ARN\cr
#'  \link[paws.security.identity:iam_get_user_policy]{get_user_policy} \tab Retrieves the specified inline policy document that is embedded in the specified IAM user\cr
#'  \link[paws.security.identity:iam_list_access_keys]{list_access_keys} \tab Returns information about the access key IDs associated with the specified IAM user\cr
#'  \link[paws.security.identity:iam_list_account_aliases]{list_account_aliases} \tab Lists the account alias associated with the Amazon Web Services account (Note: you can have only one)\cr
#'  \link[paws.security.identity:iam_list_attached_group_policies]{list_attached_group_policies} \tab Lists all managed policies that are attached to the specified IAM group\cr
#'  \link[paws.security.identity:iam_list_attached_role_policies]{list_attached_role_policies} \tab Lists all managed policies that are attached to the specified IAM role\cr
#'  \link[paws.security.identity:iam_list_attached_user_policies]{list_attached_user_policies} \tab Lists all managed policies that are attached to the specified IAM user\cr
#'  \link[paws.security.identity:iam_list_entities_for_policy]{list_entities_for_policy} \tab Lists all IAM users, groups, and roles that the specified managed policy is attached to\cr
#'  \link[paws.security.identity:iam_list_group_policies]{list_group_policies} \tab Lists the names of the inline policies that are embedded in the specified IAM group\cr
#'  \link[paws.security.identity:iam_list_groups]{list_groups} \tab Lists the IAM groups that have the specified path prefix\cr
#'  \link[paws.security.identity:iam_list_groups_for_user]{list_groups_for_user} \tab Lists the IAM groups that the specified IAM user belongs to\cr
#'  \link[paws.security.identity:iam_list_instance_profiles]{list_instance_profiles} \tab Lists the instance profiles that have the specified path prefix\cr
#'  \link[paws.security.identity:iam_list_instance_profiles_for_role]{list_instance_profiles_for_role} \tab Lists the instance profiles that have the specified associated IAM role\cr
#'  \link[paws.security.identity:iam_list_instance_profile_tags]{list_instance_profile_tags} \tab Lists the tags that are attached to the specified IAM instance profile\cr
#'  \link[paws.security.identity:iam_list_mfa_devices]{list_mfa_devices} \tab Lists the MFA devices for an IAM user\cr
#'  \link[paws.security.identity:iam_list_mfa_device_tags]{list_mfa_device_tags} \tab Lists the tags that are attached to the specified IAM virtual multi-factor authentication (MFA) device\cr
#'  \link[paws.security.identity:iam_list_open_id_connect_providers]{list_open_id_connect_providers} \tab Lists information about the IAM OpenID Connect (OIDC) provider resource objects defined in the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_list_open_id_connect_provider_tags]{list_open_id_connect_provider_tags} \tab Lists the tags that are attached to the specified OpenID Connect (OIDC)-compatible identity provider\cr
#'  \link[paws.security.identity:iam_list_organizations_features]{list_organizations_features} \tab Lists the centralized root access features enabled for your organization\cr
#'  \link[paws.security.identity:iam_list_policies]{list_policies} \tab Lists all the managed policies that are available in your Amazon Web Services account, including your own customer-defined managed policies and all Amazon Web Services managed policies\cr
#'  \link[paws.security.identity:iam_list_policies_granting_service_access]{list_policies_granting_service_access} \tab Retrieves a list of policies that the IAM identity (user, group, or role) can use to access each specified service\cr
#'  \link[paws.security.identity:iam_list_policy_tags]{list_policy_tags} \tab Lists the tags that are attached to the specified IAM customer managed policy\cr
#'  \link[paws.security.identity:iam_list_policy_versions]{list_policy_versions} \tab Lists information about the versions of the specified managed policy, including the version that is currently set as the policy's default version\cr
#'  \link[paws.security.identity:iam_list_role_policies]{list_role_policies} \tab Lists the names of the inline policies that are embedded in the specified IAM role\cr
#'  \link[paws.security.identity:iam_list_roles]{list_roles} \tab Lists the IAM roles that have the specified path prefix\cr
#'  \link[paws.security.identity:iam_list_role_tags]{list_role_tags} \tab Lists the tags that are attached to the specified role\cr
#'  \link[paws.security.identity:iam_list_saml_providers]{list_saml_providers} \tab Lists the SAML provider resource objects defined in IAM in the account\cr
#'  \link[paws.security.identity:iam_list_saml_provider_tags]{list_saml_provider_tags} \tab Lists the tags that are attached to the specified Security Assertion Markup Language (SAML) identity provider\cr
#'  \link[paws.security.identity:iam_list_server_certificates]{list_server_certificates} \tab Lists the server certificates stored in IAM that have the specified path prefix\cr
#'  \link[paws.security.identity:iam_list_server_certificate_tags]{list_server_certificate_tags} \tab Lists the tags that are attached to the specified IAM server certificate\cr
#'  \link[paws.security.identity:iam_list_service_specific_credentials]{list_service_specific_credentials} \tab Returns information about the service-specific credentials associated with the specified IAM user\cr
#'  \link[paws.security.identity:iam_list_signing_certificates]{list_signing_certificates} \tab Returns information about the signing certificates associated with the specified IAM user\cr
#'  \link[paws.security.identity:iam_list_ssh_public_keys]{list_ssh_public_keys} \tab Returns information about the SSH public keys associated with the specified IAM user\cr
#'  \link[paws.security.identity:iam_list_user_policies]{list_user_policies} \tab Lists the names of the inline policies embedded in the specified IAM user\cr
#'  \link[paws.security.identity:iam_list_users]{list_users} \tab Lists the IAM users that have the specified path prefix\cr
#'  \link[paws.security.identity:iam_list_user_tags]{list_user_tags} \tab Lists the tags that are attached to the specified IAM user\cr
#'  \link[paws.security.identity:iam_list_virtual_mfa_devices]{list_virtual_mfa_devices} \tab Lists the virtual MFA devices defined in the Amazon Web Services account by assignment status\cr
#'  \link[paws.security.identity:iam_put_group_policy]{put_group_policy} \tab Adds or updates an inline policy document that is embedded in the specified IAM group\cr
#'  \link[paws.security.identity:iam_put_role_permissions_boundary]{put_role_permissions_boundary} \tab Adds or updates the policy that is specified as the IAM role's permissions boundary\cr
#'  \link[paws.security.identity:iam_put_role_policy]{put_role_policy} \tab Adds or updates an inline policy document that is embedded in the specified IAM role\cr
#'  \link[paws.security.identity:iam_put_user_permissions_boundary]{put_user_permissions_boundary} \tab Adds or updates the policy that is specified as the IAM user's permissions boundary\cr
#'  \link[paws.security.identity:iam_put_user_policy]{put_user_policy} \tab Adds or updates an inline policy document that is embedded in the specified IAM user\cr
#'  \link[paws.security.identity:iam_remove_client_id_from_open_id_connect_provider]{remove_client_id_from_open_id_connect_provider} \tab Removes the specified client ID (also known as audience) from the list of client IDs registered for the specified IAM OpenID Connect (OIDC) provider resource object\cr
#'  \link[paws.security.identity:iam_remove_role_from_instance_profile]{remove_role_from_instance_profile} \tab Removes the specified IAM role from the specified Amazon EC2 instance profile\cr
#'  \link[paws.security.identity:iam_remove_user_from_group]{remove_user_from_group} \tab Removes the specified user from the specified group\cr
#'  \link[paws.security.identity:iam_reset_service_specific_credential]{reset_service_specific_credential} \tab Resets the password for a service-specific credential\cr
#'  \link[paws.security.identity:iam_resync_mfa_device]{resync_mfa_device} \tab Synchronizes the specified MFA device with its IAM resource object on the Amazon Web Services servers\cr
#'  \link[paws.security.identity:iam_set_default_policy_version]{set_default_policy_version} \tab Sets the specified version of the specified policy as the policy's default (operative) version\cr
#'  \link[paws.security.identity:iam_set_security_token_service_preferences]{set_security_token_service_preferences} \tab Sets the specified version of the global endpoint token as the token version used for the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_simulate_custom_policy]{simulate_custom_policy} \tab Simulate how a set of IAM policies and optionally a resource-based policy works with a list of API operations and Amazon Web Services resources to determine the policies' effective permissions\cr
#'  \link[paws.security.identity:iam_simulate_principal_policy]{simulate_principal_policy} \tab Simulate how a set of IAM policies attached to an IAM entity works with a list of API operations and Amazon Web Services resources to determine the policies' effective permissions\cr
#'  \link[paws.security.identity:iam_tag_instance_profile]{tag_instance_profile} \tab Adds one or more tags to an IAM instance profile\cr
#'  \link[paws.security.identity:iam_tag_mfa_device]{tag_mfa_device} \tab Adds one or more tags to an IAM virtual multi-factor authentication (MFA) device\cr
#'  \link[paws.security.identity:iam_tag_open_id_connect_provider]{tag_open_id_connect_provider} \tab Adds one or more tags to an OpenID Connect (OIDC)-compatible identity provider\cr
#'  \link[paws.security.identity:iam_tag_policy]{tag_policy} \tab Adds one or more tags to an IAM customer managed policy\cr
#'  \link[paws.security.identity:iam_tag_role]{tag_role} \tab Adds one or more tags to an IAM role\cr
#'  \link[paws.security.identity:iam_tag_saml_provider]{tag_saml_provider} \tab Adds one or more tags to a Security Assertion Markup Language (SAML) identity provider\cr
#'  \link[paws.security.identity:iam_tag_server_certificate]{tag_server_certificate} \tab Adds one or more tags to an IAM server certificate\cr
#'  \link[paws.security.identity:iam_tag_user]{tag_user} \tab Adds one or more tags to an IAM user\cr
#'  \link[paws.security.identity:iam_untag_instance_profile]{untag_instance_profile} \tab Removes the specified tags from the IAM instance profile\cr
#'  \link[paws.security.identity:iam_untag_mfa_device]{untag_mfa_device} \tab Removes the specified tags from the IAM virtual multi-factor authentication (MFA) device\cr
#'  \link[paws.security.identity:iam_untag_open_id_connect_provider]{untag_open_id_connect_provider} \tab Removes the specified tags from the specified OpenID Connect (OIDC)-compatible identity provider in IAM\cr
#'  \link[paws.security.identity:iam_untag_policy]{untag_policy} \tab Removes the specified tags from the customer managed policy\cr
#'  \link[paws.security.identity:iam_untag_role]{untag_role} \tab Removes the specified tags from the role\cr
#'  \link[paws.security.identity:iam_untag_saml_provider]{untag_saml_provider} \tab Removes the specified tags from the specified Security Assertion Markup Language (SAML) identity provider in IAM\cr
#'  \link[paws.security.identity:iam_untag_server_certificate]{untag_server_certificate} \tab Removes the specified tags from the IAM server certificate\cr
#'  \link[paws.security.identity:iam_untag_user]{untag_user} \tab Removes the specified tags from the user\cr
#'  \link[paws.security.identity:iam_update_access_key]{update_access_key} \tab Changes the status of the specified access key from Active to Inactive, or vice versa\cr
#'  \link[paws.security.identity:iam_update_account_password_policy]{update_account_password_policy} \tab Updates the password policy settings for the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_update_assume_role_policy]{update_assume_role_policy} \tab Updates the policy that grants an IAM entity permission to assume a role\cr
#'  \link[paws.security.identity:iam_update_group]{update_group} \tab Updates the name and/or the path of the specified IAM group\cr
#'  \link[paws.security.identity:iam_update_login_profile]{update_login_profile} \tab Changes the password for the specified IAM user\cr
#'  \link[paws.security.identity:iam_update_open_id_connect_provider_thumbprint]{update_open_id_connect_provider_thumbprint} \tab Replaces the existing list of server certificate thumbprints associated with an OpenID Connect (OIDC) provider resource object with a new list of thumbprints\cr
#'  \link[paws.security.identity:iam_update_role]{update_role} \tab Updates the description or maximum session duration setting of a role\cr
#'  \link[paws.security.identity:iam_update_role_description]{update_role_description} \tab Use UpdateRole instead\cr
#'  \link[paws.security.identity:iam_update_saml_provider]{update_saml_provider} \tab Updates the metadata document, SAML encryption settings, and private keys for an existing SAML provider\cr
#'  \link[paws.security.identity:iam_update_server_certificate]{update_server_certificate} \tab Updates the name and/or the path of the specified server certificate stored in IAM\cr
#'  \link[paws.security.identity:iam_update_service_specific_credential]{update_service_specific_credential} \tab Sets the status of a service-specific credential to Active or Inactive\cr
#'  \link[paws.security.identity:iam_update_signing_certificate]{update_signing_certificate} \tab Changes the status of the specified user signing certificate from active to disabled, or vice versa\cr
#'  \link[paws.security.identity:iam_update_ssh_public_key]{update_ssh_public_key} \tab Sets the status of an IAM user's SSH public key to active or inactive\cr
#'  \link[paws.security.identity:iam_update_user]{update_user} \tab Updates the name and/or the path of the specified IAM user\cr
#'  \link[paws.security.identity:iam_upload_server_certificate]{upload_server_certificate} \tab Uploads a server certificate entity for the Amazon Web Services account\cr
#'  \link[paws.security.identity:iam_upload_signing_certificate]{upload_signing_certificate} \tab Uploads an X\cr
#'  \link[paws.security.identity:iam_upload_ssh_public_key]{upload_ssh_public_key} \tab Uploads an SSH public key and associates it with the specified IAM user
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname iam
#' @export
iam <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::iam(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS SSO Identity Store
#'
#' @description
#' The Identity Store service used by IAM Identity Center provides a single
#' place to retrieve all of your identities (users and groups). For more
#' information, see the [IAM Identity Center User
#' Guide](https://docs.aws.amazon.com/singlesignon/latest/userguide/what-is.html).
#' 
#' This reference guide describes the identity store operations that you
#' can call programmatically and includes detailed information about data
#' types and errors.
#' 
#' IAM Identity Center uses the `sso` and `identitystore` API namespaces.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- identitystore(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- identitystore()
#' svc$create_group(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:identitystore_create_group]{create_group} \tab Creates a group within the specified identity store\cr
#'  \link[paws.security.identity:identitystore_create_group_membership]{create_group_membership} \tab Creates a relationship between a member and a group\cr
#'  \link[paws.security.identity:identitystore_create_user]{create_user} \tab Creates a user within the specified identity store\cr
#'  \link[paws.security.identity:identitystore_delete_group]{delete_group} \tab Delete a group within an identity store given GroupId\cr
#'  \link[paws.security.identity:identitystore_delete_group_membership]{delete_group_membership} \tab Delete a membership within a group given MembershipId\cr
#'  \link[paws.security.identity:identitystore_delete_user]{delete_user} \tab Deletes a user within an identity store given UserId\cr
#'  \link[paws.security.identity:identitystore_describe_group]{describe_group} \tab Retrieves the group metadata and attributes from GroupId in an identity store\cr
#'  \link[paws.security.identity:identitystore_describe_group_membership]{describe_group_membership} \tab Retrieves membership metadata and attributes from MembershipId in an identity store\cr
#'  \link[paws.security.identity:identitystore_describe_user]{describe_user} \tab Retrieves the user metadata and attributes from the UserId in an identity store\cr
#'  \link[paws.security.identity:identitystore_get_group_id]{get_group_id} \tab Retrieves GroupId in an identity store\cr
#'  \link[paws.security.identity:identitystore_get_group_membership_id]{get_group_membership_id} \tab Retrieves the MembershipId in an identity store\cr
#'  \link[paws.security.identity:identitystore_get_user_id]{get_user_id} \tab Retrieves the UserId in an identity store\cr
#'  \link[paws.security.identity:identitystore_is_member_in_groups]{is_member_in_groups} \tab Checks the user's membership in all requested groups and returns if the member exists in all queried groups\cr
#'  \link[paws.security.identity:identitystore_list_group_memberships]{list_group_memberships} \tab For the specified group in the specified identity store, returns the list of all GroupMembership objects and returns results in paginated form\cr
#'  \link[paws.security.identity:identitystore_list_group_memberships_for_member]{list_group_memberships_for_member} \tab For the specified member in the specified identity store, returns the list of all GroupMembership objects and returns results in paginated form\cr
#'  \link[paws.security.identity:identitystore_list_groups]{list_groups} \tab Lists all groups in the identity store\cr
#'  \link[paws.security.identity:identitystore_list_users]{list_users} \tab Lists all users in the identity store\cr
#'  \link[paws.security.identity:identitystore_update_group]{update_group} \tab For the specified group in the specified identity store, updates the group metadata and attributes\cr
#'  \link[paws.security.identity:identitystore_update_user]{update_user} \tab For the specified user in the specified identity store, updates the user metadata and attributes
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname identitystore
#' @export
identitystore <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::identitystore(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Inspector
#'
#' @description
#' Amazon Inspector enables you to analyze the behavior of your AWS
#' resources and to identify potential security issues. For more
#' information, see [Amazon Inspector User
#' Guide](https://docs.aws.amazon.com/inspector/v1/userguide/inspector_introduction.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- inspector(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- inspector()
#' # Assigns attributes (key and value pairs) to the findings that are
#' # specified by the ARNs of the findings.
#' svc$add_attributes_to_findings(
#'   attributes = list(
#'     list(
#'       key = "Example",
#'       value = "example"
#'     )
#'   ),
#'   findingArns = list(
#'     "arn:aws:inspector:us-west-2:123456789012:target/0-0kFIPusq/template/0-..."
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:inspector_add_attributes_to_findings]{add_attributes_to_findings} \tab Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings\cr
#'  \link[paws.security.identity:inspector_create_assessment_target]{create_assessment_target} \tab Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup\cr
#'  \link[paws.security.identity:inspector_create_assessment_template]{create_assessment_template} \tab Creates an assessment template for the assessment target that is specified by the ARN of the assessment target\cr
#'  \link[paws.security.identity:inspector_create_exclusions_preview]{create_exclusions_preview} \tab Starts the generation of an exclusions preview for the specified assessment template\cr
#'  \link[paws.security.identity:inspector_create_resource_group]{create_resource_group} \tab Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target\cr
#'  \link[paws.security.identity:inspector_delete_assessment_run]{delete_assessment_run} \tab Deletes the assessment run that is specified by the ARN of the assessment run\cr
#'  \link[paws.security.identity:inspector_delete_assessment_target]{delete_assessment_target} \tab Deletes the assessment target that is specified by the ARN of the assessment target\cr
#'  \link[paws.security.identity:inspector_delete_assessment_template]{delete_assessment_template} \tab Deletes the assessment template that is specified by the ARN of the assessment template\cr
#'  \link[paws.security.identity:inspector_describe_assessment_runs]{describe_assessment_runs} \tab Describes the assessment runs that are specified by the ARNs of the assessment runs\cr
#'  \link[paws.security.identity:inspector_describe_assessment_targets]{describe_assessment_targets} \tab Describes the assessment targets that are specified by the ARNs of the assessment targets\cr
#'  \link[paws.security.identity:inspector_describe_assessment_templates]{describe_assessment_templates} \tab Describes the assessment templates that are specified by the ARNs of the assessment templates\cr
#'  \link[paws.security.identity:inspector_describe_cross_account_access_role]{describe_cross_account_access_role} \tab Describes the IAM role that enables Amazon Inspector to access your AWS account\cr
#'  \link[paws.security.identity:inspector_describe_exclusions]{describe_exclusions} \tab Describes the exclusions that are specified by the exclusions' ARNs\cr
#'  \link[paws.security.identity:inspector_describe_findings]{describe_findings} \tab Describes the findings that are specified by the ARNs of the findings\cr
#'  \link[paws.security.identity:inspector_describe_resource_groups]{describe_resource_groups} \tab Describes the resource groups that are specified by the ARNs of the resource groups\cr
#'  \link[paws.security.identity:inspector_describe_rules_packages]{describe_rules_packages} \tab Describes the rules packages that are specified by the ARNs of the rules packages\cr
#'  \link[paws.security.identity:inspector_get_assessment_report]{get_assessment_report} \tab Produces an assessment report that includes detailed and comprehensive results of a specified assessment run\cr
#'  \link[paws.security.identity:inspector_get_exclusions_preview]{get_exclusions_preview} \tab Retrieves the exclusions preview (a list of ExclusionPreview objects) specified by the preview token\cr
#'  \link[paws.security.identity:inspector_get_telemetry_metadata]{get_telemetry_metadata} \tab Information about the data that is collected for the specified assessment run\cr
#'  \link[paws.security.identity:inspector_list_assessment_run_agents]{list_assessment_run_agents} \tab Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs\cr
#'  \link[paws.security.identity:inspector_list_assessment_runs]{list_assessment_runs} \tab Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates\cr
#'  \link[paws.security.identity:inspector_list_assessment_targets]{list_assessment_targets} \tab Lists the ARNs of the assessment targets within this AWS account\cr
#'  \link[paws.security.identity:inspector_list_assessment_templates]{list_assessment_templates} \tab Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets\cr
#'  \link[paws.security.identity:inspector_list_event_subscriptions]{list_event_subscriptions} \tab Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template\cr
#'  \link[paws.security.identity:inspector_list_exclusions]{list_exclusions} \tab List exclusions that are generated by the assessment run\cr
#'  \link[paws.security.identity:inspector_list_findings]{list_findings} \tab Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs\cr
#'  \link[paws.security.identity:inspector_list_rules_packages]{list_rules_packages} \tab Lists all available Amazon Inspector rules packages\cr
#'  \link[paws.security.identity:inspector_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags associated with an assessment template\cr
#'  \link[paws.security.identity:inspector_preview_agents]{preview_agents} \tab Previews the agents installed on the EC2 instances that are part of the specified assessment target\cr
#'  \link[paws.security.identity:inspector_register_cross_account_access_role]{register_cross_account_access_role} \tab Registers the IAM role that grants Amazon Inspector access to AWS Services needed to perform security assessments\cr
#'  \link[paws.security.identity:inspector_remove_attributes_from_findings]{remove_attributes_from_findings} \tab Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists\cr
#'  \link[paws.security.identity:inspector_set_tags_for_resource]{set_tags_for_resource} \tab Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template\cr
#'  \link[paws.security.identity:inspector_start_assessment_run]{start_assessment_run} \tab Starts the assessment run specified by the ARN of the assessment template\cr
#'  \link[paws.security.identity:inspector_stop_assessment_run]{stop_assessment_run} \tab Stops the assessment run that is specified by the ARN of the assessment run\cr
#'  \link[paws.security.identity:inspector_subscribe_to_event]{subscribe_to_event} \tab Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic\cr
#'  \link[paws.security.identity:inspector_unsubscribe_from_event]{unsubscribe_from_event} \tab Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic\cr
#'  \link[paws.security.identity:inspector_update_assessment_target]{update_assessment_target} \tab Updates the assessment target that is specified by the ARN of the assessment target
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname inspector
#' @export
inspector <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::inspector(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Inspector2
#'
#' @description
#' Amazon Inspector is a vulnerability discovery service that automates
#' continuous scanning for security vulnerabilities within your Amazon EC2,
#' Amazon ECR, and Amazon Web Services Lambda environments.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- inspector2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- inspector2()
#' svc$associate_member(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:inspector2_associate_member]{associate_member} \tab Associates an Amazon Web Services account with an Amazon Inspector delegated administrator\cr
#'  \link[paws.security.identity:inspector2_batch_get_account_status]{batch_get_account_status} \tab Retrieves the Amazon Inspector status of multiple Amazon Web Services accounts within your environment\cr
#'  \link[paws.security.identity:inspector2_batch_get_code_snippet]{batch_get_code_snippet} \tab Retrieves code snippets from findings that Amazon Inspector detected code vulnerabilities in\cr
#'  \link[paws.security.identity:inspector2_batch_get_finding_details]{batch_get_finding_details} \tab Gets vulnerability details for findings\cr
#'  \link[paws.security.identity:inspector2_batch_get_free_trial_info]{batch_get_free_trial_info} \tab Gets free trial status for multiple Amazon Web Services accounts\cr
#'  \link[paws.security.identity:inspector2_batch_get_member_ec_2_deep_inspection_status]{batch_get_member_ec_2_deep_inspection_status} \tab Retrieves Amazon Inspector deep inspection activation status of multiple member accounts within your organization\cr
#'  \link[paws.security.identity:inspector2_batch_update_member_ec_2_deep_inspection_status]{batch_update_member_ec_2_deep_inspection_status} \tab Activates or deactivates Amazon Inspector deep inspection for the provided member accounts in your organization\cr
#'  \link[paws.security.identity:inspector2_cancel_findings_report]{cancel_findings_report} \tab Cancels the given findings report\cr
#'  \link[paws.security.identity:inspector2_cancel_sbom_export]{cancel_sbom_export} \tab Cancels a software bill of materials (SBOM) report\cr
#'  \link[paws.security.identity:inspector2_create_cis_scan_configuration]{create_cis_scan_configuration} \tab Creates a CIS scan configuration\cr
#'  \link[paws.security.identity:inspector2_create_filter]{create_filter} \tab Creates a filter resource using specified filter criteria\cr
#'  \link[paws.security.identity:inspector2_create_findings_report]{create_findings_report} \tab Creates a finding report\cr
#'  \link[paws.security.identity:inspector2_create_sbom_export]{create_sbom_export} \tab Creates a software bill of materials (SBOM) report\cr
#'  \link[paws.security.identity:inspector2_delete_cis_scan_configuration]{delete_cis_scan_configuration} \tab Deletes a CIS scan configuration\cr
#'  \link[paws.security.identity:inspector2_delete_filter]{delete_filter} \tab Deletes a filter resource\cr
#'  \link[paws.security.identity:inspector2_describe_organization_configuration]{describe_organization_configuration} \tab Describe Amazon Inspector configuration settings for an Amazon Web Services organization\cr
#'  \link[paws.security.identity:inspector2_disable]{disable} \tab Disables Amazon Inspector scans for one or more Amazon Web Services accounts\cr
#'  \link[paws.security.identity:inspector2_disable_delegated_admin_account]{disable_delegated_admin_account} \tab Disables the Amazon Inspector delegated administrator for your organization\cr
#'  \link[paws.security.identity:inspector2_disassociate_member]{disassociate_member} \tab Disassociates a member account from an Amazon Inspector delegated administrator\cr
#'  \link[paws.security.identity:inspector2_enable]{enable} \tab Enables Amazon Inspector scans for one or more Amazon Web Services accounts\cr
#'  \link[paws.security.identity:inspector2_enable_delegated_admin_account]{enable_delegated_admin_account} \tab Enables the Amazon Inspector delegated administrator for your Organizations organization\cr
#'  \link[paws.security.identity:inspector2_get_cis_scan_report]{get_cis_scan_report} \tab Retrieves a CIS scan report\cr
#'  \link[paws.security.identity:inspector2_get_cis_scan_result_details]{get_cis_scan_result_details} \tab Retrieves CIS scan result details\cr
#'  \link[paws.security.identity:inspector2_get_configuration]{get_configuration} \tab Retrieves setting configurations for Inspector scans\cr
#'  \link[paws.security.identity:inspector2_get_delegated_admin_account]{get_delegated_admin_account} \tab Retrieves information about the Amazon Inspector delegated administrator for your organization\cr
#'  \link[paws.security.identity:inspector2_get_ec_2_deep_inspection_configuration]{get_ec_2_deep_inspection_configuration} \tab Retrieves the activation status of Amazon Inspector deep inspection and custom paths associated with your account\cr
#'  \link[paws.security.identity:inspector2_get_encryption_key]{get_encryption_key} \tab Gets an encryption key\cr
#'  \link[paws.security.identity:inspector2_get_findings_report_status]{get_findings_report_status} \tab Gets the status of a findings report\cr
#'  \link[paws.security.identity:inspector2_get_member]{get_member} \tab Gets member information for your organization\cr
#'  \link[paws.security.identity:inspector2_get_sbom_export]{get_sbom_export} \tab Gets details of a software bill of materials (SBOM) report\cr
#'  \link[paws.security.identity:inspector2_list_account_permissions]{list_account_permissions} \tab Lists the permissions an account has to configure Amazon Inspector\cr
#'  \link[paws.security.identity:inspector2_list_cis_scan_configurations]{list_cis_scan_configurations} \tab Lists CIS scan configurations\cr
#'  \link[paws.security.identity:inspector2_list_cis_scan_results_aggregated_by_checks]{list_cis_scan_results_aggregated_by_checks} \tab Lists scan results aggregated by checks\cr
#'  \link[paws.security.identity:inspector2_list_cis_scan_results_aggregated_by_target_resource]{list_cis_scan_results_aggregated_by_target_resource} \tab Lists scan results aggregated by a target resource\cr
#'  \link[paws.security.identity:inspector2_list_cis_scans]{list_cis_scans} \tab Returns a CIS scan list\cr
#'  \link[paws.security.identity:inspector2_list_coverage]{list_coverage} \tab Lists coverage details for your environment\cr
#'  \link[paws.security.identity:inspector2_list_coverage_statistics]{list_coverage_statistics} \tab Lists Amazon Inspector coverage statistics for your environment\cr
#'  \link[paws.security.identity:inspector2_list_delegated_admin_accounts]{list_delegated_admin_accounts} \tab Lists information about the Amazon Inspector delegated administrator of your organization\cr
#'  \link[paws.security.identity:inspector2_list_filters]{list_filters} \tab Lists the filters associated with your account\cr
#'  \link[paws.security.identity:inspector2_list_finding_aggregations]{list_finding_aggregations} \tab Lists aggregated finding data for your environment based on specific criteria\cr
#'  \link[paws.security.identity:inspector2_list_findings]{list_findings} \tab Lists findings for your environment\cr
#'  \link[paws.security.identity:inspector2_list_members]{list_members} \tab List members associated with the Amazon Inspector delegated administrator for your organization\cr
#'  \link[paws.security.identity:inspector2_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags attached to a given resource\cr
#'  \link[paws.security.identity:inspector2_list_usage_totals]{list_usage_totals} \tab Lists the Amazon Inspector usage totals over the last 30 days\cr
#'  \link[paws.security.identity:inspector2_reset_encryption_key]{reset_encryption_key} \tab Resets an encryption key\cr
#'  \link[paws.security.identity:inspector2_search_vulnerabilities]{search_vulnerabilities} \tab Lists Amazon Inspector coverage details for a specific vulnerability\cr
#'  \link[paws.security.identity:inspector2_send_cis_session_health]{send_cis_session_health} \tab Sends a CIS session health\cr
#'  \link[paws.security.identity:inspector2_send_cis_session_telemetry]{send_cis_session_telemetry} \tab Sends a CIS session telemetry\cr
#'  \link[paws.security.identity:inspector2_start_cis_session]{start_cis_session} \tab Starts a CIS session\cr
#'  \link[paws.security.identity:inspector2_stop_cis_session]{stop_cis_session} \tab Stops a CIS session\cr
#'  \link[paws.security.identity:inspector2_tag_resource]{tag_resource} \tab Adds tags to a resource\cr
#'  \link[paws.security.identity:inspector2_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.security.identity:inspector2_update_cis_scan_configuration]{update_cis_scan_configuration} \tab Updates a CIS scan configuration\cr
#'  \link[paws.security.identity:inspector2_update_configuration]{update_configuration} \tab Updates setting configurations for your Amazon Inspector account\cr
#'  \link[paws.security.identity:inspector2_update_ec_2_deep_inspection_configuration]{update_ec_2_deep_inspection_configuration} \tab Activates, deactivates Amazon Inspector deep inspection, or updates custom paths for your account\cr
#'  \link[paws.security.identity:inspector2_update_encryption_key]{update_encryption_key} \tab Updates an encryption key\cr
#'  \link[paws.security.identity:inspector2_update_filter]{update_filter} \tab Specifies the action that is to be applied to the findings that match the filter\cr
#'  \link[paws.security.identity:inspector2_update_organization_configuration]{update_organization_configuration} \tab Updates the configurations for your Amazon Inspector organization\cr
#'  \link[paws.security.identity:inspector2_update_org_ec_2_deep_inspection_configuration]{update_org_ec_2_deep_inspection_configuration} \tab Updates the Amazon Inspector deep inspection custom paths for your organization
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname inspector2
#' @export
inspector2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::inspector2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Key Management Service
#'
#' @description
#' Key Management Service
#' 
#' Key Management Service (KMS) is an encryption and key management web
#' service. This guide describes the KMS operations that you can call
#' programmatically. For general information about KMS, see the [*Key
#' Management Service Developer
#' Guide*](https://docs.aws.amazon.com/kms/latest/developerguide/) .
#' 
#' KMS has replaced the term *customer master key (CMK)* with *KMS key* and
#' *KMS key*. The concept has not changed. To prevent breaking changes, KMS
#' is keeping some variations of this term.
#' 
#' Amazon Web Services provides SDKs that consist of libraries and sample
#' code for various programming languages and platforms (Java, Ruby, .Net,
#' macOS, Android, etc.). The SDKs provide a convenient way to create
#' programmatic access to KMS and other Amazon Web Services services. For
#' example, the SDKs take care of tasks such as signing requests (see
#' below), managing errors, and retrying requests automatically. For more
#' information about the Amazon Web Services SDKs, including how to
#' download and install them, see [Tools for Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#' 
#' We recommend that you use the Amazon Web Services SDKs to make
#' programmatic API calls to KMS.
#' 
#' If you need to use FIPS 140-2 validated cryptographic modules when
#' communicating with Amazon Web Services, use the FIPS endpoint in your
#' preferred Amazon Web Services Region. For more information about the
#' available FIPS endpoints, see [Service
#' endpoints](https://docs.aws.amazon.com/general/latest/gr/kms.html#kms_region)
#' in the Key Management Service topic of the *Amazon Web Services General
#' Reference*.
#' 
#' All KMS API calls must be signed and be transmitted using Transport
#' Layer Security (TLS). KMS recommends you always use the latest supported
#' TLS version. Clients must also support cipher suites with Perfect
#' Forward Secrecy (PFS) such as Ephemeral Diffie-Hellman (DHE) or Elliptic
#' Curve Ephemeral Diffie-Hellman (ECDHE). Most modern systems such as Java
#' 7 and later support these modes.
#' 
#' **Signing Requests**
#' 
#' Requests must be signed using an access key ID and a secret access key.
#' We strongly recommend that you do not use your Amazon Web Services
#' account root access key ID and secret access key for everyday work. You
#' can use the access key ID and secret access key for an IAM user or you
#' can use the Security Token Service (STS) to generate temporary security
#' credentials and use those to sign requests.
#' 
#' All KMS requests must be signed with [Signature Version
#' 4](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html).
#' 
#' **Logging API Requests**
#' 
#' KMS supports CloudTrail, a service that logs Amazon Web Services API
#' calls and related events for your Amazon Web Services account and
#' delivers them to an Amazon S3 bucket that you specify. By using the
#' information collected by CloudTrail, you can determine what requests
#' were made to KMS, who made the request, when it was made, and so on. To
#' learn more about CloudTrail, including how to turn it on and find your
#' log files, see the [CloudTrail User
#' Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/).
#' 
#' **Additional Resources**
#' 
#' For more information about credentials and request signing, see the
#' following:
#' 
#' -   [Amazon Web Services Security
#'     Credentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/security-creds.html) -
#'     This topic provides general information about the types of
#'     credentials used to access Amazon Web Services.
#' 
#' -   [Temporary Security
#'     Credentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp.html) -
#'     This section of the *IAM User Guide* describes how to create and use
#'     temporary security credentials.
#' 
#' -   [Signature Version 4 Signing
#'     Process](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_sigv.html) -
#'     This set of topics walks you through the process of signing a
#'     request using an access key ID and a secret access key.
#' 
#' **Commonly Used API Operations**
#' 
#' Of the API operations discussed in this guide, the following will prove
#' the most useful for most applications. You will likely perform
#' operations other than these, such as creating keys and assigning
#' policies, by using the console.
#' 
#' -   `encrypt`
#' 
#' -   `decrypt`
#' 
#' -   `generate_data_key`
#' 
#' -   `generate_data_key_without_plaintext`
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- kms(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- kms()
#' # The following example cancels deletion of the specified KMS key.
#' svc$cancel_key_deletion(
#'   KeyId = "1234abcd-12ab-34cd-56ef-1234567890ab"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:kms_cancel_key_deletion]{cancel_key_deletion} \tab Cancels the deletion of a KMS key\cr
#'  \link[paws.security.identity:kms_connect_custom_key_store]{connect_custom_key_store} \tab Connects or reconnects a custom key store to its backing key store\cr
#'  \link[paws.security.identity:kms_create_alias]{create_alias} \tab Creates a friendly name for a KMS key\cr
#'  \link[paws.security.identity:kms_create_custom_key_store]{create_custom_key_store} \tab Creates a custom key store backed by a key store that you own and manage\cr
#'  \link[paws.security.identity:kms_create_grant]{create_grant} \tab Adds a grant to a KMS key\cr
#'  \link[paws.security.identity:kms_create_key]{create_key} \tab Creates a unique customer managed KMS key in your Amazon Web Services account and Region\cr
#'  \link[paws.security.identity:kms_decrypt]{decrypt} \tab Decrypts ciphertext that was encrypted by a KMS key using any of the following operations:\cr
#'  \link[paws.security.identity:kms_delete_alias]{delete_alias} \tab Deletes the specified alias\cr
#'  \link[paws.security.identity:kms_delete_custom_key_store]{delete_custom_key_store} \tab Deletes a custom key store\cr
#'  \link[paws.security.identity:kms_delete_imported_key_material]{delete_imported_key_material} \tab Deletes key material that was previously imported\cr
#'  \link[paws.security.identity:kms_derive_shared_secret]{derive_shared_secret} \tab Derives a shared secret using a key agreement algorithm\cr
#'  \link[paws.security.identity:kms_describe_custom_key_stores]{describe_custom_key_stores} \tab Gets information about custom key stores in the account and Region\cr
#'  \link[paws.security.identity:kms_describe_key]{describe_key} \tab Provides detailed information about a KMS key\cr
#'  \link[paws.security.identity:kms_disable_key]{disable_key} \tab Sets the state of a KMS key to disabled\cr
#'  \link[paws.security.identity:kms_disable_key_rotation]{disable_key_rotation} \tab Disables automatic rotation of the key material of the specified symmetric encryption KMS key\cr
#'  \link[paws.security.identity:kms_disconnect_custom_key_store]{disconnect_custom_key_store} \tab Disconnects the custom key store from its backing key store\cr
#'  \link[paws.security.identity:kms_enable_key]{enable_key} \tab Sets the key state of a KMS key to enabled\cr
#'  \link[paws.security.identity:kms_enable_key_rotation]{enable_key_rotation} \tab Enables automatic rotation of the key material of the specified symmetric encryption KMS key\cr
#'  \link[paws.security.identity:kms_encrypt]{encrypt} \tab Encrypts plaintext of up to 4,096 bytes using a KMS key\cr
#'  \link[paws.security.identity:kms_generate_data_key]{generate_data_key} \tab Returns a unique symmetric data key for use outside of KMS\cr
#'  \link[paws.security.identity:kms_generate_data_key_pair]{generate_data_key_pair} \tab Returns a unique asymmetric data key pair for use outside of KMS\cr
#'  \link[paws.security.identity:kms_generate_data_key_pair_without_plaintext]{generate_data_key_pair_without_plaintext} \tab Returns a unique asymmetric data key pair for use outside of KMS\cr
#'  \link[paws.security.identity:kms_generate_data_key_without_plaintext]{generate_data_key_without_plaintext} \tab Returns a unique symmetric data key for use outside of KMS\cr
#'  \link[paws.security.identity:kms_generate_mac]{generate_mac} \tab Generates a hash-based message authentication code (HMAC) for a message using an HMAC KMS key and a MAC algorithm that the key supports\cr
#'  \link[paws.security.identity:kms_generate_random]{generate_random} \tab Returns a random byte string that is cryptographically secure\cr
#'  \link[paws.security.identity:kms_get_key_policy]{get_key_policy} \tab Gets a key policy attached to the specified KMS key\cr
#'  \link[paws.security.identity:kms_get_key_rotation_status]{get_key_rotation_status} \tab Provides detailed information about the rotation status for a KMS key, including whether automatic rotation of the key material is enabled for the specified KMS key, the rotation period, and the next scheduled rotation date\cr
#'  \link[paws.security.identity:kms_get_parameters_for_import]{get_parameters_for_import} \tab Returns the public key and an import token you need to import or reimport key material for a KMS key\cr
#'  \link[paws.security.identity:kms_get_public_key]{get_public_key} \tab Returns the public key of an asymmetric KMS key\cr
#'  \link[paws.security.identity:kms_import_key_material]{import_key_material} \tab Imports or reimports key material into an existing KMS key that was created without key material\cr
#'  \link[paws.security.identity:kms_list_aliases]{list_aliases} \tab Gets a list of aliases in the caller's Amazon Web Services account and region\cr
#'  \link[paws.security.identity:kms_list_grants]{list_grants} \tab Gets a list of all grants for the specified KMS key\cr
#'  \link[paws.security.identity:kms_list_key_policies]{list_key_policies} \tab Gets the names of the key policies that are attached to a KMS key\cr
#'  \link[paws.security.identity:kms_list_key_rotations]{list_key_rotations} \tab Returns information about all completed key material rotations for the specified KMS key\cr
#'  \link[paws.security.identity:kms_list_keys]{list_keys} \tab Gets a list of all KMS keys in the caller's Amazon Web Services account and Region\cr
#'  \link[paws.security.identity:kms_list_resource_tags]{list_resource_tags} \tab Returns all tags on the specified KMS key\cr
#'  \link[paws.security.identity:kms_list_retirable_grants]{list_retirable_grants} \tab Returns information about all grants in the Amazon Web Services account and Region that have the specified retiring principal\cr
#'  \link[paws.security.identity:kms_put_key_policy]{put_key_policy} \tab Attaches a key policy to the specified KMS key\cr
#'  \link[paws.security.identity:kms_re_encrypt]{re_encrypt} \tab Decrypts ciphertext and then reencrypts it entirely within KMS\cr
#'  \link[paws.security.identity:kms_replicate_key]{replicate_key} \tab Replicates a multi-Region key into the specified Region\cr
#'  \link[paws.security.identity:kms_retire_grant]{retire_grant} \tab Deletes a grant\cr
#'  \link[paws.security.identity:kms_revoke_grant]{revoke_grant} \tab Deletes the specified grant\cr
#'  \link[paws.security.identity:kms_rotate_key_on_demand]{rotate_key_on_demand} \tab Immediately initiates rotation of the key material of the specified symmetric encryption KMS key\cr
#'  \link[paws.security.identity:kms_schedule_key_deletion]{schedule_key_deletion} \tab Schedules the deletion of a KMS key\cr
#'  \link[paws.security.identity:kms_sign]{sign} \tab Creates a digital signature for a message or message digest by using the private key in an asymmetric signing KMS key\cr
#'  \link[paws.security.identity:kms_tag_resource]{tag_resource} \tab Adds or edits tags on a customer managed key\cr
#'  \link[paws.security.identity:kms_untag_resource]{untag_resource} \tab Deletes tags from a customer managed key\cr
#'  \link[paws.security.identity:kms_update_alias]{update_alias} \tab Associates an existing KMS alias with a different KMS key\cr
#'  \link[paws.security.identity:kms_update_custom_key_store]{update_custom_key_store} \tab Changes the properties of a custom key store\cr
#'  \link[paws.security.identity:kms_update_key_description]{update_key_description} \tab Updates the description of a KMS key\cr
#'  \link[paws.security.identity:kms_update_primary_region]{update_primary_region} \tab Changes the primary key of a multi-Region key\cr
#'  \link[paws.security.identity:kms_verify]{verify} \tab Verifies a digital signature that was generated by the Sign operation\cr
#'  \link[paws.security.identity:kms_verify_mac]{verify_mac} \tab Verifies the hash-based message authentication code (HMAC) for a specified message, HMAC KMS key, and MAC algorithm
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname kms
#' @export
kms <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::kms(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Macie 2
#'
#' @description
#' Amazon Macie
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- macie2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- macie2()
#' svc$accept_invitation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:macie2_accept_invitation]{accept_invitation} \tab Accepts an Amazon Macie membership invitation that was received from a specific account\cr
#'  \link[paws.security.identity:macie2_batch_get_custom_data_identifiers]{batch_get_custom_data_identifiers} \tab Retrieves information about one or more custom data identifiers\cr
#'  \link[paws.security.identity:macie2_batch_update_automated_discovery_accounts]{batch_update_automated_discovery_accounts} \tab Changes the status of automated sensitive data discovery for one or more accounts\cr
#'  \link[paws.security.identity:macie2_create_allow_list]{create_allow_list} \tab Creates and defines the settings for an allow list\cr
#'  \link[paws.security.identity:macie2_create_classification_job]{create_classification_job} \tab Creates and defines the settings for a classification job\cr
#'  \link[paws.security.identity:macie2_create_custom_data_identifier]{create_custom_data_identifier} \tab Creates and defines the criteria and other settings for a custom data identifier\cr
#'  \link[paws.security.identity:macie2_create_findings_filter]{create_findings_filter} \tab Creates and defines the criteria and other settings for a findings filter\cr
#'  \link[paws.security.identity:macie2_create_invitations]{create_invitations} \tab Sends an Amazon Macie membership invitation to one or more accounts\cr
#'  \link[paws.security.identity:macie2_create_member]{create_member} \tab Associates an account with an Amazon Macie administrator account\cr
#'  \link[paws.security.identity:macie2_create_sample_findings]{create_sample_findings} \tab Creates sample findings\cr
#'  \link[paws.security.identity:macie2_decline_invitations]{decline_invitations} \tab Declines Amazon Macie membership invitations that were received from specific accounts\cr
#'  \link[paws.security.identity:macie2_delete_allow_list]{delete_allow_list} \tab Deletes an allow list\cr
#'  \link[paws.security.identity:macie2_delete_custom_data_identifier]{delete_custom_data_identifier} \tab Soft deletes a custom data identifier\cr
#'  \link[paws.security.identity:macie2_delete_findings_filter]{delete_findings_filter} \tab Deletes a findings filter\cr
#'  \link[paws.security.identity:macie2_delete_invitations]{delete_invitations} \tab Deletes Amazon Macie membership invitations that were received from specific accounts\cr
#'  \link[paws.security.identity:macie2_delete_member]{delete_member} \tab Deletes the association between an Amazon Macie administrator account and an account\cr
#'  \link[paws.security.identity:macie2_describe_buckets]{describe_buckets} \tab Retrieves (queries) statistical data and other information about one or more S3 buckets that Amazon Macie monitors and analyzes for an account\cr
#'  \link[paws.security.identity:macie2_describe_classification_job]{describe_classification_job} \tab Retrieves the status and settings for a classification job\cr
#'  \link[paws.security.identity:macie2_describe_organization_configuration]{describe_organization_configuration} \tab Retrieves the Amazon Macie configuration settings for an organization in Organizations\cr
#'  \link[paws.security.identity:macie2_disable_macie]{disable_macie} \tab Disables Amazon Macie and deletes all settings and resources for a Macie account\cr
#'  \link[paws.security.identity:macie2_disable_organization_admin_account]{disable_organization_admin_account} \tab Disables an account as the delegated Amazon Macie administrator account for an organization in Organizations\cr
#'  \link[paws.security.identity:macie2_disassociate_from_administrator_account]{disassociate_from_administrator_account} \tab Disassociates a member account from its Amazon Macie administrator account\cr
#'  \link[paws.security.identity:macie2_disassociate_from_master_account]{disassociate_from_master_account} \tab (Deprecated) Disassociates a member account from its Amazon Macie administrator account\cr
#'  \link[paws.security.identity:macie2_disassociate_member]{disassociate_member} \tab Disassociates an Amazon Macie administrator account from a member account\cr
#'  \link[paws.security.identity:macie2_enable_macie]{enable_macie} \tab Enables Amazon Macie and specifies the configuration settings for a Macie account\cr
#'  \link[paws.security.identity:macie2_enable_organization_admin_account]{enable_organization_admin_account} \tab Designates an account as the delegated Amazon Macie administrator account for an organization in Organizations\cr
#'  \link[paws.security.identity:macie2_get_administrator_account]{get_administrator_account} \tab Retrieves information about the Amazon Macie administrator account for an account\cr
#'  \link[paws.security.identity:macie2_get_allow_list]{get_allow_list} \tab Retrieves the settings and status of an allow list\cr
#'  \link[paws.security.identity:macie2_get_automated_discovery_configuration]{get_automated_discovery_configuration} \tab Retrieves the configuration settings and status of automated sensitive data discovery for an organization or standalone account\cr
#'  \link[paws.security.identity:macie2_get_bucket_statistics]{get_bucket_statistics} \tab Retrieves (queries) aggregated statistical data about all the S3 buckets that Amazon Macie monitors and analyzes for an account\cr
#'  \link[paws.security.identity:macie2_get_classification_export_configuration]{get_classification_export_configuration} \tab Retrieves the configuration settings for storing data classification results\cr
#'  \link[paws.security.identity:macie2_get_classification_scope]{get_classification_scope} \tab Retrieves the classification scope settings for an account\cr
#'  \link[paws.security.identity:macie2_get_custom_data_identifier]{get_custom_data_identifier} \tab Retrieves the criteria and other settings for a custom data identifier\cr
#'  \link[paws.security.identity:macie2_get_findings]{get_findings} \tab Retrieves the details of one or more findings\cr
#'  \link[paws.security.identity:macie2_get_findings_filter]{get_findings_filter} \tab Retrieves the criteria and other settings for a findings filter\cr
#'  \link[paws.security.identity:macie2_get_findings_publication_configuration]{get_findings_publication_configuration} \tab Retrieves the configuration settings for publishing findings to Security Hub\cr
#'  \link[paws.security.identity:macie2_get_finding_statistics]{get_finding_statistics} \tab Retrieves (queries) aggregated statistical data about findings\cr
#'  \link[paws.security.identity:macie2_get_invitations_count]{get_invitations_count} \tab Retrieves the count of Amazon Macie membership invitations that were received by an account\cr
#'  \link[paws.security.identity:macie2_get_macie_session]{get_macie_session} \tab Retrieves the status and configuration settings for an Amazon Macie account\cr
#'  \link[paws.security.identity:macie2_get_master_account]{get_master_account} \tab (Deprecated) Retrieves information about the Amazon Macie administrator account for an account\cr
#'  \link[paws.security.identity:macie2_get_member]{get_member} \tab Retrieves information about an account that's associated with an Amazon Macie administrator account\cr
#'  \link[paws.security.identity:macie2_get_resource_profile]{get_resource_profile} \tab Retrieves (queries) sensitive data discovery statistics and the sensitivity score for an S3 bucket\cr
#'  \link[paws.security.identity:macie2_get_reveal_configuration]{get_reveal_configuration} \tab Retrieves the status and configuration settings for retrieving occurrences of sensitive data reported by findings\cr
#'  \link[paws.security.identity:macie2_get_sensitive_data_occurrences]{get_sensitive_data_occurrences} \tab Retrieves occurrences of sensitive data reported by a finding\cr
#'  \link[paws.security.identity:macie2_get_sensitive_data_occurrences_availability]{get_sensitive_data_occurrences_availability} \tab Checks whether occurrences of sensitive data can be retrieved for a finding\cr
#'  \link[paws.security.identity:macie2_get_sensitivity_inspection_template]{get_sensitivity_inspection_template} \tab Retrieves the settings for the sensitivity inspection template for an account\cr
#'  \link[paws.security.identity:macie2_get_usage_statistics]{get_usage_statistics} \tab Retrieves (queries) quotas and aggregated usage data for one or more accounts\cr
#'  \link[paws.security.identity:macie2_get_usage_totals]{get_usage_totals} \tab Retrieves (queries) aggregated usage data for an account\cr
#'  \link[paws.security.identity:macie2_list_allow_lists]{list_allow_lists} \tab Retrieves a subset of information about all the allow lists for an account\cr
#'  \link[paws.security.identity:macie2_list_automated_discovery_accounts]{list_automated_discovery_accounts} \tab Retrieves the status of automated sensitive data discovery for one or more accounts\cr
#'  \link[paws.security.identity:macie2_list_classification_jobs]{list_classification_jobs} \tab Retrieves a subset of information about one or more classification jobs\cr
#'  \link[paws.security.identity:macie2_list_classification_scopes]{list_classification_scopes} \tab Retrieves a subset of information about the classification scope for an account\cr
#'  \link[paws.security.identity:macie2_list_custom_data_identifiers]{list_custom_data_identifiers} \tab Retrieves a subset of information about the custom data identifiers for an account\cr
#'  \link[paws.security.identity:macie2_list_findings]{list_findings} \tab Retrieves a subset of information about one or more findings\cr
#'  \link[paws.security.identity:macie2_list_findings_filters]{list_findings_filters} \tab Retrieves a subset of information about all the findings filters for an account\cr
#'  \link[paws.security.identity:macie2_list_invitations]{list_invitations} \tab Retrieves information about Amazon Macie membership invitations that were received by an account\cr
#'  \link[paws.security.identity:macie2_list_managed_data_identifiers]{list_managed_data_identifiers} \tab Retrieves information about all the managed data identifiers that Amazon Macie currently provides\cr
#'  \link[paws.security.identity:macie2_list_members]{list_members} \tab Retrieves information about the accounts that are associated with an Amazon Macie administrator account\cr
#'  \link[paws.security.identity:macie2_list_organization_admin_accounts]{list_organization_admin_accounts} \tab Retrieves information about the delegated Amazon Macie administrator account for an organization in Organizations\cr
#'  \link[paws.security.identity:macie2_list_resource_profile_artifacts]{list_resource_profile_artifacts} \tab Retrieves information about objects that Amazon Macie selected from an S3 bucket for automated sensitive data discovery\cr
#'  \link[paws.security.identity:macie2_list_resource_profile_detections]{list_resource_profile_detections} \tab Retrieves information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket\cr
#'  \link[paws.security.identity:macie2_list_sensitivity_inspection_templates]{list_sensitivity_inspection_templates} \tab Retrieves a subset of information about the sensitivity inspection template for an account\cr
#'  \link[paws.security.identity:macie2_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves the tags (keys and values) that are associated with an Amazon Macie resource\cr
#'  \link[paws.security.identity:macie2_put_classification_export_configuration]{put_classification_export_configuration} \tab Adds or updates the configuration settings for storing data classification results\cr
#'  \link[paws.security.identity:macie2_put_findings_publication_configuration]{put_findings_publication_configuration} \tab Updates the configuration settings for publishing findings to Security Hub\cr
#'  \link[paws.security.identity:macie2_search_resources]{search_resources} \tab Retrieves (queries) statistical data and other information about Amazon Web Services resources that Amazon Macie monitors and analyzes for an account\cr
#'  \link[paws.security.identity:macie2_tag_resource]{tag_resource} \tab Adds or updates one or more tags (keys and values) that are associated with an Amazon Macie resource\cr
#'  \link[paws.security.identity:macie2_test_custom_data_identifier]{test_custom_data_identifier} \tab Tests criteria for a custom data identifier\cr
#'  \link[paws.security.identity:macie2_untag_resource]{untag_resource} \tab Removes one or more tags (keys and values) from an Amazon Macie resource\cr
#'  \link[paws.security.identity:macie2_update_allow_list]{update_allow_list} \tab Updates the settings for an allow list\cr
#'  \link[paws.security.identity:macie2_update_automated_discovery_configuration]{update_automated_discovery_configuration} \tab Changes the configuration settings and status of automated sensitive data discovery for an organization or standalone account\cr
#'  \link[paws.security.identity:macie2_update_classification_job]{update_classification_job} \tab Changes the status of a classification job\cr
#'  \link[paws.security.identity:macie2_update_classification_scope]{update_classification_scope} \tab Updates the classification scope settings for an account\cr
#'  \link[paws.security.identity:macie2_update_findings_filter]{update_findings_filter} \tab Updates the criteria and other settings for a findings filter\cr
#'  \link[paws.security.identity:macie2_update_macie_session]{update_macie_session} \tab Suspends or re-enables Amazon Macie, or updates the configuration settings for a Macie account\cr
#'  \link[paws.security.identity:macie2_update_member_session]{update_member_session} \tab Enables an Amazon Macie administrator to suspend or re-enable Macie for a member account\cr
#'  \link[paws.security.identity:macie2_update_organization_configuration]{update_organization_configuration} \tab Updates the Amazon Macie configuration settings for an organization in Organizations\cr
#'  \link[paws.security.identity:macie2_update_resource_profile]{update_resource_profile} \tab Updates the sensitivity score for an S3 bucket\cr
#'  \link[paws.security.identity:macie2_update_resource_profile_detections]{update_resource_profile_detections} \tab Updates the sensitivity scoring settings for an S3 bucket\cr
#'  \link[paws.security.identity:macie2_update_reveal_configuration]{update_reveal_configuration} \tab Updates the status and configuration settings for retrieving occurrences of sensitive data reported by findings\cr
#'  \link[paws.security.identity:macie2_update_sensitivity_inspection_template]{update_sensitivity_inspection_template} \tab Updates the settings for the sensitivity inspection template for an account
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname macie2
#' @export
macie2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::macie2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' PcaConnectorAd
#'
#' @description
#' Amazon Web Services Private CA Connector for Active Directory creates a
#' connector between Amazon Web Services Private CA and Active Directory
#' (AD) that enables you to provision security certificates for AD signed
#' by a private CA that you own. For more information, see [Amazon Web
#' Services Private CA Connector for Active
#' Directory](https://docs.aws.amazon.com/privateca/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- pcaconnectorad(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- pcaconnectorad()
#' svc$create_connector(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:pcaconnectorad_create_connector]{create_connector} \tab Creates a connector between Amazon Web Services Private CA and an Active Directory\cr
#'  \link[paws.security.identity:pcaconnectorad_create_directory_registration]{create_directory_registration} \tab Creates a directory registration that authorizes communication between Amazon Web Services Private CA and an Active Directory\cr
#'  \link[paws.security.identity:pcaconnectorad_create_service_principal_name]{create_service_principal_name} \tab Creates a service principal name (SPN) for the service account in Active Directory\cr
#'  \link[paws.security.identity:pcaconnectorad_create_template]{create_template} \tab Creates an Active Directory compatible certificate template\cr
#'  \link[paws.security.identity:pcaconnectorad_create_template_group_access_control_entry]{create_template_group_access_control_entry} \tab Create a group access control entry\cr
#'  \link[paws.security.identity:pcaconnectorad_delete_connector]{delete_connector} \tab Deletes a connector for Active Directory\cr
#'  \link[paws.security.identity:pcaconnectorad_delete_directory_registration]{delete_directory_registration} \tab Deletes a directory registration\cr
#'  \link[paws.security.identity:pcaconnectorad_delete_service_principal_name]{delete_service_principal_name} \tab Deletes the service principal name (SPN) used by a connector to authenticate with your Active Directory\cr
#'  \link[paws.security.identity:pcaconnectorad_delete_template]{delete_template} \tab Deletes a template\cr
#'  \link[paws.security.identity:pcaconnectorad_delete_template_group_access_control_entry]{delete_template_group_access_control_entry} \tab Deletes a group access control entry\cr
#'  \link[paws.security.identity:pcaconnectorad_get_connector]{get_connector} \tab Lists information about your connector\cr
#'  \link[paws.security.identity:pcaconnectorad_get_directory_registration]{get_directory_registration} \tab A structure that contains information about your directory registration\cr
#'  \link[paws.security.identity:pcaconnectorad_get_service_principal_name]{get_service_principal_name} \tab Lists the service principal name that the connector uses to authenticate with Active Directory\cr
#'  \link[paws.security.identity:pcaconnectorad_get_template]{get_template} \tab Retrieves a certificate template that the connector uses to issue certificates from a private CA\cr
#'  \link[paws.security.identity:pcaconnectorad_get_template_group_access_control_entry]{get_template_group_access_control_entry} \tab Retrieves the group access control entries for a template\cr
#'  \link[paws.security.identity:pcaconnectorad_list_connectors]{list_connectors} \tab Lists the connectors that you created by using the https://docs\cr
#'  \link[paws.security.identity:pcaconnectorad_list_directory_registrations]{list_directory_registrations} \tab Lists the directory registrations that you created by using the https://docs\cr
#'  \link[paws.security.identity:pcaconnectorad_list_service_principal_names]{list_service_principal_names} \tab Lists the service principal names that the connector uses to authenticate with Active Directory\cr
#'  \link[paws.security.identity:pcaconnectorad_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags, if any, that are associated with your resource\cr
#'  \link[paws.security.identity:pcaconnectorad_list_template_group_access_control_entries]{list_template_group_access_control_entries} \tab Lists group access control entries you created\cr
#'  \link[paws.security.identity:pcaconnectorad_list_templates]{list_templates} \tab Lists the templates, if any, that are associated with a connector\cr
#'  \link[paws.security.identity:pcaconnectorad_tag_resource]{tag_resource} \tab Adds one or more tags to your resource\cr
#'  \link[paws.security.identity:pcaconnectorad_untag_resource]{untag_resource} \tab Removes one or more tags from your resource\cr
#'  \link[paws.security.identity:pcaconnectorad_update_template]{update_template} \tab Update template configuration to define the information included in certificates\cr
#'  \link[paws.security.identity:pcaconnectorad_update_template_group_access_control_entry]{update_template_group_access_control_entry} \tab Update a group access control entry you created using CreateTemplateGroupAccessControlEntry
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname pcaconnectorad
#' @export
pcaconnectorad <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::pcaconnectorad(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Resource Access Manager
#'
#' @description
#' This is the *Resource Access Manager API Reference*. This documentation
#' provides descriptions and syntax for each of the actions and data types
#' in RAM. RAM is a service that helps you securely share your Amazon Web
#' Services resources to other Amazon Web Services accounts. If you use
#' Organizations to manage your accounts, then you can share your resources
#' with your entire organization or to organizational units (OUs). For
#' supported resource types, you can also share resources with individual
#' Identity and Access Management (IAM) roles and users.
#' 
#' To learn more about RAM, see the following resources:
#' 
#' -   [Resource Access Manager product page](https://aws.amazon.com/ram/)
#' 
#' -   [Resource Access Manager User
#'     Guide](https://docs.aws.amazon.com/ram/latest/userguide/)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ram(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ram()
#' svc$accept_resource_share_invitation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:ram_accept_resource_share_invitation]{accept_resource_share_invitation} \tab Accepts an invitation to a resource share from another Amazon Web Services account\cr
#'  \link[paws.security.identity:ram_associate_resource_share]{associate_resource_share} \tab Adds the specified list of principals and list of resources to a resource share\cr
#'  \link[paws.security.identity:ram_associate_resource_share_permission]{associate_resource_share_permission} \tab Adds or replaces the RAM permission for a resource type included in a resource share\cr
#'  \link[paws.security.identity:ram_create_permission]{create_permission} \tab Creates a customer managed permission for a specified resource type that you can attach to resource shares\cr
#'  \link[paws.security.identity:ram_create_permission_version]{create_permission_version} \tab Creates a new version of the specified customer managed permission\cr
#'  \link[paws.security.identity:ram_create_resource_share]{create_resource_share} \tab Creates a resource share\cr
#'  \link[paws.security.identity:ram_delete_permission]{delete_permission} \tab Deletes the specified customer managed permission in the Amazon Web Services Region in which you call this operation\cr
#'  \link[paws.security.identity:ram_delete_permission_version]{delete_permission_version} \tab Deletes one version of a customer managed permission\cr
#'  \link[paws.security.identity:ram_delete_resource_share]{delete_resource_share} \tab Deletes the specified resource share\cr
#'  \link[paws.security.identity:ram_disassociate_resource_share]{disassociate_resource_share} \tab Removes the specified principals or resources from participating in the specified resource share\cr
#'  \link[paws.security.identity:ram_disassociate_resource_share_permission]{disassociate_resource_share_permission} \tab Removes a managed permission from a resource share\cr
#'  \link[paws.security.identity:ram_enable_sharing_with_aws_organization]{enable_sharing_with_aws_organization} \tab Enables resource sharing within your organization in Organizations\cr
#'  \link[paws.security.identity:ram_get_permission]{get_permission} \tab Retrieves the contents of a managed permission in JSON format\cr
#'  \link[paws.security.identity:ram_get_resource_policies]{get_resource_policies} \tab Retrieves the resource policies for the specified resources that you own and have shared\cr
#'  \link[paws.security.identity:ram_get_resource_share_associations]{get_resource_share_associations} \tab Retrieves the lists of resources and principals that associated for resource shares that you own\cr
#'  \link[paws.security.identity:ram_get_resource_share_invitations]{get_resource_share_invitations} \tab Retrieves details about invitations that you have received for resource shares\cr
#'  \link[paws.security.identity:ram_get_resource_shares]{get_resource_shares} \tab Retrieves details about the resource shares that you own or that are shared with you\cr
#'  \link[paws.security.identity:ram_list_pending_invitation_resources]{list_pending_invitation_resources} \tab Lists the resources in a resource share that is shared with you but for which the invitation is still PENDING\cr
#'  \link[paws.security.identity:ram_list_permission_associations]{list_permission_associations} \tab Lists information about the managed permission and its associations to any resource shares that use this managed permission\cr
#'  \link[paws.security.identity:ram_list_permissions]{list_permissions} \tab Retrieves a list of available RAM permissions that you can use for the supported resource types\cr
#'  \link[paws.security.identity:ram_list_permission_versions]{list_permission_versions} \tab Lists the available versions of the specified RAM permission\cr
#'  \link[paws.security.identity:ram_list_principals]{list_principals} \tab Lists the principals that you are sharing resources with or that are sharing resources with you\cr
#'  \link[paws.security.identity:ram_list_replace_permission_associations_work]{list_replace_permission_associations_work} \tab Retrieves the current status of the asynchronous tasks performed by RAM when you perform the ReplacePermissionAssociationsWork operation\cr
#'  \link[paws.security.identity:ram_list_resources]{list_resources} \tab Lists the resources that you added to a resource share or the resources that are shared with you\cr
#'  \link[paws.security.identity:ram_list_resource_share_permissions]{list_resource_share_permissions} \tab Lists the RAM permissions that are associated with a resource share\cr
#'  \link[paws.security.identity:ram_list_resource_types]{list_resource_types} \tab Lists the resource types that can be shared by RAM\cr
#'  \link[paws.security.identity:ram_promote_permission_created_from_policy]{promote_permission_created_from_policy} \tab When you attach a resource-based policy to a resource, RAM automatically creates a resource share of featureSet=CREATED_FROM_POLICY with a managed permission that has the same IAM permissions as the original resource-based policy\cr
#'  \link[paws.security.identity:ram_promote_resource_share_created_from_policy]{promote_resource_share_created_from_policy} \tab When you attach a resource-based policy to a resource, RAM automatically creates a resource share of featureSet=CREATED_FROM_POLICY with a managed permission that has the same IAM permissions as the original resource-based policy\cr
#'  \link[paws.security.identity:ram_reject_resource_share_invitation]{reject_resource_share_invitation} \tab Rejects an invitation to a resource share from another Amazon Web Services account\cr
#'  \link[paws.security.identity:ram_replace_permission_associations]{replace_permission_associations} \tab Updates all resource shares that use a managed permission to a different managed permission\cr
#'  \link[paws.security.identity:ram_set_default_permission_version]{set_default_permission_version} \tab Designates the specified version number as the default version for the specified customer managed permission\cr
#'  \link[paws.security.identity:ram_tag_resource]{tag_resource} \tab Adds the specified tag keys and values to a resource share or managed permission\cr
#'  \link[paws.security.identity:ram_untag_resource]{untag_resource} \tab Removes the specified tag key and value pairs from the specified resource share or managed permission\cr
#'  \link[paws.security.identity:ram_update_resource_share]{update_resource_share} \tab Modifies some of the properties of the specified resource share
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ram
#' @export
ram <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::ram(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' IAM Roles Anywhere
#'
#' @description
#' Identity and Access Management Roles Anywhere provides a secure way for
#' your workloads such as servers, containers, and applications that run
#' outside of Amazon Web Services to obtain temporary Amazon Web Services
#' credentials. Your workloads can use the same IAM policies and roles you
#' have for native Amazon Web Services applications to access Amazon Web
#' Services resources. Using IAM Roles Anywhere eliminates the need to
#' manage long-term credentials for workloads running outside of Amazon Web
#' Services.
#' 
#' To use IAM Roles Anywhere, your workloads must use X.509 certificates
#' issued by their certificate authority (CA). You register the CA with IAM
#' Roles Anywhere as a trust anchor to establish trust between your public
#' key infrastructure (PKI) and IAM Roles Anywhere. If you don't manage
#' your own PKI system, you can use Private Certificate Authority to create
#' a CA and then use that to establish trust with IAM Roles Anywhere.
#' 
#' This guide describes the IAM Roles Anywhere operations that you can call
#' programmatically. For more information about IAM Roles Anywhere, see the
#' [IAM Roles Anywhere User
#' Guide](https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- iamrolesanywhere(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- iamrolesanywhere()
#' svc$create_profile(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:iamrolesanywhere_create_profile]{create_profile} \tab Creates a profile, a list of the roles that Roles Anywhere service is trusted to assume\cr
#'  \link[paws.security.identity:iamrolesanywhere_create_trust_anchor]{create_trust_anchor} \tab Creates a trust anchor to establish trust between IAM Roles Anywhere and your certificate authority (CA)\cr
#'  \link[paws.security.identity:iamrolesanywhere_delete_attribute_mapping]{delete_attribute_mapping} \tab Delete an entry from the attribute mapping rules enforced by a given profile\cr
#'  \link[paws.security.identity:iamrolesanywhere_delete_crl]{delete_crl} \tab Deletes a certificate revocation list (CRL)\cr
#'  \link[paws.security.identity:iamrolesanywhere_delete_profile]{delete_profile} \tab Deletes a profile\cr
#'  \link[paws.security.identity:iamrolesanywhere_delete_trust_anchor]{delete_trust_anchor} \tab Deletes a trust anchor\cr
#'  \link[paws.security.identity:iamrolesanywhere_disable_crl]{disable_crl} \tab Disables a certificate revocation list (CRL)\cr
#'  \link[paws.security.identity:iamrolesanywhere_disable_profile]{disable_profile} \tab Disables a profile\cr
#'  \link[paws.security.identity:iamrolesanywhere_disable_trust_anchor]{disable_trust_anchor} \tab Disables a trust anchor\cr
#'  \link[paws.security.identity:iamrolesanywhere_enable_crl]{enable_crl} \tab Enables a certificate revocation list (CRL)\cr
#'  \link[paws.security.identity:iamrolesanywhere_enable_profile]{enable_profile} \tab Enables temporary credential requests for a profile\cr
#'  \link[paws.security.identity:iamrolesanywhere_enable_trust_anchor]{enable_trust_anchor} \tab Enables a trust anchor\cr
#'  \link[paws.security.identity:iamrolesanywhere_get_crl]{get_crl} \tab Gets a certificate revocation list (CRL)\cr
#'  \link[paws.security.identity:iamrolesanywhere_get_profile]{get_profile} \tab Gets a profile\cr
#'  \link[paws.security.identity:iamrolesanywhere_get_subject]{get_subject} \tab Gets a subject, which associates a certificate identity with authentication attempts\cr
#'  \link[paws.security.identity:iamrolesanywhere_get_trust_anchor]{get_trust_anchor} \tab Gets a trust anchor\cr
#'  \link[paws.security.identity:iamrolesanywhere_import_crl]{import_crl} \tab Imports the certificate revocation list (CRL)\cr
#'  \link[paws.security.identity:iamrolesanywhere_list_crls]{list_crls} \tab Lists all certificate revocation lists (CRL) in the authenticated account and Amazon Web Services Region\cr
#'  \link[paws.security.identity:iamrolesanywhere_list_profiles]{list_profiles} \tab Lists all profiles in the authenticated account and Amazon Web Services Region\cr
#'  \link[paws.security.identity:iamrolesanywhere_list_subjects]{list_subjects} \tab Lists the subjects in the authenticated account and Amazon Web Services Region\cr
#'  \link[paws.security.identity:iamrolesanywhere_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags attached to the resource\cr
#'  \link[paws.security.identity:iamrolesanywhere_list_trust_anchors]{list_trust_anchors} \tab Lists the trust anchors in the authenticated account and Amazon Web Services Region\cr
#'  \link[paws.security.identity:iamrolesanywhere_put_attribute_mapping]{put_attribute_mapping} \tab Put an entry in the attribute mapping rules that will be enforced by a given profile\cr
#'  \link[paws.security.identity:iamrolesanywhere_put_notification_settings]{put_notification_settings} \tab Attaches a list of notification settings to a trust anchor\cr
#'  \link[paws.security.identity:iamrolesanywhere_reset_notification_settings]{reset_notification_settings} \tab Resets the custom notification setting to IAM Roles Anywhere default setting\cr
#'  \link[paws.security.identity:iamrolesanywhere_tag_resource]{tag_resource} \tab Attaches tags to a resource\cr
#'  \link[paws.security.identity:iamrolesanywhere_untag_resource]{untag_resource} \tab Removes tags from the resource\cr
#'  \link[paws.security.identity:iamrolesanywhere_update_crl]{update_crl} \tab Updates the certificate revocation list (CRL)\cr
#'  \link[paws.security.identity:iamrolesanywhere_update_profile]{update_profile} \tab Updates a profile, a list of the roles that IAM Roles Anywhere service is trusted to assume\cr
#'  \link[paws.security.identity:iamrolesanywhere_update_trust_anchor]{update_trust_anchor} \tab Updates a trust anchor
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname iamrolesanywhere
#' @export
iamrolesanywhere <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::iamrolesanywhere(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Secrets Manager
#'
#' @description
#' Amazon Web Services Secrets Manager
#' 
#' Amazon Web Services Secrets Manager provides a service to enable you to
#' store, manage, and retrieve, secrets.
#' 
#' This guide provides descriptions of the Secrets Manager API. For more
#' information about using this service, see the [Amazon Web Services
#' Secrets Manager User
#' Guide](https://docs.aws.amazon.com/secretsmanager/latest/userguide/).
#' 
#' **API Version**
#' 
#' This version of the Secrets Manager API Reference documents the Secrets
#' Manager API version 2017-10-17.
#' 
#' For a list of endpoints, see [Amazon Web Services Secrets Manager
#' endpoints](https://docs.aws.amazon.com/secretsmanager/latest/userguide/asm_access.html#endpoints).
#' 
#' **Support and Feedback for Amazon Web Services Secrets Manager**
#' 
#' We welcome your feedback. Send your comments to
#' <awssecretsmanager-feedback@@amazon.com>, or post your feedback and
#' questions in the Amazon Web Services Secrets Manager Discussion Forum.
#' For more information about the Amazon Web Services Discussion Forums,
#' see Forums Help.
#' 
#' **Logging API Requests**
#' 
#' Amazon Web Services Secrets Manager supports Amazon Web Services
#' CloudTrail, a service that records Amazon Web Services API calls for
#' your Amazon Web Services account and delivers log files to an Amazon S3
#' bucket. By using information that's collected by Amazon Web Services
#' CloudTrail, you can determine the requests successfully made to Secrets
#' Manager, who made the request, when it was made, and so on. For more
#' about Amazon Web Services Secrets Manager and support for Amazon Web
#' Services CloudTrail, see [Logging Amazon Web Services Secrets Manager
#' Events with Amazon Web Services
#' CloudTrail](https://docs.aws.amazon.com/secretsmanager/latest/userguide/monitoring.html#monitoring_cloudtrail)
#' in the *Amazon Web Services Secrets Manager User Guide*. To learn more
#' about CloudTrail, including enabling it and find your log files, see the
#' [Amazon Web Services CloudTrail User
#' Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-user-guide.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- secretsmanager(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- secretsmanager()
#' # The following example shows how to cancel rotation for a secret. The
#' # operation sets the RotationEnabled field to false and cancels all
#' # scheduled rotations. To resume scheduled rotations, you must re-enable
#' # rotation by calling the rotate-secret operation.
#' svc$cancel_rotate_secret(
#'   SecretId = "MyTestDatabaseSecret"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:secretsmanager_batch_get_secret_value]{batch_get_secret_value} \tab Retrieves the contents of the encrypted fields SecretString or SecretBinary for up to 20 secrets\cr
#'  \link[paws.security.identity:secretsmanager_cancel_rotate_secret]{cancel_rotate_secret} \tab Turns off automatic rotation, and if a rotation is currently in progress, cancels the rotation\cr
#'  \link[paws.security.identity:secretsmanager_create_secret]{create_secret} \tab Creates a new secret\cr
#'  \link[paws.security.identity:secretsmanager_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource-based permission policy attached to the secret\cr
#'  \link[paws.security.identity:secretsmanager_delete_secret]{delete_secret} \tab Deletes a secret and all of its versions\cr
#'  \link[paws.security.identity:secretsmanager_describe_secret]{describe_secret} \tab Retrieves the details of a secret\cr
#'  \link[paws.security.identity:secretsmanager_get_random_password]{get_random_password} \tab Generates a random password\cr
#'  \link[paws.security.identity:secretsmanager_get_resource_policy]{get_resource_policy} \tab Retrieves the JSON text of the resource-based policy document attached to the secret\cr
#'  \link[paws.security.identity:secretsmanager_get_secret_value]{get_secret_value} \tab Retrieves the contents of the encrypted fields SecretString or SecretBinary from the specified version of a secret, whichever contains content\cr
#'  \link[paws.security.identity:secretsmanager_list_secrets]{list_secrets} \tab Lists the secrets that are stored by Secrets Manager in the Amazon Web Services account, not including secrets that are marked for deletion\cr
#'  \link[paws.security.identity:secretsmanager_list_secret_version_ids]{list_secret_version_ids} \tab Lists the versions of a secret\cr
#'  \link[paws.security.identity:secretsmanager_put_resource_policy]{put_resource_policy} \tab Attaches a resource-based permission policy to a secret\cr
#'  \link[paws.security.identity:secretsmanager_put_secret_value]{put_secret_value} \tab Creates a new version with a new encrypted secret value and attaches it to the secret\cr
#'  \link[paws.security.identity:secretsmanager_remove_regions_from_replication]{remove_regions_from_replication} \tab For a secret that is replicated to other Regions, deletes the secret replicas from the Regions you specify\cr
#'  \link[paws.security.identity:secretsmanager_replicate_secret_to_regions]{replicate_secret_to_regions} \tab Replicates the secret to a new Regions\cr
#'  \link[paws.security.identity:secretsmanager_restore_secret]{restore_secret} \tab Cancels the scheduled deletion of a secret by removing the DeletedDate time stamp\cr
#'  \link[paws.security.identity:secretsmanager_rotate_secret]{rotate_secret} \tab Configures and starts the asynchronous process of rotating the secret\cr
#'  \link[paws.security.identity:secretsmanager_stop_replication_to_replica]{stop_replication_to_replica} \tab Removes the link between the replica secret and the primary secret and promotes the replica to a primary secret in the replica Region\cr
#'  \link[paws.security.identity:secretsmanager_tag_resource]{tag_resource} \tab Attaches tags to a secret\cr
#'  \link[paws.security.identity:secretsmanager_untag_resource]{untag_resource} \tab Removes specific tags from a secret\cr
#'  \link[paws.security.identity:secretsmanager_update_secret]{update_secret} \tab Modifies the details of a secret, including metadata and the secret value\cr
#'  \link[paws.security.identity:secretsmanager_update_secret_version_stage]{update_secret_version_stage} \tab Modifies the staging labels attached to a version of a secret\cr
#'  \link[paws.security.identity:secretsmanager_validate_resource_policy]{validate_resource_policy} \tab Validates that a resource policy does not grant a wide range of principals access to your secret
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname secretsmanager
#' @export
secretsmanager <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::secretsmanager(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS SecurityHub
#'
#' @description
#' Security Hub provides you with a comprehensive view of your security
#' state in Amazon Web Services and helps you assess your Amazon Web
#' Services environment against security industry standards and best
#' practices.
#' 
#' Security Hub collects security data across Amazon Web Services accounts,
#' Amazon Web Services services, and supported third-party products and
#' helps you analyze your security trends and identify the highest priority
#' security issues.
#' 
#' To help you manage the security state of your organization, Security Hub
#' supports multiple security standards. These include the Amazon Web
#' Services Foundational Security Best Practices (FSBP) standard developed
#' by Amazon Web Services, and external compliance frameworks such as the
#' Center for Internet Security (CIS), the Payment Card Industry Data
#' Security Standard (PCI DSS), and the National Institute of Standards and
#' Technology (NIST). Each standard includes several security controls,
#' each of which represents a security best practice. Security Hub runs
#' checks against security controls and generates control findings to help
#' you assess your compliance against security best practices.
#' 
#' In addition to generating control findings, Security Hub also receives
#' findings from other Amazon Web Services services, such as Amazon
#' GuardDuty and Amazon Inspector, and supported third-party products. This
#' gives you a single pane of glass into a variety of security-related
#' issues. You can also send Security Hub findings to other Amazon Web
#' Services services and supported third-party products.
#' 
#' Security Hub offers automation features that help you triage and
#' remediate security issues. For example, you can use automation rules to
#' automatically update critical findings when a security check fails. You
#' can also leverage the integration with Amazon EventBridge to trigger
#' automatic responses to specific findings.
#' 
#' This guide, the *Security Hub API Reference*, provides information about
#' the Security Hub API. This includes supported resources, HTTP methods,
#' parameters, and schemas. If you're new to Security Hub, you might find
#' it helpful to also review the [*Security Hub User
#' Guide*](https://docs.aws.amazon.com/securityhub/latest/userguide/what-is-securityhub.html)
#' . The user guide explains key concepts and provides procedures that
#' demonstrate how to use Security Hub features. It also provides
#' information about topics such as integrating Security Hub with other
#' Amazon Web Services services.
#' 
#' In addition to interacting with Security Hub by making calls to the
#' Security Hub API, you can use a current version of an Amazon Web
#' Services command line tool or SDK. Amazon Web Services provides tools
#' and SDKs that consist of libraries and sample code for various languages
#' and platforms, such as PowerShell, Java, Go, Python, C++, and .NET.
#' These tools and SDKs provide convenient, programmatic access to Security
#' Hub and other Amazon Web Services services . They also handle tasks such
#' as signing requests, managing errors, and retrying requests
#' automatically. For information about installing and using the Amazon Web
#' Services tools and SDKs, see [Tools to Build on Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#' 
#' With the exception of operations that are related to central
#' configuration, Security Hub API requests are executed only in the Amazon
#' Web Services Region that is currently active or in the specific Amazon
#' Web Services Region that you specify in your request. Any configuration
#' or settings change that results from the operation is applied only to
#' that Region. To make the same change in other Regions, call the same API
#' operation in each Region in which you want to apply the change. When you
#' use central configuration, API requests for enabling Security Hub,
#' standards, and controls are executed in the home Region and all linked
#' Regions. For a list of central configuration operations, see the
#' [Central configuration terms and
#' concepts](https://docs.aws.amazon.com/securityhub/latest/userguide/central-configuration-intro.html#central-configuration-concepts)
#' section of the *Security Hub User Guide*.
#' 
#' The following throttling limits apply to Security Hub API operations.
#' 
#' -   `batch_enable_standards` -
#'     `RateLimit` of 1 request per second. `BurstLimit` of 1 request per
#'     second.
#' 
#' -   `get_findings` - `RateLimit` of 3
#'     requests per second. `BurstLimit` of 6 requests per second.
#' 
#' -   `batch_import_findings` -
#'     `RateLimit` of 10 requests per second. `BurstLimit` of 30 requests
#'     per second.
#' 
#' -   `batch_update_findings` -
#'     `RateLimit` of 10 requests per second. `BurstLimit` of 30 requests
#'     per second.
#' 
#' -   `update_standards_control` -
#'     `RateLimit` of 1 request per second. `BurstLimit` of 5 requests per
#'     second.
#' 
#' -   All other operations - `RateLimit` of 10 requests per second.
#'     `BurstLimit` of 30 requests per second.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- securityhub(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- securityhub()
#' svc$accept_administrator_invitation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:securityhub_accept_administrator_invitation]{accept_administrator_invitation} \tab We recommend using Organizations instead of Security Hub invitations to manage your member accounts\cr
#'  \link[paws.security.identity:securityhub_accept_invitation]{accept_invitation} \tab This method is deprecated\cr
#'  \link[paws.security.identity:securityhub_batch_delete_automation_rules]{batch_delete_automation_rules} \tab Deletes one or more automation rules\cr
#'  \link[paws.security.identity:securityhub_batch_disable_standards]{batch_disable_standards} \tab Disables the standards specified by the provided StandardsSubscriptionArns\cr
#'  \link[paws.security.identity:securityhub_batch_enable_standards]{batch_enable_standards} \tab Enables the standards specified by the provided StandardsArn\cr
#'  \link[paws.security.identity:securityhub_batch_get_automation_rules]{batch_get_automation_rules} \tab Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs)\cr
#'  \link[paws.security.identity:securityhub_batch_get_configuration_policy_associations]{batch_get_configuration_policy_associations} \tab Returns associations between an Security Hub configuration and a batch of target accounts, organizational units, or the root\cr
#'  \link[paws.security.identity:securityhub_batch_get_security_controls]{batch_get_security_controls} \tab Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web Services Region\cr
#'  \link[paws.security.identity:securityhub_batch_get_standards_control_associations]{batch_get_standards_control_associations} \tab For a batch of security controls and standards, identifies whether each control is currently enabled or disabled in a standard\cr
#'  \link[paws.security.identity:securityhub_batch_import_findings]{batch_import_findings} \tab Imports security findings generated by a finding provider into Security Hub\cr
#'  \link[paws.security.identity:securityhub_batch_update_automation_rules]{batch_update_automation_rules} \tab Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters\cr
#'  \link[paws.security.identity:securityhub_batch_update_findings]{batch_update_findings} \tab Used by Security Hub customers to update information about their investigation into a finding\cr
#'  \link[paws.security.identity:securityhub_batch_update_standards_control_associations]{batch_update_standards_control_associations} \tab For a batch of security controls and standards, this operation updates the enablement status of a control in a standard\cr
#'  \link[paws.security.identity:securityhub_create_action_target]{create_action_target} \tab Creates a custom action target in Security Hub\cr
#'  \link[paws.security.identity:securityhub_create_automation_rule]{create_automation_rule} \tab Creates an automation rule based on input parameters\cr
#'  \link[paws.security.identity:securityhub_create_configuration_policy]{create_configuration_policy} \tab Creates a configuration policy with the defined configuration\cr
#'  \link[paws.security.identity:securityhub_create_finding_aggregator]{create_finding_aggregator} \tab The aggregation Region is now called the home Region\cr
#'  \link[paws.security.identity:securityhub_create_insight]{create_insight} \tab Creates a custom insight in Security Hub\cr
#'  \link[paws.security.identity:securityhub_create_members]{create_members} \tab Creates a member association in Security Hub between the specified accounts and the account used to make the request, which is the administrator account\cr
#'  \link[paws.security.identity:securityhub_decline_invitations]{decline_invitations} \tab We recommend using Organizations instead of Security Hub invitations to manage your member accounts\cr
#'  \link[paws.security.identity:securityhub_delete_action_target]{delete_action_target} \tab Deletes a custom action target from Security Hub\cr
#'  \link[paws.security.identity:securityhub_delete_configuration_policy]{delete_configuration_policy} \tab Deletes a configuration policy\cr
#'  \link[paws.security.identity:securityhub_delete_finding_aggregator]{delete_finding_aggregator} \tab The aggregation Region is now called the home Region\cr
#'  \link[paws.security.identity:securityhub_delete_insight]{delete_insight} \tab Deletes the insight specified by the InsightArn\cr
#'  \link[paws.security.identity:securityhub_delete_invitations]{delete_invitations} \tab We recommend using Organizations instead of Security Hub invitations to manage your member accounts\cr
#'  \link[paws.security.identity:securityhub_delete_members]{delete_members} \tab Deletes the specified member accounts from Security Hub\cr
#'  \link[paws.security.identity:securityhub_describe_action_targets]{describe_action_targets} \tab Returns a list of the custom action targets in Security Hub in your account\cr
#'  \link[paws.security.identity:securityhub_describe_hub]{describe_hub} \tab Returns details about the Hub resource in your account, including the HubArn and the time when you enabled Security Hub\cr
#'  \link[paws.security.identity:securityhub_describe_organization_configuration]{describe_organization_configuration} \tab Returns information about the way your organization is configured in Security Hub\cr
#'  \link[paws.security.identity:securityhub_describe_products]{describe_products} \tab Returns information about product integrations in Security Hub\cr
#'  \link[paws.security.identity:securityhub_describe_standards]{describe_standards} \tab Returns a list of the available standards in Security Hub\cr
#'  \link[paws.security.identity:securityhub_describe_standards_controls]{describe_standards_controls} \tab Returns a list of security standards controls\cr
#'  \link[paws.security.identity:securityhub_disable_import_findings_for_product]{disable_import_findings_for_product} \tab Disables the integration of the specified product with Security Hub\cr
#'  \link[paws.security.identity:securityhub_disable_organization_admin_account]{disable_organization_admin_account} \tab Disables a Security Hub administrator account\cr
#'  \link[paws.security.identity:securityhub_disable_security_hub]{disable_security_hub} \tab Disables Security Hub in your account only in the current Amazon Web Services Region\cr
#'  \link[paws.security.identity:securityhub_disassociate_from_administrator_account]{disassociate_from_administrator_account} \tab Disassociates the current Security Hub member account from the associated administrator account\cr
#'  \link[paws.security.identity:securityhub_disassociate_from_master_account]{disassociate_from_master_account} \tab This method is deprecated\cr
#'  \link[paws.security.identity:securityhub_disassociate_members]{disassociate_members} \tab Disassociates the specified member accounts from the associated administrator account\cr
#'  \link[paws.security.identity:securityhub_enable_import_findings_for_product]{enable_import_findings_for_product} \tab Enables the integration of a partner product with Security Hub\cr
#'  \link[paws.security.identity:securityhub_enable_organization_admin_account]{enable_organization_admin_account} \tab Designates the Security Hub administrator account for an organization\cr
#'  \link[paws.security.identity:securityhub_enable_security_hub]{enable_security_hub} \tab Enables Security Hub for your account in the current Region or the Region you specify in the request\cr
#'  \link[paws.security.identity:securityhub_get_administrator_account]{get_administrator_account} \tab Provides the details for the Security Hub administrator account for the current member account\cr
#'  \link[paws.security.identity:securityhub_get_configuration_policy]{get_configuration_policy} \tab Provides information about a configuration policy\cr
#'  \link[paws.security.identity:securityhub_get_configuration_policy_association]{get_configuration_policy_association} \tab Returns the association between a configuration and a target account, organizational unit, or the root\cr
#'  \link[paws.security.identity:securityhub_get_enabled_standards]{get_enabled_standards} \tab Returns a list of the standards that are currently enabled\cr
#'  \link[paws.security.identity:securityhub_get_finding_aggregator]{get_finding_aggregator} \tab The aggregation Region is now called the home Region\cr
#'  \link[paws.security.identity:securityhub_get_finding_history]{get_finding_history} \tab Returns history for a Security Hub finding in the last 90 days\cr
#'  \link[paws.security.identity:securityhub_get_findings]{get_findings} \tab Returns a list of findings that match the specified criteria\cr
#'  \link[paws.security.identity:securityhub_get_insight_results]{get_insight_results} \tab Lists the results of the Security Hub insight specified by the insight ARN\cr
#'  \link[paws.security.identity:securityhub_get_insights]{get_insights} \tab Lists and describes insights for the specified insight ARNs\cr
#'  \link[paws.security.identity:securityhub_get_invitations_count]{get_invitations_count} \tab We recommend using Organizations instead of Security Hub invitations to manage your member accounts\cr
#'  \link[paws.security.identity:securityhub_get_master_account]{get_master_account} \tab This method is deprecated\cr
#'  \link[paws.security.identity:securityhub_get_members]{get_members} \tab Returns the details for the Security Hub member accounts for the specified account IDs\cr
#'  \link[paws.security.identity:securityhub_get_security_control_definition]{get_security_control_definition} \tab Retrieves the definition of a security control\cr
#'  \link[paws.security.identity:securityhub_invite_members]{invite_members} \tab We recommend using Organizations instead of Security Hub invitations to manage your member accounts\cr
#'  \link[paws.security.identity:securityhub_list_automation_rules]{list_automation_rules} \tab A list of automation rules and their metadata for the calling account\cr
#'  \link[paws.security.identity:securityhub_list_configuration_policies]{list_configuration_policies} \tab Lists the configuration policies that the Security Hub delegated administrator has created for your organization\cr
#'  \link[paws.security.identity:securityhub_list_configuration_policy_associations]{list_configuration_policy_associations} \tab Provides information about the associations for your configuration policies and self-managed behavior\cr
#'  \link[paws.security.identity:securityhub_list_enabled_products_for_import]{list_enabled_products_for_import} \tab Lists all findings-generating solutions (products) that you are subscribed to receive findings from in Security Hub\cr
#'  \link[paws.security.identity:securityhub_list_finding_aggregators]{list_finding_aggregators} \tab If cross-Region aggregation is enabled, then ListFindingAggregators returns the Amazon Resource Name (ARN) of the finding aggregator\cr
#'  \link[paws.security.identity:securityhub_list_invitations]{list_invitations} \tab We recommend using Organizations instead of Security Hub invitations to manage your member accounts\cr
#'  \link[paws.security.identity:securityhub_list_members]{list_members} \tab Lists details about all member accounts for the current Security Hub administrator account\cr
#'  \link[paws.security.identity:securityhub_list_organization_admin_accounts]{list_organization_admin_accounts} \tab Lists the Security Hub administrator accounts\cr
#'  \link[paws.security.identity:securityhub_list_security_control_definitions]{list_security_control_definitions} \tab Lists all of the security controls that apply to a specified standard\cr
#'  \link[paws.security.identity:securityhub_list_standards_control_associations]{list_standards_control_associations} \tab Specifies whether a control is currently enabled or disabled in each enabled standard in the calling account\cr
#'  \link[paws.security.identity:securityhub_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags associated with a resource\cr
#'  \link[paws.security.identity:securityhub_start_configuration_policy_association]{start_configuration_policy_association} \tab Associates a target account, organizational unit, or the root with a specified configuration\cr
#'  \link[paws.security.identity:securityhub_start_configuration_policy_disassociation]{start_configuration_policy_disassociation} \tab Disassociates a target account, organizational unit, or the root from a specified configuration\cr
#'  \link[paws.security.identity:securityhub_tag_resource]{tag_resource} \tab Adds one or more tags to a resource\cr
#'  \link[paws.security.identity:securityhub_untag_resource]{untag_resource} \tab Removes one or more tags from a resource\cr
#'  \link[paws.security.identity:securityhub_update_action_target]{update_action_target} \tab Updates the name and description of a custom action target in Security Hub\cr
#'  \link[paws.security.identity:securityhub_update_configuration_policy]{update_configuration_policy} \tab Updates a configuration policy\cr
#'  \link[paws.security.identity:securityhub_update_finding_aggregator]{update_finding_aggregator} \tab The aggregation Region is now called the home Region\cr
#'  \link[paws.security.identity:securityhub_update_findings]{update_findings} \tab UpdateFindings is a deprecated operation\cr
#'  \link[paws.security.identity:securityhub_update_insight]{update_insight} \tab Updates the Security Hub insight identified by the specified insight ARN\cr
#'  \link[paws.security.identity:securityhub_update_organization_configuration]{update_organization_configuration} \tab Updates the configuration of your organization in Security Hub\cr
#'  \link[paws.security.identity:securityhub_update_security_control]{update_security_control} \tab Updates the properties of a security control\cr
#'  \link[paws.security.identity:securityhub_update_security_hub_configuration]{update_security_hub_configuration} \tab Updates configuration options for Security Hub\cr
#'  \link[paws.security.identity:securityhub_update_standards_control]{update_standards_control} \tab Used to control whether an individual security standard control is enabled or disabled
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname securityhub
#' @export
securityhub <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::securityhub(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Security Lake
#'
#' @description
#' Amazon Security Lake is a fully managed security data lake service. You
#' can use Security Lake to automatically centralize security data from
#' cloud, on-premises, and custom sources into a data lake that's stored in
#' your Amazon Web Services account. Amazon Web Services Organizations is
#' an account management service that lets you consolidate multiple Amazon
#' Web Services accounts into an organization that you create and centrally
#' manage. With Organizations, you can create member accounts and invite
#' existing accounts to join your organization. Security Lake helps you
#' analyze security data for a more complete understanding of your security
#' posture across the entire organization. It can also help you improve the
#' protection of your workloads, applications, and data.
#' 
#' The data lake is backed by Amazon Simple Storage Service (Amazon S3)
#' buckets, and you retain ownership over your data.
#' 
#' Amazon Security Lake integrates with CloudTrail, a service that provides
#' a record of actions taken by a user, role, or an Amazon Web Services
#' service. In Security Lake, CloudTrail captures API calls for Security
#' Lake as events. The calls captured include calls from the Security Lake
#' console and code calls to the Security Lake API operations. If you
#' create a trail, you can enable continuous delivery of CloudTrail events
#' to an Amazon S3 bucket, including events for Security Lake. If you don't
#' configure a trail, you can still view the most recent events in the
#' CloudTrail console in Event history. Using the information collected by
#' CloudTrail you can determine the request that was made to Security Lake,
#' the IP address from which the request was made, who made the request,
#' when it was made, and additional details. To learn more about Security
#' Lake information in CloudTrail, see the [Amazon Security Lake User
#' Guide](https://docs.aws.amazon.com/security-lake/latest/userguide/securitylake-cloudtrail.html).
#' 
#' Security Lake automates the collection of security-related log and event
#' data from integrated Amazon Web Services services and third-party
#' services. It also helps you manage the lifecycle of data with
#' customizable retention and replication settings. Security Lake converts
#' ingested data into Apache Parquet format and a standard open-source
#' schema called the Open Cybersecurity Schema Framework (OCSF).
#' 
#' Other Amazon Web Services services and third-party services can
#' subscribe to the data that's stored in Security Lake for incident
#' response and security data analytics.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- securitylake(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- securitylake()
#' svc$create_aws_log_source(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:securitylake_create_aws_log_source]{create_aws_log_source} \tab Adds a natively supported Amazon Web Services service as an Amazon Security Lake source\cr
#'  \link[paws.security.identity:securitylake_create_custom_log_source]{create_custom_log_source} \tab Adds a third-party custom source in Amazon Security Lake, from the Amazon Web Services Region where you want to create a custom source\cr
#'  \link[paws.security.identity:securitylake_create_data_lake]{create_data_lake} \tab Initializes an Amazon Security Lake instance with the provided (or default) configuration\cr
#'  \link[paws.security.identity:securitylake_create_data_lake_exception_subscription]{create_data_lake_exception_subscription} \tab Creates the specified notification subscription in Amazon Security Lake for the organization you specify\cr
#'  \link[paws.security.identity:securitylake_create_data_lake_organization_configuration]{create_data_lake_organization_configuration} \tab Automatically enables Amazon Security Lake for new member accounts in your organization\cr
#'  \link[paws.security.identity:securitylake_create_subscriber]{create_subscriber} \tab Creates a subscriber for accounts that are already enabled in Amazon Security Lake\cr
#'  \link[paws.security.identity:securitylake_create_subscriber_notification]{create_subscriber_notification} \tab Notifies the subscriber when new data is written to the data lake for the sources that the subscriber consumes in Security Lake\cr
#'  \link[paws.security.identity:securitylake_delete_aws_log_source]{delete_aws_log_source} \tab Removes a natively supported Amazon Web Services service as an Amazon Security Lake source\cr
#'  \link[paws.security.identity:securitylake_delete_custom_log_source]{delete_custom_log_source} \tab Removes a custom log source from Amazon Security Lake, to stop sending data from the custom source to Security Lake\cr
#'  \link[paws.security.identity:securitylake_delete_data_lake]{delete_data_lake} \tab When you disable Amazon Security Lake from your account, Security Lake is disabled in all Amazon Web Services Regions and it stops collecting data from your sources\cr
#'  \link[paws.security.identity:securitylake_delete_data_lake_exception_subscription]{delete_data_lake_exception_subscription} \tab Deletes the specified notification subscription in Amazon Security Lake for the organization you specify\cr
#'  \link[paws.security.identity:securitylake_delete_data_lake_organization_configuration]{delete_data_lake_organization_configuration} \tab Turns off automatic enablement of Amazon Security Lake for member accounts that are added to an organization in Organizations\cr
#'  \link[paws.security.identity:securitylake_delete_subscriber]{delete_subscriber} \tab Deletes the subscription permission and all notification settings for accounts that are already enabled in Amazon Security Lake\cr
#'  \link[paws.security.identity:securitylake_delete_subscriber_notification]{delete_subscriber_notification} \tab Deletes the specified subscription notification in Amazon Security Lake for the organization you specify\cr
#'  \link[paws.security.identity:securitylake_deregister_data_lake_delegated_administrator]{deregister_data_lake_delegated_administrator} \tab Deletes the Amazon Security Lake delegated administrator account for the organization\cr
#'  \link[paws.security.identity:securitylake_get_data_lake_exception_subscription]{get_data_lake_exception_subscription} \tab Retrieves the protocol and endpoint that were provided when subscribing to Amazon SNS topics for exception notifications\cr
#'  \link[paws.security.identity:securitylake_get_data_lake_organization_configuration]{get_data_lake_organization_configuration} \tab Retrieves the configuration that will be automatically set up for accounts added to the organization after the organization has onboarded to Amazon Security Lake\cr
#'  \link[paws.security.identity:securitylake_get_data_lake_sources]{get_data_lake_sources} \tab Retrieves a snapshot of the current Region, including whether Amazon Security Lake is enabled for those accounts and which sources Security Lake is collecting data from\cr
#'  \link[paws.security.identity:securitylake_get_subscriber]{get_subscriber} \tab Retrieves the subscription information for the specified subscription ID\cr
#'  \link[paws.security.identity:securitylake_list_data_lake_exceptions]{list_data_lake_exceptions} \tab Lists the Amazon Security Lake exceptions that you can use to find the source of problems and fix them\cr
#'  \link[paws.security.identity:securitylake_list_data_lakes]{list_data_lakes} \tab Retrieves the Amazon Security Lake configuration object for the specified Amazon Web Services Regions\cr
#'  \link[paws.security.identity:securitylake_list_log_sources]{list_log_sources} \tab Retrieves the log sources\cr
#'  \link[paws.security.identity:securitylake_list_subscribers]{list_subscribers} \tab Lists all subscribers for the specific Amazon Security Lake account ID\cr
#'  \link[paws.security.identity:securitylake_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves the tags (keys and values) that are associated with an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region\cr
#'  \link[paws.security.identity:securitylake_register_data_lake_delegated_administrator]{register_data_lake_delegated_administrator} \tab Designates the Amazon Security Lake delegated administrator account for the organization\cr
#'  \link[paws.security.identity:securitylake_tag_resource]{tag_resource} \tab Adds or updates one or more tags that are associated with an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region\cr
#'  \link[paws.security.identity:securitylake_untag_resource]{untag_resource} \tab Removes one or more tags (keys and values) from an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region\cr
#'  \link[paws.security.identity:securitylake_update_data_lake]{update_data_lake} \tab You can use UpdateDataLake to specify where to store your security data, how it should be encrypted at rest and for how long\cr
#'  \link[paws.security.identity:securitylake_update_data_lake_exception_subscription]{update_data_lake_exception_subscription} \tab Updates the specified notification subscription in Amazon Security Lake for the organization you specify\cr
#'  \link[paws.security.identity:securitylake_update_subscriber]{update_subscriber} \tab Updates an existing subscription for the given Amazon Security Lake account ID\cr
#'  \link[paws.security.identity:securitylake_update_subscriber_notification]{update_subscriber_notification} \tab Updates an existing notification method for the subscription (SQS or HTTPs endpoint) or switches the notification subscription endpoint for a subscriber
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname securitylake
#' @export
securitylake <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::securitylake(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Shield
#'
#' @description
#' Shield Advanced
#' 
#' This is the *Shield Advanced API Reference*. This guide is for
#' developers who need detailed information about the Shield Advanced API
#' actions, data types, and errors. For detailed information about WAF and
#' Shield Advanced features and an overview of how to use the WAF and
#' Shield Advanced APIs, see the [WAF and Shield Developer
#' Guide](https://docs.aws.amazon.com/waf/latest/developerguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- shield(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- shield()
#' svc$associate_drt_log_bucket(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:shield_associate_drt_log_bucket]{associate_drt_log_bucket} \tab Authorizes the Shield Response Team (SRT) to access the specified Amazon S3 bucket containing log data such as Application Load Balancer access logs, CloudFront logs, or logs from third party sources\cr
#'  \link[paws.security.identity:shield_associate_drt_role]{associate_drt_role} \tab Authorizes the Shield Response Team (SRT) using the specified role, to access your Amazon Web Services account to assist with DDoS attack mitigation during potential attacks\cr
#'  \link[paws.security.identity:shield_associate_health_check]{associate_health_check} \tab Adds health-based detection to the Shield Advanced protection for a resource\cr
#'  \link[paws.security.identity:shield_associate_proactive_engagement_details]{associate_proactive_engagement_details} \tab Initializes proactive engagement and sets the list of contacts for the Shield Response Team (SRT) to use\cr
#'  \link[paws.security.identity:shield_create_protection]{create_protection} \tab Enables Shield Advanced for a specific Amazon Web Services resource\cr
#'  \link[paws.security.identity:shield_create_protection_group]{create_protection_group} \tab Creates a grouping of protected resources so they can be handled as a collective\cr
#'  \link[paws.security.identity:shield_create_subscription]{create_subscription} \tab Activates Shield Advanced for an account\cr
#'  \link[paws.security.identity:shield_delete_protection]{delete_protection} \tab Deletes an Shield Advanced Protection\cr
#'  \link[paws.security.identity:shield_delete_protection_group]{delete_protection_group} \tab Removes the specified protection group\cr
#'  \link[paws.security.identity:shield_delete_subscription]{delete_subscription} \tab Removes Shield Advanced from an account\cr
#'  \link[paws.security.identity:shield_describe_attack]{describe_attack} \tab Describes the details of a DDoS attack\cr
#'  \link[paws.security.identity:shield_describe_attack_statistics]{describe_attack_statistics} \tab Provides information about the number and type of attacks Shield has detected in the last year for all resources that belong to your account, regardless of whether you've defined Shield protections for them\cr
#'  \link[paws.security.identity:shield_describe_drt_access]{describe_drt_access} \tab Returns the current role and list of Amazon S3 log buckets used by the Shield Response Team (SRT) to access your Amazon Web Services account while assisting with attack mitigation\cr
#'  \link[paws.security.identity:shield_describe_emergency_contact_settings]{describe_emergency_contact_settings} \tab A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support\cr
#'  \link[paws.security.identity:shield_describe_protection]{describe_protection} \tab Lists the details of a Protection object\cr
#'  \link[paws.security.identity:shield_describe_protection_group]{describe_protection_group} \tab Returns the specification for the specified protection group\cr
#'  \link[paws.security.identity:shield_describe_subscription]{describe_subscription} \tab Provides details about the Shield Advanced subscription for an account\cr
#'  \link[paws.security.identity:shield_disable_application_layer_automatic_response]{disable_application_layer_automatic_response} \tab Disable the Shield Advanced automatic application layer DDoS mitigation feature for the protected resource\cr
#'  \link[paws.security.identity:shield_disable_proactive_engagement]{disable_proactive_engagement} \tab Removes authorization from the Shield Response Team (SRT) to notify contacts about escalations to the SRT and to initiate proactive customer support\cr
#'  \link[paws.security.identity:shield_disassociate_drt_log_bucket]{disassociate_drt_log_bucket} \tab Removes the Shield Response Team's (SRT) access to the specified Amazon S3 bucket containing the logs that you shared previously\cr
#'  \link[paws.security.identity:shield_disassociate_drt_role]{disassociate_drt_role} \tab Removes the Shield Response Team's (SRT) access to your Amazon Web Services account\cr
#'  \link[paws.security.identity:shield_disassociate_health_check]{disassociate_health_check} \tab Removes health-based detection from the Shield Advanced protection for a resource\cr
#'  \link[paws.security.identity:shield_enable_application_layer_automatic_response]{enable_application_layer_automatic_response} \tab Enable the Shield Advanced automatic application layer DDoS mitigation for the protected resource\cr
#'  \link[paws.security.identity:shield_enable_proactive_engagement]{enable_proactive_engagement} \tab Authorizes the Shield Response Team (SRT) to use email and phone to notify contacts about escalations to the SRT and to initiate proactive customer support\cr
#'  \link[paws.security.identity:shield_get_subscription_state]{get_subscription_state} \tab Returns the SubscriptionState, either Active or Inactive\cr
#'  \link[paws.security.identity:shield_list_attacks]{list_attacks} \tab Returns all ongoing DDoS attacks or all DDoS attacks during a specified time period\cr
#'  \link[paws.security.identity:shield_list_protection_groups]{list_protection_groups} \tab Retrieves ProtectionGroup objects for the account\cr
#'  \link[paws.security.identity:shield_list_protections]{list_protections} \tab Retrieves Protection objects for the account\cr
#'  \link[paws.security.identity:shield_list_resources_in_protection_group]{list_resources_in_protection_group} \tab Retrieves the resources that are included in the protection group\cr
#'  \link[paws.security.identity:shield_list_tags_for_resource]{list_tags_for_resource} \tab Gets information about Amazon Web Services tags for a specified Amazon Resource Name (ARN) in Shield\cr
#'  \link[paws.security.identity:shield_tag_resource]{tag_resource} \tab Adds or updates tags for a resource in Shield\cr
#'  \link[paws.security.identity:shield_untag_resource]{untag_resource} \tab Removes tags from a resource in Shield\cr
#'  \link[paws.security.identity:shield_update_application_layer_automatic_response]{update_application_layer_automatic_response} \tab Updates an existing Shield Advanced automatic application layer DDoS mitigation configuration for the specified resource\cr
#'  \link[paws.security.identity:shield_update_emergency_contact_settings]{update_emergency_contact_settings} \tab Updates the details of the list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support\cr
#'  \link[paws.security.identity:shield_update_protection_group]{update_protection_group} \tab Updates an existing protection group\cr
#'  \link[paws.security.identity:shield_update_subscription]{update_subscription} \tab Updates the details of an existing subscription
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname shield
#' @export
shield <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::shield(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Single Sign-On
#'
#' @description
#' AWS IAM Identity Center (successor to AWS Single Sign-On) Portal is a
#' web service that makes it easy for you to assign user access to IAM
#' Identity Center resources such as the AWS access portal. Users can get
#' AWS account applications and roles assigned to them and get federated
#' into the application.
#' 
#' Although AWS Single Sign-On was renamed, the `sso` and `identitystore`
#' API namespaces will continue to retain their original name for backward
#' compatibility purposes. For more information, see [IAM Identity Center
#' rename](https://docs.aws.amazon.com/singlesignon/latest/userguide/what-is.html#renamed).
#' 
#' This reference guide describes the IAM Identity Center Portal operations
#' that you can call programatically and includes detailed information on
#' data types and errors.
#' 
#' AWS provides SDKs that consist of libraries and sample code for various
#' programming languages and platforms, such as Java, Ruby, .Net, iOS, or
#' Android. The SDKs provide a convenient way to create programmatic access
#' to IAM Identity Center and other AWS services. For more information
#' about the AWS SDKs, including how to download and install them, see
#' [Tools for Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sso(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sso()
#' svc$get_role_credentials(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:sso_get_role_credentials]{get_role_credentials} \tab Returns the STS short-term credentials for a given role name that is assigned to the user\cr
#'  \link[paws.security.identity:sso_list_account_roles]{list_account_roles} \tab Lists all roles that are assigned to the user for a given AWS account\cr
#'  \link[paws.security.identity:sso_list_accounts]{list_accounts} \tab Lists all AWS accounts assigned to the user\cr
#'  \link[paws.security.identity:sso_logout]{logout} \tab Removes the locally stored SSO tokens from the client-side cache and sends an API call to the IAM Identity Center service to invalidate the corresponding server-side IAM Identity Center sign in session
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sso
#' @export
sso <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::sso(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Single Sign-On Admin
#'
#' @description
#' IAM Identity Center (successor to Single Sign-On) helps you securely
#' create, or connect, your workforce identities and manage their access
#' centrally across Amazon Web Services accounts and applications. IAM
#' Identity Center is the recommended approach for workforce authentication
#' and authorization in Amazon Web Services, for organizations of any size
#' and type.
#' 
#' IAM Identity Center uses the `sso` and `identitystore` API namespaces.
#' 
#' This reference guide provides information on single sign-on operations
#' which could be used for access management of Amazon Web Services
#' accounts. For information about IAM Identity Center features, see the
#' [IAM Identity Center User
#' Guide](https://docs.aws.amazon.com/singlesignon/latest/userguide/what-is.html).
#' 
#' Many operations in the IAM Identity Center APIs rely on identifiers for
#' users and groups, known as principals. For more information about how to
#' work with principals and principal IDs in IAM Identity Center, see the
#' [Identity Store API
#' Reference](https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/welcome.html).
#' 
#' Amazon Web Services provides SDKs that consist of libraries and sample
#' code for various programming languages and platforms (Java, Ruby, .Net,
#' iOS, Android, and more). The SDKs provide a convenient way to create
#' programmatic access to IAM Identity Center and other Amazon Web Services
#' services. For more information about the Amazon Web Services SDKs,
#' including how to download and install them, see [Tools for Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ssoadmin(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ssoadmin()
#' svc$attach_customer_managed_policy_reference_to_permission_set(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:ssoadmin_attach_customer_managed_policy_reference_to_permission_set]{attach_customer_managed_policy_reference_to_permission_set} \tab Attaches the specified customer managed policy to the specified PermissionSet\cr
#'  \link[paws.security.identity:ssoadmin_attach_managed_policy_to_permission_set]{attach_managed_policy_to_permission_set} \tab Attaches an Amazon Web Services managed policy ARN to a permission set\cr
#'  \link[paws.security.identity:ssoadmin_create_account_assignment]{create_account_assignment} \tab Assigns access to a principal for a specified Amazon Web Services account using a specified permission set\cr
#'  \link[paws.security.identity:ssoadmin_create_application]{create_application} \tab Creates an application in IAM Identity Center for the given application provider\cr
#'  \link[paws.security.identity:ssoadmin_create_application_assignment]{create_application_assignment} \tab Grant application access to a user or group\cr
#'  \link[paws.security.identity:ssoadmin_create_instance]{create_instance} \tab Creates an instance of IAM Identity Center for a standalone Amazon Web Services account that is not managed by Organizations or a member Amazon Web Services account in an organization\cr
#'  \link[paws.security.identity:ssoadmin_create_instance_access_control_attribute_configuration]{create_instance_access_control_attribute_configuration} \tab Enables the attributes-based access control (ABAC) feature for the specified IAM Identity Center instance\cr
#'  \link[paws.security.identity:ssoadmin_create_permission_set]{create_permission_set} \tab Creates a permission set within a specified IAM Identity Center instance\cr
#'  \link[paws.security.identity:ssoadmin_create_trusted_token_issuer]{create_trusted_token_issuer} \tab Creates a connection to a trusted token issuer in an instance of IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_delete_account_assignment]{delete_account_assignment} \tab Deletes a principal's access from a specified Amazon Web Services account using a specified permission set\cr
#'  \link[paws.security.identity:ssoadmin_delete_application]{delete_application} \tab Deletes the association with the application\cr
#'  \link[paws.security.identity:ssoadmin_delete_application_access_scope]{delete_application_access_scope} \tab Deletes an IAM Identity Center access scope from an application\cr
#'  \link[paws.security.identity:ssoadmin_delete_application_assignment]{delete_application_assignment} \tab Revoke application access to an application by deleting application assignments for a user or group\cr
#'  \link[paws.security.identity:ssoadmin_delete_application_authentication_method]{delete_application_authentication_method} \tab Deletes an authentication method from an application\cr
#'  \link[paws.security.identity:ssoadmin_delete_application_grant]{delete_application_grant} \tab Deletes a grant from an application\cr
#'  \link[paws.security.identity:ssoadmin_delete_inline_policy_from_permission_set]{delete_inline_policy_from_permission_set} \tab Deletes the inline policy from a specified permission set\cr
#'  \link[paws.security.identity:ssoadmin_delete_instance]{delete_instance} \tab Deletes the instance of IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_delete_instance_access_control_attribute_configuration]{delete_instance_access_control_attribute_configuration} \tab Disables the attributes-based access control (ABAC) feature for the specified IAM Identity Center instance and deletes all of the attribute mappings that have been configured\cr
#'  \link[paws.security.identity:ssoadmin_delete_permissions_boundary_from_permission_set]{delete_permissions_boundary_from_permission_set} \tab Deletes the permissions boundary from a specified PermissionSet\cr
#'  \link[paws.security.identity:ssoadmin_delete_permission_set]{delete_permission_set} \tab Deletes the specified permission set\cr
#'  \link[paws.security.identity:ssoadmin_delete_trusted_token_issuer]{delete_trusted_token_issuer} \tab Deletes a trusted token issuer configuration from an instance of IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_describe_account_assignment_creation_status]{describe_account_assignment_creation_status} \tab Describes the status of the assignment creation request\cr
#'  \link[paws.security.identity:ssoadmin_describe_account_assignment_deletion_status]{describe_account_assignment_deletion_status} \tab Describes the status of the assignment deletion request\cr
#'  \link[paws.security.identity:ssoadmin_describe_application]{describe_application} \tab Retrieves the details of an application associated with an instance of IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_describe_application_assignment]{describe_application_assignment} \tab Retrieves a direct assignment of a user or group to an application\cr
#'  \link[paws.security.identity:ssoadmin_describe_application_provider]{describe_application_provider} \tab Retrieves details about a provider that can be used to connect an Amazon Web Services managed application or customer managed application to IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_describe_instance]{describe_instance} \tab Returns the details of an instance of IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_describe_instance_access_control_attribute_configuration]{describe_instance_access_control_attribute_configuration} \tab Returns the list of IAM Identity Center identity store attributes that have been configured to work with attributes-based access control (ABAC) for the specified IAM Identity Center instance\cr
#'  \link[paws.security.identity:ssoadmin_describe_permission_set]{describe_permission_set} \tab Gets the details of the permission set\cr
#'  \link[paws.security.identity:ssoadmin_describe_permission_set_provisioning_status]{describe_permission_set_provisioning_status} \tab Describes the status for the given permission set provisioning request\cr
#'  \link[paws.security.identity:ssoadmin_describe_trusted_token_issuer]{describe_trusted_token_issuer} \tab Retrieves details about a trusted token issuer configuration stored in an instance of IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_detach_customer_managed_policy_reference_from_permission_set]{detach_customer_managed_policy_reference_from_permission_set} \tab Detaches the specified customer managed policy from the specified PermissionSet\cr
#'  \link[paws.security.identity:ssoadmin_detach_managed_policy_from_permission_set]{detach_managed_policy_from_permission_set} \tab Detaches the attached Amazon Web Services managed policy ARN from the specified permission set\cr
#'  \link[paws.security.identity:ssoadmin_get_application_access_scope]{get_application_access_scope} \tab Retrieves the authorized targets for an IAM Identity Center access scope for an application\cr
#'  \link[paws.security.identity:ssoadmin_get_application_assignment_configuration]{get_application_assignment_configuration} \tab Retrieves the configuration of PutApplicationAssignmentConfiguration\cr
#'  \link[paws.security.identity:ssoadmin_get_application_authentication_method]{get_application_authentication_method} \tab Retrieves details about an authentication method used by an application\cr
#'  \link[paws.security.identity:ssoadmin_get_application_grant]{get_application_grant} \tab Retrieves details about an application grant\cr
#'  \link[paws.security.identity:ssoadmin_get_inline_policy_for_permission_set]{get_inline_policy_for_permission_set} \tab Obtains the inline policy assigned to the permission set\cr
#'  \link[paws.security.identity:ssoadmin_get_permissions_boundary_for_permission_set]{get_permissions_boundary_for_permission_set} \tab Obtains the permissions boundary for a specified PermissionSet\cr
#'  \link[paws.security.identity:ssoadmin_list_account_assignment_creation_status]{list_account_assignment_creation_status} \tab Lists the status of the Amazon Web Services account assignment creation requests for a specified IAM Identity Center instance\cr
#'  \link[paws.security.identity:ssoadmin_list_account_assignment_deletion_status]{list_account_assignment_deletion_status} \tab Lists the status of the Amazon Web Services account assignment deletion requests for a specified IAM Identity Center instance\cr
#'  \link[paws.security.identity:ssoadmin_list_account_assignments]{list_account_assignments} \tab Lists the assignee of the specified Amazon Web Services account with the specified permission set\cr
#'  \link[paws.security.identity:ssoadmin_list_account_assignments_for_principal]{list_account_assignments_for_principal} \tab Retrieves a list of the IAM Identity Center associated Amazon Web Services accounts that the principal has access to\cr
#'  \link[paws.security.identity:ssoadmin_list_accounts_for_provisioned_permission_set]{list_accounts_for_provisioned_permission_set} \tab Lists all the Amazon Web Services accounts where the specified permission set is provisioned\cr
#'  \link[paws.security.identity:ssoadmin_list_application_access_scopes]{list_application_access_scopes} \tab Lists the access scopes and authorized targets associated with an application\cr
#'  \link[paws.security.identity:ssoadmin_list_application_assignments]{list_application_assignments} \tab Lists Amazon Web Services account users that are assigned to an application\cr
#'  \link[paws.security.identity:ssoadmin_list_application_assignments_for_principal]{list_application_assignments_for_principal} \tab Lists the applications to which a specified principal is assigned\cr
#'  \link[paws.security.identity:ssoadmin_list_application_authentication_methods]{list_application_authentication_methods} \tab Lists all of the authentication methods supported by the specified application\cr
#'  \link[paws.security.identity:ssoadmin_list_application_grants]{list_application_grants} \tab List the grants associated with an application\cr
#'  \link[paws.security.identity:ssoadmin_list_application_providers]{list_application_providers} \tab Lists the application providers configured in the IAM Identity Center identity store\cr
#'  \link[paws.security.identity:ssoadmin_list_applications]{list_applications} \tab Lists all applications associated with the instance of IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_list_customer_managed_policy_references_in_permission_set]{list_customer_managed_policy_references_in_permission_set} \tab Lists all customer managed policies attached to a specified PermissionSet\cr
#'  \link[paws.security.identity:ssoadmin_list_instances]{list_instances} \tab Lists the details of the organization and account instances of IAM Identity Center that were created in or visible to the account calling this API\cr
#'  \link[paws.security.identity:ssoadmin_list_managed_policies_in_permission_set]{list_managed_policies_in_permission_set} \tab Lists the Amazon Web Services managed policy that is attached to a specified permission set\cr
#'  \link[paws.security.identity:ssoadmin_list_permission_set_provisioning_status]{list_permission_set_provisioning_status} \tab Lists the status of the permission set provisioning requests for a specified IAM Identity Center instance\cr
#'  \link[paws.security.identity:ssoadmin_list_permission_sets]{list_permission_sets} \tab Lists the PermissionSets in an IAM Identity Center instance\cr
#'  \link[paws.security.identity:ssoadmin_list_permission_sets_provisioned_to_account]{list_permission_sets_provisioned_to_account} \tab Lists all the permission sets that are provisioned to a specified Amazon Web Services account\cr
#'  \link[paws.security.identity:ssoadmin_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that are attached to a specified resource\cr
#'  \link[paws.security.identity:ssoadmin_list_trusted_token_issuers]{list_trusted_token_issuers} \tab Lists all the trusted token issuers configured in an instance of IAM Identity Center\cr
#'  \link[paws.security.identity:ssoadmin_provision_permission_set]{provision_permission_set} \tab The process by which a specified permission set is provisioned to the specified target\cr
#'  \link[paws.security.identity:ssoadmin_put_application_access_scope]{put_application_access_scope} \tab Adds or updates the list of authorized targets for an IAM Identity Center access scope for an application\cr
#'  \link[paws.security.identity:ssoadmin_put_application_assignment_configuration]{put_application_assignment_configuration} \tab Configure how users gain access to an application\cr
#'  \link[paws.security.identity:ssoadmin_put_application_authentication_method]{put_application_authentication_method} \tab Adds or updates an authentication method for an application\cr
#'  \link[paws.security.identity:ssoadmin_put_application_grant]{put_application_grant} \tab Adds a grant to an application\cr
#'  \link[paws.security.identity:ssoadmin_put_inline_policy_to_permission_set]{put_inline_policy_to_permission_set} \tab Attaches an inline policy to a permission set\cr
#'  \link[paws.security.identity:ssoadmin_put_permissions_boundary_to_permission_set]{put_permissions_boundary_to_permission_set} \tab Attaches an Amazon Web Services managed or customer managed policy to the specified PermissionSet as a permissions boundary\cr
#'  \link[paws.security.identity:ssoadmin_tag_resource]{tag_resource} \tab Associates a set of tags with a specified resource\cr
#'  \link[paws.security.identity:ssoadmin_untag_resource]{untag_resource} \tab Disassociates a set of tags from a specified resource\cr
#'  \link[paws.security.identity:ssoadmin_update_application]{update_application} \tab Updates application properties\cr
#'  \link[paws.security.identity:ssoadmin_update_instance]{update_instance} \tab Update the details for the instance of IAM Identity Center that is owned by the Amazon Web Services account\cr
#'  \link[paws.security.identity:ssoadmin_update_instance_access_control_attribute_configuration]{update_instance_access_control_attribute_configuration} \tab Updates the IAM Identity Center identity store attributes that you can use with the IAM Identity Center instance for attributes-based access control (ABAC)\cr
#'  \link[paws.security.identity:ssoadmin_update_permission_set]{update_permission_set} \tab Updates an existing permission set\cr
#'  \link[paws.security.identity:ssoadmin_update_trusted_token_issuer]{update_trusted_token_issuer} \tab Updates the name of the trusted token issuer, or the path of a source attribute or destination attribute for a trusted token issuer configuration
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ssoadmin
#' @export
ssoadmin <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::ssoadmin(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS SSO OIDC
#'
#' @description
#' IAM Identity Center OpenID Connect (OIDC) is a web service that enables
#' a client (such as CLI or a native application) to register with IAM
#' Identity Center. The service also enables the client to fetch the user’s
#' access token upon successful authentication and authorization with IAM
#' Identity Center.
#' 
#' **API namespaces**
#' 
#' IAM Identity Center uses the `sso` and `identitystore` API namespaces.
#' IAM Identity Center OpenID Connect uses the `sso-oidc` namespace.
#' 
#' **Considerations for using this guide**
#' 
#' Before you begin using this guide, we recommend that you first review
#' the following important information about how the IAM Identity Center
#' OIDC service works.
#' 
#' -   The IAM Identity Center OIDC service currently implements only the
#'     portions of the OAuth 2.0 Device Authorization Grant standard
#'     ([https://tools.ietf.org/html/rfc8628](https://datatracker.ietf.org/doc/html/rfc8628))
#'     that are necessary to enable single sign-on authentication with the
#'     CLI.
#' 
#' -   With older versions of the CLI, the service only emits OIDC access
#'     tokens, so to obtain a new token, users must explicitly
#'     re-authenticate. To access the OIDC flow that supports token refresh
#'     and doesn’t require re-authentication, update to the latest CLI
#'     version (1.27.10 for CLI V1 and 2.9.0 for CLI V2) with support for
#'     OIDC token refresh and configurable IAM Identity Center session
#'     durations. For more information, see [Configure Amazon Web Services
#'     access portal session
#'     duration](https://docs.aws.amazon.com/singlesignon/latest/userguide/configure-user-session.html)
#'     .
#' 
#' -   The access tokens provided by this service grant access to all
#'     Amazon Web Services account entitlements assigned to an IAM Identity
#'     Center user, not just a particular application.
#' 
#' -   The documentation in this guide does not describe the mechanism to
#'     convert the access token into Amazon Web Services Auth (“sigv4”)
#'     credentials for use with IAM-protected Amazon Web Services service
#'     endpoints. For more information, see
#'     [GetRoleCredentials](https://docs.aws.amazon.com/singlesignon/latest/PortalAPIReference/API_GetRoleCredentials.html)
#'     in the *IAM Identity Center Portal API Reference Guide*.
#' 
#' For general information about IAM Identity Center, see [What is IAM
#' Identity
#' Center?](https://docs.aws.amazon.com/singlesignon/latest/userguide/what-is.html)
#' in the *IAM Identity Center User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ssooidc(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ssooidc()
#' svc$create_token(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:ssooidc_create_token]{create_token} \tab Creates and returns access and refresh tokens for clients that are authenticated using client secrets\cr
#'  \link[paws.security.identity:ssooidc_create_token_with_iam]{create_token_with_iam} \tab Creates and returns access and refresh tokens for clients and applications that are authenticated using IAM entities\cr
#'  \link[paws.security.identity:ssooidc_register_client]{register_client} \tab Registers a public client with IAM Identity Center\cr
#'  \link[paws.security.identity:ssooidc_start_device_authorization]{start_device_authorization} \tab Initiates device authorization by requesting a pair of verification codes from the authorization service
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ssooidc
#' @export
ssooidc <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::ssooidc(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Security Token Service
#'
#' @description
#' Security Token Service
#' 
#' Security Token Service (STS) enables you to request temporary,
#' limited-privilege credentials for users. This guide provides
#' descriptions of the STS API. For more information about using this
#' service, see [Temporary Security
#' Credentials](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sts(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sts()
#' # 
#' svc$assume_role(
#'   ExternalId = "123ABC",
#'   Policy = "\{\"Version\":\"2012-10-17\",\"Statement\":[\{\"Sid\":\"Stmt1\",\"Effect\":\"A...",
#'   RoleArn = "arn:aws:iam::123456789012:role/demo",
#'   RoleSessionName = "testAssumeRoleSession",
#'   Tags = list(
#'     list(
#'       Key = "Project",
#'       Value = "Unicorn"
#'     ),
#'     list(
#'       Key = "Team",
#'       Value = "Automation"
#'     ),
#'     list(
#'       Key = "Cost-Center",
#'       Value = "12345"
#'     )
#'   ),
#'   TransitiveTagKeys = list(
#'     "Project",
#'     "Cost-Center"
#'   )
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:sts_assume_role]{assume_role} \tab Returns a set of temporary security credentials that you can use to access Amazon Web Services resources\cr
#'  \link[paws.security.identity:sts_assume_role_with_saml]{assume_role_with_saml} \tab Returns a set of temporary security credentials for users who have been authenticated via a SAML authentication response\cr
#'  \link[paws.security.identity:sts_assume_role_with_web_identity]{assume_role_with_web_identity} \tab Returns a set of temporary security credentials for users who have been authenticated in a mobile or web application with a web identity provider\cr
#'  \link[paws.security.identity:sts_assume_root]{assume_root} \tab Returns a set of short term credentials you can use to perform privileged tasks on a member account in your organization\cr
#'  \link[paws.security.identity:sts_decode_authorization_message]{decode_authorization_message} \tab Decodes additional information about the authorization status of a request from an encoded message returned in response to an Amazon Web Services request\cr
#'  \link[paws.security.identity:sts_get_access_key_info]{get_access_key_info} \tab Returns the account identifier for the specified access key ID\cr
#'  \link[paws.security.identity:sts_get_caller_identity]{get_caller_identity} \tab Returns details about the IAM user or role whose credentials are used to call the operation\cr
#'  \link[paws.security.identity:sts_get_federation_token]{get_federation_token} \tab Returns a set of temporary security credentials (consisting of an access key ID, a secret access key, and a security token) for a user\cr
#'  \link[paws.security.identity:sts_get_session_token]{get_session_token} \tab Returns a set of temporary credentials for an Amazon Web Services account or IAM user
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sts
#' @export
sts <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::sts(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Verified Permissions
#'
#' @description
#' Amazon Verified Permissions is a permissions management service from
#' Amazon Web Services. You can use Verified Permissions to manage
#' permissions for your application, and authorize user access based on
#' those permissions. Using Verified Permissions, application developers
#' can grant access based on information about the users, resources, and
#' requested actions. You can also evaluate additional information like
#' group membership, attributes of the resources, and session context, such
#' as time of request and IP addresses. Verified Permissions manages these
#' permissions by letting you create and store authorization policies for
#' your applications, such as consumer-facing web sites and enterprise
#' business systems.
#' 
#' Verified Permissions uses Cedar as the policy language to express your
#' permission requirements. Cedar supports both role-based access control
#' (RBAC) and attribute-based access control (ABAC) authorization models.
#' 
#' For more information about configuring, administering, and using Amazon
#' Verified Permissions in your applications, see the [Amazon Verified
#' Permissions User
#' Guide](https://docs.aws.amazon.com/verifiedpermissions/latest/userguide/).
#' 
#' For more information about the Cedar policy language, see the [Cedar
#' Policy Language Guide](https://docs.cedarpolicy.com/).
#' 
#' When you write Cedar policies that reference principals, resources and
#' actions, you can define the unique identifiers used for each of those
#' elements. We strongly recommend that you follow these best practices:
#' 
#' -   **Use values like universally unique identifiers (UUIDs) for all
#'     principal and resource identifiers.**
#' 
#'     For example, if user `jane` leaves the company, and you later let
#'     someone else use the name `jane`, then that new user automatically
#'     gets access to everything granted by policies that still reference
#'     `User::"jane"`. Cedar can’t distinguish between the new user and the
#'     old. This applies to both principal and resource identifiers. Always
#'     use identifiers that are guaranteed unique and never reused to
#'     ensure that you don’t unintentionally grant access because of the
#'     presence of an old identifier in a policy.
#' 
#'     Where you use a UUID for an entity, we recommend that you follow it
#'     with the // comment specifier and the ‘friendly’ name of your
#'     entity. This helps to make your policies easier to understand. For
#'     example: principal == User::"a1b2c3d4-e5f6-a1b2-c3d4-EXAMPLE11111",
#'     // alice
#' 
#' -   **Do not include personally identifying, confidential, or sensitive
#'     information as part of the unique identifier for your principals or
#'     resources.** These identifiers are included in log entries shared in
#'     CloudTrail trails.
#' 
#' Several operations return structures that appear similar, but have
#' different purposes. As new functionality is added to the product, the
#' structure used in a parameter of one operation might need to change in a
#' way that wouldn't make sense for the same parameter in a different
#' operation. To help you understand the purpose of each, the following
#' naming convention is used for the structures:
#' 
#' -   Parameter type structures that end in `Detail` are used in `Get`
#'     operations.
#' 
#' -   Parameter type structures that end in `Item` are used in `List`
#'     operations.
#' 
#' -   Parameter type structures that use neither suffix are used in the
#'     mutating (create and update) operations.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- verifiedpermissions(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- verifiedpermissions()
#' svc$batch_get_policy(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:verifiedpermissions_batch_get_policy]{batch_get_policy} \tab Retrieves information about a group (batch) of policies\cr
#'  \link[paws.security.identity:verifiedpermissions_batch_is_authorized]{batch_is_authorized} \tab Makes a series of decisions about multiple authorization requests for one principal or resource\cr
#'  \link[paws.security.identity:verifiedpermissions_batch_is_authorized_with_token]{batch_is_authorized_with_token} \tab Makes a series of decisions about multiple authorization requests for one token\cr
#'  \link[paws.security.identity:verifiedpermissions_create_identity_source]{create_identity_source} \tab Adds an identity source to a policy store–an Amazon Cognito user pool or OpenID Connect (OIDC) identity provider (IdP)\cr
#'  \link[paws.security.identity:verifiedpermissions_create_policy]{create_policy} \tab Creates a Cedar policy and saves it in the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_create_policy_store]{create_policy_store} \tab Creates a policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_create_policy_template]{create_policy_template} \tab Creates a policy template\cr
#'  \link[paws.security.identity:verifiedpermissions_delete_identity_source]{delete_identity_source} \tab Deletes an identity source that references an identity provider (IdP) such as Amazon Cognito\cr
#'  \link[paws.security.identity:verifiedpermissions_delete_policy]{delete_policy} \tab Deletes the specified policy from the policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_delete_policy_store]{delete_policy_store} \tab Deletes the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_delete_policy_template]{delete_policy_template} \tab Deletes the specified policy template from the policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_get_identity_source]{get_identity_source} \tab Retrieves the details about the specified identity source\cr
#'  \link[paws.security.identity:verifiedpermissions_get_policy]{get_policy} \tab Retrieves information about the specified policy\cr
#'  \link[paws.security.identity:verifiedpermissions_get_policy_store]{get_policy_store} \tab Retrieves details about a policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_get_policy_template]{get_policy_template} \tab Retrieve the details for the specified policy template in the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_get_schema]{get_schema} \tab Retrieve the details for the specified schema in the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_is_authorized]{is_authorized} \tab Makes an authorization decision about a service request described in the parameters\cr
#'  \link[paws.security.identity:verifiedpermissions_is_authorized_with_token]{is_authorized_with_token} \tab Makes an authorization decision about a service request described in the parameters\cr
#'  \link[paws.security.identity:verifiedpermissions_list_identity_sources]{list_identity_sources} \tab Returns a paginated list of all of the identity sources defined in the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_list_policies]{list_policies} \tab Returns a paginated list of all policies stored in the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_list_policy_stores]{list_policy_stores} \tab Returns a paginated list of all policy stores in the calling Amazon Web Services account\cr
#'  \link[paws.security.identity:verifiedpermissions_list_policy_templates]{list_policy_templates} \tab Returns a paginated list of all policy templates in the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_put_schema]{put_schema} \tab Creates or updates the policy schema in the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_update_identity_source]{update_identity_source} \tab Updates the specified identity source to use a new identity provider (IdP), or to change the mapping of identities from the IdP to a different principal entity type\cr
#'  \link[paws.security.identity:verifiedpermissions_update_policy]{update_policy} \tab Modifies a Cedar static policy in the specified policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_update_policy_store]{update_policy_store} \tab Modifies the validation setting for a policy store\cr
#'  \link[paws.security.identity:verifiedpermissions_update_policy_template]{update_policy_template} \tab Updates the specified policy template
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname verifiedpermissions
#' @export
verifiedpermissions <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::verifiedpermissions(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS WAF
#'
#' @description
#' This is **AWS WAF Classic** documentation. For more information, see
#' [AWS WAF
#' Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)
#' in the developer guide.
#' 
#' **For the latest version of AWS WAF**, use the AWS WAFV2 API and see the
#' [AWS WAF Developer
#' Guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).
#' With the latest version, AWS WAF has a single set of endpoints for
#' regional and global use.
#' 
#' This is the *AWS WAF Classic API Reference* for using AWS WAF Classic
#' with Amazon CloudFront. The AWS WAF Classic actions and data types
#' listed in the reference are available for protecting Amazon CloudFront
#' distributions. You can use these actions and data types via the endpoint
#' *waf.amazonaws.com*. This guide is for developers who need detailed
#' information about the AWS WAF Classic API actions, data types, and
#' errors. For detailed information about AWS WAF Classic features and an
#' overview of how to use the AWS WAF Classic API, see the [AWS WAF
#' Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)
#' in the developer guide.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- waf(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- waf()
#' # The following example creates an IP match set named MyIPSetFriendlyName.
#' svc$create_ip_set(
#'   ChangeToken = "abcd12f2-46da-4fdb-b8d5-fbd4c466928f",
#'   Name = "MyIPSetFriendlyName"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:waf_create_byte_match_set]{create_byte_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_geo_match_set]{create_geo_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_ip_set]{create_ip_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_rate_based_rule]{create_rate_based_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_regex_match_set]{create_regex_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_regex_pattern_set]{create_regex_pattern_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_rule]{create_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_rule_group]{create_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_size_constraint_set]{create_size_constraint_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_sql_injection_match_set]{create_sql_injection_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_web_acl]{create_web_acl} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_create_web_acl_migration_stack]{create_web_acl_migration_stack} \tab Creates an AWS CloudFormation WAFV2 template for the specified web ACL in the specified Amazon S3 bucket\cr
#'  \link[paws.security.identity:waf_create_xss_match_set]{create_xss_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_byte_match_set]{delete_byte_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_geo_match_set]{delete_geo_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_ip_set]{delete_ip_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_logging_configuration]{delete_logging_configuration} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_permission_policy]{delete_permission_policy} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_rate_based_rule]{delete_rate_based_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_regex_match_set]{delete_regex_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_regex_pattern_set]{delete_regex_pattern_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_rule]{delete_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_rule_group]{delete_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_size_constraint_set]{delete_size_constraint_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_sql_injection_match_set]{delete_sql_injection_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_web_acl]{delete_web_acl} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_delete_xss_match_set]{delete_xss_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_byte_match_set]{get_byte_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_change_token]{get_change_token} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_change_token_status]{get_change_token_status} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_geo_match_set]{get_geo_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_ip_set]{get_ip_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_logging_configuration]{get_logging_configuration} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_permission_policy]{get_permission_policy} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_rate_based_rule]{get_rate_based_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_rate_based_rule_managed_keys]{get_rate_based_rule_managed_keys} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_regex_match_set]{get_regex_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_regex_pattern_set]{get_regex_pattern_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_rule]{get_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_rule_group]{get_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_sampled_requests]{get_sampled_requests} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_size_constraint_set]{get_size_constraint_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_sql_injection_match_set]{get_sql_injection_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_web_acl]{get_web_acl} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_get_xss_match_set]{get_xss_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_activated_rules_in_rule_group]{list_activated_rules_in_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_byte_match_sets]{list_byte_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_geo_match_sets]{list_geo_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_ip_sets]{list_ip_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_logging_configurations]{list_logging_configurations} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_rate_based_rules]{list_rate_based_rules} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_regex_match_sets]{list_regex_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_regex_pattern_sets]{list_regex_pattern_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_rule_groups]{list_rule_groups} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_rules]{list_rules} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_size_constraint_sets]{list_size_constraint_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_sql_injection_match_sets]{list_sql_injection_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_subscribed_rule_groups]{list_subscribed_rule_groups} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_tags_for_resource]{list_tags_for_resource} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_web_ac_ls]{list_web_ac_ls} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_list_xss_match_sets]{list_xss_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_put_logging_configuration]{put_logging_configuration} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_put_permission_policy]{put_permission_policy} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_tag_resource]{tag_resource} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_untag_resource]{untag_resource} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_byte_match_set]{update_byte_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_geo_match_set]{update_geo_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_ip_set]{update_ip_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_rate_based_rule]{update_rate_based_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_regex_match_set]{update_regex_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_regex_pattern_set]{update_regex_pattern_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_rule]{update_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_rule_group]{update_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_size_constraint_set]{update_size_constraint_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_sql_injection_match_set]{update_sql_injection_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_web_acl]{update_web_acl} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:waf_update_xss_match_set]{update_xss_match_set} \tab This is AWS WAF Classic documentation
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname waf
#' @export
waf <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::waf(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS WAF Regional
#'
#' @description
#' This is **AWS WAF Classic Regional** documentation. For more
#' information, see [AWS WAF
#' Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)
#' in the developer guide.
#' 
#' **For the latest version of AWS WAF**, use the AWS WAFV2 API and see the
#' [AWS WAF Developer
#' Guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).
#' With the latest version, AWS WAF has a single set of endpoints for
#' regional and global use.
#' 
#' This is the *AWS WAF Regional Classic API Reference* for using AWS WAF
#' Classic with the AWS resources, Elastic Load Balancing (ELB) Application
#' Load Balancers and API Gateway APIs. The AWS WAF Classic actions and
#' data types listed in the reference are available for protecting Elastic
#' Load Balancing (ELB) Application Load Balancers and API Gateway APIs.
#' You can use these actions and data types by means of the endpoints
#' listed in [AWS Regions and
#' Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#waf_region).
#' This guide is for developers who need detailed information about the AWS
#' WAF Classic API actions, data types, and errors. For detailed
#' information about AWS WAF Classic features and an overview of how to use
#' the AWS WAF Classic API, see the [AWS WAF
#' Classic](https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)
#' in the developer guide.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- wafregional(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- wafregional()
#' # The following example creates an IP match set named MyIPSetFriendlyName.
#' svc$create_ip_set(
#'   ChangeToken = "abcd12f2-46da-4fdb-b8d5-fbd4c466928f",
#'   Name = "MyIPSetFriendlyName"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:wafregional_associate_web_acl]{associate_web_acl} \tab This is AWS WAF Classic Regional documentation\cr
#'  \link[paws.security.identity:wafregional_create_byte_match_set]{create_byte_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_geo_match_set]{create_geo_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_ip_set]{create_ip_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_rate_based_rule]{create_rate_based_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_regex_match_set]{create_regex_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_regex_pattern_set]{create_regex_pattern_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_rule]{create_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_rule_group]{create_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_size_constraint_set]{create_size_constraint_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_sql_injection_match_set]{create_sql_injection_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_web_acl]{create_web_acl} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_create_web_acl_migration_stack]{create_web_acl_migration_stack} \tab Creates an AWS CloudFormation WAFV2 template for the specified web ACL in the specified Amazon S3 bucket\cr
#'  \link[paws.security.identity:wafregional_create_xss_match_set]{create_xss_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_byte_match_set]{delete_byte_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_geo_match_set]{delete_geo_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_ip_set]{delete_ip_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_logging_configuration]{delete_logging_configuration} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_permission_policy]{delete_permission_policy} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_rate_based_rule]{delete_rate_based_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_regex_match_set]{delete_regex_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_regex_pattern_set]{delete_regex_pattern_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_rule]{delete_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_rule_group]{delete_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_size_constraint_set]{delete_size_constraint_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_sql_injection_match_set]{delete_sql_injection_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_web_acl]{delete_web_acl} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_delete_xss_match_set]{delete_xss_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_disassociate_web_acl]{disassociate_web_acl} \tab This is AWS WAF Classic Regional documentation\cr
#'  \link[paws.security.identity:wafregional_get_byte_match_set]{get_byte_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_change_token]{get_change_token} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_change_token_status]{get_change_token_status} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_geo_match_set]{get_geo_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_ip_set]{get_ip_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_logging_configuration]{get_logging_configuration} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_permission_policy]{get_permission_policy} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_rate_based_rule]{get_rate_based_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_rate_based_rule_managed_keys]{get_rate_based_rule_managed_keys} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_regex_match_set]{get_regex_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_regex_pattern_set]{get_regex_pattern_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_rule]{get_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_rule_group]{get_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_sampled_requests]{get_sampled_requests} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_size_constraint_set]{get_size_constraint_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_sql_injection_match_set]{get_sql_injection_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_web_acl]{get_web_acl} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_get_web_acl_for_resource]{get_web_acl_for_resource} \tab This is AWS WAF Classic Regional documentation\cr
#'  \link[paws.security.identity:wafregional_get_xss_match_set]{get_xss_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_activated_rules_in_rule_group]{list_activated_rules_in_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_byte_match_sets]{list_byte_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_geo_match_sets]{list_geo_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_ip_sets]{list_ip_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_logging_configurations]{list_logging_configurations} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_rate_based_rules]{list_rate_based_rules} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_regex_match_sets]{list_regex_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_regex_pattern_sets]{list_regex_pattern_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_resources_for_web_acl]{list_resources_for_web_acl} \tab This is AWS WAF Classic Regional documentation\cr
#'  \link[paws.security.identity:wafregional_list_rule_groups]{list_rule_groups} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_rules]{list_rules} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_size_constraint_sets]{list_size_constraint_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_sql_injection_match_sets]{list_sql_injection_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_subscribed_rule_groups]{list_subscribed_rule_groups} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_tags_for_resource]{list_tags_for_resource} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_web_ac_ls]{list_web_ac_ls} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_list_xss_match_sets]{list_xss_match_sets} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_put_logging_configuration]{put_logging_configuration} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_put_permission_policy]{put_permission_policy} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_tag_resource]{tag_resource} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_untag_resource]{untag_resource} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_byte_match_set]{update_byte_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_geo_match_set]{update_geo_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_ip_set]{update_ip_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_rate_based_rule]{update_rate_based_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_regex_match_set]{update_regex_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_regex_pattern_set]{update_regex_pattern_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_rule]{update_rule} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_rule_group]{update_rule_group} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_size_constraint_set]{update_size_constraint_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_sql_injection_match_set]{update_sql_injection_match_set} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_web_acl]{update_web_acl} \tab This is AWS WAF Classic documentation\cr
#'  \link[paws.security.identity:wafregional_update_xss_match_set]{update_xss_match_set} \tab This is AWS WAF Classic documentation
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname wafregional
#' @export
wafregional <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::wafregional(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS WAFV2
#'
#' @description
#' WAF
#' 
#' This is the latest version of the **WAF** API, released in November,
#' 2019. The names of the entities that you use to access this API, like
#' endpoints and namespaces, all have the versioning information added,
#' like "V2" or "v2", to distinguish from the prior version. We recommend
#' migrating your resources to this version, because it has a number of
#' significant improvements.
#' 
#' If you used WAF prior to this release, you can't use this WAFV2 API to
#' access any WAF resources that you created before. WAF Classic support
#' will end on September 30, 2025.
#' 
#' For information about WAF, including how to migrate your WAF Classic
#' resources to this version, see the [WAF Developer
#' Guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).
#' 
#' WAF is a web application firewall that lets you monitor the HTTP and
#' HTTPS requests that are forwarded to a protected resource. Protected
#' resource types include Amazon CloudFront distribution, Amazon API
#' Gateway REST API, Application Load Balancer, AppSync GraphQL API, Amazon
#' Cognito user pool, App Runner service, and Amazon Web Services Verified
#' Access instance. WAF also lets you control access to your content, to
#' protect the Amazon Web Services resource that WAF is monitoring. Based
#' on conditions that you specify, such as the IP addresses that requests
#' originate from or the values of query strings, the protected resource
#' responds to requests with either the requested content, an HTTP 403
#' status code (Forbidden), or with a custom response.
#' 
#' This API guide is for developers who need detailed information about WAF
#' API actions, data types, and errors. For detailed information about WAF
#' features and guidance for configuring and using WAF, see the [WAF
#' Developer
#' Guide](https://docs.aws.amazon.com/waf/latest/developerguide/what-is-aws-waf.html).
#' 
#' You can make calls using the endpoints listed in [WAF endpoints and
#' quotas](https://docs.aws.amazon.com/general/latest/gr/waf.html).
#' 
#' -   For regional resources, you can use any of the endpoints in the
#'     list. A regional application can be an Application Load Balancer
#'     (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an
#'     Amazon Cognito user pool, an App Runner service, or an Amazon Web
#'     Services Verified Access instance.
#' 
#' -   For Amazon CloudFront, you must use the API endpoint listed for US
#'     East (N. Virginia): us-east-1.
#' 
#' Alternatively, you can use one of the Amazon Web Services SDKs to access
#' an API that's tailored to the programming language or platform that
#' you're using. For more information, see [Amazon Web Services
#' SDKs](https://aws.amazon.com/developer/tools/#SDKs).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- wafv2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- wafv2()
#' svc$associate_web_acl(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.security.identity:wafv2_associate_web_acl]{associate_web_acl} \tab Associates a web ACL with a resource, to protect the resource\cr
#'  \link[paws.security.identity:wafv2_check_capacity]{check_capacity} \tab Returns the web ACL capacity unit (WCU) requirements for a specified scope and set of rules\cr
#'  \link[paws.security.identity:wafv2_create_api_key]{create_api_key} \tab Creates an API key that contains a set of token domains\cr
#'  \link[paws.security.identity:wafv2_create_ip_set]{create_ip_set} \tab Creates an IPSet, which you use to identify web requests that originate from specific IP addresses or ranges of IP addresses\cr
#'  \link[paws.security.identity:wafv2_create_regex_pattern_set]{create_regex_pattern_set} \tab Creates a RegexPatternSet, which you reference in a RegexPatternSetReferenceStatement, to have WAF inspect a web request component for the specified patterns\cr
#'  \link[paws.security.identity:wafv2_create_rule_group]{create_rule_group} \tab Creates a RuleGroup per the specifications provided\cr
#'  \link[paws.security.identity:wafv2_create_web_acl]{create_web_acl} \tab Creates a WebACL per the specifications provided\cr
#'  \link[paws.security.identity:wafv2_delete_api_key]{delete_api_key} \tab Deletes the specified API key\cr
#'  \link[paws.security.identity:wafv2_delete_firewall_manager_rule_groups]{delete_firewall_manager_rule_groups} \tab Deletes all rule groups that are managed by Firewall Manager from the specified WebACL\cr
#'  \link[paws.security.identity:wafv2_delete_ip_set]{delete_ip_set} \tab Deletes the specified IPSet\cr
#'  \link[paws.security.identity:wafv2_delete_logging_configuration]{delete_logging_configuration} \tab Deletes the LoggingConfiguration from the specified web ACL\cr
#'  \link[paws.security.identity:wafv2_delete_permission_policy]{delete_permission_policy} \tab Permanently deletes an IAM policy from the specified rule group\cr
#'  \link[paws.security.identity:wafv2_delete_regex_pattern_set]{delete_regex_pattern_set} \tab Deletes the specified RegexPatternSet\cr
#'  \link[paws.security.identity:wafv2_delete_rule_group]{delete_rule_group} \tab Deletes the specified RuleGroup\cr
#'  \link[paws.security.identity:wafv2_delete_web_acl]{delete_web_acl} \tab Deletes the specified WebACL\cr
#'  \link[paws.security.identity:wafv2_describe_all_managed_products]{describe_all_managed_products} \tab Provides high-level information for the Amazon Web Services Managed Rules rule groups and Amazon Web Services Marketplace managed rule groups\cr
#'  \link[paws.security.identity:wafv2_describe_managed_products_by_vendor]{describe_managed_products_by_vendor} \tab Provides high-level information for the managed rule groups owned by a specific vendor\cr
#'  \link[paws.security.identity:wafv2_describe_managed_rule_group]{describe_managed_rule_group} \tab Provides high-level information for a managed rule group, including descriptions of the rules\cr
#'  \link[paws.security.identity:wafv2_disassociate_web_acl]{disassociate_web_acl} \tab Disassociates the specified resource from its web ACL association, if it has one\cr
#'  \link[paws.security.identity:wafv2_generate_mobile_sdk_release_url]{generate_mobile_sdk_release_url} \tab Generates a presigned download URL for the specified release of the mobile SDK\cr
#'  \link[paws.security.identity:wafv2_get_decrypted_api_key]{get_decrypted_api_key} \tab Returns your API key in decrypted form\cr
#'  \link[paws.security.identity:wafv2_get_ip_set]{get_ip_set} \tab Retrieves the specified IPSet\cr
#'  \link[paws.security.identity:wafv2_get_logging_configuration]{get_logging_configuration} \tab Returns the LoggingConfiguration for the specified web ACL\cr
#'  \link[paws.security.identity:wafv2_get_managed_rule_set]{get_managed_rule_set} \tab Retrieves the specified managed rule set\cr
#'  \link[paws.security.identity:wafv2_get_mobile_sdk_release]{get_mobile_sdk_release} \tab Retrieves information for the specified mobile SDK release, including release notes and tags\cr
#'  \link[paws.security.identity:wafv2_get_permission_policy]{get_permission_policy} \tab Returns the IAM policy that is attached to the specified rule group\cr
#'  \link[paws.security.identity:wafv2_get_rate_based_statement_managed_keys]{get_rate_based_statement_managed_keys} \tab Retrieves the IP addresses that are currently blocked by a rate-based rule instance\cr
#'  \link[paws.security.identity:wafv2_get_regex_pattern_set]{get_regex_pattern_set} \tab Retrieves the specified RegexPatternSet\cr
#'  \link[paws.security.identity:wafv2_get_rule_group]{get_rule_group} \tab Retrieves the specified RuleGroup\cr
#'  \link[paws.security.identity:wafv2_get_sampled_requests]{get_sampled_requests} \tab Gets detailed information about a specified number of requests--a sample--that WAF randomly selects from among the first 5,000 requests that your Amazon Web Services resource received during a time range that you choose\cr
#'  \link[paws.security.identity:wafv2_get_web_acl]{get_web_acl} \tab Retrieves the specified WebACL\cr
#'  \link[paws.security.identity:wafv2_get_web_acl_for_resource]{get_web_acl_for_resource} \tab Retrieves the WebACL for the specified resource\cr
#'  \link[paws.security.identity:wafv2_list_api_keys]{list_api_keys} \tab Retrieves a list of the API keys that you've defined for the specified scope\cr
#'  \link[paws.security.identity:wafv2_list_available_managed_rule_groups]{list_available_managed_rule_groups} \tab Retrieves an array of managed rule groups that are available for you to use\cr
#'  \link[paws.security.identity:wafv2_list_available_managed_rule_group_versions]{list_available_managed_rule_group_versions} \tab Returns a list of the available versions for the specified managed rule group\cr
#'  \link[paws.security.identity:wafv2_list_ip_sets]{list_ip_sets} \tab Retrieves an array of IPSetSummary objects for the IP sets that you manage\cr
#'  \link[paws.security.identity:wafv2_list_logging_configurations]{list_logging_configurations} \tab Retrieves an array of your LoggingConfiguration objects\cr
#'  \link[paws.security.identity:wafv2_list_managed_rule_sets]{list_managed_rule_sets} \tab Retrieves the managed rule sets that you own\cr
#'  \link[paws.security.identity:wafv2_list_mobile_sdk_releases]{list_mobile_sdk_releases} \tab Retrieves a list of the available releases for the mobile SDK and the specified device platform\cr
#'  \link[paws.security.identity:wafv2_list_regex_pattern_sets]{list_regex_pattern_sets} \tab Retrieves an array of RegexPatternSetSummary objects for the regex pattern sets that you manage\cr
#'  \link[paws.security.identity:wafv2_list_resources_for_web_acl]{list_resources_for_web_acl} \tab Retrieves an array of the Amazon Resource Names (ARNs) for the resources that are associated with the specified web ACL\cr
#'  \link[paws.security.identity:wafv2_list_rule_groups]{list_rule_groups} \tab Retrieves an array of RuleGroupSummary objects for the rule groups that you manage\cr
#'  \link[paws.security.identity:wafv2_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves the TagInfoForResource for the specified resource\cr
#'  \link[paws.security.identity:wafv2_list_web_ac_ls]{list_web_ac_ls} \tab Retrieves an array of WebACLSummary objects for the web ACLs that you manage\cr
#'  \link[paws.security.identity:wafv2_put_logging_configuration]{put_logging_configuration} \tab Enables the specified LoggingConfiguration, to start logging from a web ACL, according to the configuration provided\cr
#'  \link[paws.security.identity:wafv2_put_managed_rule_set_versions]{put_managed_rule_set_versions} \tab Defines the versions of your managed rule set that you are offering to the customers\cr
#'  \link[paws.security.identity:wafv2_put_permission_policy]{put_permission_policy} \tab Use this to share a rule group with other accounts\cr
#'  \link[paws.security.identity:wafv2_tag_resource]{tag_resource} \tab Associates tags with the specified Amazon Web Services resource\cr
#'  \link[paws.security.identity:wafv2_untag_resource]{untag_resource} \tab Disassociates tags from an Amazon Web Services resource\cr
#'  \link[paws.security.identity:wafv2_update_ip_set]{update_ip_set} \tab Updates the specified IPSet\cr
#'  \link[paws.security.identity:wafv2_update_managed_rule_set_version_expiry_date]{update_managed_rule_set_version_expiry_date} \tab Updates the expiration information for your managed rule set\cr
#'  \link[paws.security.identity:wafv2_update_regex_pattern_set]{update_regex_pattern_set} \tab Updates the specified RegexPatternSet\cr
#'  \link[paws.security.identity:wafv2_update_rule_group]{update_rule_group} \tab Updates the specified RuleGroup\cr
#'  \link[paws.security.identity:wafv2_update_web_acl]{update_web_acl} \tab Updates the specified WebACL
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname wafv2
#' @export
wafv2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.security.identity::wafv2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon EventBridge
#'
#' @description
#' Amazon EventBridge helps you to respond to state changes in your Amazon
#' Web Services resources. When your resources change state, they
#' automatically send events to an event stream. You can create rules that
#' match selected events in the stream and route them to targets to take
#' action. You can also use rules to take action on a predetermined
#' schedule. For example, you can configure rules to:
#' 
#' -   Automatically invoke an Lambda function to update DNS entries when
#'     an event notifies you that Amazon EC2 instance enters the running
#'     state.
#' 
#' -   Direct specific API records from CloudTrail to an Amazon Kinesis
#'     data stream for detailed analysis of potential security or
#'     availability risks.
#' 
#' -   Periodically invoke a built-in target to create a snapshot of an
#'     Amazon EBS volume.
#' 
#' For more information about the features of Amazon EventBridge, see the
#' [Amazon EventBridge User
#' Guide](https://docs.aws.amazon.com/eventbridge/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- eventbridge(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- eventbridge()
#' svc$activate_event_source(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:eventbridge_activate_event_source]{activate_event_source} \tab Activates a partner event source that has been deactivated\cr
#'  \link[paws.application.integration:eventbridge_cancel_replay]{cancel_replay} \tab Cancels the specified replay\cr
#'  \link[paws.application.integration:eventbridge_create_api_destination]{create_api_destination} \tab Creates an API destination, which is an HTTP invocation endpoint configured as a target for events\cr
#'  \link[paws.application.integration:eventbridge_create_archive]{create_archive} \tab Creates an archive of events with the specified settings\cr
#'  \link[paws.application.integration:eventbridge_create_connection]{create_connection} \tab Creates a connection\cr
#'  \link[paws.application.integration:eventbridge_create_endpoint]{create_endpoint} \tab Creates a global endpoint\cr
#'  \link[paws.application.integration:eventbridge_create_event_bus]{create_event_bus} \tab Creates a new event bus within your account\cr
#'  \link[paws.application.integration:eventbridge_create_partner_event_source]{create_partner_event_source} \tab Called by an SaaS partner to create a partner event source\cr
#'  \link[paws.application.integration:eventbridge_deactivate_event_source]{deactivate_event_source} \tab You can use this operation to temporarily stop receiving events from the specified partner event source\cr
#'  \link[paws.application.integration:eventbridge_deauthorize_connection]{deauthorize_connection} \tab Removes all authorization parameters from the connection\cr
#'  \link[paws.application.integration:eventbridge_delete_api_destination]{delete_api_destination} \tab Deletes the specified API destination\cr
#'  \link[paws.application.integration:eventbridge_delete_archive]{delete_archive} \tab Deletes the specified archive\cr
#'  \link[paws.application.integration:eventbridge_delete_connection]{delete_connection} \tab Deletes a connection\cr
#'  \link[paws.application.integration:eventbridge_delete_endpoint]{delete_endpoint} \tab Delete an existing global endpoint\cr
#'  \link[paws.application.integration:eventbridge_delete_event_bus]{delete_event_bus} \tab Deletes the specified custom event bus or partner event bus\cr
#'  \link[paws.application.integration:eventbridge_delete_partner_event_source]{delete_partner_event_source} \tab This operation is used by SaaS partners to delete a partner event source\cr
#'  \link[paws.application.integration:eventbridge_delete_rule]{delete_rule} \tab Deletes the specified rule\cr
#'  \link[paws.application.integration:eventbridge_describe_api_destination]{describe_api_destination} \tab Retrieves details about an API destination\cr
#'  \link[paws.application.integration:eventbridge_describe_archive]{describe_archive} \tab Retrieves details about an archive\cr
#'  \link[paws.application.integration:eventbridge_describe_connection]{describe_connection} \tab Retrieves details about a connection\cr
#'  \link[paws.application.integration:eventbridge_describe_endpoint]{describe_endpoint} \tab Get the information about an existing global endpoint\cr
#'  \link[paws.application.integration:eventbridge_describe_event_bus]{describe_event_bus} \tab Displays details about an event bus in your account\cr
#'  \link[paws.application.integration:eventbridge_describe_event_source]{describe_event_source} \tab This operation lists details about a partner event source that is shared with your account\cr
#'  \link[paws.application.integration:eventbridge_describe_partner_event_source]{describe_partner_event_source} \tab An SaaS partner can use this operation to list details about a partner event source that they have created\cr
#'  \link[paws.application.integration:eventbridge_describe_replay]{describe_replay} \tab Retrieves details about a replay\cr
#'  \link[paws.application.integration:eventbridge_describe_rule]{describe_rule} \tab Describes the specified rule\cr
#'  \link[paws.application.integration:eventbridge_disable_rule]{disable_rule} \tab Disables the specified rule\cr
#'  \link[paws.application.integration:eventbridge_enable_rule]{enable_rule} \tab Enables the specified rule\cr
#'  \link[paws.application.integration:eventbridge_list_api_destinations]{list_api_destinations} \tab Retrieves a list of API destination in the account in the current Region\cr
#'  \link[paws.application.integration:eventbridge_list_archives]{list_archives} \tab Lists your archives\cr
#'  \link[paws.application.integration:eventbridge_list_connections]{list_connections} \tab Retrieves a list of connections from the account\cr
#'  \link[paws.application.integration:eventbridge_list_endpoints]{list_endpoints} \tab List the global endpoints associated with this account\cr
#'  \link[paws.application.integration:eventbridge_list_event_buses]{list_event_buses} \tab Lists all the event buses in your account, including the default event bus, custom event buses, and partner event buses\cr
#'  \link[paws.application.integration:eventbridge_list_event_sources]{list_event_sources} \tab You can use this to see all the partner event sources that have been shared with your Amazon Web Services account\cr
#'  \link[paws.application.integration:eventbridge_list_partner_event_source_accounts]{list_partner_event_source_accounts} \tab An SaaS partner can use this operation to display the Amazon Web Services account ID that a particular partner event source name is associated with\cr
#'  \link[paws.application.integration:eventbridge_list_partner_event_sources]{list_partner_event_sources} \tab An SaaS partner can use this operation to list all the partner event source names that they have created\cr
#'  \link[paws.application.integration:eventbridge_list_replays]{list_replays} \tab Lists your replays\cr
#'  \link[paws.application.integration:eventbridge_list_rule_names_by_target]{list_rule_names_by_target} \tab Lists the rules for the specified target\cr
#'  \link[paws.application.integration:eventbridge_list_rules]{list_rules} \tab Lists your Amazon EventBridge rules\cr
#'  \link[paws.application.integration:eventbridge_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with an EventBridge resource\cr
#'  \link[paws.application.integration:eventbridge_list_targets_by_rule]{list_targets_by_rule} \tab Lists the targets assigned to the specified rule\cr
#'  \link[paws.application.integration:eventbridge_put_events]{put_events} \tab Sends custom events to Amazon EventBridge so that they can be matched to rules\cr
#'  \link[paws.application.integration:eventbridge_put_partner_events]{put_partner_events} \tab This is used by SaaS partners to write events to a customer's partner event bus\cr
#'  \link[paws.application.integration:eventbridge_put_permission]{put_permission} \tab Running PutPermission permits the specified Amazon Web Services account or Amazon Web Services organization to put events to the specified event bus\cr
#'  \link[paws.application.integration:eventbridge_put_rule]{put_rule} \tab Creates or updates the specified rule\cr
#'  \link[paws.application.integration:eventbridge_put_targets]{put_targets} \tab Adds the specified targets to the specified rule, or updates the targets if they are already associated with the rule\cr
#'  \link[paws.application.integration:eventbridge_remove_permission]{remove_permission} \tab Revokes the permission of another Amazon Web Services account to be able to put events to the specified event bus\cr
#'  \link[paws.application.integration:eventbridge_remove_targets]{remove_targets} \tab Removes the specified targets from the specified rule\cr
#'  \link[paws.application.integration:eventbridge_start_replay]{start_replay} \tab Starts the specified replay\cr
#'  \link[paws.application.integration:eventbridge_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified EventBridge resource\cr
#'  \link[paws.application.integration:eventbridge_test_event_pattern]{test_event_pattern} \tab Tests whether the specified event pattern matches the provided event\cr
#'  \link[paws.application.integration:eventbridge_untag_resource]{untag_resource} \tab Removes one or more tags from the specified EventBridge resource\cr
#'  \link[paws.application.integration:eventbridge_update_api_destination]{update_api_destination} \tab Updates an API destination\cr
#'  \link[paws.application.integration:eventbridge_update_archive]{update_archive} \tab Updates the specified archive\cr
#'  \link[paws.application.integration:eventbridge_update_connection]{update_connection} \tab Updates settings for a connection\cr
#'  \link[paws.application.integration:eventbridge_update_endpoint]{update_endpoint} \tab Update an existing endpoint\cr
#'  \link[paws.application.integration:eventbridge_update_event_bus]{update_event_bus} \tab Updates the specified event bus
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname eventbridge
#' @export
eventbridge <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::eventbridge(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Location Service
#'
#' @description
#' "Suite of geospatial services including Maps, Places, Routes, Tracking,
#' and Geofencing"
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- locationservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- locationservice()
#' svc$associate_tracker_consumer(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:locationservice_associate_tracker_consumer]{associate_tracker_consumer} \tab Creates an association between a geofence collection and a tracker resource\cr
#'  \link[paws.application.integration:locationservice_batch_delete_device_position_history]{batch_delete_device_position_history} \tab Deletes the position history of one or more devices from a tracker resource\cr
#'  \link[paws.application.integration:locationservice_batch_delete_geofence]{batch_delete_geofence} \tab Deletes a batch of geofences from a geofence collection\cr
#'  \link[paws.application.integration:locationservice_batch_evaluate_geofences]{batch_evaluate_geofences} \tab Evaluates device positions against the geofence geometries from a given geofence collection\cr
#'  \link[paws.application.integration:locationservice_batch_get_device_position]{batch_get_device_position} \tab Lists the latest device positions for requested devices\cr
#'  \link[paws.application.integration:locationservice_batch_put_geofence]{batch_put_geofence} \tab A batch request for storing geofence geometries into a given geofence collection, or updates the geometry of an existing geofence if a geofence ID is included in the request\cr
#'  \link[paws.application.integration:locationservice_batch_update_device_position]{batch_update_device_position} \tab Uploads position update data for one or more devices to a tracker resource (up to 10 devices per batch)\cr
#'  \link[paws.application.integration:locationservice_calculate_route]{calculate_route} \tab Calculates a route given the following required parameters: DeparturePosition and DestinationPosition\cr
#'  \link[paws.application.integration:locationservice_calculate_route_matrix]{calculate_route_matrix} \tab Calculates a route matrix given the following required parameters: DeparturePositions and DestinationPositions\cr
#'  \link[paws.application.integration:locationservice_create_geofence_collection]{create_geofence_collection} \tab Creates a geofence collection, which manages and stores geofences\cr
#'  \link[paws.application.integration:locationservice_create_key]{create_key} \tab Creates an API key resource in your Amazon Web Services account, which lets you grant actions for Amazon Location resources to the API key bearer\cr
#'  \link[paws.application.integration:locationservice_create_map]{create_map} \tab Creates a map resource in your Amazon Web Services account, which provides map tiles of different styles sourced from global location data providers\cr
#'  \link[paws.application.integration:locationservice_create_place_index]{create_place_index} \tab Creates a place index resource in your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_create_route_calculator]{create_route_calculator} \tab Creates a route calculator resource in your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_create_tracker]{create_tracker} \tab Creates a tracker resource in your Amazon Web Services account, which lets you retrieve current and historical location of devices\cr
#'  \link[paws.application.integration:locationservice_delete_geofence_collection]{delete_geofence_collection} \tab Deletes a geofence collection from your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_delete_key]{delete_key} \tab Deletes the specified API key\cr
#'  \link[paws.application.integration:locationservice_delete_map]{delete_map} \tab Deletes a map resource from your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_delete_place_index]{delete_place_index} \tab Deletes a place index resource from your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_delete_route_calculator]{delete_route_calculator} \tab Deletes a route calculator resource from your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_delete_tracker]{delete_tracker} \tab Deletes a tracker resource from your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_describe_geofence_collection]{describe_geofence_collection} \tab Retrieves the geofence collection details\cr
#'  \link[paws.application.integration:locationservice_describe_key]{describe_key} \tab Retrieves the API key resource details\cr
#'  \link[paws.application.integration:locationservice_describe_map]{describe_map} \tab Retrieves the map resource details\cr
#'  \link[paws.application.integration:locationservice_describe_place_index]{describe_place_index} \tab Retrieves the place index resource details\cr
#'  \link[paws.application.integration:locationservice_describe_route_calculator]{describe_route_calculator} \tab Retrieves the route calculator resource details\cr
#'  \link[paws.application.integration:locationservice_describe_tracker]{describe_tracker} \tab Retrieves the tracker resource details\cr
#'  \link[paws.application.integration:locationservice_disassociate_tracker_consumer]{disassociate_tracker_consumer} \tab Removes the association between a tracker resource and a geofence collection\cr
#'  \link[paws.application.integration:locationservice_forecast_geofence_events]{forecast_geofence_events} \tab Evaluates device positions against geofence geometries from a given geofence collection\cr
#'  \link[paws.application.integration:locationservice_get_device_position]{get_device_position} \tab Retrieves a device's most recent position according to its sample time\cr
#'  \link[paws.application.integration:locationservice_get_device_position_history]{get_device_position_history} \tab Retrieves the device position history from a tracker resource within a specified range of time\cr
#'  \link[paws.application.integration:locationservice_get_geofence]{get_geofence} \tab Retrieves the geofence details from a geofence collection\cr
#'  \link[paws.application.integration:locationservice_get_map_glyphs]{get_map_glyphs} \tab Retrieves glyphs used to display labels on a map\cr
#'  \link[paws.application.integration:locationservice_get_map_sprites]{get_map_sprites} \tab Retrieves the sprite sheet corresponding to a map resource\cr
#'  \link[paws.application.integration:locationservice_get_map_style_descriptor]{get_map_style_descriptor} \tab Retrieves the map style descriptor from a map resource\cr
#'  \link[paws.application.integration:locationservice_get_map_tile]{get_map_tile} \tab Retrieves a vector data tile from the map resource\cr
#'  \link[paws.application.integration:locationservice_get_place]{get_place} \tab Finds a place by its unique ID\cr
#'  \link[paws.application.integration:locationservice_list_device_positions]{list_device_positions} \tab A batch request to retrieve all device positions\cr
#'  \link[paws.application.integration:locationservice_list_geofence_collections]{list_geofence_collections} \tab Lists geofence collections in your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_list_geofences]{list_geofences} \tab Lists geofences stored in a given geofence collection\cr
#'  \link[paws.application.integration:locationservice_list_keys]{list_keys} \tab Lists API key resources in your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_list_maps]{list_maps} \tab Lists map resources in your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_list_place_indexes]{list_place_indexes} \tab Lists place index resources in your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_list_route_calculators]{list_route_calculators} \tab Lists route calculator resources in your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of tags that are applied to the specified Amazon Location resource\cr
#'  \link[paws.application.integration:locationservice_list_tracker_consumers]{list_tracker_consumers} \tab Lists geofence collections currently associated to the given tracker resource\cr
#'  \link[paws.application.integration:locationservice_list_trackers]{list_trackers} \tab Lists tracker resources in your Amazon Web Services account\cr
#'  \link[paws.application.integration:locationservice_put_geofence]{put_geofence} \tab Stores a geofence geometry in a given geofence collection, or updates the geometry of an existing geofence if a geofence ID is included in the request\cr
#'  \link[paws.application.integration:locationservice_search_place_index_for_position]{search_place_index_for_position} \tab Reverse geocodes a given coordinate and returns a legible address\cr
#'  \link[paws.application.integration:locationservice_search_place_index_for_suggestions]{search_place_index_for_suggestions} \tab Generates suggestions for addresses and points of interest based on partial or misspelled free-form text\cr
#'  \link[paws.application.integration:locationservice_search_place_index_for_text]{search_place_index_for_text} \tab Geocodes free-form text, such as an address, name, city, or region to allow you to search for Places or points of interest\cr
#'  \link[paws.application.integration:locationservice_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified Amazon Location Service resource\cr
#'  \link[paws.application.integration:locationservice_untag_resource]{untag_resource} \tab Removes one or more tags from the specified Amazon Location resource\cr
#'  \link[paws.application.integration:locationservice_update_geofence_collection]{update_geofence_collection} \tab Updates the specified properties of a given geofence collection\cr
#'  \link[paws.application.integration:locationservice_update_key]{update_key} \tab Updates the specified properties of a given API key resource\cr
#'  \link[paws.application.integration:locationservice_update_map]{update_map} \tab Updates the specified properties of a given map resource\cr
#'  \link[paws.application.integration:locationservice_update_place_index]{update_place_index} \tab Updates the specified properties of a given place index resource\cr
#'  \link[paws.application.integration:locationservice_update_route_calculator]{update_route_calculator} \tab Updates the specified properties for a given route calculator resource\cr
#'  \link[paws.application.integration:locationservice_update_tracker]{update_tracker} \tab Updates the specified properties of a given tracker resource\cr
#'  \link[paws.application.integration:locationservice_verify_device_position]{verify_device_position} \tab Verifies the integrity of the device's position by determining if it was reported behind a proxy, and by comparing it to an inferred position estimated based on the device's state
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname locationservice
#' @export
locationservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::locationservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AmazonMQ
#'
#' @description
#' Amazon MQ is a managed message broker service for Apache ActiveMQ and
#' RabbitMQ that makes it easy to set up and operate message brokers in the
#' cloud. A message broker allows software applications and components to
#' communicate using various programming languages, operating systems, and
#' formal messaging protocols.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- mq(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- mq()
#' svc$create_broker(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:mq_create_broker]{create_broker} \tab Creates a broker\cr
#'  \link[paws.application.integration:mq_create_configuration]{create_configuration} \tab Creates a new configuration for the specified configuration name\cr
#'  \link[paws.application.integration:mq_create_tags]{create_tags} \tab Add a tag to a resource\cr
#'  \link[paws.application.integration:mq_create_user]{create_user} \tab Creates an ActiveMQ user\cr
#'  \link[paws.application.integration:mq_delete_broker]{delete_broker} \tab Deletes a broker\cr
#'  \link[paws.application.integration:mq_delete_tags]{delete_tags} \tab Removes a tag from a resource\cr
#'  \link[paws.application.integration:mq_delete_user]{delete_user} \tab Deletes an ActiveMQ user\cr
#'  \link[paws.application.integration:mq_describe_broker]{describe_broker} \tab Returns information about the specified broker\cr
#'  \link[paws.application.integration:mq_describe_broker_engine_types]{describe_broker_engine_types} \tab Describe available engine types and versions\cr
#'  \link[paws.application.integration:mq_describe_broker_instance_options]{describe_broker_instance_options} \tab Describe available broker instance options\cr
#'  \link[paws.application.integration:mq_describe_configuration]{describe_configuration} \tab Returns information about the specified configuration\cr
#'  \link[paws.application.integration:mq_describe_configuration_revision]{describe_configuration_revision} \tab Returns the specified configuration revision for the specified configuration\cr
#'  \link[paws.application.integration:mq_describe_user]{describe_user} \tab Returns information about an ActiveMQ user\cr
#'  \link[paws.application.integration:mq_list_brokers]{list_brokers} \tab Returns a list of all brokers\cr
#'  \link[paws.application.integration:mq_list_configuration_revisions]{list_configuration_revisions} \tab Returns a list of all revisions for the specified configuration\cr
#'  \link[paws.application.integration:mq_list_configurations]{list_configurations} \tab Returns a list of all configurations\cr
#'  \link[paws.application.integration:mq_list_tags]{list_tags} \tab Lists tags for a resource\cr
#'  \link[paws.application.integration:mq_list_users]{list_users} \tab Returns a list of all ActiveMQ users\cr
#'  \link[paws.application.integration:mq_promote]{promote} \tab Promotes a data replication replica broker to the primary broker role\cr
#'  \link[paws.application.integration:mq_reboot_broker]{reboot_broker} \tab Reboots a broker\cr
#'  \link[paws.application.integration:mq_update_broker]{update_broker} \tab Adds a pending configuration change to a broker\cr
#'  \link[paws.application.integration:mq_update_configuration]{update_configuration} \tab Updates the specified configuration\cr
#'  \link[paws.application.integration:mq_update_user]{update_user} \tab Updates the information for an ActiveMQ user
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname mq
#' @export
mq <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::mq(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AmazonMWAA
#'
#' @description
#' Amazon Managed Workflows for Apache Airflow
#' 
#' This section contains the Amazon Managed Workflows for Apache Airflow
#' (MWAA) API reference documentation. For more information, see [What is
#' Amazon
#' MWAA?](https://docs.aws.amazon.com/mwaa/latest/userguide/what-is-mwaa.html).
#' 
#' **Endpoints**
#' 
#' -   `api.airflow.{region}.amazonaws.com` - This endpoint is used for
#'     environment management.
#' 
#'     -   `create_environment`
#' 
#'     -   `delete_environment`
#' 
#'     -   `get_environment`
#' 
#'     -   `list_environments`
#' 
#'     -   `list_tags_for_resource`
#' 
#'     -   `tag_resource`
#' 
#'     -   `untag_resource`
#' 
#'     -   `update_environment`
#' 
#' -   `env.airflow.{region}.amazonaws.com` - This endpoint is used to
#'     operate the Airflow environment.
#' 
#'     -   `create_cli_token`
#' 
#'     -   `create_web_login_token`
#' 
#'     -   `invoke_rest_api`
#' 
#' **Regions**
#' 
#' For a list of supported regions, see [Amazon MWAA endpoints and
#' quotas](https://docs.aws.amazon.com/general/latest/gr/mwaa.html) in the
#' *Amazon Web Services General Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- mwaa(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- mwaa()
#' svc$create_cli_token(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:mwaa_create_cli_token]{create_cli_token} \tab Creates a CLI token for the Airflow CLI\cr
#'  \link[paws.application.integration:mwaa_create_environment]{create_environment} \tab Creates an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment\cr
#'  \link[paws.application.integration:mwaa_create_web_login_token]{create_web_login_token} \tab Creates a web login token for the Airflow Web UI\cr
#'  \link[paws.application.integration:mwaa_delete_environment]{delete_environment} \tab Deletes an Amazon Managed Workflows for Apache Airflow (Amazon MWAA) environment\cr
#'  \link[paws.application.integration:mwaa_get_environment]{get_environment} \tab Describes an Amazon Managed Workflows for Apache Airflow (MWAA) environment\cr
#'  \link[paws.application.integration:mwaa_invoke_rest_api]{invoke_rest_api} \tab Invokes the Apache Airflow REST API on the webserver with the specified inputs\cr
#'  \link[paws.application.integration:mwaa_list_environments]{list_environments} \tab Lists the Amazon Managed Workflows for Apache Airflow (MWAA) environments\cr
#'  \link[paws.application.integration:mwaa_list_tags_for_resource]{list_tags_for_resource} \tab Lists the key-value tag pairs associated to the Amazon Managed Workflows for Apache Airflow (MWAA) environment\cr
#'  \link[paws.application.integration:mwaa_publish_metrics]{publish_metrics} \tab Internal only\cr
#'  \link[paws.application.integration:mwaa_tag_resource]{tag_resource} \tab Associates key-value tag pairs to your Amazon Managed Workflows for Apache Airflow (MWAA) environment\cr
#'  \link[paws.application.integration:mwaa_untag_resource]{untag_resource} \tab Removes key-value tag pairs associated to your Amazon Managed Workflows for Apache Airflow (MWAA) environment\cr
#'  \link[paws.application.integration:mwaa_update_environment]{update_environment} \tab Updates an Amazon Managed Workflows for Apache Airflow (MWAA) environment
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname mwaa
#' @export
mwaa <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::mwaa(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon EventBridge Pipes
#'
#' @description
#' Amazon EventBridge Pipes connects event sources to targets. Pipes
#' reduces the need for specialized knowledge and integration code when
#' developing event driven architectures. This helps ensures consistency
#' across your company’s applications. With Pipes, the target can be any
#' available EventBridge target. To set up a pipe, you select the event
#' source, add optional event filtering, define optional enrichment, and
#' select the target for the event data.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- eventbridgepipes(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- eventbridgepipes()
#' svc$create_pipe(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:eventbridgepipes_create_pipe]{create_pipe} \tab Create a pipe\cr
#'  \link[paws.application.integration:eventbridgepipes_delete_pipe]{delete_pipe} \tab Delete an existing pipe\cr
#'  \link[paws.application.integration:eventbridgepipes_describe_pipe]{describe_pipe} \tab Get the information about an existing pipe\cr
#'  \link[paws.application.integration:eventbridgepipes_list_pipes]{list_pipes} \tab Get the pipes associated with this account\cr
#'  \link[paws.application.integration:eventbridgepipes_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with a pipe\cr
#'  \link[paws.application.integration:eventbridgepipes_start_pipe]{start_pipe} \tab Start an existing pipe\cr
#'  \link[paws.application.integration:eventbridgepipes_stop_pipe]{stop_pipe} \tab Stop an existing pipe\cr
#'  \link[paws.application.integration:eventbridgepipes_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified pipe\cr
#'  \link[paws.application.integration:eventbridgepipes_untag_resource]{untag_resource} \tab Removes one or more tags from the specified pipes\cr
#'  \link[paws.application.integration:eventbridgepipes_update_pipe]{update_pipe} \tab Update an existing pipe
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname eventbridgepipes
#' @export
eventbridgepipes <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::eventbridgepipes(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Resource Explorer
#'
#' @description
#' Amazon Web Services Resource Explorer is a resource search and discovery
#' service. By using Resource Explorer, you can explore your resources
#' using an internet search engine-like experience. Examples of resources
#' include Amazon Relational Database Service (Amazon RDS) instances,
#' Amazon Simple Storage Service (Amazon S3) buckets, or Amazon DynamoDB
#' tables. You can search for your resources using resource metadata like
#' names, tags, and IDs. Resource Explorer can search across all of the
#' Amazon Web Services Regions in your account in which you turn the
#' service on, to simplify your cross-Region workloads.
#' 
#' Resource Explorer scans the resources in each of the Amazon Web Services
#' Regions in your Amazon Web Services account in which you turn on
#' Resource Explorer. Resource Explorer [creates and maintains an
#' index](https://docs.aws.amazon.com/resource-explorer/latest/userguide/getting-started-terms-and-concepts.html#term-index)
#' in each Region, with the details of that Region's resources.
#' 
#' You can [search across all of the indexed Regions in your
#' account](https://docs.aws.amazon.com/resource-explorer/latest/userguide/manage-aggregator-region.html)
#' by designating one of your Amazon Web Services Regions to contain the
#' aggregator index for the account. When you [promote a local index in a
#' Region to become the aggregator index for the
#' account](https://docs.aws.amazon.com/resource-explorer/latest/userguide/manage-aggregator-region-turn-on.html),
#' Resource Explorer automatically replicates the index information from
#' all local indexes in the other Regions to the aggregator index.
#' Therefore, the Region with the aggregator index has a copy of all
#' resource information for all Regions in the account where you turned on
#' Resource Explorer. As a result, views in the aggregator index Region
#' include resources from all of the indexed Regions in your account.
#' 
#' For more information about Amazon Web Services Resource Explorer,
#' including how to enable and configure the service, see the [Amazon Web
#' Services Resource Explorer User
#' Guide](https://docs.aws.amazon.com/resource-explorer/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- resourceexplorer(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- resourceexplorer()
#' svc$associate_default_view(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:resourceexplorer_associate_default_view]{associate_default_view} \tab Sets the specified view as the default for the Amazon Web Services Region in which you call this operation\cr
#'  \link[paws.application.integration:resourceexplorer_batch_get_view]{batch_get_view} \tab Retrieves details about a list of views\cr
#'  \link[paws.application.integration:resourceexplorer_create_index]{create_index} \tab Turns on Amazon Web Services Resource Explorer in the Amazon Web Services Region in which you called this operation by creating an index\cr
#'  \link[paws.application.integration:resourceexplorer_create_view]{create_view} \tab Creates a view that users can query by using the Search operation\cr
#'  \link[paws.application.integration:resourceexplorer_delete_index]{delete_index} \tab Deletes the specified index and turns off Amazon Web Services Resource Explorer in the specified Amazon Web Services Region\cr
#'  \link[paws.application.integration:resourceexplorer_delete_view]{delete_view} \tab Deletes the specified view\cr
#'  \link[paws.application.integration:resourceexplorer_disassociate_default_view]{disassociate_default_view} \tab After you call this operation, the affected Amazon Web Services Region no longer has a default view\cr
#'  \link[paws.application.integration:resourceexplorer_get_account_level_service_configuration]{get_account_level_service_configuration} \tab Retrieves the status of your account's Amazon Web Services service access, and validates the service linked role required to access the multi-account search feature\cr
#'  \link[paws.application.integration:resourceexplorer_get_default_view]{get_default_view} \tab Retrieves the Amazon Resource Name (ARN) of the view that is the default for the Amazon Web Services Region in which you call this operation\cr
#'  \link[paws.application.integration:resourceexplorer_get_index]{get_index} \tab Retrieves details about the Amazon Web Services Resource Explorer index in the Amazon Web Services Region in which you invoked the operation\cr
#'  \link[paws.application.integration:resourceexplorer_get_managed_view]{get_managed_view} \tab Retrieves details of the specified Amazon Web Services-managed view\cr
#'  \link[paws.application.integration:resourceexplorer_get_view]{get_view} \tab Retrieves details of the specified view\cr
#'  \link[paws.application.integration:resourceexplorer_list_indexes]{list_indexes} \tab Retrieves a list of all of the indexes in Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer\cr
#'  \link[paws.application.integration:resourceexplorer_list_indexes_for_members]{list_indexes_for_members} \tab Retrieves a list of a member's indexes in all Amazon Web Services Regions that are currently collecting resource information for Amazon Web Services Resource Explorer\cr
#'  \link[paws.application.integration:resourceexplorer_list_managed_views]{list_managed_views} \tab Lists the Amazon resource names (ARNs) of the Amazon Web Services-managed views available in the Amazon Web Services Region in which you call this operation\cr
#'  \link[paws.application.integration:resourceexplorer_list_resources]{list_resources} \tab Returns a list of resources and their details that match the specified criteria\cr
#'  \link[paws.application.integration:resourceexplorer_list_supported_resource_types]{list_supported_resource_types} \tab Retrieves a list of all resource types currently supported by Amazon Web Services Resource Explorer\cr
#'  \link[paws.application.integration:resourceexplorer_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that are attached to the specified resource\cr
#'  \link[paws.application.integration:resourceexplorer_list_views]{list_views} \tab Lists the Amazon resource names (ARNs) of the views available in the Amazon Web Services Region in which you call this operation\cr
#'  \link[paws.application.integration:resourceexplorer_search]{search} \tab Searches for resources and displays details about all resources that match the specified criteria\cr
#'  \link[paws.application.integration:resourceexplorer_tag_resource]{tag_resource} \tab Adds one or more tag key and value pairs to an Amazon Web Services Resource Explorer view or index\cr
#'  \link[paws.application.integration:resourceexplorer_untag_resource]{untag_resource} \tab Removes one or more tag key and value pairs from an Amazon Web Services Resource Explorer view or index\cr
#'  \link[paws.application.integration:resourceexplorer_update_index_type]{update_index_type} \tab Changes the type of the index from one of the following types to the other\cr
#'  \link[paws.application.integration:resourceexplorer_update_view]{update_view} \tab Modifies some of the details of a view
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname resourceexplorer
#' @export
resourceexplorer <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::resourceexplorer(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Schemas
#'
#' @description
#' Amazon EventBridge Schema Registry
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- schemas(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- schemas()
#' svc$create_discoverer(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:schemas_create_discoverer]{create_discoverer} \tab Creates a discoverer\cr
#'  \link[paws.application.integration:schemas_create_registry]{create_registry} \tab Creates a registry\cr
#'  \link[paws.application.integration:schemas_create_schema]{create_schema} \tab Creates a schema definition\cr
#'  \link[paws.application.integration:schemas_delete_discoverer]{delete_discoverer} \tab Deletes a discoverer\cr
#'  \link[paws.application.integration:schemas_delete_registry]{delete_registry} \tab Deletes a Registry\cr
#'  \link[paws.application.integration:schemas_delete_resource_policy]{delete_resource_policy} \tab Delete the resource-based policy attached to the specified registry\cr
#'  \link[paws.application.integration:schemas_delete_schema]{delete_schema} \tab Delete a schema definition\cr
#'  \link[paws.application.integration:schemas_delete_schema_version]{delete_schema_version} \tab Delete the schema version definition\cr
#'  \link[paws.application.integration:schemas_describe_code_binding]{describe_code_binding} \tab Describe the code binding URI\cr
#'  \link[paws.application.integration:schemas_describe_discoverer]{describe_discoverer} \tab Describes the discoverer\cr
#'  \link[paws.application.integration:schemas_describe_registry]{describe_registry} \tab Describes the registry\cr
#'  \link[paws.application.integration:schemas_describe_schema]{describe_schema} \tab Retrieve the schema definition\cr
#'  \link[paws.application.integration:schemas_export_schema]{export_schema} \tab Export schema\cr
#'  \link[paws.application.integration:schemas_get_code_binding_source]{get_code_binding_source} \tab Get the code binding source URI\cr
#'  \link[paws.application.integration:schemas_get_discovered_schema]{get_discovered_schema} \tab Get the discovered schema that was generated based on sampled events\cr
#'  \link[paws.application.integration:schemas_get_resource_policy]{get_resource_policy} \tab Retrieves the resource-based policy attached to a given registry\cr
#'  \link[paws.application.integration:schemas_list_discoverers]{list_discoverers} \tab List the discoverers\cr
#'  \link[paws.application.integration:schemas_list_registries]{list_registries} \tab List the registries\cr
#'  \link[paws.application.integration:schemas_list_schemas]{list_schemas} \tab List the schemas\cr
#'  \link[paws.application.integration:schemas_list_schema_versions]{list_schema_versions} \tab Provides a list of the schema versions and related information\cr
#'  \link[paws.application.integration:schemas_list_tags_for_resource]{list_tags_for_resource} \tab Get tags for resource\cr
#'  \link[paws.application.integration:schemas_put_code_binding]{put_code_binding} \tab Put code binding URI\cr
#'  \link[paws.application.integration:schemas_put_resource_policy]{put_resource_policy} \tab The name of the policy\cr
#'  \link[paws.application.integration:schemas_search_schemas]{search_schemas} \tab Search the schemas\cr
#'  \link[paws.application.integration:schemas_start_discoverer]{start_discoverer} \tab Starts the discoverer\cr
#'  \link[paws.application.integration:schemas_stop_discoverer]{stop_discoverer} \tab Stops the discoverer\cr
#'  \link[paws.application.integration:schemas_tag_resource]{tag_resource} \tab Add tags to a resource\cr
#'  \link[paws.application.integration:schemas_untag_resource]{untag_resource} \tab Removes tags from a resource\cr
#'  \link[paws.application.integration:schemas_update_discoverer]{update_discoverer} \tab Updates the discoverer\cr
#'  \link[paws.application.integration:schemas_update_registry]{update_registry} \tab Updates a registry\cr
#'  \link[paws.application.integration:schemas_update_schema]{update_schema} \tab Updates the schema definition
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname schemas
#' @export
schemas <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::schemas(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon EventBridge Scheduler
#'
#' @description
#' Amazon EventBridge Scheduler is a serverless scheduler that allows you
#' to create, run, and manage tasks from one central, managed service.
#' EventBridge Scheduler delivers your tasks reliably, with built-in
#' mechanisms that adjust your schedules based on the availability of
#' downstream targets. The following reference lists the available API
#' actions, and data types for EventBridge Scheduler.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- eventbridgescheduler(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- eventbridgescheduler()
#' svc$create_schedule(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:eventbridgescheduler_create_schedule]{create_schedule} \tab Creates the specified schedule\cr
#'  \link[paws.application.integration:eventbridgescheduler_create_schedule_group]{create_schedule_group} \tab Creates the specified schedule group\cr
#'  \link[paws.application.integration:eventbridgescheduler_delete_schedule]{delete_schedule} \tab Deletes the specified schedule\cr
#'  \link[paws.application.integration:eventbridgescheduler_delete_schedule_group]{delete_schedule_group} \tab Deletes the specified schedule group\cr
#'  \link[paws.application.integration:eventbridgescheduler_get_schedule]{get_schedule} \tab Retrieves the specified schedule\cr
#'  \link[paws.application.integration:eventbridgescheduler_get_schedule_group]{get_schedule_group} \tab Retrieves the specified schedule group\cr
#'  \link[paws.application.integration:eventbridgescheduler_list_schedule_groups]{list_schedule_groups} \tab Returns a paginated list of your schedule groups\cr
#'  \link[paws.application.integration:eventbridgescheduler_list_schedules]{list_schedules} \tab Returns a paginated list of your EventBridge Scheduler schedules\cr
#'  \link[paws.application.integration:eventbridgescheduler_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags associated with the Scheduler resource\cr
#'  \link[paws.application.integration:eventbridgescheduler_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified EventBridge Scheduler resource\cr
#'  \link[paws.application.integration:eventbridgescheduler_untag_resource]{untag_resource} \tab Removes one or more tags from the specified EventBridge Scheduler schedule group\cr
#'  \link[paws.application.integration:eventbridgescheduler_update_schedule]{update_schedule} \tab Updates the specified schedule
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname eventbridgescheduler
#' @export
eventbridgescheduler <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::eventbridgescheduler(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Step Functions
#'
#' @description
#' Step Functions
#' 
#' Step Functions coordinates the components of distributed applications
#' and microservices using visual workflows.
#' 
#' You can use Step Functions to build applications from individual
#' components, each of which performs a discrete function, or *task*,
#' allowing you to scale and change applications quickly. Step Functions
#' provides a console that helps visualize the components of your
#' application as a series of steps. Step Functions automatically triggers
#' and tracks each step, and retries steps when there are errors, so your
#' application executes predictably and in the right order every time. Step
#' Functions logs the state of each step, so you can quickly diagnose and
#' debug any issues.
#' 
#' Step Functions manages operations and underlying infrastructure to
#' ensure your application is available at any scale. You can run tasks on
#' Amazon Web Services, your own servers, or any system that has access to
#' Amazon Web Services. You can access and use Step Functions using the
#' console, the Amazon Web Services SDKs, or an HTTP API. For more
#' information about Step Functions, see the *\href{https://docs.aws.amazon.com/step-functions/latest/dg/welcome.html}{Step Functions Developer Guide}* .
#' 
#' If you use the Step Functions API actions using Amazon Web Services SDK
#' integrations, make sure the API actions are in camel case and parameter
#' names are in Pascal case. For example, you could use Step Functions API
#' action `startSyncExecution` and specify its parameter as
#' `StateMachineArn`.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sfn(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sfn()
#' svc$create_activity(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:sfn_create_activity]{create_activity} \tab Creates an activity\cr
#'  \link[paws.application.integration:sfn_create_state_machine]{create_state_machine} \tab Creates a state machine\cr
#'  \link[paws.application.integration:sfn_create_state_machine_alias]{create_state_machine_alias} \tab Creates an alias for a state machine that points to one or two versions of the same state machine\cr
#'  \link[paws.application.integration:sfn_delete_activity]{delete_activity} \tab Deletes an activity\cr
#'  \link[paws.application.integration:sfn_delete_state_machine]{delete_state_machine} \tab Deletes a state machine\cr
#'  \link[paws.application.integration:sfn_delete_state_machine_alias]{delete_state_machine_alias} \tab Deletes a state machine alias\cr
#'  \link[paws.application.integration:sfn_delete_state_machine_version]{delete_state_machine_version} \tab Deletes a state machine version\cr
#'  \link[paws.application.integration:sfn_describe_activity]{describe_activity} \tab Describes an activity\cr
#'  \link[paws.application.integration:sfn_describe_execution]{describe_execution} \tab Provides information about a state machine execution, such as the state machine associated with the execution, the execution input and output, and relevant execution metadata\cr
#'  \link[paws.application.integration:sfn_describe_map_run]{describe_map_run} \tab Provides information about a Map Run's configuration, progress, and results\cr
#'  \link[paws.application.integration:sfn_describe_state_machine]{describe_state_machine} \tab Provides information about a state machine's definition, its IAM role Amazon Resource Name (ARN), and configuration\cr
#'  \link[paws.application.integration:sfn_describe_state_machine_alias]{describe_state_machine_alias} \tab Returns details about a state machine alias\cr
#'  \link[paws.application.integration:sfn_describe_state_machine_for_execution]{describe_state_machine_for_execution} \tab Provides information about a state machine's definition, its execution role ARN, and configuration\cr
#'  \link[paws.application.integration:sfn_get_activity_task]{get_activity_task} \tab Used by workers to retrieve a task (with the specified activity ARN) which has been scheduled for execution by a running state machine\cr
#'  \link[paws.application.integration:sfn_get_execution_history]{get_execution_history} \tab Returns the history of the specified execution as a list of events\cr
#'  \link[paws.application.integration:sfn_list_activities]{list_activities} \tab Lists the existing activities\cr
#'  \link[paws.application.integration:sfn_list_executions]{list_executions} \tab Lists all executions of a state machine or a Map Run\cr
#'  \link[paws.application.integration:sfn_list_map_runs]{list_map_runs} \tab Lists all Map Runs that were started by a given state machine execution\cr
#'  \link[paws.application.integration:sfn_list_state_machine_aliases]{list_state_machine_aliases} \tab Lists aliases for a specified state machine ARN\cr
#'  \link[paws.application.integration:sfn_list_state_machines]{list_state_machines} \tab Lists the existing state machines\cr
#'  \link[paws.application.integration:sfn_list_state_machine_versions]{list_state_machine_versions} \tab Lists versions for the specified state machine Amazon Resource Name (ARN)\cr
#'  \link[paws.application.integration:sfn_list_tags_for_resource]{list_tags_for_resource} \tab List tags for a given resource\cr
#'  \link[paws.application.integration:sfn_publish_state_machine_version]{publish_state_machine_version} \tab Creates a version from the current revision of a state machine\cr
#'  \link[paws.application.integration:sfn_redrive_execution]{redrive_execution} \tab Restarts unsuccessful executions of Standard workflows that didn't complete successfully in the last 14 days\cr
#'  \link[paws.application.integration:sfn_send_task_failure]{send_task_failure} \tab Used by activity workers, Task states using the callback pattern, and optionally Task states using the job run pattern to report that the task identified by the taskToken failed\cr
#'  \link[paws.application.integration:sfn_send_task_heartbeat]{send_task_heartbeat} \tab Used by activity workers and Task states using the callback pattern, and optionally Task states using the job run pattern to report to Step Functions that the task represented by the specified taskToken is still making progress\cr
#'  \link[paws.application.integration:sfn_send_task_success]{send_task_success} \tab Used by activity workers, Task states using the callback pattern, and optionally Task states using the job run pattern to report that the task identified by the taskToken completed successfully\cr
#'  \link[paws.application.integration:sfn_start_execution]{start_execution} \tab Starts a state machine execution\cr
#'  \link[paws.application.integration:sfn_start_sync_execution]{start_sync_execution} \tab Starts a Synchronous Express state machine execution\cr
#'  \link[paws.application.integration:sfn_stop_execution]{stop_execution} \tab Stops an execution\cr
#'  \link[paws.application.integration:sfn_tag_resource]{tag_resource} \tab Add a tag to a Step Functions resource\cr
#'  \link[paws.application.integration:sfn_test_state]{test_state} \tab Accepts the definition of a single state and executes it\cr
#'  \link[paws.application.integration:sfn_untag_resource]{untag_resource} \tab Remove a tag from a Step Functions resource\cr
#'  \link[paws.application.integration:sfn_update_map_run]{update_map_run} \tab Updates an in-progress Map Run's configuration to include changes to the settings that control maximum concurrency and Map Run failure\cr
#'  \link[paws.application.integration:sfn_update_state_machine]{update_state_machine} \tab Updates an existing state machine by modifying its definition, roleArn, loggingConfiguration, or EncryptionConfiguration\cr
#'  \link[paws.application.integration:sfn_update_state_machine_alias]{update_state_machine_alias} \tab Updates the configuration of an existing state machine alias by modifying its description or routingConfiguration\cr
#'  \link[paws.application.integration:sfn_validate_state_machine_definition]{validate_state_machine_definition} \tab Validates the syntax of a state machine definition specified in Amazon States Language (ASL), a JSON-based, structured language
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sfn
#' @export
sfn <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::sfn(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Simple Notification Service
#'
#' @description
#' Amazon Simple Notification Service (Amazon SNS) is a web service that
#' enables you to build distributed web-enabled applications. Applications
#' can use Amazon SNS to easily push real-time notification messages to
#' interested subscribers over multiple delivery protocols. For more
#' information about this product see the [Amazon SNS product
#' page](https://aws.amazon.com/sns/). For detailed information about
#' Amazon SNS features and their associated API calls, see the [Amazon SNS
#' Developer Guide](https://docs.aws.amazon.com/sns/latest/dg/).
#' 
#' For information on the permissions you need to use this API, see
#' [Identity and access management in Amazon
#' SNS](https://docs.aws.amazon.com/sns/latest/dg/) in the *Amazon SNS
#' Developer Guide.*
#' 
#' We also provide SDKs that enable you to access Amazon SNS from your
#' preferred programming language. The SDKs contain functionality that
#' automatically takes care of tasks such as: cryptographically signing
#' your service requests, retrying requests, and handling error responses.
#' For a list of available SDKs, go to [Tools for Amazon Web
#' Services](https://aws.amazon.com/developer/tools/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sns(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sns()
#' svc$add_permission(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:sns_add_permission]{add_permission} \tab Adds a statement to a topic's access control policy, granting access for the specified Amazon Web Services accounts to the specified actions\cr
#'  \link[paws.application.integration:sns_check_if_phone_number_is_opted_out]{check_if_phone_number_is_opted_out} \tab Accepts a phone number and indicates whether the phone holder has opted out of receiving SMS messages from your Amazon Web Services account\cr
#'  \link[paws.application.integration:sns_confirm_subscription]{confirm_subscription} \tab Verifies an endpoint owner's intent to receive messages by validating the token sent to the endpoint by an earlier Subscribe action\cr
#'  \link[paws.application.integration:sns_create_platform_application]{create_platform_application} \tab Creates a platform application object for one of the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging), to which devices and mobile apps may register\cr
#'  \link[paws.application.integration:sns_create_platform_endpoint]{create_platform_endpoint} \tab Creates an endpoint for a device and mobile app on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS\cr
#'  \link[paws.application.integration:sns_create_sms_sandbox_phone_number]{create_sms_sandbox_phone_number} \tab Adds a destination phone number to an Amazon Web Services account in the SMS sandbox and sends a one-time password (OTP) to that phone number\cr
#'  \link[paws.application.integration:sns_create_topic]{create_topic} \tab Creates a topic to which notifications can be published\cr
#'  \link[paws.application.integration:sns_delete_endpoint]{delete_endpoint} \tab Deletes the endpoint for a device and mobile app from Amazon SNS\cr
#'  \link[paws.application.integration:sns_delete_platform_application]{delete_platform_application} \tab Deletes a platform application object for one of the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging)\cr
#'  \link[paws.application.integration:sns_delete_sms_sandbox_phone_number]{delete_sms_sandbox_phone_number} \tab Deletes an Amazon Web Services account's verified or pending phone number from the SMS sandbox\cr
#'  \link[paws.application.integration:sns_delete_topic]{delete_topic} \tab Deletes a topic and all its subscriptions\cr
#'  \link[paws.application.integration:sns_get_data_protection_policy]{get_data_protection_policy} \tab Retrieves the specified inline DataProtectionPolicy document that is stored in the specified Amazon SNS topic\cr
#'  \link[paws.application.integration:sns_get_endpoint_attributes]{get_endpoint_attributes} \tab Retrieves the endpoint attributes for a device on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS\cr
#'  \link[paws.application.integration:sns_get_platform_application_attributes]{get_platform_application_attributes} \tab Retrieves the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging)\cr
#'  \link[paws.application.integration:sns_get_sms_attributes]{get_sms_attributes} \tab Returns the settings for sending SMS messages from your Amazon Web Services account\cr
#'  \link[paws.application.integration:sns_get_sms_sandbox_account_status]{get_sms_sandbox_account_status} \tab Retrieves the SMS sandbox status for the calling Amazon Web Services account in the target Amazon Web Services Region\cr
#'  \link[paws.application.integration:sns_get_subscription_attributes]{get_subscription_attributes} \tab Returns all of the properties of a subscription\cr
#'  \link[paws.application.integration:sns_get_topic_attributes]{get_topic_attributes} \tab Returns all of the properties of a topic\cr
#'  \link[paws.application.integration:sns_list_endpoints_by_platform_application]{list_endpoints_by_platform_application} \tab Lists the endpoints and endpoint attributes for devices in a supported push notification service, such as GCM (Firebase Cloud Messaging) and APNS\cr
#'  \link[paws.application.integration:sns_list_origination_numbers]{list_origination_numbers} \tab Lists the calling Amazon Web Services account's dedicated origination numbers and their metadata\cr
#'  \link[paws.application.integration:sns_list_phone_numbers_opted_out]{list_phone_numbers_opted_out} \tab Returns a list of phone numbers that are opted out, meaning you cannot send SMS messages to them\cr
#'  \link[paws.application.integration:sns_list_platform_applications]{list_platform_applications} \tab Lists the platform application objects for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging)\cr
#'  \link[paws.application.integration:sns_list_sms_sandbox_phone_numbers]{list_sms_sandbox_phone_numbers} \tab Lists the calling Amazon Web Services account's current verified and pending destination phone numbers in the SMS sandbox\cr
#'  \link[paws.application.integration:sns_list_subscriptions]{list_subscriptions} \tab Returns a list of the requester's subscriptions\cr
#'  \link[paws.application.integration:sns_list_subscriptions_by_topic]{list_subscriptions_by_topic} \tab Returns a list of the subscriptions to a specific topic\cr
#'  \link[paws.application.integration:sns_list_tags_for_resource]{list_tags_for_resource} \tab List all tags added to the specified Amazon SNS topic\cr
#'  \link[paws.application.integration:sns_list_topics]{list_topics} \tab Returns a list of the requester's topics\cr
#'  \link[paws.application.integration:sns_opt_in_phone_number]{opt_in_phone_number} \tab Use this request to opt in a phone number that is opted out, which enables you to resume sending SMS messages to the number\cr
#'  \link[paws.application.integration:sns_publish]{publish} \tab Sends a message to an Amazon SNS topic, a text message (SMS message) directly to a phone number, or a message to a mobile platform endpoint (when you specify the TargetArn)\cr
#'  \link[paws.application.integration:sns_publish_batch]{publish_batch} \tab Publishes up to ten messages to the specified topic\cr
#'  \link[paws.application.integration:sns_put_data_protection_policy]{put_data_protection_policy} \tab Adds or updates an inline policy document that is stored in the specified Amazon SNS topic\cr
#'  \link[paws.application.integration:sns_remove_permission]{remove_permission} \tab Removes a statement from a topic's access control policy\cr
#'  \link[paws.application.integration:sns_set_endpoint_attributes]{set_endpoint_attributes} \tab Sets the attributes for an endpoint for a device on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS\cr
#'  \link[paws.application.integration:sns_set_platform_application_attributes]{set_platform_application_attributes} \tab Sets the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging)\cr
#'  \link[paws.application.integration:sns_set_sms_attributes]{set_sms_attributes} \tab Use this request to set the default settings for sending SMS messages and receiving daily SMS usage reports\cr
#'  \link[paws.application.integration:sns_set_subscription_attributes]{set_subscription_attributes} \tab Allows a subscription owner to set an attribute of the subscription to a new value\cr
#'  \link[paws.application.integration:sns_set_topic_attributes]{set_topic_attributes} \tab Allows a topic owner to set an attribute of the topic to a new value\cr
#'  \link[paws.application.integration:sns_subscribe]{subscribe} \tab Subscribes an endpoint to an Amazon SNS topic\cr
#'  \link[paws.application.integration:sns_tag_resource]{tag_resource} \tab Add tags to the specified Amazon SNS topic\cr
#'  \link[paws.application.integration:sns_unsubscribe]{unsubscribe} \tab Deletes a subscription\cr
#'  \link[paws.application.integration:sns_untag_resource]{untag_resource} \tab Remove tags from the specified Amazon SNS topic\cr
#'  \link[paws.application.integration:sns_verify_sms_sandbox_phone_number]{verify_sms_sandbox_phone_number} \tab Verifies a destination phone number with a one-time password (OTP) for the calling Amazon Web Services account
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sns
#' @export
sns <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::sns(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Simple Queue Service
#'
#' @description
#' Welcome to the *Amazon SQS API Reference*.
#' 
#' Amazon SQS is a reliable, highly-scalable hosted queue for storing
#' messages as they travel between applications or microservices. Amazon
#' SQS moves data between distributed application components and helps you
#' decouple these components.
#' 
#' For information on the permissions you need to use this API, see
#' [Identity and access
#' management](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-authentication-and-access-control.html)
#' in the *Amazon SQS Developer Guide.*
#' 
#' You can use [Amazon Web Services
#' SDKs](https://aws.amazon.com/developer/tools/#sdk) to access Amazon SQS
#' using your favorite programming language. The SDKs perform tasks such as
#' the following automatically:
#' 
#' -   Cryptographically sign your service requests
#' 
#' -   Retry requests
#' 
#' -   Handle error responses
#' 
#' **Additional information**
#' 
#' -   [Amazon SQS Product Page](https://aws.amazon.com/sqs/)
#' 
#' -   *Amazon SQS Developer Guide*
#' 
#'     -   [Making API
#'         Requests](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-making-api-requests-xml.html)
#' 
#'     -   [Amazon SQS Message
#'         Attributes](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-message-metadata.html#sqs-message-attributes)
#' 
#'     -   [Amazon SQS Dead-Letter
#'         Queues](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-dead-letter-queues.html)
#' 
#' -   [Amazon SQS in the *Command Line
#'     Interface*](https://docs.aws.amazon.com/cli/latest/reference/sqs/)
#' 
#' -   *Amazon Web Services General Reference*
#' 
#'     -   [Regions and
#'         Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#sqs_region)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sqs(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sqs()
#' svc$add_permission(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:sqs_add_permission]{add_permission} \tab Adds a permission to a queue for a specific principal\cr
#'  \link[paws.application.integration:sqs_cancel_message_move_task]{cancel_message_move_task} \tab Cancels a specified message movement task\cr
#'  \link[paws.application.integration:sqs_change_message_visibility]{change_message_visibility} \tab Changes the visibility timeout of a specified message in a queue to a new value\cr
#'  \link[paws.application.integration:sqs_change_message_visibility_batch]{change_message_visibility_batch} \tab Changes the visibility timeout of multiple messages\cr
#'  \link[paws.application.integration:sqs_create_queue]{create_queue} \tab Creates a new standard or FIFO queue\cr
#'  \link[paws.application.integration:sqs_delete_message]{delete_message} \tab Deletes the specified message from the specified queue\cr
#'  \link[paws.application.integration:sqs_delete_message_batch]{delete_message_batch} \tab Deletes up to ten messages from the specified queue\cr
#'  \link[paws.application.integration:sqs_delete_queue]{delete_queue} \tab Deletes the queue specified by the QueueUrl, regardless of the queue's contents\cr
#'  \link[paws.application.integration:sqs_get_queue_attributes]{get_queue_attributes} \tab Gets attributes for the specified queue\cr
#'  \link[paws.application.integration:sqs_get_queue_url]{get_queue_url} \tab The GetQueueUrl API returns the URL of an existing Amazon SQS queue\cr
#'  \link[paws.application.integration:sqs_list_dead_letter_source_queues]{list_dead_letter_source_queues} \tab Returns a list of your queues that have the RedrivePolicy queue attribute configured with a dead-letter queue\cr
#'  \link[paws.application.integration:sqs_list_message_move_tasks]{list_message_move_tasks} \tab Gets the most recent message movement tasks (up to 10) under a specific source queue\cr
#'  \link[paws.application.integration:sqs_list_queues]{list_queues} \tab Returns a list of your queues in the current region\cr
#'  \link[paws.application.integration:sqs_list_queue_tags]{list_queue_tags} \tab List all cost allocation tags added to the specified Amazon SQS queue\cr
#'  \link[paws.application.integration:sqs_purge_queue]{purge_queue} \tab Deletes available messages in a queue (including in-flight messages) specified by the QueueURL parameter\cr
#'  \link[paws.application.integration:sqs_receive_message]{receive_message} \tab Retrieves one or more messages (up to 10), from the specified queue\cr
#'  \link[paws.application.integration:sqs_remove_permission]{remove_permission} \tab Revokes any permissions in the queue policy that matches the specified Label parameter\cr
#'  \link[paws.application.integration:sqs_send_message]{send_message} \tab Delivers a message to the specified queue\cr
#'  \link[paws.application.integration:sqs_send_message_batch]{send_message_batch} \tab You can use SendMessageBatch to send up to 10 messages to the specified queue by assigning either identical or different values to each message (or by not assigning values at all)\cr
#'  \link[paws.application.integration:sqs_set_queue_attributes]{set_queue_attributes} \tab Sets the value of one or more queue attributes, like a policy\cr
#'  \link[paws.application.integration:sqs_start_message_move_task]{start_message_move_task} \tab Starts an asynchronous task to move messages from a specified source queue to a specified destination queue\cr
#'  \link[paws.application.integration:sqs_tag_queue]{tag_queue} \tab Add cost allocation tags to the specified Amazon SQS queue\cr
#'  \link[paws.application.integration:sqs_untag_queue]{untag_queue} \tab Remove cost allocation tags from the specified Amazon SQS queue
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sqs
#' @export
sqs <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::sqs(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Simple Workflow Service
#'
#' @description
#' The Amazon Simple Workflow Service (Amazon SWF) makes it easy to build
#' applications that use Amazon's cloud to coordinate work across
#' distributed components. In Amazon SWF, a *task* represents a logical
#' unit of work that is performed by a component of your workflow.
#' Coordinating tasks in a workflow involves managing intertask
#' dependencies, scheduling, and concurrency in accordance with the logical
#' flow of the application.
#' 
#' Amazon SWF gives you full control over implementing tasks and
#' coordinating them without worrying about underlying complexities such as
#' tracking their progress and maintaining their state.
#' 
#' This documentation serves as reference only. For a broader overview of
#' the Amazon SWF programming model, see the *\href{https://docs.aws.amazon.com/amazonswf/latest/developerguide/welcome.html}{Amazon SWF Developer Guide}* .
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- swf(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- swf()
#' svc$count_closed_workflow_executions(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.application.integration:swf_count_closed_workflow_executions]{count_closed_workflow_executions} \tab Returns the number of closed workflow executions within the given domain that meet the specified filtering criteria\cr
#'  \link[paws.application.integration:swf_count_open_workflow_executions]{count_open_workflow_executions} \tab Returns the number of open workflow executions within the given domain that meet the specified filtering criteria\cr
#'  \link[paws.application.integration:swf_count_pending_activity_tasks]{count_pending_activity_tasks} \tab Returns the estimated number of activity tasks in the specified task list\cr
#'  \link[paws.application.integration:swf_count_pending_decision_tasks]{count_pending_decision_tasks} \tab Returns the estimated number of decision tasks in the specified task list\cr
#'  \link[paws.application.integration:swf_delete_activity_type]{delete_activity_type} \tab Deletes the specified activity type\cr
#'  \link[paws.application.integration:swf_delete_workflow_type]{delete_workflow_type} \tab Deletes the specified workflow type\cr
#'  \link[paws.application.integration:swf_deprecate_activity_type]{deprecate_activity_type} \tab Deprecates the specified activity type\cr
#'  \link[paws.application.integration:swf_deprecate_domain]{deprecate_domain} \tab Deprecates the specified domain\cr
#'  \link[paws.application.integration:swf_deprecate_workflow_type]{deprecate_workflow_type} \tab Deprecates the specified workflow type\cr
#'  \link[paws.application.integration:swf_describe_activity_type]{describe_activity_type} \tab Returns information about the specified activity type\cr
#'  \link[paws.application.integration:swf_describe_domain]{describe_domain} \tab Returns information about the specified domain, including description and status\cr
#'  \link[paws.application.integration:swf_describe_workflow_execution]{describe_workflow_execution} \tab Returns information about the specified workflow execution including its type and some statistics\cr
#'  \link[paws.application.integration:swf_describe_workflow_type]{describe_workflow_type} \tab Returns information about the specified workflow type\cr
#'  \link[paws.application.integration:swf_get_workflow_execution_history]{get_workflow_execution_history} \tab Returns the history of the specified workflow execution\cr
#'  \link[paws.application.integration:swf_list_activity_types]{list_activity_types} \tab Returns information about all activities registered in the specified domain that match the specified name and registration status\cr
#'  \link[paws.application.integration:swf_list_closed_workflow_executions]{list_closed_workflow_executions} \tab Returns a list of closed workflow executions in the specified domain that meet the filtering criteria\cr
#'  \link[paws.application.integration:swf_list_domains]{list_domains} \tab Returns the list of domains registered in the account\cr
#'  \link[paws.application.integration:swf_list_open_workflow_executions]{list_open_workflow_executions} \tab Returns a list of open workflow executions in the specified domain that meet the filtering criteria\cr
#'  \link[paws.application.integration:swf_list_tags_for_resource]{list_tags_for_resource} \tab List tags for a given domain\cr
#'  \link[paws.application.integration:swf_list_workflow_types]{list_workflow_types} \tab Returns information about workflow types in the specified domain\cr
#'  \link[paws.application.integration:swf_poll_for_activity_task]{poll_for_activity_task} \tab Used by workers to get an ActivityTask from the specified activity taskList\cr
#'  \link[paws.application.integration:swf_poll_for_decision_task]{poll_for_decision_task} \tab Used by deciders to get a DecisionTask from the specified decision taskList\cr
#'  \link[paws.application.integration:swf_record_activity_task_heartbeat]{record_activity_task_heartbeat} \tab Used by activity workers to report to the service that the ActivityTask represented by the specified taskToken is still making progress\cr
#'  \link[paws.application.integration:swf_register_activity_type]{register_activity_type} \tab Registers a new activity type along with its configuration settings in the specified domain\cr
#'  \link[paws.application.integration:swf_register_domain]{register_domain} \tab Registers a new domain\cr
#'  \link[paws.application.integration:swf_register_workflow_type]{register_workflow_type} \tab Registers a new workflow type and its configuration settings in the specified domain\cr
#'  \link[paws.application.integration:swf_request_cancel_workflow_execution]{request_cancel_workflow_execution} \tab Records a WorkflowExecutionCancelRequested event in the currently running workflow execution identified by the given domain, workflowId, and runId\cr
#'  \link[paws.application.integration:swf_respond_activity_task_canceled]{respond_activity_task_canceled} \tab Used by workers to tell the service that the ActivityTask identified by the taskToken was successfully canceled\cr
#'  \link[paws.application.integration:swf_respond_activity_task_completed]{respond_activity_task_completed} \tab Used by workers to tell the service that the ActivityTask identified by the taskToken completed successfully with a result (if provided)\cr
#'  \link[paws.application.integration:swf_respond_activity_task_failed]{respond_activity_task_failed} \tab Used by workers to tell the service that the ActivityTask identified by the taskToken has failed with reason (if specified)\cr
#'  \link[paws.application.integration:swf_respond_decision_task_completed]{respond_decision_task_completed} \tab Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed\cr
#'  \link[paws.application.integration:swf_signal_workflow_execution]{signal_workflow_execution} \tab Records a WorkflowExecutionSignaled event in the workflow execution history and creates a decision task for the workflow execution identified by the given domain, workflowId and runId\cr
#'  \link[paws.application.integration:swf_start_workflow_execution]{start_workflow_execution} \tab Starts an execution of the workflow type in the specified domain using the provided workflowId and input data\cr
#'  \link[paws.application.integration:swf_tag_resource]{tag_resource} \tab Add a tag to a Amazon SWF domain\cr
#'  \link[paws.application.integration:swf_terminate_workflow_execution]{terminate_workflow_execution} \tab Records a WorkflowExecutionTerminated event and forces closure of the workflow execution identified by the given domain, runId, and workflowId\cr
#'  \link[paws.application.integration:swf_undeprecate_activity_type]{undeprecate_activity_type} \tab Undeprecates a previously deprecated activity type\cr
#'  \link[paws.application.integration:swf_undeprecate_domain]{undeprecate_domain} \tab Undeprecates a previously deprecated domain\cr
#'  \link[paws.application.integration:swf_undeprecate_workflow_type]{undeprecate_workflow_type} \tab Undeprecates a previously deprecated workflow type\cr
#'  \link[paws.application.integration:swf_untag_resource]{untag_resource} \tab Remove a tag from a Amazon SWF domain
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname swf
#' @export
swf <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.application.integration::swf(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWSBillingConductor
#'
#' @description
#' Amazon Web Services Billing Conductor is a fully managed service that
#' you can use to customize a
#' [proforma](https://docs.aws.amazon.com/billingconductor/latest/userguide/#eb-other-definitions)
#' version of your billing data each month, to accurately show or
#' chargeback your end customers. Amazon Web Services Billing Conductor
#' doesn't change the way you're billed by Amazon Web Services each month
#' by design. Instead, it provides you with a mechanism to configure,
#' generate, and display rates to certain customers over a given billing
#' period. You can also analyze the difference between the rates you apply
#' to your accounting groupings relative to your actual rates from Amazon
#' Web Services. As a result of your Amazon Web Services Billing Conductor
#' configuration, the payer account can also see the custom rate applied on
#' the billing details page of the Amazon Web Services Billing console, or
#' configure a cost and usage report per billing group.
#' 
#' This documentation shows how you can configure Amazon Web Services
#' Billing Conductor using its API. For more information about using the
#' Amazon Web Services Billing Conductor user interface, see the [Amazon
#' Web Services Billing Conductor User
#' Guide](https://docs.aws.amazon.com/billingconductor/latest/userguide/what-is-billingconductor.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- billingconductor(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- billingconductor()
#' svc$associate_accounts(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:billingconductor_associate_accounts]{associate_accounts} \tab Connects an array of account IDs in a consolidated billing family to a predefined billing group\cr
#'  \link[paws.cost.management:billingconductor_associate_pricing_rules]{associate_pricing_rules} \tab Connects an array of PricingRuleArns to a defined PricingPlan\cr
#'  \link[paws.cost.management:billingconductor_batch_associate_resources_to_custom_line_item]{batch_associate_resources_to_custom_line_item} \tab Associates a batch of resources to a percentage custom line item\cr
#'  \link[paws.cost.management:billingconductor_batch_disassociate_resources_from_custom_line_item]{batch_disassociate_resources_from_custom_line_item} \tab Disassociates a batch of resources from a percentage custom line item\cr
#'  \link[paws.cost.management:billingconductor_create_billing_group]{create_billing_group} \tab Creates a billing group that resembles a consolidated billing family that Amazon Web Services charges, based off of the predefined pricing plan computation\cr
#'  \link[paws.cost.management:billingconductor_create_custom_line_item]{create_custom_line_item} \tab Creates a custom line item that can be used to create a one-time fixed charge that can be applied to a single billing group for the current or previous billing period\cr
#'  \link[paws.cost.management:billingconductor_create_pricing_plan]{create_pricing_plan} \tab Creates a pricing plan that is used for computing Amazon Web Services charges for billing groups\cr
#'  \link[paws.cost.management:billingconductor_create_pricing_rule]{create_pricing_rule} \tab Creates a pricing rule can be associated to a pricing plan, or a set of pricing plans\cr
#'  \link[paws.cost.management:billingconductor_delete_billing_group]{delete_billing_group} \tab Deletes a billing group\cr
#'  \link[paws.cost.management:billingconductor_delete_custom_line_item]{delete_custom_line_item} \tab Deletes the custom line item identified by the given ARN in the current, or previous billing period\cr
#'  \link[paws.cost.management:billingconductor_delete_pricing_plan]{delete_pricing_plan} \tab Deletes a pricing plan\cr
#'  \link[paws.cost.management:billingconductor_delete_pricing_rule]{delete_pricing_rule} \tab Deletes the pricing rule that's identified by the input Amazon Resource Name (ARN)\cr
#'  \link[paws.cost.management:billingconductor_disassociate_accounts]{disassociate_accounts} \tab Removes the specified list of account IDs from the given billing group\cr
#'  \link[paws.cost.management:billingconductor_disassociate_pricing_rules]{disassociate_pricing_rules} \tab Disassociates a list of pricing rules from a pricing plan\cr
#'  \link[paws.cost.management:billingconductor_get_billing_group_cost_report]{get_billing_group_cost_report} \tab Retrieves the margin summary report, which includes the Amazon Web Services cost and charged amount (pro forma cost) by Amazon Web Service for a specific billing group\cr
#'  \link[paws.cost.management:billingconductor_list_account_associations]{list_account_associations} \tab This is a paginated call to list linked accounts that are linked to the payer account for the specified time period\cr
#'  \link[paws.cost.management:billingconductor_list_billing_group_cost_reports]{list_billing_group_cost_reports} \tab A paginated call to retrieve a summary report of actual Amazon Web Services charges and the calculated Amazon Web Services charges based on the associated pricing plan of a billing group\cr
#'  \link[paws.cost.management:billingconductor_list_billing_groups]{list_billing_groups} \tab A paginated call to retrieve a list of billing groups for the given billing period\cr
#'  \link[paws.cost.management:billingconductor_list_custom_line_items]{list_custom_line_items} \tab A paginated call to get a list of all custom line items (FFLIs) for the given billing period\cr
#'  \link[paws.cost.management:billingconductor_list_custom_line_item_versions]{list_custom_line_item_versions} \tab A paginated call to get a list of all custom line item versions\cr
#'  \link[paws.cost.management:billingconductor_list_pricing_plans]{list_pricing_plans} \tab A paginated call to get pricing plans for the given billing period\cr
#'  \link[paws.cost.management:billingconductor_list_pricing_plans_associated_with_pricing_rule]{list_pricing_plans_associated_with_pricing_rule} \tab A list of the pricing plans that are associated with a pricing rule\cr
#'  \link[paws.cost.management:billingconductor_list_pricing_rules]{list_pricing_rules} \tab Describes a pricing rule that can be associated to a pricing plan, or set of pricing plans\cr
#'  \link[paws.cost.management:billingconductor_list_pricing_rules_associated_to_pricing_plan]{list_pricing_rules_associated_to_pricing_plan} \tab Lists the pricing rules that are associated with a pricing plan\cr
#'  \link[paws.cost.management:billingconductor_list_resources_associated_to_custom_line_item]{list_resources_associated_to_custom_line_item} \tab List the resources that are associated to a custom line item\cr
#'  \link[paws.cost.management:billingconductor_list_tags_for_resource]{list_tags_for_resource} \tab A list the tags for a resource\cr
#'  \link[paws.cost.management:billingconductor_tag_resource]{tag_resource} \tab Associates the specified tags to a resource with the specified resourceArn\cr
#'  \link[paws.cost.management:billingconductor_untag_resource]{untag_resource} \tab Deletes specified tags from a resource\cr
#'  \link[paws.cost.management:billingconductor_update_billing_group]{update_billing_group} \tab This updates an existing billing group\cr
#'  \link[paws.cost.management:billingconductor_update_custom_line_item]{update_custom_line_item} \tab Update an existing custom line item in the current or previous billing period\cr
#'  \link[paws.cost.management:billingconductor_update_pricing_plan]{update_pricing_plan} \tab This updates an existing pricing plan\cr
#'  \link[paws.cost.management:billingconductor_update_pricing_rule]{update_pricing_rule} \tab Updates an existing pricing rule
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname billingconductor
#' @export
billingconductor <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::billingconductor(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Billing
#'
#' @description
#' You can use the Billing API to programatically list the billing views
#' available to you for a given time period. A billing view represents a
#' set of billing data.
#' 
#' The Billing API provides the following endpoint:
#' 
#' `https://billing.us-east-1.api.aws`
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- billing(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- billing()
#' svc$create_billing_view(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:billing_create_billing_view]{create_billing_view} \tab Creates a billing view with the specified billing view attributes\cr
#'  \link[paws.cost.management:billing_delete_billing_view]{delete_billing_view} \tab Deletes the specified billing view\cr
#'  \link[paws.cost.management:billing_get_billing_view]{get_billing_view} \tab Returns the metadata associated to the specified billing view ARN\cr
#'  \link[paws.cost.management:billing_get_resource_policy]{get_resource_policy} \tab Returns the resource-based policy document attached to the resource in JSON format\cr
#'  \link[paws.cost.management:billing_list_billing_views]{list_billing_views} \tab Lists the billing views available for a given time period\cr
#'  \link[paws.cost.management:billing_list_source_views_for_billing_view]{list_source_views_for_billing_view} \tab Lists the source views (managed Amazon Web Services billing views) associated with the billing view\cr
#'  \link[paws.cost.management:billing_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags associated with the billing view resource\cr
#'  \link[paws.cost.management:billing_tag_resource]{tag_resource} \tab An API operation for adding one or more tags (key-value pairs) to a resource\cr
#'  \link[paws.cost.management:billing_untag_resource]{untag_resource} \tab Removes one or more tags from a resource\cr
#'  \link[paws.cost.management:billing_update_billing_view]{update_billing_view} \tab An API to update the attributes of the billing view
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname billing
#' @export
billing <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::billing(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Budgets
#'
#' @description
#' Use the Amazon Web Services Budgets API to plan your service usage,
#' service costs, and instance reservations. This API reference provides
#' descriptions, syntax, and usage examples for each of the actions and
#' data types for the Amazon Web Services Budgets feature.
#' 
#' Budgets provide you with a way to see the following information:
#' 
#' -   How close your plan is to your budgeted amount or to the free tier
#'     limits
#' 
#' -   Your usage-to-date, including how much you've used of your Reserved
#'     Instances (RIs)
#' 
#' -   Your current estimated charges from Amazon Web Services, and how
#'     much your predicted usage will accrue in charges by the end of the
#'     month
#' 
#' -   How much of your budget has been used
#' 
#' Amazon Web Services updates your budget status several times a day.
#' Budgets track your unblended costs, subscriptions, refunds, and RIs. You
#' can create the following types of budgets:
#' 
#' -   **Cost budgets** - Plan how much you want to spend on a service.
#' 
#' -   **Usage budgets** - Plan how much you want to use one or more
#'     services.
#' 
#' -   **RI utilization budgets** - Define a utilization threshold, and
#'     receive alerts when your RI usage falls below that threshold. This
#'     lets you see if your RIs are unused or under-utilized.
#' 
#' -   **RI coverage budgets** - Define a coverage threshold, and receive
#'     alerts when the number of your instance hours that are covered by
#'     RIs fall below that threshold. This lets you see how much of your
#'     instance usage is covered by a reservation.
#' 
#' Service Endpoint
#' 
#' The Amazon Web Services Budgets API provides the following endpoint:
#' 
#' -   https://budgets.amazonaws.com
#' 
#' For information about costs that are associated with the Amazon Web
#' Services Budgets API, see [Amazon Web Services Cost Management
#' Pricing](https://aws.amazon.com/aws-cost-management/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- budgets(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- budgets()
#' svc$create_budget(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:budgets_create_budget]{create_budget} \tab Creates a budget and, if included, notifications and subscribers\cr
#'  \link[paws.cost.management:budgets_create_budget_action]{create_budget_action} \tab Creates a budget action\cr
#'  \link[paws.cost.management:budgets_create_notification]{create_notification} \tab Creates a notification\cr
#'  \link[paws.cost.management:budgets_create_subscriber]{create_subscriber} \tab Creates a subscriber\cr
#'  \link[paws.cost.management:budgets_delete_budget]{delete_budget} \tab Deletes a budget\cr
#'  \link[paws.cost.management:budgets_delete_budget_action]{delete_budget_action} \tab Deletes a budget action\cr
#'  \link[paws.cost.management:budgets_delete_notification]{delete_notification} \tab Deletes a notification\cr
#'  \link[paws.cost.management:budgets_delete_subscriber]{delete_subscriber} \tab Deletes a subscriber\cr
#'  \link[paws.cost.management:budgets_describe_budget]{describe_budget} \tab Describes a budget\cr
#'  \link[paws.cost.management:budgets_describe_budget_action]{describe_budget_action} \tab Describes a budget action detail\cr
#'  \link[paws.cost.management:budgets_describe_budget_action_histories]{describe_budget_action_histories} \tab Describes a budget action history detail\cr
#'  \link[paws.cost.management:budgets_describe_budget_actions_for_account]{describe_budget_actions_for_account} \tab Describes all of the budget actions for an account\cr
#'  \link[paws.cost.management:budgets_describe_budget_actions_for_budget]{describe_budget_actions_for_budget} \tab Describes all of the budget actions for a budget\cr
#'  \link[paws.cost.management:budgets_describe_budget_notifications_for_account]{describe_budget_notifications_for_account} \tab Lists the budget names and notifications that are associated with an account\cr
#'  \link[paws.cost.management:budgets_describe_budget_performance_history]{describe_budget_performance_history} \tab Describes the history for DAILY, MONTHLY, and QUARTERLY budgets\cr
#'  \link[paws.cost.management:budgets_describe_budgets]{describe_budgets} \tab Lists the budgets that are associated with an account\cr
#'  \link[paws.cost.management:budgets_describe_notifications_for_budget]{describe_notifications_for_budget} \tab Lists the notifications that are associated with a budget\cr
#'  \link[paws.cost.management:budgets_describe_subscribers_for_notification]{describe_subscribers_for_notification} \tab Lists the subscribers that are associated with a notification\cr
#'  \link[paws.cost.management:budgets_execute_budget_action]{execute_budget_action} \tab Executes a budget action\cr
#'  \link[paws.cost.management:budgets_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags associated with a budget or budget action resource\cr
#'  \link[paws.cost.management:budgets_tag_resource]{tag_resource} \tab Creates tags for a budget or budget action resource\cr
#'  \link[paws.cost.management:budgets_untag_resource]{untag_resource} \tab Deletes tags associated with a budget or budget action resource\cr
#'  \link[paws.cost.management:budgets_update_budget]{update_budget} \tab Updates a budget\cr
#'  \link[paws.cost.management:budgets_update_budget_action]{update_budget_action} \tab Updates a budget action\cr
#'  \link[paws.cost.management:budgets_update_notification]{update_notification} \tab Updates a notification\cr
#'  \link[paws.cost.management:budgets_update_subscriber]{update_subscriber} \tab Updates a subscriber
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname budgets
#' @export
budgets <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::budgets(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Cost and Usage Report Service
#'
#' @description
#' You can use the Amazon Web Services Cost and Usage Report API to
#' programmatically create, query, and delete Amazon Web Services Cost and
#' Usage Report definitions.
#' 
#' Amazon Web Services Cost and Usage Report track the monthly Amazon Web
#' Services costs and usage associated with your Amazon Web Services
#' account. The report contains line items for each unique combination of
#' Amazon Web Services product, usage type, and operation that your Amazon
#' Web Services account uses. You can configure the Amazon Web Services
#' Cost and Usage Report to show only the data that you want, using the
#' Amazon Web Services Cost and Usage Report API.
#' 
#' Service Endpoint
#' 
#' The Amazon Web Services Cost and Usage Report API provides the following
#' endpoint:
#' 
#' -   cur.us-east-1.amazonaws.com
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- costandusagereportservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- costandusagereportservice()
#' # The following example deletes the AWS Cost and Usage report named
#' # ExampleReport.
#' svc$delete_report_definition(
#'   ReportName = "ExampleReport"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:costandusagereportservice_delete_report_definition]{delete_report_definition} \tab Deletes the specified report\cr
#'  \link[paws.cost.management:costandusagereportservice_describe_report_definitions]{describe_report_definitions} \tab Lists the Amazon Web Services Cost and Usage Report available to this account\cr
#'  \link[paws.cost.management:costandusagereportservice_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags associated with the specified report definition\cr
#'  \link[paws.cost.management:costandusagereportservice_modify_report_definition]{modify_report_definition} \tab Allows you to programmatically update your report preferences\cr
#'  \link[paws.cost.management:costandusagereportservice_put_report_definition]{put_report_definition} \tab Creates a new report using the description that you provide\cr
#'  \link[paws.cost.management:costandusagereportservice_tag_resource]{tag_resource} \tab Associates a set of tags with a report definition\cr
#'  \link[paws.cost.management:costandusagereportservice_untag_resource]{untag_resource} \tab Disassociates a set of tags from a report definition
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname costandusagereportservice
#' @export
costandusagereportservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::costandusagereportservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Cost Explorer Service
#'
#' @description
#' You can use the Cost Explorer API to programmatically query your cost
#' and usage data. You can query for aggregated data such as total monthly
#' costs or total daily usage. You can also query for granular data. This
#' might include the number of daily write operations for Amazon DynamoDB
#' database tables in your production environment.
#' 
#' Service Endpoint
#' 
#' The Cost Explorer API provides the following endpoint:
#' 
#' -   `https://ce.us-east-1.amazonaws.com`
#' 
#' For information about the costs that are associated with the Cost
#' Explorer API, see [Amazon Web Services Cost Management
#' Pricing](https://aws.amazon.com/aws-cost-management/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- costexplorer(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- costexplorer()
#' svc$create_anomaly_monitor(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:costexplorer_create_anomaly_monitor]{create_anomaly_monitor} \tab Creates a new cost anomaly detection monitor with the requested type and monitor specification\cr
#'  \link[paws.cost.management:costexplorer_create_anomaly_subscription]{create_anomaly_subscription} \tab Adds an alert subscription to a cost anomaly detection monitor\cr
#'  \link[paws.cost.management:costexplorer_create_cost_category_definition]{create_cost_category_definition} \tab Creates a new Cost Category with the requested name and rules\cr
#'  \link[paws.cost.management:costexplorer_delete_anomaly_monitor]{delete_anomaly_monitor} \tab Deletes a cost anomaly monitor\cr
#'  \link[paws.cost.management:costexplorer_delete_anomaly_subscription]{delete_anomaly_subscription} \tab Deletes a cost anomaly subscription\cr
#'  \link[paws.cost.management:costexplorer_delete_cost_category_definition]{delete_cost_category_definition} \tab Deletes a Cost Category\cr
#'  \link[paws.cost.management:costexplorer_describe_cost_category_definition]{describe_cost_category_definition} \tab Returns the name, Amazon Resource Name (ARN), rules, definition, and effective dates of a Cost Category that's defined in the account\cr
#'  \link[paws.cost.management:costexplorer_get_anomalies]{get_anomalies} \tab Retrieves all of the cost anomalies detected on your account during the time period that's specified by the DateInterval object\cr
#'  \link[paws.cost.management:costexplorer_get_anomaly_monitors]{get_anomaly_monitors} \tab Retrieves the cost anomaly monitor definitions for your account\cr
#'  \link[paws.cost.management:costexplorer_get_anomaly_subscriptions]{get_anomaly_subscriptions} \tab Retrieves the cost anomaly subscription objects for your account\cr
#'  \link[paws.cost.management:costexplorer_get_approximate_usage_records]{get_approximate_usage_records} \tab Retrieves estimated usage records for hourly granularity or resource-level data at daily granularity\cr
#'  \link[paws.cost.management:costexplorer_get_commitment_purchase_analysis]{get_commitment_purchase_analysis} \tab Retrieves a commitment purchase analysis result based on the AnalysisId\cr
#'  \link[paws.cost.management:costexplorer_get_cost_and_usage]{get_cost_and_usage} \tab Retrieves cost and usage metrics for your account\cr
#'  \link[paws.cost.management:costexplorer_get_cost_and_usage_with_resources]{get_cost_and_usage_with_resources} \tab Retrieves cost and usage metrics with resources for your account\cr
#'  \link[paws.cost.management:costexplorer_get_cost_categories]{get_cost_categories} \tab Retrieves an array of Cost Category names and values incurred cost\cr
#'  \link[paws.cost.management:costexplorer_get_cost_forecast]{get_cost_forecast} \tab Retrieves a forecast for how much Amazon Web Services predicts that you will spend over the forecast time period that you select, based on your past costs\cr
#'  \link[paws.cost.management:costexplorer_get_dimension_values]{get_dimension_values} \tab Retrieves all available filter values for a specified filter over a period of time\cr
#'  \link[paws.cost.management:costexplorer_get_reservation_coverage]{get_reservation_coverage} \tab Retrieves the reservation coverage for your account, which you can use to see how much of your Amazon Elastic Compute Cloud, Amazon ElastiCache, Amazon Relational Database Service, or Amazon Redshift usage is covered by a reservation\cr
#'  \link[paws.cost.management:costexplorer_get_reservation_purchase_recommendation]{get_reservation_purchase_recommendation} \tab Gets recommendations for reservation purchases\cr
#'  \link[paws.cost.management:costexplorer_get_reservation_utilization]{get_reservation_utilization} \tab Retrieves the reservation utilization for your account\cr
#'  \link[paws.cost.management:costexplorer_get_rightsizing_recommendation]{get_rightsizing_recommendation} \tab Creates recommendations that help you save cost by identifying idle and underutilized Amazon EC2 instances\cr
#'  \link[paws.cost.management:costexplorer_get_savings_plan_purchase_recommendation_details]{get_savings_plan_purchase_recommendation_details} \tab Retrieves the details for a Savings Plan recommendation\cr
#'  \link[paws.cost.management:costexplorer_get_savings_plans_coverage]{get_savings_plans_coverage} \tab Retrieves the Savings Plans covered for your account\cr
#'  \link[paws.cost.management:costexplorer_get_savings_plans_purchase_recommendation]{get_savings_plans_purchase_recommendation} \tab Retrieves the Savings Plans recommendations for your account\cr
#'  \link[paws.cost.management:costexplorer_get_savings_plans_utilization]{get_savings_plans_utilization} \tab Retrieves the Savings Plans utilization for your account across date ranges with daily or monthly granularity\cr
#'  \link[paws.cost.management:costexplorer_get_savings_plans_utilization_details]{get_savings_plans_utilization_details} \tab Retrieves attribute data along with aggregate utilization and savings data for a given time period\cr
#'  \link[paws.cost.management:costexplorer_get_tags]{get_tags} \tab Queries for available tag keys and tag values for a specified period\cr
#'  \link[paws.cost.management:costexplorer_get_usage_forecast]{get_usage_forecast} \tab Retrieves a forecast for how much Amazon Web Services predicts that you will use over the forecast time period that you select, based on your past usage\cr
#'  \link[paws.cost.management:costexplorer_list_commitment_purchase_analyses]{list_commitment_purchase_analyses} \tab Lists the commitment purchase analyses for your account\cr
#'  \link[paws.cost.management:costexplorer_list_cost_allocation_tag_backfill_history]{list_cost_allocation_tag_backfill_history} \tab Retrieves a list of your historical cost allocation tag backfill requests\cr
#'  \link[paws.cost.management:costexplorer_list_cost_allocation_tags]{list_cost_allocation_tags} \tab Get a list of cost allocation tags\cr
#'  \link[paws.cost.management:costexplorer_list_cost_category_definitions]{list_cost_category_definitions} \tab Returns the name, Amazon Resource Name (ARN), NumberOfRules and effective dates of all Cost Categories defined in the account\cr
#'  \link[paws.cost.management:costexplorer_list_savings_plans_purchase_recommendation_generation]{list_savings_plans_purchase_recommendation_generation} \tab Retrieves a list of your historical recommendation generations within the past 30 days\cr
#'  \link[paws.cost.management:costexplorer_list_tags_for_resource]{list_tags_for_resource} \tab Returns a list of resource tags associated with the resource specified by the Amazon Resource Name (ARN)\cr
#'  \link[paws.cost.management:costexplorer_provide_anomaly_feedback]{provide_anomaly_feedback} \tab Modifies the feedback property of a given cost anomaly\cr
#'  \link[paws.cost.management:costexplorer_start_commitment_purchase_analysis]{start_commitment_purchase_analysis} \tab Specifies the parameters of a planned commitment purchase and starts the generation of the analysis\cr
#'  \link[paws.cost.management:costexplorer_start_cost_allocation_tag_backfill]{start_cost_allocation_tag_backfill} \tab Request a cost allocation tag backfill\cr
#'  \link[paws.cost.management:costexplorer_start_savings_plans_purchase_recommendation_generation]{start_savings_plans_purchase_recommendation_generation} \tab Requests a Savings Plans recommendation generation\cr
#'  \link[paws.cost.management:costexplorer_tag_resource]{tag_resource} \tab An API operation for adding one or more tags (key-value pairs) to a resource\cr
#'  \link[paws.cost.management:costexplorer_untag_resource]{untag_resource} \tab Removes one or more tags from a resource\cr
#'  \link[paws.cost.management:costexplorer_update_anomaly_monitor]{update_anomaly_monitor} \tab Updates an existing cost anomaly monitor\cr
#'  \link[paws.cost.management:costexplorer_update_anomaly_subscription]{update_anomaly_subscription} \tab Updates an existing cost anomaly subscription\cr
#'  \link[paws.cost.management:costexplorer_update_cost_allocation_tags_status]{update_cost_allocation_tags_status} \tab Updates status for cost allocation tags in bulk, with maximum batch size of 20\cr
#'  \link[paws.cost.management:costexplorer_update_cost_category_definition]{update_cost_category_definition} \tab Updates an existing Cost Category
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname costexplorer
#' @export
costexplorer <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::costexplorer(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Marketplace Catalog Service
#'
#' @description
#' Catalog API actions allow you to manage your entities through list,
#' describe, and update capabilities. An entity can be a product or an
#' offer on AWS Marketplace.
#' 
#' You can automate your entity update process by integrating the AWS
#' Marketplace Catalog API with your AWS Marketplace product build or
#' deployment pipelines. You can also create your own applications on top
#' of the Catalog API to manage your products on AWS Marketplace.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- marketplacecatalog(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- marketplacecatalog()
#' svc$batch_describe_entities(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:marketplacecatalog_batch_describe_entities]{batch_describe_entities} \tab Returns metadata and content for multiple entities\cr
#'  \link[paws.cost.management:marketplacecatalog_cancel_change_set]{cancel_change_set} \tab Used to cancel an open change request\cr
#'  \link[paws.cost.management:marketplacecatalog_delete_resource_policy]{delete_resource_policy} \tab Deletes a resource-based policy on an entity that is identified by its resource ARN\cr
#'  \link[paws.cost.management:marketplacecatalog_describe_change_set]{describe_change_set} \tab Provides information about a given change set\cr
#'  \link[paws.cost.management:marketplacecatalog_describe_entity]{describe_entity} \tab Returns the metadata and content of the entity\cr
#'  \link[paws.cost.management:marketplacecatalog_get_resource_policy]{get_resource_policy} \tab Gets a resource-based policy of an entity that is identified by its resource ARN\cr
#'  \link[paws.cost.management:marketplacecatalog_list_change_sets]{list_change_sets} \tab Returns the list of change sets owned by the account being used to make the call\cr
#'  \link[paws.cost.management:marketplacecatalog_list_entities]{list_entities} \tab Provides the list of entities of a given type\cr
#'  \link[paws.cost.management:marketplacecatalog_list_tags_for_resource]{list_tags_for_resource} \tab Lists all tags that have been added to a resource (either an entity or change set)\cr
#'  \link[paws.cost.management:marketplacecatalog_put_resource_policy]{put_resource_policy} \tab Attaches a resource-based policy to an entity\cr
#'  \link[paws.cost.management:marketplacecatalog_start_change_set]{start_change_set} \tab Allows you to request changes for your entities\cr
#'  \link[paws.cost.management:marketplacecatalog_tag_resource]{tag_resource} \tab Tags a resource (either an entity or change set)\cr
#'  \link[paws.cost.management:marketplacecatalog_untag_resource]{untag_resource} \tab Removes a tag or list of tags from a resource (either an entity or change set)
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname marketplacecatalog
#' @export
marketplacecatalog <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::marketplacecatalog(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Marketplace Commerce Analytics
#'
#' @description
#' Provides AWS Marketplace business intelligence data on-demand.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- marketplacecommerceanalytics(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- marketplacecommerceanalytics()
#' svc$generate_data_set(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:marketplacecommerceanalytics_generate_data_set]{generate_data_set} \tab Given a data set type and data set publication date, asynchronously publishes the requested data set to the specified S3 bucket and notifies the specified SNS topic once the data is available\cr
#'  \link[paws.cost.management:marketplacecommerceanalytics_start_support_data_export]{start_support_data_export} \tab This target has been deprecated
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname marketplacecommerceanalytics
#' @export
marketplacecommerceanalytics <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::marketplacecommerceanalytics(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Marketplace Entitlement Service
#'
#' @description
#' This reference provides descriptions of the AWS Marketplace Entitlement
#' Service API.
#' 
#' AWS Marketplace Entitlement Service is used to determine the entitlement
#' of a customer to a given product. An entitlement represents capacity in
#' a product owned by the customer. For example, a customer might own some
#' number of users or seats in an SaaS application or some amount of data
#' capacity in a multi-tenant database.
#' 
#' **Getting Entitlement Records**
#' 
#' -   *GetEntitlements*- Gets the entitlements for a Marketplace product.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- marketplaceentitlementservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- marketplaceentitlementservice()
#' svc$get_entitlements(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:marketplaceentitlementservice_get_entitlements]{get_entitlements} \tab GetEntitlements retrieves entitlement values for a given product
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname marketplaceentitlementservice
#' @export
marketplaceentitlementservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::marketplaceentitlementservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWSMarketplace Metering
#'
#' @description
#' AWS Marketplace Metering Service
#' 
#' This reference provides descriptions of the low-level AWS Marketplace
#' Metering Service API.
#' 
#' AWS Marketplace sellers can use this API to submit usage data for custom
#' usage dimensions.
#' 
#' For information on the permissions you need to use this API, see [AWS
#' Marketplace metering and entitlement API
#' permissions](https://docs.aws.amazon.com/marketplace/latest/userguide/iam-user-policy-for-aws-marketplace-actions.html)
#' in the *AWS Marketplace Seller Guide.*
#' 
#' **Submitting Metering Records**
#' 
#' -   *MeterUsage* - Submits the metering record for an AWS Marketplace
#'     product. `meter_usage` is called
#'     from an EC2 instance or a container running on EKS or ECS.
#' 
#' -   *BatchMeterUsage* - Submits the metering record for a set of
#'     customers.
#'     `batch_meter_usage` is
#'     called from a software-as-a-service (SaaS) application.
#' 
#' **Accepting New Customers**
#' 
#' -   *ResolveCustomer* - Called by a SaaS application during the
#'     registration process. When a buyer visits your website during the
#'     registration process, the buyer submits a Registration Token through
#'     the browser. The Registration Token is resolved through this API to
#'     obtain a `CustomerIdentifier` along with the `CustomerAWSAccountId`
#'     and `ProductCode`.
#' 
#' **Entitlement and Metering for Paid Container Products**
#' 
#' -   Paid container software products sold through AWS Marketplace must
#'     integrate with the AWS Marketplace Metering Service and call the
#'     `register_usage` operation for
#'     software entitlement and metering. Free and BYOL products for Amazon
#'     ECS or Amazon EKS aren't required to call
#'     `register_usage`, but you can
#'     do so if you want to receive usage data in your seller reports. For
#'     more information on using the
#'     `register_usage` operation,
#'     see [Container-Based
#'     Products](https://docs.aws.amazon.com/marketplace/latest/userguide/container-based-products.html).
#' 
#' `batch_meter_usage` API calls
#' are captured by AWS CloudTrail. You can use Cloudtrail to verify that
#' the SaaS metering records that you sent are accurate by searching for
#' records with the `eventName` of
#' `batch_meter_usage`. You can
#' also use CloudTrail to audit records over time. For more information,
#' see the *\href{https://docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-concepts.html}{AWS CloudTrail User Guide}.*
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- marketplacemetering(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- marketplacemetering()
#' svc$batch_meter_usage(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:marketplacemetering_batch_meter_usage]{batch_meter_usage} \tab BatchMeterUsage is called from a SaaS application listed on AWS Marketplace to post metering records for a set of customers\cr
#'  \link[paws.cost.management:marketplacemetering_meter_usage]{meter_usage} \tab API to emit metering records\cr
#'  \link[paws.cost.management:marketplacemetering_register_usage]{register_usage} \tab Paid container software products sold through AWS Marketplace must integrate with the AWS Marketplace Metering Service and call the RegisterUsage operation for software entitlement and metering\cr
#'  \link[paws.cost.management:marketplacemetering_resolve_customer]{resolve_customer} \tab ResolveCustomer is called by a SaaS application during the registration process
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname marketplacemetering
#' @export
marketplacemetering <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::marketplacemetering(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Price List Service
#'
#' @description
#' The Amazon Web Services Price List API is a centralized and convenient
#' way to programmatically query Amazon Web Services for services,
#' products, and pricing information. The Amazon Web Services Price List
#' uses standardized product attributes such as `Location`,
#' `Storage Class`, and `Operating System`, and provides prices at the SKU
#' level. You can use the Amazon Web Services Price List to do the
#' following:
#' 
#' -   Build cost control and scenario planning tools
#' 
#' -   Reconcile billing data
#' 
#' -   Forecast future spend for budgeting purposes
#' 
#' -   Provide cost benefit analysis that compare your internal workloads
#'     with Amazon Web Services
#' 
#' Use `GetServices` without a service code to retrieve the service codes
#' for all Amazon Web Services services, then `GetServices` with a service
#' code to retrieve the attribute names for that service. After you have
#' the service code and attribute names, you can use
#' `get_attribute_values` to see what
#' values are available for an attribute. With the service code and an
#' attribute name and value, you can use
#' `get_products` to find specific products that
#' you're interested in, such as an `AmazonEC2` instance, with a
#' `Provisioned IOPS` `volumeType`.
#' 
#' For more information, see [Using the Amazon Web Services Price List
#' API](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/price-changes.html)
#' in the *Billing User Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- pricing(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- pricing()
#' # Retrieves the service for the given Service Code.
#' svc$describe_services(
#'   FormatVersion = "aws_v1",
#'   MaxResults = 1L,
#'   ServiceCode = "AmazonEC2"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:pricing_describe_services]{describe_services} \tab Returns the metadata for one service or a list of the metadata for all services\cr
#'  \link[paws.cost.management:pricing_get_attribute_values]{get_attribute_values} \tab Returns a list of attribute values\cr
#'  \link[paws.cost.management:pricing_get_price_list_file_url]{get_price_list_file_url} \tab This feature is in preview release and is subject to change\cr
#'  \link[paws.cost.management:pricing_get_products]{get_products} \tab Returns a list of all products that match the filter criteria\cr
#'  \link[paws.cost.management:pricing_list_price_lists]{list_price_lists} \tab This feature is in preview release and is subject to change
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname pricing
#' @export
pricing <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::pricing(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Savings Plans
#'
#' @description
#' Savings Plans are a pricing model that offer significant savings on
#' Amazon Web Services usage (for example, on Amazon EC2 instances). You
#' commit to a consistent amount of usage per hour, in the specified
#' currency, for a term of one or three years, and receive a lower price
#' for that usage. For more information, see the [Amazon Web Services
#' Savings Plans User
#' Guide](https://docs.aws.amazon.com/savingsplans/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- savingsplans(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- savingsplans()
#' svc$create_savings_plan(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:savingsplans_create_savings_plan]{create_savings_plan} \tab Creates a Savings Plan\cr
#'  \link[paws.cost.management:savingsplans_delete_queued_savings_plan]{delete_queued_savings_plan} \tab Deletes the queued purchase for the specified Savings Plan\cr
#'  \link[paws.cost.management:savingsplans_describe_savings_plan_rates]{describe_savings_plan_rates} \tab Describes the rates for the specified Savings Plan\cr
#'  \link[paws.cost.management:savingsplans_describe_savings_plans]{describe_savings_plans} \tab Describes the specified Savings Plans\cr
#'  \link[paws.cost.management:savingsplans_describe_savings_plans_offering_rates]{describe_savings_plans_offering_rates} \tab Describes the offering rates for the specified Savings Plans\cr
#'  \link[paws.cost.management:savingsplans_describe_savings_plans_offerings]{describe_savings_plans_offerings} \tab Describes the offerings for the specified Savings Plans\cr
#'  \link[paws.cost.management:savingsplans_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for the specified resource\cr
#'  \link[paws.cost.management:savingsplans_return_savings_plan]{return_savings_plan} \tab Returns the specified Savings Plan\cr
#'  \link[paws.cost.management:savingsplans_tag_resource]{tag_resource} \tab Adds the specified tags to the specified resource\cr
#'  \link[paws.cost.management:savingsplans_untag_resource]{untag_resource} \tab Removes the specified tags from the specified resource
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname savingsplans
#' @export
savingsplans <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::savingsplans(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Payment Cryptography Control Plane
#'
#' @description
#' Amazon Web Services Payment Cryptography Control Plane APIs manage
#' encryption keys for use during payment-related cryptographic operations.
#' You can create, import, export, share, manage, and delete keys. You can
#' also manage Identity and Access Management (IAM) policies for keys. For
#' more information, see [Identity and access
#' management](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/security-iam.html)
#' in the *Amazon Web Services Payment Cryptography User Guide.*
#' 
#' To use encryption keys for payment-related transaction processing and
#' associated cryptographic operations, you use the [Amazon Web Services
#' Payment Cryptography Data
#' Plane](https://docs.aws.amazon.com/payment-cryptography/latest/DataAPIReference/Welcome.html).
#' You can perform actions like encrypt, decrypt, generate, and verify
#' payment-related data.
#' 
#' All Amazon Web Services Payment Cryptography API calls must be signed
#' and transmitted using Transport Layer Security (TLS). We recommend you
#' always use the latest supported TLS version for logging API requests.
#' 
#' Amazon Web Services Payment Cryptography supports CloudTrail for control
#' plane operations, a service that logs Amazon Web Services API calls and
#' related events for your Amazon Web Services account and delivers them to
#' an Amazon S3 bucket you specify. By using the information collected by
#' CloudTrail, you can determine what requests were made to Amazon Web
#' Services Payment Cryptography, who made the request, when it was made,
#' and so on. If you don't configure a trail, you can still view the most
#' recent events in the CloudTrail console. For more information, see the
#' [CloudTrail User
#' Guide](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- paymentcryptographycontrolplane(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- paymentcryptographycontrolplane()
#' svc$create_alias(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:paymentcryptographycontrolplane_create_alias]{create_alias} \tab Creates an alias, or a friendly name, for an Amazon Web Services Payment Cryptography key\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_create_key]{create_key} \tab Creates an Amazon Web Services Payment Cryptography key, a logical representation of a cryptographic key, that is unique in your account and Amazon Web Services Region\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_delete_alias]{delete_alias} \tab Deletes the alias, but doesn't affect the underlying key\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_delete_key]{delete_key} \tab Deletes the key material and metadata associated with Amazon Web Services Payment Cryptography key\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_export_key]{export_key} \tab Exports a key from Amazon Web Services Payment Cryptography\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_get_alias]{get_alias} \tab Gets the Amazon Web Services Payment Cryptography key associated with the alias\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_get_key]{get_key} \tab Gets the key material for an Amazon Web Services Payment Cryptography key, including the immutable and mutable data specified when the key was created\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_get_parameters_for_export]{get_parameters_for_export} \tab Gets the export token and the signing key certificate to initiate a TR-34 key export from Amazon Web Services Payment Cryptography\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_get_parameters_for_import]{get_parameters_for_import} \tab Gets the import token and the wrapping key certificate in PEM format (base64 encoded) to initiate a TR-34 WrappedKeyBlock or a RSA WrappedKeyCryptogram import into Amazon Web Services Payment Cryptography\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_get_public_key_certificate]{get_public_key_certificate} \tab Gets the public key certificate of the asymmetric key pair that exists within Amazon Web Services Payment Cryptography\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_import_key]{import_key} \tab Imports symmetric keys and public key certificates in PEM format (base64 encoded) into Amazon Web Services Payment Cryptography\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_list_aliases]{list_aliases} \tab Lists the aliases for all keys in the caller's Amazon Web Services account and Amazon Web Services Region\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_list_keys]{list_keys} \tab Lists the keys in the caller's Amazon Web Services account and Amazon Web Services Region\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for an Amazon Web Services resource\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_restore_key]{restore_key} \tab Cancels a scheduled key deletion during the waiting period\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_start_key_usage]{start_key_usage} \tab Enables an Amazon Web Services Payment Cryptography key, which makes it active for cryptographic operations within Amazon Web Services Payment Cryptography\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_stop_key_usage]{stop_key_usage} \tab Disables an Amazon Web Services Payment Cryptography key, which makes it inactive within Amazon Web Services Payment Cryptography\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_tag_resource]{tag_resource} \tab Adds or edits tags on an Amazon Web Services Payment Cryptography key\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_untag_resource]{untag_resource} \tab Deletes a tag from an Amazon Web Services Payment Cryptography key\cr
#'  \link[paws.cost.management:paymentcryptographycontrolplane_update_alias]{update_alias} \tab Associates an existing Amazon Web Services Payment Cryptography alias with a different key
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname paymentcryptographycontrolplane
#' @export
paymentcryptographycontrolplane <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::paymentcryptographycontrolplane(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Payment Cryptography Data Plane
#'
#' @description
#' You use the Amazon Web Services Payment Cryptography Data Plane to
#' manage how encryption keys are used for payment-related transaction
#' processing and associated cryptographic operations. You can encrypt,
#' decrypt, generate, verify, and translate payment-related cryptographic
#' operations in Amazon Web Services Payment Cryptography. For more
#' information, see [Data
#' operations](https://docs.aws.amazon.com/payment-cryptography/latest/userguide/data-operations.html)
#' in the *Amazon Web Services Payment Cryptography User Guide*.
#' 
#' To manage your encryption keys, you use the [Amazon Web Services Payment
#' Cryptography Control
#' Plane](https://docs.aws.amazon.com/payment-cryptography/latest/APIReference/Welcome.html).
#' You can create, import, export, share, manage, and delete keys. You can
#' also manage Identity and Access Management (IAM) policies for keys.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- paymentcryptographydataplane(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- paymentcryptographydataplane()
#' svc$decrypt_data(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.cost.management:paymentcryptographydataplane_decrypt_data]{decrypt_data} \tab Decrypts ciphertext data to plaintext using a symmetric (TDES, AES), asymmetric (RSA), or derived (DUKPT or EMV) encryption key scheme\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_encrypt_data]{encrypt_data} \tab Encrypts plaintext data to ciphertext using a symmetric (TDES, AES), asymmetric (RSA), or derived (DUKPT or EMV) encryption key scheme\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_generate_card_validation_data]{generate_card_validation_data} \tab Generates card-related validation data using algorithms such as Card Verification Values (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2), or Card Security Codes (CSC)\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_generate_mac]{generate_mac} \tab Generates a Message Authentication Code (MAC) cryptogram within Amazon Web Services Payment Cryptography\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_generate_mac_emv_pin_change]{generate_mac_emv_pin_change} \tab Generates an issuer script mac for EMV payment cards that use offline PINs as the cardholder verification method (CVM)\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_generate_pin_data]{generate_pin_data} \tab Generates pin-related data such as PIN, PIN Verification Value (PVV), PIN Block, and PIN Offset during new card issuance or reissuance\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_re_encrypt_data]{re_encrypt_data} \tab Re-encrypt ciphertext using DUKPT or Symmetric data encryption keys\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_translate_pin_data]{translate_pin_data} \tab Translates encrypted PIN block from and to ISO 9564 formats 0,1,3,4\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_verify_auth_request_cryptogram]{verify_auth_request_cryptogram} \tab Verifies Authorization Request Cryptogram (ARQC) for a EMV chip payment card authorization\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_verify_card_validation_data]{verify_card_validation_data} \tab Verifies card-related validation data using algorithms such as Card Verification Values (CVV/CVV2), Dynamic Card Verification Values (dCVV/dCVV2) and Card Security Codes (CSC)\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_verify_mac]{verify_mac} \tab Verifies a Message Authentication Code (MAC)\cr
#'  \link[paws.cost.management:paymentcryptographydataplane_verify_pin_data]{verify_pin_data} \tab Verifies pin-related data such as PIN and PIN Offset using algorithms including VISA PVV and IBM3624
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname paymentcryptographydataplane
#' @export
paymentcryptographydataplane <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.cost.management::paymentcryptographydataplane(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Connect Service
#'
#' @description
#' -   [Amazon Connect
#'     actions](https://docs.aws.amazon.com/connect/latest/APIReference/API_Operations_Amazon_Connect_Service.html)
#' 
#' -   [Amazon Connect data
#'     types](https://docs.aws.amazon.com/connect/latest/APIReference/API_Types_Amazon_Connect_Service.html)
#' 
#' Amazon Connect is a cloud-based contact center solution that you use to
#' set up and manage a customer contact center and provide reliable
#' customer engagement at any scale.
#' 
#' Amazon Connect provides metrics and real-time reporting that enable you
#' to optimize contact routing. You can also resolve customer issues more
#' efficiently by getting customers in touch with the appropriate agents.
#' 
#' There are limits to the number of Amazon Connect resources that you can
#' create. There are also limits to the number of requests that you can
#' make per second. For more information, see [Amazon Connect Service
#' Quotas](https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html)
#' in the *Amazon Connect Administrator Guide*.
#' 
#' You can use an endpoint to connect programmatically to an Amazon Web
#' Services service. For a list of Amazon Connect endpoints, see [Amazon
#' Connect
#' Endpoints](https://docs.aws.amazon.com/general/latest/gr/connect_region.html).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- connect(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- connect()
#' svc$activate_evaluation_form(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:connect_activate_evaluation_form]{activate_evaluation_form} \tab Activates an evaluation form in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_associate_analytics_data_set]{associate_analytics_data_set} \tab Associates the specified dataset for a Amazon Connect instance with the target account\cr
#'  \link[paws.customer.engagement:connect_associate_approved_origin]{associate_approved_origin} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_associate_bot]{associate_bot} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_associate_default_vocabulary]{associate_default_vocabulary} \tab Associates an existing vocabulary as the default\cr
#'  \link[paws.customer.engagement:connect_associate_flow]{associate_flow} \tab Associates a connect resource to a flow\cr
#'  \link[paws.customer.engagement:connect_associate_instance_storage_config]{associate_instance_storage_config} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_associate_lambda_function]{associate_lambda_function} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_associate_lex_bot]{associate_lex_bot} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_associate_phone_number_contact_flow]{associate_phone_number_contact_flow} \tab Associates a flow with a phone number claimed to your Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_associate_queue_quick_connects]{associate_queue_quick_connects} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_associate_routing_profile_queues]{associate_routing_profile_queues} \tab Associates a set of queues with a routing profile\cr
#'  \link[paws.customer.engagement:connect_associate_security_key]{associate_security_key} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_associate_traffic_distribution_group_user]{associate_traffic_distribution_group_user} \tab Associates an agent with a traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_associate_user_proficiencies]{associate_user_proficiencies} \tab Associates a set of proficiencies with a user\cr
#'  \link[paws.customer.engagement:connect_batch_associate_analytics_data_set]{batch_associate_analytics_data_set} \tab Associates a list of analytics datasets for a given Amazon Connect instance to a target account\cr
#'  \link[paws.customer.engagement:connect_batch_disassociate_analytics_data_set]{batch_disassociate_analytics_data_set} \tab Removes a list of analytics datasets associated with a given Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_batch_get_attached_file_metadata]{batch_get_attached_file_metadata} \tab Allows you to retrieve metadata about multiple attached files on an associated resource\cr
#'  \link[paws.customer.engagement:connect_batch_get_flow_association]{batch_get_flow_association} \tab Retrieve the flow associations for the given resources\cr
#'  \link[paws.customer.engagement:connect_batch_put_contact]{batch_put_contact} \tab Only the Amazon Connect outbound campaigns service principal is allowed to assume a role in your account and call this API\cr
#'  \link[paws.customer.engagement:connect_claim_phone_number]{claim_phone_number} \tab Claims an available phone number to your Amazon Connect instance or traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_complete_attached_file_upload]{complete_attached_file_upload} \tab Allows you to confirm that the attached file has been uploaded using the pre-signed URL provided in the StartAttachedFileUpload API\cr
#'  \link[paws.customer.engagement:connect_create_agent_status]{create_agent_status} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_create_contact]{create_contact} \tab Only the EMAIL channel is supported\cr
#'  \link[paws.customer.engagement:connect_create_contact_flow]{create_contact_flow} \tab Creates a flow for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_contact_flow_module]{create_contact_flow_module} \tab Creates a flow module for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_contact_flow_version]{create_contact_flow_version} \tab Publishes a new version of the flow provided\cr
#'  \link[paws.customer.engagement:connect_create_email_address]{create_email_address} \tab Create new email address in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_evaluation_form]{create_evaluation_form} \tab Creates an evaluation form in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_hours_of_operation]{create_hours_of_operation} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_create_hours_of_operation_override]{create_hours_of_operation_override} \tab Creates an hours of operation override in an Amazon Connect hours of operation resource\cr
#'  \link[paws.customer.engagement:connect_create_instance]{create_instance} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_create_integration_association]{create_integration_association} \tab Creates an Amazon Web Services resource association with an Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_participant]{create_participant} \tab Adds a new participant into an on-going chat contact\cr
#'  \link[paws.customer.engagement:connect_create_persistent_contact_association]{create_persistent_contact_association} \tab Enables rehydration of chats for the lifespan of a contact\cr
#'  \link[paws.customer.engagement:connect_create_predefined_attribute]{create_predefined_attribute} \tab Creates a new predefined attribute for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_prompt]{create_prompt} \tab Creates a prompt\cr
#'  \link[paws.customer.engagement:connect_create_push_notification_registration]{create_push_notification_registration} \tab Creates registration for a device token and a chat contact to receive real-time push notifications\cr
#'  \link[paws.customer.engagement:connect_create_queue]{create_queue} \tab Creates a new queue for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_quick_connect]{create_quick_connect} \tab Creates a quick connect for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_routing_profile]{create_routing_profile} \tab Creates a new routing profile\cr
#'  \link[paws.customer.engagement:connect_create_rule]{create_rule} \tab Creates a rule for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_security_profile]{create_security_profile} \tab Creates a security profile\cr
#'  \link[paws.customer.engagement:connect_create_task_template]{create_task_template} \tab Creates a new task template in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_traffic_distribution_group]{create_traffic_distribution_group} \tab Creates a traffic distribution group given an Amazon Connect instance that has been replicated\cr
#'  \link[paws.customer.engagement:connect_create_use_case]{create_use_case} \tab Creates a use case for an integration association\cr
#'  \link[paws.customer.engagement:connect_create_user]{create_user} \tab Creates a user account for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_create_user_hierarchy_group]{create_user_hierarchy_group} \tab Creates a new user hierarchy group\cr
#'  \link[paws.customer.engagement:connect_create_view]{create_view} \tab Creates a new view with the possible status of SAVED or PUBLISHED\cr
#'  \link[paws.customer.engagement:connect_create_view_version]{create_view_version} \tab Publishes a new version of the view identifier\cr
#'  \link[paws.customer.engagement:connect_create_vocabulary]{create_vocabulary} \tab Creates a custom vocabulary associated with your Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_deactivate_evaluation_form]{deactivate_evaluation_form} \tab Deactivates an evaluation form in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_attached_file]{delete_attached_file} \tab Deletes an attached file along with the underlying S3 Object\cr
#'  \link[paws.customer.engagement:connect_delete_contact_evaluation]{delete_contact_evaluation} \tab Deletes a contact evaluation in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_contact_flow]{delete_contact_flow} \tab Deletes a flow for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_contact_flow_module]{delete_contact_flow_module} \tab Deletes the specified flow module\cr
#'  \link[paws.customer.engagement:connect_delete_contact_flow_version]{delete_contact_flow_version} \tab Deletes the particular version specified in flow version identifier\cr
#'  \link[paws.customer.engagement:connect_delete_email_address]{delete_email_address} \tab Deletes email address from the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_evaluation_form]{delete_evaluation_form} \tab Deletes an evaluation form in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_hours_of_operation]{delete_hours_of_operation} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_delete_hours_of_operation_override]{delete_hours_of_operation_override} \tab Deletes an hours of operation override in an Amazon Connect hours of operation resource\cr
#'  \link[paws.customer.engagement:connect_delete_instance]{delete_instance} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_delete_integration_association]{delete_integration_association} \tab Deletes an Amazon Web Services resource association from an Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_predefined_attribute]{delete_predefined_attribute} \tab Deletes a predefined attribute from the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_prompt]{delete_prompt} \tab Deletes a prompt\cr
#'  \link[paws.customer.engagement:connect_delete_push_notification_registration]{delete_push_notification_registration} \tab Deletes registration for a device token and a chat contact\cr
#'  \link[paws.customer.engagement:connect_delete_queue]{delete_queue} \tab Deletes a queue\cr
#'  \link[paws.customer.engagement:connect_delete_quick_connect]{delete_quick_connect} \tab Deletes a quick connect\cr
#'  \link[paws.customer.engagement:connect_delete_routing_profile]{delete_routing_profile} \tab Deletes a routing profile\cr
#'  \link[paws.customer.engagement:connect_delete_rule]{delete_rule} \tab Deletes a rule for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_security_profile]{delete_security_profile} \tab Deletes a security profile\cr
#'  \link[paws.customer.engagement:connect_delete_task_template]{delete_task_template} \tab Deletes the task template\cr
#'  \link[paws.customer.engagement:connect_delete_traffic_distribution_group]{delete_traffic_distribution_group} \tab Deletes a traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_delete_use_case]{delete_use_case} \tab Deletes a use case from an integration association\cr
#'  \link[paws.customer.engagement:connect_delete_user]{delete_user} \tab Deletes a user account from the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_delete_user_hierarchy_group]{delete_user_hierarchy_group} \tab Deletes an existing user hierarchy group\cr
#'  \link[paws.customer.engagement:connect_delete_view]{delete_view} \tab Deletes the view entirely\cr
#'  \link[paws.customer.engagement:connect_delete_view_version]{delete_view_version} \tab Deletes the particular version specified in ViewVersion identifier\cr
#'  \link[paws.customer.engagement:connect_delete_vocabulary]{delete_vocabulary} \tab Deletes the vocabulary that has the given identifier\cr
#'  \link[paws.customer.engagement:connect_describe_agent_status]{describe_agent_status} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_describe_authentication_profile]{describe_authentication_profile} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_describe_contact]{describe_contact} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_describe_contact_evaluation]{describe_contact_evaluation} \tab Describes a contact evaluation in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_describe_contact_flow]{describe_contact_flow} \tab Describes the specified flow\cr
#'  \link[paws.customer.engagement:connect_describe_contact_flow_module]{describe_contact_flow_module} \tab Describes the specified flow module\cr
#'  \link[paws.customer.engagement:connect_describe_email_address]{describe_email_address} \tab Describe email address form the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_describe_evaluation_form]{describe_evaluation_form} \tab Describes an evaluation form in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_describe_hours_of_operation]{describe_hours_of_operation} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_describe_hours_of_operation_override]{describe_hours_of_operation_override} \tab Describes the hours of operation override\cr
#'  \link[paws.customer.engagement:connect_describe_instance]{describe_instance} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_describe_instance_attribute]{describe_instance_attribute} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_describe_instance_storage_config]{describe_instance_storage_config} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_describe_phone_number]{describe_phone_number} \tab Gets details and status of a phone number that’s claimed to your Amazon Connect instance or traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_describe_predefined_attribute]{describe_predefined_attribute} \tab Describes a predefined attribute for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_describe_prompt]{describe_prompt} \tab Describes the prompt\cr
#'  \link[paws.customer.engagement:connect_describe_queue]{describe_queue} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_describe_quick_connect]{describe_quick_connect} \tab Describes the quick connect\cr
#'  \link[paws.customer.engagement:connect_describe_routing_profile]{describe_routing_profile} \tab Describes the specified routing profile\cr
#'  \link[paws.customer.engagement:connect_describe_rule]{describe_rule} \tab Describes a rule for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_describe_security_profile]{describe_security_profile} \tab Gets basic information about the security profile\cr
#'  \link[paws.customer.engagement:connect_describe_traffic_distribution_group]{describe_traffic_distribution_group} \tab Gets details and status of a traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_describe_user]{describe_user} \tab Describes the specified user\cr
#'  \link[paws.customer.engagement:connect_describe_user_hierarchy_group]{describe_user_hierarchy_group} \tab Describes the specified hierarchy group\cr
#'  \link[paws.customer.engagement:connect_describe_user_hierarchy_structure]{describe_user_hierarchy_structure} \tab Describes the hierarchy structure of the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_describe_view]{describe_view} \tab Retrieves the view for the specified Amazon Connect instance and view identifier\cr
#'  \link[paws.customer.engagement:connect_describe_vocabulary]{describe_vocabulary} \tab Describes the specified vocabulary\cr
#'  \link[paws.customer.engagement:connect_disassociate_analytics_data_set]{disassociate_analytics_data_set} \tab Removes the dataset ID associated with a given Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_disassociate_approved_origin]{disassociate_approved_origin} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_disassociate_bot]{disassociate_bot} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_disassociate_flow]{disassociate_flow} \tab Disassociates a connect resource from a flow\cr
#'  \link[paws.customer.engagement:connect_disassociate_instance_storage_config]{disassociate_instance_storage_config} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_disassociate_lambda_function]{disassociate_lambda_function} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_disassociate_lex_bot]{disassociate_lex_bot} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_disassociate_phone_number_contact_flow]{disassociate_phone_number_contact_flow} \tab Removes the flow association from a phone number claimed to your Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_disassociate_queue_quick_connects]{disassociate_queue_quick_connects} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_disassociate_routing_profile_queues]{disassociate_routing_profile_queues} \tab Disassociates a set of queues from a routing profile\cr
#'  \link[paws.customer.engagement:connect_disassociate_security_key]{disassociate_security_key} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_disassociate_traffic_distribution_group_user]{disassociate_traffic_distribution_group_user} \tab Disassociates an agent from a traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_disassociate_user_proficiencies]{disassociate_user_proficiencies} \tab Disassociates a set of proficiencies from a user\cr
#'  \link[paws.customer.engagement:connect_dismiss_user_contact]{dismiss_user_contact} \tab Dismisses contacts from an agent’s CCP and returns the agent to an available state, which allows the agent to receive a new routed contact\cr
#'  \link[paws.customer.engagement:connect_get_attached_file]{get_attached_file} \tab Provides a pre-signed URL for download of an approved attached file\cr
#'  \link[paws.customer.engagement:connect_get_contact_attributes]{get_contact_attributes} \tab Retrieves the contact attributes for the specified contact\cr
#'  \link[paws.customer.engagement:connect_get_current_metric_data]{get_current_metric_data} \tab Gets the real-time metric data from the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_get_current_user_data]{get_current_user_data} \tab Gets the real-time active user data from the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_get_effective_hours_of_operations]{get_effective_hours_of_operations} \tab Get the hours of operations with the effective override applied\cr
#'  \link[paws.customer.engagement:connect_get_federation_token]{get_federation_token} \tab Supports SAML sign-in for Amazon Connect\cr
#'  \link[paws.customer.engagement:connect_get_flow_association]{get_flow_association} \tab Retrieves the flow associated for a given resource\cr
#'  \link[paws.customer.engagement:connect_get_metric_data]{get_metric_data} \tab Gets historical metric data from the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_get_metric_data_v2]{get_metric_data_v2} \tab Gets metric data from the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_get_prompt_file]{get_prompt_file} \tab Gets the prompt file\cr
#'  \link[paws.customer.engagement:connect_get_task_template]{get_task_template} \tab Gets details about a specific task template in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_get_traffic_distribution]{get_traffic_distribution} \tab Retrieves the current traffic distribution for a given traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_import_phone_number]{import_phone_number} \tab Imports a claimed phone number from an external service, such as Amazon Web Services End User Messaging, into an Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_agent_statuses]{list_agent_statuses} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_analytics_data_associations]{list_analytics_data_associations} \tab Lists the association status of requested dataset ID for a given Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_analytics_data_lake_data_sets]{list_analytics_data_lake_data_sets} \tab Lists the data lake datasets available to associate with for a given Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_approved_origins]{list_approved_origins} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_associated_contacts]{list_associated_contacts} \tab Provides information about contact tree, a list of associated contacts with a unique identifier\cr
#'  \link[paws.customer.engagement:connect_list_authentication_profiles]{list_authentication_profiles} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_bots]{list_bots} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_contact_evaluations]{list_contact_evaluations} \tab Lists contact evaluations in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_contact_flow_modules]{list_contact_flow_modules} \tab Provides information about the flow modules for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_contact_flows]{list_contact_flows} \tab Provides information about the flows for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_contact_flow_versions]{list_contact_flow_versions} \tab Returns all the available versions for the specified Amazon Connect instance and flow identifier\cr
#'  \link[paws.customer.engagement:connect_list_contact_references]{list_contact_references} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_default_vocabularies]{list_default_vocabularies} \tab Lists the default vocabularies for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_evaluation_forms]{list_evaluation_forms} \tab Lists evaluation forms in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_evaluation_form_versions]{list_evaluation_form_versions} \tab Lists versions of an evaluation form in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_flow_associations]{list_flow_associations} \tab List the flow association based on the filters\cr
#'  \link[paws.customer.engagement:connect_list_hours_of_operation_overrides]{list_hours_of_operation_overrides} \tab List the hours of operation overrides\cr
#'  \link[paws.customer.engagement:connect_list_hours_of_operations]{list_hours_of_operations} \tab Provides information about the hours of operation for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_instance_attributes]{list_instance_attributes} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_instances]{list_instances} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_instance_storage_configs]{list_instance_storage_configs} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_integration_associations]{list_integration_associations} \tab Provides summary information about the Amazon Web Services resource associations for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_lambda_functions]{list_lambda_functions} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_lex_bots]{list_lex_bots} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_phone_numbers]{list_phone_numbers} \tab Provides information about the phone numbers for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_phone_numbers_v2]{list_phone_numbers_v2} \tab Lists phone numbers claimed to your Amazon Connect instance or traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_list_predefined_attributes]{list_predefined_attributes} \tab Lists predefined attributes for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_prompts]{list_prompts} \tab Provides information about the prompts for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_queue_quick_connects]{list_queue_quick_connects} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_queues]{list_queues} \tab Provides information about the queues for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_quick_connects]{list_quick_connects} \tab Provides information about the quick connects for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_realtime_contact_analysis_segments_v2]{list_realtime_contact_analysis_segments_v2} \tab Provides a list of analysis segments for a real-time analysis session\cr
#'  \link[paws.customer.engagement:connect_list_routing_profile_queues]{list_routing_profile_queues} \tab Lists the queues associated with a routing profile\cr
#'  \link[paws.customer.engagement:connect_list_routing_profiles]{list_routing_profiles} \tab Provides summary information about the routing profiles for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_rules]{list_rules} \tab List all rules for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_security_keys]{list_security_keys} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_list_security_profile_applications]{list_security_profile_applications} \tab Returns a list of third-party applications in a specific security profile\cr
#'  \link[paws.customer.engagement:connect_list_security_profile_permissions]{list_security_profile_permissions} \tab Lists the permissions granted to a security profile\cr
#'  \link[paws.customer.engagement:connect_list_security_profiles]{list_security_profiles} \tab Provides summary information about the security profiles for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for the specified resource\cr
#'  \link[paws.customer.engagement:connect_list_task_templates]{list_task_templates} \tab Lists task templates for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_traffic_distribution_groups]{list_traffic_distribution_groups} \tab Lists traffic distribution groups\cr
#'  \link[paws.customer.engagement:connect_list_traffic_distribution_group_users]{list_traffic_distribution_group_users} \tab Lists traffic distribution group users\cr
#'  \link[paws.customer.engagement:connect_list_use_cases]{list_use_cases} \tab Lists the use cases for the integration association\cr
#'  \link[paws.customer.engagement:connect_list_user_hierarchy_groups]{list_user_hierarchy_groups} \tab Provides summary information about the hierarchy groups for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_user_proficiencies]{list_user_proficiencies} \tab Lists proficiencies associated with a user\cr
#'  \link[paws.customer.engagement:connect_list_users]{list_users} \tab Provides summary information about the users for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_list_views]{list_views} \tab Returns views in the given instance\cr
#'  \link[paws.customer.engagement:connect_list_view_versions]{list_view_versions} \tab Returns all the available versions for the specified Amazon Connect instance and view identifier\cr
#'  \link[paws.customer.engagement:connect_monitor_contact]{monitor_contact} \tab Initiates silent monitoring of a contact\cr
#'  \link[paws.customer.engagement:connect_pause_contact]{pause_contact} \tab Allows pausing an ongoing task contact\cr
#'  \link[paws.customer.engagement:connect_put_user_status]{put_user_status} \tab Changes the current status of a user or agent in Amazon Connect\cr
#'  \link[paws.customer.engagement:connect_release_phone_number]{release_phone_number} \tab Releases a phone number previously claimed to an Amazon Connect instance or traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_replicate_instance]{replicate_instance} \tab Replicates an Amazon Connect instance in the specified Amazon Web Services Region and copies configuration information for Amazon Connect resources across Amazon Web Services Regions\cr
#'  \link[paws.customer.engagement:connect_resume_contact]{resume_contact} \tab Allows resuming a task contact in a paused state\cr
#'  \link[paws.customer.engagement:connect_resume_contact_recording]{resume_contact_recording} \tab When a contact is being recorded, and the recording has been suspended using SuspendContactRecording, this API resumes recording whatever recording is selected in the flow configuration: call, screen, or both\cr
#'  \link[paws.customer.engagement:connect_search_agent_statuses]{search_agent_statuses} \tab Searches AgentStatuses in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_available_phone_numbers]{search_available_phone_numbers} \tab Searches for available phone numbers that you can claim to your Amazon Connect instance or traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_search_contact_flow_modules]{search_contact_flow_modules} \tab Searches the flow modules in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_contact_flows]{search_contact_flows} \tab Searches the flows in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_contacts]{search_contacts} \tab Searches contacts in an Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_search_email_addresses]{search_email_addresses} \tab Searches email address in an instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_hours_of_operation_overrides]{search_hours_of_operation_overrides} \tab Searches the hours of operation overrides\cr
#'  \link[paws.customer.engagement:connect_search_hours_of_operations]{search_hours_of_operations} \tab Searches the hours of operation in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_predefined_attributes]{search_predefined_attributes} \tab Searches predefined attributes that meet certain criteria\cr
#'  \link[paws.customer.engagement:connect_search_prompts]{search_prompts} \tab Searches prompts in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_queues]{search_queues} \tab Searches queues in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_quick_connects]{search_quick_connects} \tab Searches quick connects in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_resource_tags]{search_resource_tags} \tab Searches tags used in an Amazon Connect instance using optional search criteria\cr
#'  \link[paws.customer.engagement:connect_search_routing_profiles]{search_routing_profiles} \tab Searches routing profiles in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_security_profiles]{search_security_profiles} \tab Searches security profiles in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_user_hierarchy_groups]{search_user_hierarchy_groups} \tab Searches UserHierarchyGroups in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_users]{search_users} \tab Searches users in an Amazon Connect instance, with optional filtering\cr
#'  \link[paws.customer.engagement:connect_search_vocabularies]{search_vocabularies} \tab Searches for vocabularies within a specific Amazon Connect instance using State, NameStartsWith, and LanguageCode\cr
#'  \link[paws.customer.engagement:connect_send_chat_integration_event]{send_chat_integration_event} \tab Processes chat integration events from Amazon Web Services or external integrations to Amazon Connect\cr
#'  \link[paws.customer.engagement:connect_send_outbound_email]{send_outbound_email} \tab Send outbound email for outbound campaigns\cr
#'  \link[paws.customer.engagement:connect_start_attached_file_upload]{start_attached_file_upload} \tab Provides a pre-signed Amazon S3 URL in response for uploading your content\cr
#'  \link[paws.customer.engagement:connect_start_chat_contact]{start_chat_contact} \tab Initiates a flow to start a new chat for the customer\cr
#'  \link[paws.customer.engagement:connect_start_contact_evaluation]{start_contact_evaluation} \tab Starts an empty evaluation in the specified Amazon Connect instance, using the given evaluation form for the particular contact\cr
#'  \link[paws.customer.engagement:connect_start_contact_recording]{start_contact_recording} \tab Starts recording the contact:\cr
#'  \link[paws.customer.engagement:connect_start_contact_streaming]{start_contact_streaming} \tab Initiates real-time message streaming for a new chat contact\cr
#'  \link[paws.customer.engagement:connect_start_email_contact]{start_email_contact} \tab Creates an inbound email contact and initiates a flow to start the email contact for the customer\cr
#'  \link[paws.customer.engagement:connect_start_outbound_chat_contact]{start_outbound_chat_contact} \tab Initiates a new outbound SMS contact to a customer\cr
#'  \link[paws.customer.engagement:connect_start_outbound_email_contact]{start_outbound_email_contact} \tab Initiates a flow to send an agent reply or outbound email contact (created from the CreateContact API) to a customer\cr
#'  \link[paws.customer.engagement:connect_start_outbound_voice_contact]{start_outbound_voice_contact} \tab Places an outbound call to a contact, and then initiates the flow\cr
#'  \link[paws.customer.engagement:connect_start_screen_sharing]{start_screen_sharing} \tab Starts screen sharing for a contact\cr
#'  \link[paws.customer.engagement:connect_start_task_contact]{start_task_contact} \tab Initiates a flow to start a new task contact\cr
#'  \link[paws.customer.engagement:connect_start_web_rtc_contact]{start_web_rtc_contact} \tab Places an inbound in-app, web, or video call to a contact, and then initiates the flow\cr
#'  \link[paws.customer.engagement:connect_stop_contact]{stop_contact} \tab Ends the specified contact\cr
#'  \link[paws.customer.engagement:connect_stop_contact_recording]{stop_contact_recording} \tab Stops recording a call when a contact is being recorded\cr
#'  \link[paws.customer.engagement:connect_stop_contact_streaming]{stop_contact_streaming} \tab Ends message streaming on a specified contact\cr
#'  \link[paws.customer.engagement:connect_submit_contact_evaluation]{submit_contact_evaluation} \tab Submits a contact evaluation in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_suspend_contact_recording]{suspend_contact_recording} \tab When a contact is being recorded, this API suspends recording whatever is selected in the flow configuration: call, screen, or both\cr
#'  \link[paws.customer.engagement:connect_tag_contact]{tag_contact} \tab Adds the specified tags to the contact resource\cr
#'  \link[paws.customer.engagement:connect_tag_resource]{tag_resource} \tab Adds the specified tags to the specified resource\cr
#'  \link[paws.customer.engagement:connect_transfer_contact]{transfer_contact} \tab Transfers contacts from one agent or queue to another agent or queue at any point after a contact is created\cr
#'  \link[paws.customer.engagement:connect_untag_contact]{untag_contact} \tab Removes the specified tags from the contact resource\cr
#'  \link[paws.customer.engagement:connect_untag_resource]{untag_resource} \tab Removes the specified tags from the specified resource\cr
#'  \link[paws.customer.engagement:connect_update_agent_status]{update_agent_status} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_authentication_profile]{update_authentication_profile} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_contact]{update_contact} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_contact_attributes]{update_contact_attributes} \tab Creates or updates user-defined contact attributes associated with the specified contact\cr
#'  \link[paws.customer.engagement:connect_update_contact_evaluation]{update_contact_evaluation} \tab Updates details about a contact evaluation in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_update_contact_flow_content]{update_contact_flow_content} \tab Updates the specified flow\cr
#'  \link[paws.customer.engagement:connect_update_contact_flow_metadata]{update_contact_flow_metadata} \tab Updates metadata about specified flow\cr
#'  \link[paws.customer.engagement:connect_update_contact_flow_module_content]{update_contact_flow_module_content} \tab Updates specified flow module for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_update_contact_flow_module_metadata]{update_contact_flow_module_metadata} \tab Updates metadata about specified flow module\cr
#'  \link[paws.customer.engagement:connect_update_contact_flow_name]{update_contact_flow_name} \tab The name of the flow\cr
#'  \link[paws.customer.engagement:connect_update_contact_routing_data]{update_contact_routing_data} \tab Updates routing priority and age on the contact (QueuePriority and QueueTimeAdjustmentInSeconds)\cr
#'  \link[paws.customer.engagement:connect_update_contact_schedule]{update_contact_schedule} \tab Updates the scheduled time of a task contact that is already scheduled\cr
#'  \link[paws.customer.engagement:connect_update_email_address_metadata]{update_email_address_metadata} \tab Updates an email address metadata\cr
#'  \link[paws.customer.engagement:connect_update_evaluation_form]{update_evaluation_form} \tab Updates details about a specific evaluation form version in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_update_hours_of_operation]{update_hours_of_operation} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_hours_of_operation_override]{update_hours_of_operation_override} \tab Update the hours of operation override\cr
#'  \link[paws.customer.engagement:connect_update_instance_attribute]{update_instance_attribute} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_instance_storage_config]{update_instance_storage_config} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_participant_authentication]{update_participant_authentication} \tab Instructs Amazon Connect to resume the authentication process\cr
#'  \link[paws.customer.engagement:connect_update_participant_role_config]{update_participant_role_config} \tab Updates timeouts for when human chat participants are to be considered idle, and when agents are automatically disconnected from a chat due to idleness\cr
#'  \link[paws.customer.engagement:connect_update_phone_number]{update_phone_number} \tab Updates your claimed phone number from its current Amazon Connect instance or traffic distribution group to another Amazon Connect instance or traffic distribution group in the same Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:connect_update_phone_number_metadata]{update_phone_number_metadata} \tab Updates a phone number’s metadata\cr
#'  \link[paws.customer.engagement:connect_update_predefined_attribute]{update_predefined_attribute} \tab Updates a predefined attribute for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_update_prompt]{update_prompt} \tab Updates a prompt\cr
#'  \link[paws.customer.engagement:connect_update_queue_hours_of_operation]{update_queue_hours_of_operation} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_queue_max_contacts]{update_queue_max_contacts} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_queue_name]{update_queue_name} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_queue_outbound_caller_config]{update_queue_outbound_caller_config} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_queue_outbound_email_config]{update_queue_outbound_email_config} \tab Updates the outbound email address Id for a specified queue\cr
#'  \link[paws.customer.engagement:connect_update_queue_status]{update_queue_status} \tab This API is in preview release for Amazon Connect and is subject to change\cr
#'  \link[paws.customer.engagement:connect_update_quick_connect_config]{update_quick_connect_config} \tab Updates the configuration settings for the specified quick connect\cr
#'  \link[paws.customer.engagement:connect_update_quick_connect_name]{update_quick_connect_name} \tab Updates the name and description of a quick connect\cr
#'  \link[paws.customer.engagement:connect_update_routing_profile_agent_availability_timer]{update_routing_profile_agent_availability_timer} \tab Whether agents with this routing profile will have their routing order calculated based on time since their last inbound contact or longest idle time\cr
#'  \link[paws.customer.engagement:connect_update_routing_profile_concurrency]{update_routing_profile_concurrency} \tab Updates the channels that agents can handle in the Contact Control Panel (CCP) for a routing profile\cr
#'  \link[paws.customer.engagement:connect_update_routing_profile_default_outbound_queue]{update_routing_profile_default_outbound_queue} \tab Updates the default outbound queue of a routing profile\cr
#'  \link[paws.customer.engagement:connect_update_routing_profile_name]{update_routing_profile_name} \tab Updates the name and description of a routing profile\cr
#'  \link[paws.customer.engagement:connect_update_routing_profile_queues]{update_routing_profile_queues} \tab Updates the properties associated with a set of queues for a routing profile\cr
#'  \link[paws.customer.engagement:connect_update_rule]{update_rule} \tab Updates a rule for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_update_security_profile]{update_security_profile} \tab Updates a security profile\cr
#'  \link[paws.customer.engagement:connect_update_task_template]{update_task_template} \tab Updates details about a specific task template in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_update_traffic_distribution]{update_traffic_distribution} \tab Updates the traffic distribution for a given traffic distribution group\cr
#'  \link[paws.customer.engagement:connect_update_user_hierarchy]{update_user_hierarchy} \tab Assigns the specified hierarchy group to the specified user\cr
#'  \link[paws.customer.engagement:connect_update_user_hierarchy_group_name]{update_user_hierarchy_group_name} \tab Updates the name of the user hierarchy group\cr
#'  \link[paws.customer.engagement:connect_update_user_hierarchy_structure]{update_user_hierarchy_structure} \tab Updates the user hierarchy structure: add, remove, and rename user hierarchy levels\cr
#'  \link[paws.customer.engagement:connect_update_user_identity_info]{update_user_identity_info} \tab Updates the identity information for the specified user\cr
#'  \link[paws.customer.engagement:connect_update_user_phone_config]{update_user_phone_config} \tab Updates the phone configuration settings for the specified user\cr
#'  \link[paws.customer.engagement:connect_update_user_proficiencies]{update_user_proficiencies} \tab Updates the properties associated with the proficiencies of a user\cr
#'  \link[paws.customer.engagement:connect_update_user_routing_profile]{update_user_routing_profile} \tab Assigns the specified routing profile to the specified user\cr
#'  \link[paws.customer.engagement:connect_update_user_security_profiles]{update_user_security_profiles} \tab Assigns the specified security profiles to the specified user\cr
#'  \link[paws.customer.engagement:connect_update_view_content]{update_view_content} \tab Updates the view content of the given view identifier in the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connect_update_view_metadata]{update_view_metadata} \tab Updates the view metadata
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname connect
#' @export
connect <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::connect(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AmazonConnectCampaignService
#'
#' @description
#' Provide APIs to create and manage Amazon Connect Campaigns.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- connectcampaignservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- connectcampaignservice()
#' svc$create_campaign(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:connectcampaignservice_create_campaign]{create_campaign} \tab Creates a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_delete_campaign]{delete_campaign} \tab Deletes a campaign from the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_delete_connect_instance_config]{delete_connect_instance_config} \tab Deletes a connect instance config from the specified AWS account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_delete_instance_onboarding_job]{delete_instance_onboarding_job} \tab Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connectcampaignservice_describe_campaign]{describe_campaign} \tab Describes the specific campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservice_get_campaign_state]{get_campaign_state} \tab Get state of a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_get_campaign_state_batch]{get_campaign_state_batch} \tab Get state of campaigns for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_get_connect_instance_config]{get_connect_instance_config} \tab Get the specific Connect instance config\cr
#'  \link[paws.customer.engagement:connectcampaignservice_get_instance_onboarding_job_status]{get_instance_onboarding_job_status} \tab Get the specific instance onboarding job status\cr
#'  \link[paws.customer.engagement:connectcampaignservice_list_campaigns]{list_campaigns} \tab Provides summary information about the campaigns under the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_list_tags_for_resource]{list_tags_for_resource} \tab List tags for a resource\cr
#'  \link[paws.customer.engagement:connectcampaignservice_pause_campaign]{pause_campaign} \tab Pauses a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_put_dial_request_batch]{put_dial_request_batch} \tab Creates dials requests for the specified campaign Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_resume_campaign]{resume_campaign} \tab Stops a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_start_campaign]{start_campaign} \tab Starts a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_start_instance_onboarding_job]{start_instance_onboarding_job} \tab Onboard the specific Amazon Connect instance to Connect Campaigns\cr
#'  \link[paws.customer.engagement:connectcampaignservice_stop_campaign]{stop_campaign} \tab Stops a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservice_tag_resource]{tag_resource} \tab Tag a resource\cr
#'  \link[paws.customer.engagement:connectcampaignservice_untag_resource]{untag_resource} \tab Untag a resource\cr
#'  \link[paws.customer.engagement:connectcampaignservice_update_campaign_dialer_config]{update_campaign_dialer_config} \tab Updates the dialer config of a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservice_update_campaign_name]{update_campaign_name} \tab Updates the name of a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservice_update_campaign_outbound_call_config]{update_campaign_outbound_call_config} \tab Updates the outbound call config of a campaign
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname connectcampaignservice
#' @export
connectcampaignservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::connectcampaignservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AmazonConnectCampaignServiceV2
#'
#' @description
#' Provide APIs to create and manage Amazon Connect Campaigns.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- connectcampaignservicev2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- connectcampaignservicev2()
#' svc$create_campaign(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:connectcampaignservicev2_create_campaign]{create_campaign} \tab Creates a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_delete_campaign]{delete_campaign} \tab Deletes a campaign from the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_delete_campaign_channel_subtype_config]{delete_campaign_channel_subtype_config} \tab Deletes the channel subtype config of a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_delete_campaign_communication_limits]{delete_campaign_communication_limits} \tab Deletes the communication limits config for a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_delete_campaign_communication_time]{delete_campaign_communication_time} \tab Deletes the communication time config for a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_delete_connect_instance_config]{delete_connect_instance_config} \tab Deletes a connect instance config from the specified AWS account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_delete_connect_instance_integration]{delete_connect_instance_integration} \tab Delete the integration for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_delete_instance_onboarding_job]{delete_instance_onboarding_job} \tab Delete the Connect Campaigns onboarding job for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_describe_campaign]{describe_campaign} \tab Describes the specific campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_get_campaign_state]{get_campaign_state} \tab Get state of a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_get_campaign_state_batch]{get_campaign_state_batch} \tab Get state of campaigns for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_get_connect_instance_config]{get_connect_instance_config} \tab Get the specific Connect instance config\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_get_instance_onboarding_job_status]{get_instance_onboarding_job_status} \tab Get the specific instance onboarding job status\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_list_campaigns]{list_campaigns} \tab Provides summary information about the campaigns under the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_list_connect_instance_integrations]{list_connect_instance_integrations} \tab Provides summary information about the integration under the specified Connect instance\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_list_tags_for_resource]{list_tags_for_resource} \tab List tags for a resource\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_pause_campaign]{pause_campaign} \tab Pauses a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_put_connect_instance_integration]{put_connect_instance_integration} \tab Put or update the integration for the specified Amazon Connect instance\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_put_outbound_request_batch]{put_outbound_request_batch} \tab Creates outbound requests for the specified campaign Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_put_profile_outbound_request_batch]{put_profile_outbound_request_batch} \tab Takes in a list of profile outbound requests to be placed as part of an outbound campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_resume_campaign]{resume_campaign} \tab Stops a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_start_campaign]{start_campaign} \tab Starts a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_start_instance_onboarding_job]{start_instance_onboarding_job} \tab Onboard the specific Amazon Connect instance to Connect Campaigns\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_stop_campaign]{stop_campaign} \tab Stops a campaign for the specified Amazon Connect account\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_tag_resource]{tag_resource} \tab Tag a resource\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_untag_resource]{untag_resource} \tab Untag a resource\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_update_campaign_channel_subtype_config]{update_campaign_channel_subtype_config} \tab Updates the channel subtype config of a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_update_campaign_communication_limits]{update_campaign_communication_limits} \tab Updates the communication limits config for a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_update_campaign_communication_time]{update_campaign_communication_time} \tab Updates the communication time config for a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_update_campaign_flow_association]{update_campaign_flow_association} \tab Updates the campaign flow associated with a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_update_campaign_name]{update_campaign_name} \tab Updates the name of a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_update_campaign_schedule]{update_campaign_schedule} \tab Updates the schedule for a campaign\cr
#'  \link[paws.customer.engagement:connectcampaignservicev2_update_campaign_source]{update_campaign_source} \tab Updates the campaign source with a campaign
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname connectcampaignservicev2
#' @export
connectcampaignservicev2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::connectcampaignservicev2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Connect Cases
#'
#' @description
#' -   [Cases
#'     actions](https://docs.aws.amazon.com/connect/latest/APIReference/API_Operations_Amazon_Connect_Cases.html)
#' 
#' -   [Cases data
#'     types](https://docs.aws.amazon.com/connect/latest/APIReference/API_Types_Amazon_Connect_Cases.html)
#' 
#' With Amazon Connect Cases, your agents can track and manage customer
#' issues that require multiple interactions, follow-up tasks, and teams in
#' your contact center. A case represents a customer issue. It records the
#' issue, the steps and interactions taken to resolve the issue, and the
#' outcome. For more information, see [Amazon Connect
#' Cases](https://docs.aws.amazon.com/connect/latest/adminguide/cases.html)
#' in the *Amazon Connect Administrator Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- connectcases(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- connectcases()
#' svc$batch_get_case_rule(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:connectcases_batch_get_case_rule]{batch_get_case_rule} \tab Gets a batch of case rules\cr
#'  \link[paws.customer.engagement:connectcases_batch_get_field]{batch_get_field} \tab Returns the description for the list of fields in the request parameters\cr
#'  \link[paws.customer.engagement:connectcases_batch_put_field_options]{batch_put_field_options} \tab Creates and updates a set of field options for a single select field in a Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_create_case]{create_case} \tab If you provide a value for PerformedBy\cr
#'  \link[paws.customer.engagement:connectcases_create_case_rule]{create_case_rule} \tab Creates a new case rule\cr
#'  \link[paws.customer.engagement:connectcases_create_domain]{create_domain} \tab Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts\cr
#'  \link[paws.customer.engagement:connectcases_create_field]{create_field} \tab Creates a field in the Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_create_layout]{create_layout} \tab Creates a layout in the Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_create_related_item]{create_related_item} \tab Creates a related item (comments, tasks, and contacts) and associates it with a case\cr
#'  \link[paws.customer.engagement:connectcases_create_template]{create_template} \tab Creates a template in the Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_delete_case_rule]{delete_case_rule} \tab Deletes a case rule\cr
#'  \link[paws.customer.engagement:connectcases_delete_domain]{delete_domain} \tab Deletes a Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_delete_field]{delete_field} \tab Deletes a field from a cases template\cr
#'  \link[paws.customer.engagement:connectcases_delete_layout]{delete_layout} \tab Deletes a layout from a cases template\cr
#'  \link[paws.customer.engagement:connectcases_delete_template]{delete_template} \tab Deletes a cases template\cr
#'  \link[paws.customer.engagement:connectcases_get_case]{get_case} \tab Returns information about a specific case if it exists\cr
#'  \link[paws.customer.engagement:connectcases_get_case_audit_events]{get_case_audit_events} \tab Returns the audit history about a specific case if it exists\cr
#'  \link[paws.customer.engagement:connectcases_get_case_event_configuration]{get_case_event_configuration} \tab Returns the case event publishing configuration\cr
#'  \link[paws.customer.engagement:connectcases_get_domain]{get_domain} \tab Returns information about a specific domain if it exists\cr
#'  \link[paws.customer.engagement:connectcases_get_layout]{get_layout} \tab Returns the details for the requested layout\cr
#'  \link[paws.customer.engagement:connectcases_get_template]{get_template} \tab Returns the details for the requested template\cr
#'  \link[paws.customer.engagement:connectcases_list_case_rules]{list_case_rules} \tab Lists all case rules in a Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_list_cases_for_contact]{list_cases_for_contact} \tab Lists cases for a given contact\cr
#'  \link[paws.customer.engagement:connectcases_list_domains]{list_domains} \tab Lists all cases domains in the Amazon Web Services account\cr
#'  \link[paws.customer.engagement:connectcases_list_field_options]{list_field_options} \tab Lists all of the field options for a field identifier in the domain\cr
#'  \link[paws.customer.engagement:connectcases_list_fields]{list_fields} \tab Lists all fields in a Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_list_layouts]{list_layouts} \tab Lists all layouts in the given cases domain\cr
#'  \link[paws.customer.engagement:connectcases_list_tags_for_resource]{list_tags_for_resource} \tab Lists tags for a resource\cr
#'  \link[paws.customer.engagement:connectcases_list_templates]{list_templates} \tab Lists all of the templates in a Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_put_case_event_configuration]{put_case_event_configuration} \tab Adds case event publishing configuration\cr
#'  \link[paws.customer.engagement:connectcases_search_cases]{search_cases} \tab Searches for cases within their associated Cases domain\cr
#'  \link[paws.customer.engagement:connectcases_search_related_items]{search_related_items} \tab Searches for related items that are associated with a case\cr
#'  \link[paws.customer.engagement:connectcases_tag_resource]{tag_resource} \tab Adds tags to a resource\cr
#'  \link[paws.customer.engagement:connectcases_untag_resource]{untag_resource} \tab Untags a resource\cr
#'  \link[paws.customer.engagement:connectcases_update_case]{update_case} \tab If you provide a value for PerformedBy\cr
#'  \link[paws.customer.engagement:connectcases_update_case_rule]{update_case_rule} \tab Updates a case rule\cr
#'  \link[paws.customer.engagement:connectcases_update_field]{update_field} \tab Updates the properties of an existing field\cr
#'  \link[paws.customer.engagement:connectcases_update_layout]{update_layout} \tab Updates the attributes of an existing layout\cr
#'  \link[paws.customer.engagement:connectcases_update_template]{update_template} \tab Updates the attributes of an existing template
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname connectcases
#' @export
connectcases <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::connectcases(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Connect Contact Lens
#'
#' @description
#' -   [Contact Lens
#'     actions](https://docs.aws.amazon.com/connect/latest/APIReference/API_Operations_Amazon_Connect_Contact_Lens.html)
#' 
#' -   [Contact Lens data
#'     types](https://docs.aws.amazon.com/connect/latest/APIReference/API_Types_Amazon_Connect_Contact_Lens.html)
#' 
#' Amazon Connect Contact Lens enables you to analyze conversations between
#' customer and agents, by using speech transcription, natural language
#' processing, and intelligent search capabilities. It performs sentiment
#' analysis, detects issues, and enables you to automatically categorize
#' contacts.
#' 
#' Amazon Connect Contact Lens provides both real-time and post-call
#' analytics of customer-agent conversations. For more information, see
#' [Analyze conversations using speech
#' analytics](https://docs.aws.amazon.com/connect/latest/adminguide/analyze-conversations.html)
#' in the *Amazon Connect Administrator Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- connectcontactlens(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- connectcontactlens()
#' svc$list_realtime_contact_analysis_segments(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:connectcontactlens_list_realtime_contact_analysis_segments]{list_realtime_contact_analysis_segments} \tab Provides a list of analysis segments for a real-time analysis session
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname connectcontactlens
#' @export
connectcontactlens <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::connectcontactlens(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Connect Participant Service
#'
#' @description
#' -   [Participant Service
#'     actions](https://docs.aws.amazon.com/connect/latest/APIReference/API_Operations_Amazon_Connect_Participant_Service.html)
#' 
#' -   [Participant Service data
#'     types](https://docs.aws.amazon.com/connect/latest/APIReference/API_Types_Amazon_Connect_Participant_Service.html)
#' 
#' Amazon Connect is an easy-to-use omnichannel cloud contact center
#' service that enables companies of any size to deliver superior customer
#' service at a lower cost. Amazon Connect communications capabilities make
#' it easy for companies to deliver personalized interactions across
#' communication channels, including chat.
#' 
#' Use the Amazon Connect Participant Service to manage participants (for
#' example, agents, customers, and managers listening in), and to send
#' messages and events within a chat contact. The APIs in the service
#' enable the following: sending chat messages, attachment sharing,
#' managing a participant's connection state and message events, and
#' retrieving chat transcripts.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- connectparticipant(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- connectparticipant()
#' svc$cancel_participant_authentication(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:connectparticipant_cancel_participant_authentication]{cancel_participant_authentication} \tab Cancels the authentication session\cr
#'  \link[paws.customer.engagement:connectparticipant_complete_attachment_upload]{complete_attachment_upload} \tab Allows you to confirm that the attachment has been uploaded using the pre-signed URL provided in StartAttachmentUpload API\cr
#'  \link[paws.customer.engagement:connectparticipant_create_participant_connection]{create_participant_connection} \tab Creates the participant's connection\cr
#'  \link[paws.customer.engagement:connectparticipant_describe_view]{describe_view} \tab Retrieves the view for the specified view token\cr
#'  \link[paws.customer.engagement:connectparticipant_disconnect_participant]{disconnect_participant} \tab Disconnects a participant\cr
#'  \link[paws.customer.engagement:connectparticipant_get_attachment]{get_attachment} \tab Provides a pre-signed URL for download of a completed attachment\cr
#'  \link[paws.customer.engagement:connectparticipant_get_authentication_url]{get_authentication_url} \tab Retrieves the AuthenticationUrl for the current authentication session for the AuthenticateCustomer flow block\cr
#'  \link[paws.customer.engagement:connectparticipant_get_transcript]{get_transcript} \tab Retrieves a transcript of the session, including details about any attachments\cr
#'  \link[paws.customer.engagement:connectparticipant_send_event]{send_event} \tab The application/vnd\cr
#'  \link[paws.customer.engagement:connectparticipant_send_message]{send_message} \tab Sends a message\cr
#'  \link[paws.customer.engagement:connectparticipant_start_attachment_upload]{start_attachment_upload} \tab Provides a pre-signed Amazon S3 URL in response for uploading the file directly to S3
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname connectparticipant
#' @export
connectparticipant <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::connectparticipant(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Connect Wisdom Service
#'
#' @description
#' Amazon Connect Wisdom delivers agents the information they need to solve
#' customer issues as they're actively speaking with customers. Agents can
#' search across connected repositories from within their agent desktop to
#' find answers quickly. Use Amazon Connect Wisdom to create an assistant
#' and a knowledge base, for example, or manage content by uploading custom
#' files.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- connectwisdomservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- connectwisdomservice()
#' svc$create_assistant(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:connectwisdomservice_create_assistant]{create_assistant} \tab Creates an Amazon Connect Wisdom assistant\cr
#'  \link[paws.customer.engagement:connectwisdomservice_create_assistant_association]{create_assistant_association} \tab Creates an association between an Amazon Connect Wisdom assistant and another resource\cr
#'  \link[paws.customer.engagement:connectwisdomservice_create_content]{create_content} \tab Creates Wisdom content\cr
#'  \link[paws.customer.engagement:connectwisdomservice_create_knowledge_base]{create_knowledge_base} \tab Creates a knowledge base\cr
#'  \link[paws.customer.engagement:connectwisdomservice_create_quick_response]{create_quick_response} \tab Creates a Wisdom quick response\cr
#'  \link[paws.customer.engagement:connectwisdomservice_create_session]{create_session} \tab Creates a session\cr
#'  \link[paws.customer.engagement:connectwisdomservice_delete_assistant]{delete_assistant} \tab Deletes an assistant\cr
#'  \link[paws.customer.engagement:connectwisdomservice_delete_assistant_association]{delete_assistant_association} \tab Deletes an assistant association\cr
#'  \link[paws.customer.engagement:connectwisdomservice_delete_content]{delete_content} \tab Deletes the content\cr
#'  \link[paws.customer.engagement:connectwisdomservice_delete_import_job]{delete_import_job} \tab Deletes the quick response import job\cr
#'  \link[paws.customer.engagement:connectwisdomservice_delete_knowledge_base]{delete_knowledge_base} \tab Deletes the knowledge base\cr
#'  \link[paws.customer.engagement:connectwisdomservice_delete_quick_response]{delete_quick_response} \tab Deletes a quick response\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_assistant]{get_assistant} \tab Retrieves information about an assistant\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_assistant_association]{get_assistant_association} \tab Retrieves information about an assistant association\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_content]{get_content} \tab Retrieves content, including a pre-signed URL to download the content\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_content_summary]{get_content_summary} \tab Retrieves summary information about the content\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_import_job]{get_import_job} \tab Retrieves the started import job\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_knowledge_base]{get_knowledge_base} \tab Retrieves information about the knowledge base\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_quick_response]{get_quick_response} \tab Retrieves the quick response\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_recommendations]{get_recommendations} \tab Retrieves recommendations for the specified session\cr
#'  \link[paws.customer.engagement:connectwisdomservice_get_session]{get_session} \tab Retrieves information for a specified session\cr
#'  \link[paws.customer.engagement:connectwisdomservice_list_assistant_associations]{list_assistant_associations} \tab Lists information about assistant associations\cr
#'  \link[paws.customer.engagement:connectwisdomservice_list_assistants]{list_assistants} \tab Lists information about assistants\cr
#'  \link[paws.customer.engagement:connectwisdomservice_list_contents]{list_contents} \tab Lists the content\cr
#'  \link[paws.customer.engagement:connectwisdomservice_list_import_jobs]{list_import_jobs} \tab Lists information about import jobs\cr
#'  \link[paws.customer.engagement:connectwisdomservice_list_knowledge_bases]{list_knowledge_bases} \tab Lists the knowledge bases\cr
#'  \link[paws.customer.engagement:connectwisdomservice_list_quick_responses]{list_quick_responses} \tab Lists information about quick response\cr
#'  \link[paws.customer.engagement:connectwisdomservice_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags for the specified resource\cr
#'  \link[paws.customer.engagement:connectwisdomservice_notify_recommendations_received]{notify_recommendations_received} \tab Removes the specified recommendations from the specified assistant's queue of newly available recommendations\cr
#'  \link[paws.customer.engagement:connectwisdomservice_query_assistant]{query_assistant} \tab Performs a manual search against the specified assistant\cr
#'  \link[paws.customer.engagement:connectwisdomservice_remove_knowledge_base_template_uri]{remove_knowledge_base_template_uri} \tab Removes a URI template from a knowledge base\cr
#'  \link[paws.customer.engagement:connectwisdomservice_search_content]{search_content} \tab Searches for content in a specified knowledge base\cr
#'  \link[paws.customer.engagement:connectwisdomservice_search_quick_responses]{search_quick_responses} \tab Searches existing Wisdom quick responses in a Wisdom knowledge base\cr
#'  \link[paws.customer.engagement:connectwisdomservice_search_sessions]{search_sessions} \tab Searches for sessions\cr
#'  \link[paws.customer.engagement:connectwisdomservice_start_content_upload]{start_content_upload} \tab Get a URL to upload content to a knowledge base\cr
#'  \link[paws.customer.engagement:connectwisdomservice_start_import_job]{start_import_job} \tab Start an asynchronous job to import Wisdom resources from an uploaded source file\cr
#'  \link[paws.customer.engagement:connectwisdomservice_tag_resource]{tag_resource} \tab Adds the specified tags to the specified resource\cr
#'  \link[paws.customer.engagement:connectwisdomservice_untag_resource]{untag_resource} \tab Removes the specified tags from the specified resource\cr
#'  \link[paws.customer.engagement:connectwisdomservice_update_content]{update_content} \tab Updates information about the content\cr
#'  \link[paws.customer.engagement:connectwisdomservice_update_knowledge_base_template_uri]{update_knowledge_base_template_uri} \tab Updates the template URI of a knowledge base\cr
#'  \link[paws.customer.engagement:connectwisdomservice_update_quick_response]{update_quick_response} \tab Updates an existing Wisdom quick response
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname connectwisdomservice
#' @export
connectwisdomservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::connectwisdomservice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Connect Customer Profiles
#'
#' @description
#' -   [Customer Profiles
#'     actions](https://docs.aws.amazon.com/connect/latest/APIReference/API_Operations_Amazon_Connect_Customer_Profiles.html)
#' 
#' -   [Customer Profiles data
#'     types](https://docs.aws.amazon.com/connect/latest/APIReference/API_Types_Amazon_Connect_Customer_Profiles.html)
#' 
#' Amazon Connect Customer Profiles is a unified customer profile for your
#' contact center that has pre-built connectors powered by AppFlow that
#' make it easy to combine customer information from third party
#' applications, such as Salesforce (CRM), ServiceNow (ITSM), and your
#' enterprise resource planning (ERP), with contact history from your
#' Amazon Connect contact center.
#' 
#' For more information about the Amazon Connect Customer Profiles feature,
#' see [Use Customer
#' Profiles](https://docs.aws.amazon.com/connect/latest/adminguide/customer-profiles.html)
#' in the *Amazon Connect Administrator's Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- customerprofiles(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- customerprofiles()
#' svc$add_profile_key(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:customerprofiles_add_profile_key]{add_profile_key} \tab Associates a new key value with a specific profile, such as a Contact Record ContactId\cr
#'  \link[paws.customer.engagement:customerprofiles_batch_get_calculated_attribute_for_profile]{batch_get_calculated_attribute_for_profile} \tab Fetch the possible attribute values given the attribute name\cr
#'  \link[paws.customer.engagement:customerprofiles_batch_get_profile]{batch_get_profile} \tab Get a batch of profiles\cr
#'  \link[paws.customer.engagement:customerprofiles_create_calculated_attribute_definition]{create_calculated_attribute_definition} \tab Creates a new calculated attribute definition\cr
#'  \link[paws.customer.engagement:customerprofiles_create_domain]{create_domain} \tab Creates a domain, which is a container for all customer data, such as customer profile attributes, object types, profile keys, and encryption keys\cr
#'  \link[paws.customer.engagement:customerprofiles_create_event_stream]{create_event_stream} \tab Creates an event stream, which is a subscription to real-time events, such as when profiles are created and updated through Amazon Connect Customer Profiles\cr
#'  \link[paws.customer.engagement:customerprofiles_create_event_trigger]{create_event_trigger} \tab Creates an event trigger, which specifies the rules when to perform action based on customer's ingested data\cr
#'  \link[paws.customer.engagement:customerprofiles_create_integration_workflow]{create_integration_workflow} \tab Creates an integration workflow\cr
#'  \link[paws.customer.engagement:customerprofiles_create_profile]{create_profile} \tab Creates a standard profile\cr
#'  \link[paws.customer.engagement:customerprofiles_create_segment_definition]{create_segment_definition} \tab Creates a segment definition associated to the given domain\cr
#'  \link[paws.customer.engagement:customerprofiles_create_segment_estimate]{create_segment_estimate} \tab Creates a segment estimate query\cr
#'  \link[paws.customer.engagement:customerprofiles_create_segment_snapshot]{create_segment_snapshot} \tab Triggers a job to export a segment to a specified destination\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_calculated_attribute_definition]{delete_calculated_attribute_definition} \tab Deletes an existing calculated attribute definition\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_domain]{delete_domain} \tab Deletes a specific domain and all of its customer data, such as customer profile attributes and their related objects\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_event_stream]{delete_event_stream} \tab Disables and deletes the specified event stream\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_event_trigger]{delete_event_trigger} \tab Disable and deletes the Event Trigger\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_integration]{delete_integration} \tab Removes an integration from a specific domain\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_profile]{delete_profile} \tab Deletes the standard customer profile and all data pertaining to the profile\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_profile_key]{delete_profile_key} \tab Removes a searchable key from a customer profile\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_profile_object]{delete_profile_object} \tab Removes an object associated with a profile of a given ProfileObjectType\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_profile_object_type]{delete_profile_object_type} \tab Removes a ProfileObjectType from a specific domain as well as removes all the ProfileObjects of that type\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_segment_definition]{delete_segment_definition} \tab Deletes a segment definition from the domain\cr
#'  \link[paws.customer.engagement:customerprofiles_delete_workflow]{delete_workflow} \tab Deletes the specified workflow and all its corresponding resources\cr
#'  \link[paws.customer.engagement:customerprofiles_detect_profile_object_type]{detect_profile_object_type} \tab The process of detecting profile object type mapping by using given objects\cr
#'  \link[paws.customer.engagement:customerprofiles_get_auto_merging_preview]{get_auto_merging_preview} \tab Tests the auto-merging settings of your Identity Resolution Job without merging your data\cr
#'  \link[paws.customer.engagement:customerprofiles_get_calculated_attribute_definition]{get_calculated_attribute_definition} \tab Provides more information on a calculated attribute definition for Customer Profiles\cr
#'  \link[paws.customer.engagement:customerprofiles_get_calculated_attribute_for_profile]{get_calculated_attribute_for_profile} \tab Retrieve a calculated attribute for a customer profile\cr
#'  \link[paws.customer.engagement:customerprofiles_get_domain]{get_domain} \tab Returns information about a specific domain\cr
#'  \link[paws.customer.engagement:customerprofiles_get_event_stream]{get_event_stream} \tab Returns information about the specified event stream in a specific domain\cr
#'  \link[paws.customer.engagement:customerprofiles_get_event_trigger]{get_event_trigger} \tab Get a specific Event Trigger from the domain\cr
#'  \link[paws.customer.engagement:customerprofiles_get_identity_resolution_job]{get_identity_resolution_job} \tab Returns information about an Identity Resolution Job in a specific domain\cr
#'  \link[paws.customer.engagement:customerprofiles_get_integration]{get_integration} \tab Returns an integration for a domain\cr
#'  \link[paws.customer.engagement:customerprofiles_get_matches]{get_matches} \tab Before calling this API, use CreateDomain or UpdateDomain to enable identity resolution: set Matching to true\cr
#'  \link[paws.customer.engagement:customerprofiles_get_profile_object_type]{get_profile_object_type} \tab Returns the object types for a specific domain\cr
#'  \link[paws.customer.engagement:customerprofiles_get_profile_object_type_template]{get_profile_object_type_template} \tab Returns the template information for a specific object type\cr
#'  \link[paws.customer.engagement:customerprofiles_get_segment_definition]{get_segment_definition} \tab Gets a segment definition from the domain\cr
#'  \link[paws.customer.engagement:customerprofiles_get_segment_estimate]{get_segment_estimate} \tab Gets the result of a segment estimate query\cr
#'  \link[paws.customer.engagement:customerprofiles_get_segment_membership]{get_segment_membership} \tab Determines if the given profiles are within a segment\cr
#'  \link[paws.customer.engagement:customerprofiles_get_segment_snapshot]{get_segment_snapshot} \tab Retrieve the latest status of a segment snapshot\cr
#'  \link[paws.customer.engagement:customerprofiles_get_similar_profiles]{get_similar_profiles} \tab Returns a set of profiles that belong to the same matching group using the matchId or profileId\cr
#'  \link[paws.customer.engagement:customerprofiles_get_workflow]{get_workflow} \tab Get details of specified workflow\cr
#'  \link[paws.customer.engagement:customerprofiles_get_workflow_steps]{get_workflow_steps} \tab Get granular list of steps in workflow\cr
#'  \link[paws.customer.engagement:customerprofiles_list_account_integrations]{list_account_integrations} \tab Lists all of the integrations associated to a specific URI in the AWS account\cr
#'  \link[paws.customer.engagement:customerprofiles_list_calculated_attribute_definitions]{list_calculated_attribute_definitions} \tab Lists calculated attribute definitions for Customer Profiles\cr
#'  \link[paws.customer.engagement:customerprofiles_list_calculated_attributes_for_profile]{list_calculated_attributes_for_profile} \tab Retrieve a list of calculated attributes for a customer profile\cr
#'  \link[paws.customer.engagement:customerprofiles_list_domains]{list_domains} \tab Returns a list of all the domains for an AWS account that have been created\cr
#'  \link[paws.customer.engagement:customerprofiles_list_event_streams]{list_event_streams} \tab Returns a list of all the event streams in a specific domain\cr
#'  \link[paws.customer.engagement:customerprofiles_list_event_triggers]{list_event_triggers} \tab List all Event Triggers under a domain\cr
#'  \link[paws.customer.engagement:customerprofiles_list_identity_resolution_jobs]{list_identity_resolution_jobs} \tab Lists all of the Identity Resolution Jobs in your domain\cr
#'  \link[paws.customer.engagement:customerprofiles_list_integrations]{list_integrations} \tab Lists all of the integrations in your domain\cr
#'  \link[paws.customer.engagement:customerprofiles_list_object_type_attributes]{list_object_type_attributes} \tab Fetch the possible attribute values given the attribute name\cr
#'  \link[paws.customer.engagement:customerprofiles_list_profile_attribute_values]{list_profile_attribute_values} \tab Fetch the possible attribute values given the attribute name\cr
#'  \link[paws.customer.engagement:customerprofiles_list_profile_objects]{list_profile_objects} \tab Returns a list of objects associated with a profile of a given ProfileObjectType\cr
#'  \link[paws.customer.engagement:customerprofiles_list_profile_object_types]{list_profile_object_types} \tab Lists all of the templates available within the service\cr
#'  \link[paws.customer.engagement:customerprofiles_list_profile_object_type_templates]{list_profile_object_type_templates} \tab Lists all of the template information for object types\cr
#'  \link[paws.customer.engagement:customerprofiles_list_rule_based_matches]{list_rule_based_matches} \tab Returns a set of MatchIds that belong to the given domain\cr
#'  \link[paws.customer.engagement:customerprofiles_list_segment_definitions]{list_segment_definitions} \tab Lists all segment definitions under a domain\cr
#'  \link[paws.customer.engagement:customerprofiles_list_tags_for_resource]{list_tags_for_resource} \tab Displays the tags associated with an Amazon Connect Customer Profiles resource\cr
#'  \link[paws.customer.engagement:customerprofiles_list_workflows]{list_workflows} \tab Query to list all workflows\cr
#'  \link[paws.customer.engagement:customerprofiles_merge_profiles]{merge_profiles} \tab Runs an AWS Lambda job that does the following:\cr
#'  \link[paws.customer.engagement:customerprofiles_put_integration]{put_integration} \tab Adds an integration between the service and a third-party service, which includes Amazon AppFlow and Amazon Connect\cr
#'  \link[paws.customer.engagement:customerprofiles_put_profile_object]{put_profile_object} \tab Adds additional objects to customer profiles of a given ObjectType\cr
#'  \link[paws.customer.engagement:customerprofiles_put_profile_object_type]{put_profile_object_type} \tab Defines a ProfileObjectType\cr
#'  \link[paws.customer.engagement:customerprofiles_search_profiles]{search_profiles} \tab Searches for profiles within a specific domain using one or more predefined search keys (e\cr
#'  \link[paws.customer.engagement:customerprofiles_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified Amazon Connect Customer Profiles resource\cr
#'  \link[paws.customer.engagement:customerprofiles_untag_resource]{untag_resource} \tab Removes one or more tags from the specified Amazon Connect Customer Profiles resource\cr
#'  \link[paws.customer.engagement:customerprofiles_update_calculated_attribute_definition]{update_calculated_attribute_definition} \tab Updates an existing calculated attribute definition\cr
#'  \link[paws.customer.engagement:customerprofiles_update_domain]{update_domain} \tab Updates the properties of a domain, including creating or selecting a dead letter queue or an encryption key\cr
#'  \link[paws.customer.engagement:customerprofiles_update_event_trigger]{update_event_trigger} \tab Update the properties of an Event Trigger\cr
#'  \link[paws.customer.engagement:customerprofiles_update_profile]{update_profile} \tab Updates the properties of a profile
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname customerprofiles
#' @export
customerprofiles <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::customerprofiles(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Pinpoint
#'
#' @description
#' Doc Engage API - Amazon Pinpoint API
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- pinpoint(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- pinpoint()
#' svc$create_app(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:pinpoint_create_app]{create_app} \tab Creates an application\cr
#'  \link[paws.customer.engagement:pinpoint_create_campaign]{create_campaign} \tab Creates a new campaign for an application or updates the settings of an existing campaign for an application\cr
#'  \link[paws.customer.engagement:pinpoint_create_email_template]{create_email_template} \tab Creates a message template for messages that are sent through the email channel\cr
#'  \link[paws.customer.engagement:pinpoint_create_export_job]{create_export_job} \tab Creates an export job for an application\cr
#'  \link[paws.customer.engagement:pinpoint_create_import_job]{create_import_job} \tab Creates an import job for an application\cr
#'  \link[paws.customer.engagement:pinpoint_create_in_app_template]{create_in_app_template} \tab Creates a new message template for messages using the in-app message channel\cr
#'  \link[paws.customer.engagement:pinpoint_create_journey]{create_journey} \tab Creates a journey for an application\cr
#'  \link[paws.customer.engagement:pinpoint_create_push_template]{create_push_template} \tab Creates a message template for messages that are sent through a push notification channel\cr
#'  \link[paws.customer.engagement:pinpoint_create_recommender_configuration]{create_recommender_configuration} \tab Creates an Amazon Pinpoint configuration for a recommender model\cr
#'  \link[paws.customer.engagement:pinpoint_create_segment]{create_segment} \tab Creates a new segment for an application or updates the configuration, dimension, and other settings for an existing segment that's associated with an application\cr
#'  \link[paws.customer.engagement:pinpoint_create_sms_template]{create_sms_template} \tab Creates a message template for messages that are sent through the SMS channel\cr
#'  \link[paws.customer.engagement:pinpoint_create_voice_template]{create_voice_template} \tab Creates a message template for messages that are sent through the voice channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_adm_channel]{delete_adm_channel} \tab Disables the ADM channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_apns_channel]{delete_apns_channel} \tab Disables the APNs channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_apns_sandbox_channel]{delete_apns_sandbox_channel} \tab Disables the APNs sandbox channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_apns_voip_channel]{delete_apns_voip_channel} \tab Disables the APNs VoIP channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_apns_voip_sandbox_channel]{delete_apns_voip_sandbox_channel} \tab Disables the APNs VoIP sandbox channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_app]{delete_app} \tab Deletes an application\cr
#'  \link[paws.customer.engagement:pinpoint_delete_baidu_channel]{delete_baidu_channel} \tab Disables the Baidu channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_campaign]{delete_campaign} \tab Deletes a campaign from an application\cr
#'  \link[paws.customer.engagement:pinpoint_delete_email_channel]{delete_email_channel} \tab Disables the email channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_email_template]{delete_email_template} \tab Deletes a message template for messages that were sent through the email channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_endpoint]{delete_endpoint} \tab Deletes an endpoint from an application\cr
#'  \link[paws.customer.engagement:pinpoint_delete_event_stream]{delete_event_stream} \tab Deletes the event stream for an application\cr
#'  \link[paws.customer.engagement:pinpoint_delete_gcm_channel]{delete_gcm_channel} \tab Disables the GCM channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_in_app_template]{delete_in_app_template} \tab Deletes a message template for messages sent using the in-app message channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_journey]{delete_journey} \tab Deletes a journey from an application\cr
#'  \link[paws.customer.engagement:pinpoint_delete_push_template]{delete_push_template} \tab Deletes a message template for messages that were sent through a push notification channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_recommender_configuration]{delete_recommender_configuration} \tab Deletes an Amazon Pinpoint configuration for a recommender model\cr
#'  \link[paws.customer.engagement:pinpoint_delete_segment]{delete_segment} \tab Deletes a segment from an application\cr
#'  \link[paws.customer.engagement:pinpoint_delete_sms_channel]{delete_sms_channel} \tab Disables the SMS channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_sms_template]{delete_sms_template} \tab Deletes a message template for messages that were sent through the SMS channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_user_endpoints]{delete_user_endpoints} \tab Deletes all the endpoints that are associated with a specific user ID\cr
#'  \link[paws.customer.engagement:pinpoint_delete_voice_channel]{delete_voice_channel} \tab Disables the voice channel for an application and deletes any existing settings for the channel\cr
#'  \link[paws.customer.engagement:pinpoint_delete_voice_template]{delete_voice_template} \tab Deletes a message template for messages that were sent through the voice channel\cr
#'  \link[paws.customer.engagement:pinpoint_get_adm_channel]{get_adm_channel} \tab Retrieves information about the status and settings of the ADM channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_apns_channel]{get_apns_channel} \tab Retrieves information about the status and settings of the APNs channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_apns_sandbox_channel]{get_apns_sandbox_channel} \tab Retrieves information about the status and settings of the APNs sandbox channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_apns_voip_channel]{get_apns_voip_channel} \tab Retrieves information about the status and settings of the APNs VoIP channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_apns_voip_sandbox_channel]{get_apns_voip_sandbox_channel} \tab Retrieves information about the status and settings of the APNs VoIP sandbox channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_app]{get_app} \tab Retrieves information about an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_application_date_range_kpi]{get_application_date_range_kpi} \tab Retrieves (queries) pre-aggregated data for a standard metric that applies to an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_application_settings]{get_application_settings} \tab Retrieves information about the settings for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_apps]{get_apps} \tab Retrieves information about all the applications that are associated with your Amazon Pinpoint account\cr
#'  \link[paws.customer.engagement:pinpoint_get_baidu_channel]{get_baidu_channel} \tab Retrieves information about the status and settings of the Baidu channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_campaign]{get_campaign} \tab Retrieves information about the status, configuration, and other settings for a campaign\cr
#'  \link[paws.customer.engagement:pinpoint_get_campaign_activities]{get_campaign_activities} \tab Retrieves information about all the activities for a campaign\cr
#'  \link[paws.customer.engagement:pinpoint_get_campaign_date_range_kpi]{get_campaign_date_range_kpi} \tab Retrieves (queries) pre-aggregated data for a standard metric that applies to a campaign\cr
#'  \link[paws.customer.engagement:pinpoint_get_campaigns]{get_campaigns} \tab Retrieves information about the status, configuration, and other settings for all the campaigns that are associated with an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_campaign_version]{get_campaign_version} \tab Retrieves information about the status, configuration, and other settings for a specific version of a campaign\cr
#'  \link[paws.customer.engagement:pinpoint_get_campaign_versions]{get_campaign_versions} \tab Retrieves information about the status, configuration, and other settings for all versions of a campaign\cr
#'  \link[paws.customer.engagement:pinpoint_get_channels]{get_channels} \tab Retrieves information about the history and status of each channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_email_channel]{get_email_channel} \tab Retrieves information about the status and settings of the email channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_email_template]{get_email_template} \tab Retrieves the content and settings of a message template for messages that are sent through the email channel\cr
#'  \link[paws.customer.engagement:pinpoint_get_endpoint]{get_endpoint} \tab Retrieves information about the settings and attributes of a specific endpoint for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_event_stream]{get_event_stream} \tab Retrieves information about the event stream settings for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_export_job]{get_export_job} \tab Retrieves information about the status and settings of a specific export job for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_export_jobs]{get_export_jobs} \tab Retrieves information about the status and settings of all the export jobs for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_gcm_channel]{get_gcm_channel} \tab Retrieves information about the status and settings of the GCM channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_import_job]{get_import_job} \tab Retrieves information about the status and settings of a specific import job for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_import_jobs]{get_import_jobs} \tab Retrieves information about the status and settings of all the import jobs for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_in_app_messages]{get_in_app_messages} \tab Retrieves the in-app messages targeted for the provided endpoint ID\cr
#'  \link[paws.customer.engagement:pinpoint_get_in_app_template]{get_in_app_template} \tab Retrieves the content and settings of a message template for messages sent through the in-app channel\cr
#'  \link[paws.customer.engagement:pinpoint_get_journey]{get_journey} \tab Retrieves information about the status, configuration, and other settings for a journey\cr
#'  \link[paws.customer.engagement:pinpoint_get_journey_date_range_kpi]{get_journey_date_range_kpi} \tab Retrieves (queries) pre-aggregated data for a standard engagement metric that applies to a journey\cr
#'  \link[paws.customer.engagement:pinpoint_get_journey_execution_activity_metrics]{get_journey_execution_activity_metrics} \tab Retrieves (queries) pre-aggregated data for a standard execution metric that applies to a journey activity\cr
#'  \link[paws.customer.engagement:pinpoint_get_journey_execution_metrics]{get_journey_execution_metrics} \tab Retrieves (queries) pre-aggregated data for a standard execution metric that applies to a journey\cr
#'  \link[paws.customer.engagement:pinpoint_get_journey_run_execution_activity_metrics]{get_journey_run_execution_activity_metrics} \tab Retrieves (queries) pre-aggregated data for a standard run execution metric that applies to a journey activity\cr
#'  \link[paws.customer.engagement:pinpoint_get_journey_run_execution_metrics]{get_journey_run_execution_metrics} \tab Retrieves (queries) pre-aggregated data for a standard run execution metric that applies to a journey\cr
#'  \link[paws.customer.engagement:pinpoint_get_journey_runs]{get_journey_runs} \tab Provides information about the runs of a journey\cr
#'  \link[paws.customer.engagement:pinpoint_get_push_template]{get_push_template} \tab Retrieves the content and settings of a message template for messages that are sent through a push notification channel\cr
#'  \link[paws.customer.engagement:pinpoint_get_recommender_configuration]{get_recommender_configuration} \tab Retrieves information about an Amazon Pinpoint configuration for a recommender model\cr
#'  \link[paws.customer.engagement:pinpoint_get_recommender_configurations]{get_recommender_configurations} \tab Retrieves information about all the recommender model configurations that are associated with your Amazon Pinpoint account\cr
#'  \link[paws.customer.engagement:pinpoint_get_segment]{get_segment} \tab Retrieves information about the configuration, dimension, and other settings for a specific segment that's associated with an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_segment_export_jobs]{get_segment_export_jobs} \tab Retrieves information about the status and settings of the export jobs for a segment\cr
#'  \link[paws.customer.engagement:pinpoint_get_segment_import_jobs]{get_segment_import_jobs} \tab Retrieves information about the status and settings of the import jobs for a segment\cr
#'  \link[paws.customer.engagement:pinpoint_get_segments]{get_segments} \tab Retrieves information about the configuration, dimension, and other settings for all the segments that are associated with an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_segment_version]{get_segment_version} \tab Retrieves information about the configuration, dimension, and other settings for a specific version of a segment that's associated with an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_segment_versions]{get_segment_versions} \tab Retrieves information about the configuration, dimension, and other settings for all the versions of a specific segment that's associated with an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_sms_channel]{get_sms_channel} \tab Retrieves information about the status and settings of the SMS channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_sms_template]{get_sms_template} \tab Retrieves the content and settings of a message template for messages that are sent through the SMS channel\cr
#'  \link[paws.customer.engagement:pinpoint_get_user_endpoints]{get_user_endpoints} \tab Retrieves information about all the endpoints that are associated with a specific user ID\cr
#'  \link[paws.customer.engagement:pinpoint_get_voice_channel]{get_voice_channel} \tab Retrieves information about the status and settings of the voice channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_get_voice_template]{get_voice_template} \tab Retrieves the content and settings of a message template for messages that are sent through the voice channel\cr
#'  \link[paws.customer.engagement:pinpoint_list_journeys]{list_journeys} \tab Retrieves information about the status, configuration, and other settings for all the journeys that are associated with an application\cr
#'  \link[paws.customer.engagement:pinpoint_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves all the tags (keys and values) that are associated with an application, campaign, message template, or segment\cr
#'  \link[paws.customer.engagement:pinpoint_list_templates]{list_templates} \tab Retrieves information about all the message templates that are associated with your Amazon Pinpoint account\cr
#'  \link[paws.customer.engagement:pinpoint_list_template_versions]{list_template_versions} \tab Retrieves information about all the versions of a specific message template\cr
#'  \link[paws.customer.engagement:pinpoint_phone_number_validate]{phone_number_validate} \tab Retrieves information about a phone number\cr
#'  \link[paws.customer.engagement:pinpoint_put_events]{put_events} \tab Creates a new event to record for endpoints, or creates or updates endpoint data that existing events are associated with\cr
#'  \link[paws.customer.engagement:pinpoint_put_event_stream]{put_event_stream} \tab Creates a new event stream for an application or updates the settings of an existing event stream for an application\cr
#'  \link[paws.customer.engagement:pinpoint_remove_attributes]{remove_attributes} \tab Removes one or more custom attributes, of the same attribute type, from the application\cr
#'  \link[paws.customer.engagement:pinpoint_send_messages]{send_messages} \tab Creates and sends a direct message\cr
#'  \link[paws.customer.engagement:pinpoint_send_otp_message]{send_otp_message} \tab Send an OTP message\cr
#'  \link[paws.customer.engagement:pinpoint_send_users_messages]{send_users_messages} \tab Creates and sends a message to a list of users\cr
#'  \link[paws.customer.engagement:pinpoint_tag_resource]{tag_resource} \tab Adds one or more tags (keys and values) to an application, campaign, message template, or segment\cr
#'  \link[paws.customer.engagement:pinpoint_untag_resource]{untag_resource} \tab Removes one or more tags (keys and values) from an application, campaign, message template, or segment\cr
#'  \link[paws.customer.engagement:pinpoint_update_adm_channel]{update_adm_channel} \tab Enables the ADM channel for an application or updates the status and settings of the ADM channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_apns_channel]{update_apns_channel} \tab Enables the APNs channel for an application or updates the status and settings of the APNs channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_apns_sandbox_channel]{update_apns_sandbox_channel} \tab Enables the APNs sandbox channel for an application or updates the status and settings of the APNs sandbox channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_apns_voip_channel]{update_apns_voip_channel} \tab Enables the APNs VoIP channel for an application or updates the status and settings of the APNs VoIP channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_apns_voip_sandbox_channel]{update_apns_voip_sandbox_channel} \tab Enables the APNs VoIP sandbox channel for an application or updates the status and settings of the APNs VoIP sandbox channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_application_settings]{update_application_settings} \tab Updates the settings for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_baidu_channel]{update_baidu_channel} \tab Enables the Baidu channel for an application or updates the status and settings of the Baidu channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_campaign]{update_campaign} \tab Updates the configuration and other settings for a campaign\cr
#'  \link[paws.customer.engagement:pinpoint_update_email_channel]{update_email_channel} \tab Enables the email channel for an application or updates the status and settings of the email channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_email_template]{update_email_template} \tab Updates an existing message template for messages that are sent through the email channel\cr
#'  \link[paws.customer.engagement:pinpoint_update_endpoint]{update_endpoint} \tab Creates a new endpoint for an application or updates the settings and attributes of an existing endpoint for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_endpoints_batch]{update_endpoints_batch} \tab Creates a new batch of endpoints for an application or updates the settings and attributes of a batch of existing endpoints for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_gcm_channel]{update_gcm_channel} \tab Enables the GCM channel for an application or updates the status and settings of the GCM channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_in_app_template]{update_in_app_template} \tab Updates an existing message template for messages sent through the in-app message channel\cr
#'  \link[paws.customer.engagement:pinpoint_update_journey]{update_journey} \tab Updates the configuration and other settings for a journey\cr
#'  \link[paws.customer.engagement:pinpoint_update_journey_state]{update_journey_state} \tab Cancels (stops) an active journey\cr
#'  \link[paws.customer.engagement:pinpoint_update_push_template]{update_push_template} \tab Updates an existing message template for messages that are sent through a push notification channel\cr
#'  \link[paws.customer.engagement:pinpoint_update_recommender_configuration]{update_recommender_configuration} \tab Updates an Amazon Pinpoint configuration for a recommender model\cr
#'  \link[paws.customer.engagement:pinpoint_update_segment]{update_segment} \tab Creates a new segment for an application or updates the configuration, dimension, and other settings for an existing segment that's associated with an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_sms_channel]{update_sms_channel} \tab Enables the SMS channel for an application or updates the status and settings of the SMS channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_sms_template]{update_sms_template} \tab Updates an existing message template for messages that are sent through the SMS channel\cr
#'  \link[paws.customer.engagement:pinpoint_update_template_active_version]{update_template_active_version} \tab Changes the status of a specific version of a message template to active\cr
#'  \link[paws.customer.engagement:pinpoint_update_voice_channel]{update_voice_channel} \tab Enables the voice channel for an application or updates the status and settings of the voice channel for an application\cr
#'  \link[paws.customer.engagement:pinpoint_update_voice_template]{update_voice_template} \tab Updates an existing message template for messages that are sent through the voice channel\cr
#'  \link[paws.customer.engagement:pinpoint_verify_otp_message]{verify_otp_message} \tab Verify an OTP
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname pinpoint
#' @export
pinpoint <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::pinpoint(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Pinpoint Email Service
#'
#' @description
#' Welcome to the *Amazon Pinpoint Email API Reference*. This guide
#' provides information about the Amazon Pinpoint Email API (version 1.0),
#' including supported operations, data types, parameters, and schemas.
#' 
#' [Amazon Pinpoint](https://aws.amazon.com/pinpoint/) is an AWS service
#' that you can use to engage with your customers across multiple messaging
#' channels. You can use Amazon Pinpoint to send email, SMS text messages,
#' voice messages, and push notifications. The Amazon Pinpoint Email API
#' provides programmatic access to options that are unique to the email
#' channel and supplement the options provided by the Amazon Pinpoint API.
#' 
#' If you're new to Amazon Pinpoint, you might find it helpful to also
#' review the [Amazon Pinpoint Developer
#' Guide](https://docs.aws.amazon.com/pinpoint/latest/developerguide/welcome.html).
#' The *Amazon Pinpoint Developer Guide* provides tutorials, code samples,
#' and procedures that demonstrate how to use Amazon Pinpoint features
#' programmatically and how to integrate Amazon Pinpoint functionality into
#' mobile apps and other types of applications. The guide also provides
#' information about key topics such as Amazon Pinpoint integration with
#' other AWS services and the limits that apply to using the service.
#' 
#' The Amazon Pinpoint Email API is available in several AWS Regions and it
#' provides an endpoint for each of these Regions. For a list of all the
#' Regions and endpoints where the API is currently available, see [AWS
#' Service
#' Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#pinpoint_region)
#' in the *Amazon Web Services General Reference*. To learn more about AWS
#' Regions, see [Managing AWS
#' Regions](https://docs.aws.amazon.com/accounts/latest/reference/manage-acct-regions.html)
#' in the *Amazon Web Services General Reference*.
#' 
#' In each Region, AWS maintains multiple Availability Zones. These
#' Availability Zones are physically isolated from each other, but are
#' united by private, low-latency, high-throughput, and highly redundant
#' network connections. These Availability Zones enable us to provide very
#' high levels of availability and redundancy, while also minimizing
#' latency. To learn more about the number of Availability Zones that are
#' available in each Region, see [AWS Global
#' Infrastructure](https://aws.amazon.com/about-aws/global-infrastructure/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- pinpointemail(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- pinpointemail()
#' svc$create_configuration_set(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:pinpointemail_create_configuration_set]{create_configuration_set} \tab Create a configuration set\cr
#'  \link[paws.customer.engagement:pinpointemail_create_configuration_set_event_destination]{create_configuration_set_event_destination} \tab Create an event destination\cr
#'  \link[paws.customer.engagement:pinpointemail_create_dedicated_ip_pool]{create_dedicated_ip_pool} \tab Create a new pool of dedicated IP addresses\cr
#'  \link[paws.customer.engagement:pinpointemail_create_deliverability_test_report]{create_deliverability_test_report} \tab Create a new predictive inbox placement test\cr
#'  \link[paws.customer.engagement:pinpointemail_create_email_identity]{create_email_identity} \tab Verifies an email identity for use with Amazon Pinpoint\cr
#'  \link[paws.customer.engagement:pinpointemail_delete_configuration_set]{delete_configuration_set} \tab Delete an existing configuration set\cr
#'  \link[paws.customer.engagement:pinpointemail_delete_configuration_set_event_destination]{delete_configuration_set_event_destination} \tab Delete an event destination\cr
#'  \link[paws.customer.engagement:pinpointemail_delete_dedicated_ip_pool]{delete_dedicated_ip_pool} \tab Delete a dedicated IP pool\cr
#'  \link[paws.customer.engagement:pinpointemail_delete_email_identity]{delete_email_identity} \tab Deletes an email identity that you previously verified for use with Amazon Pinpoint\cr
#'  \link[paws.customer.engagement:pinpointemail_get_account]{get_account} \tab Obtain information about the email-sending status and capabilities of your Amazon Pinpoint account in the current AWS Region\cr
#'  \link[paws.customer.engagement:pinpointemail_get_blacklist_reports]{get_blacklist_reports} \tab Retrieve a list of the blacklists that your dedicated IP addresses appear on\cr
#'  \link[paws.customer.engagement:pinpointemail_get_configuration_set]{get_configuration_set} \tab Get information about an existing configuration set, including the dedicated IP pool that it's associated with, whether or not it's enabled for sending email, and more\cr
#'  \link[paws.customer.engagement:pinpointemail_get_configuration_set_event_destinations]{get_configuration_set_event_destinations} \tab Retrieve a list of event destinations that are associated with a configuration set\cr
#'  \link[paws.customer.engagement:pinpointemail_get_dedicated_ip]{get_dedicated_ip} \tab Get information about a dedicated IP address, including the name of the dedicated IP pool that it's associated with, as well information about the automatic warm-up process for the address\cr
#'  \link[paws.customer.engagement:pinpointemail_get_dedicated_ips]{get_dedicated_ips} \tab List the dedicated IP addresses that are associated with your Amazon Pinpoint account\cr
#'  \link[paws.customer.engagement:pinpointemail_get_deliverability_dashboard_options]{get_deliverability_dashboard_options} \tab Retrieve information about the status of the Deliverability dashboard for your Amazon Pinpoint account\cr
#'  \link[paws.customer.engagement:pinpointemail_get_deliverability_test_report]{get_deliverability_test_report} \tab Retrieve the results of a predictive inbox placement test\cr
#'  \link[paws.customer.engagement:pinpointemail_get_domain_deliverability_campaign]{get_domain_deliverability_campaign} \tab Retrieve all the deliverability data for a specific campaign\cr
#'  \link[paws.customer.engagement:pinpointemail_get_domain_statistics_report]{get_domain_statistics_report} \tab Retrieve inbox placement and engagement rates for the domains that you use to send email\cr
#'  \link[paws.customer.engagement:pinpointemail_get_email_identity]{get_email_identity} \tab Provides information about a specific identity associated with your Amazon Pinpoint account, including the identity's verification status, its DKIM authentication status, and its custom Mail-From settings\cr
#'  \link[paws.customer.engagement:pinpointemail_list_configuration_sets]{list_configuration_sets} \tab List all of the configuration sets associated with your Amazon Pinpoint account in the current region\cr
#'  \link[paws.customer.engagement:pinpointemail_list_dedicated_ip_pools]{list_dedicated_ip_pools} \tab List all of the dedicated IP pools that exist in your Amazon Pinpoint account in the current AWS Region\cr
#'  \link[paws.customer.engagement:pinpointemail_list_deliverability_test_reports]{list_deliverability_test_reports} \tab Show a list of the predictive inbox placement tests that you've performed, regardless of their statuses\cr
#'  \link[paws.customer.engagement:pinpointemail_list_domain_deliverability_campaigns]{list_domain_deliverability_campaigns} \tab Retrieve deliverability data for all the campaigns that used a specific domain to send email during a specified time range\cr
#'  \link[paws.customer.engagement:pinpointemail_list_email_identities]{list_email_identities} \tab Returns a list of all of the email identities that are associated with your Amazon Pinpoint account\cr
#'  \link[paws.customer.engagement:pinpointemail_list_tags_for_resource]{list_tags_for_resource} \tab Retrieve a list of the tags (keys and values) that are associated with a specified resource\cr
#'  \link[paws.customer.engagement:pinpointemail_put_account_dedicated_ip_warmup_attributes]{put_account_dedicated_ip_warmup_attributes} \tab Enable or disable the automatic warm-up feature for dedicated IP addresses\cr
#'  \link[paws.customer.engagement:pinpointemail_put_account_sending_attributes]{put_account_sending_attributes} \tab Enable or disable the ability of your account to send email\cr
#'  \link[paws.customer.engagement:pinpointemail_put_configuration_set_delivery_options]{put_configuration_set_delivery_options} \tab Associate a configuration set with a dedicated IP pool\cr
#'  \link[paws.customer.engagement:pinpointemail_put_configuration_set_reputation_options]{put_configuration_set_reputation_options} \tab Enable or disable collection of reputation metrics for emails that you send using a particular configuration set in a specific AWS Region\cr
#'  \link[paws.customer.engagement:pinpointemail_put_configuration_set_sending_options]{put_configuration_set_sending_options} \tab Enable or disable email sending for messages that use a particular configuration set in a specific AWS Region\cr
#'  \link[paws.customer.engagement:pinpointemail_put_configuration_set_tracking_options]{put_configuration_set_tracking_options} \tab Specify a custom domain to use for open and click tracking elements in email that you send using Amazon Pinpoint\cr
#'  \link[paws.customer.engagement:pinpointemail_put_dedicated_ip_in_pool]{put_dedicated_ip_in_pool} \tab Move a dedicated IP address to an existing dedicated IP pool\cr
#'  \link[paws.customer.engagement:pinpointemail_put_dedicated_ip_warmup_attributes]{put_dedicated_ip_warmup_attributes} \tab Put dedicated ip warmup attributes\cr
#'  \link[paws.customer.engagement:pinpointemail_put_deliverability_dashboard_option]{put_deliverability_dashboard_option} \tab Enable or disable the Deliverability dashboard for your Amazon Pinpoint account\cr
#'  \link[paws.customer.engagement:pinpointemail_put_email_identity_dkim_attributes]{put_email_identity_dkim_attributes} \tab Used to enable or disable DKIM authentication for an email identity\cr
#'  \link[paws.customer.engagement:pinpointemail_put_email_identity_feedback_attributes]{put_email_identity_feedback_attributes} \tab Used to enable or disable feedback forwarding for an identity\cr
#'  \link[paws.customer.engagement:pinpointemail_put_email_identity_mail_from_attributes]{put_email_identity_mail_from_attributes} \tab Used to enable or disable the custom Mail-From domain configuration for an email identity\cr
#'  \link[paws.customer.engagement:pinpointemail_send_email]{send_email} \tab Sends an email message\cr
#'  \link[paws.customer.engagement:pinpointemail_tag_resource]{tag_resource} \tab Add one or more tags (keys and values) to a specified resource\cr
#'  \link[paws.customer.engagement:pinpointemail_untag_resource]{untag_resource} \tab Remove one or more tags (keys and values) from a specified resource\cr
#'  \link[paws.customer.engagement:pinpointemail_update_configuration_set_event_destination]{update_configuration_set_event_destination} \tab Update the configuration of an event destination for a configuration set
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname pinpointemail
#' @export
pinpointemail <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::pinpointemail(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Pinpoint SMS Voice V2
#'
#' @description
#' Welcome to the *AWS End User Messaging SMS and Voice, version 2 API
#' Reference*. This guide provides information about AWS End User Messaging
#' SMS and Voice, version 2 API resources, including supported HTTP
#' methods, parameters, and schemas.
#' 
#' Amazon Pinpoint is an Amazon Web Services service that you can use to
#' engage with your recipients across multiple messaging channels. The AWS
#' End User Messaging SMS and Voice, version 2 API provides programmatic
#' access to options that are unique to the SMS and voice channels. AWS End
#' User Messaging SMS and Voice, version 2 resources such as phone numbers,
#' sender IDs, and opt-out lists can be used by the Amazon Pinpoint API.
#' 
#' If you're new to AWS End User Messaging SMS and Voice, it's also helpful
#' to review the [AWS End User Messaging SMS User
#' Guide](https://docs.aws.amazon.com/sms-voice/latest/userguide/what-is-sms-mms.html).
#' The *AWS End User Messaging SMS User Guide* provides tutorials, code
#' samples, and procedures that demonstrate how to use AWS End User
#' Messaging SMS and Voice features programmatically and how to integrate
#' functionality into mobile apps and other types of applications. The
#' guide also provides key information, such as AWS End User Messaging SMS
#' and Voice integration with other Amazon Web Services services, and the
#' quotas that apply to use of the service.
#' 
#' **Regional availability**
#' 
#' The *AWS End User Messaging SMS and Voice version 2 API Reference* is
#' available in several Amazon Web Services Regions and it provides an
#' endpoint for each of these Regions. For a list of all the Regions and
#' endpoints where the API is currently available, see [Amazon Web Services
#' Service
#' Endpoints](https://docs.aws.amazon.com/general/latest/gr/rande.html#pinpoint_region)
#' and [Amazon Pinpoint endpoints and
#' quotas](https://docs.aws.amazon.com/general/latest/gr/pinpoint.html) in
#' the Amazon Web Services General Reference. To learn more about Amazon
#' Web Services Regions, see [Managing Amazon Web Services
#' Regions](https://docs.aws.amazon.com/accounts/latest/reference/manage-acct-regions.html)
#' in the Amazon Web Services General Reference.
#' 
#' In each Region, Amazon Web Services maintains multiple Availability
#' Zones. These Availability Zones are physically isolated from each other,
#' but are united by private, low-latency, high-throughput, and highly
#' redundant network connections. These Availability Zones enable us to
#' provide very high levels of availability and redundancy, while also
#' minimizing latency. To learn more about the number of Availability Zones
#' that are available in each Region, see [Amazon Web Services Global
#' Infrastructure.](https://aws.amazon.com/about-aws/global-infrastructure/)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- pinpointsmsvoicev2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- pinpointsmsvoicev2()
#' svc$associate_origination_identity(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_associate_origination_identity]{associate_origination_identity} \tab Associates the specified origination identity with a pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_associate_protect_configuration]{associate_protect_configuration} \tab Associate a protect configuration with a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_configuration_set]{create_configuration_set} \tab Creates a new configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_event_destination]{create_event_destination} \tab Creates a new event destination in a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_opt_out_list]{create_opt_out_list} \tab Creates a new opt-out list\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_pool]{create_pool} \tab Creates a new pool and associates the specified origination identity to the pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_protect_configuration]{create_protect_configuration} \tab Create a new protect configuration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_registration]{create_registration} \tab Creates a new registration based on the RegistrationType field\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_registration_association]{create_registration_association} \tab Associate the registration with an origination identity such as a phone number or sender ID\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_registration_attachment]{create_registration_attachment} \tab Create a new registration attachment to use for uploading a file or a URL to a file\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_registration_version]{create_registration_version} \tab Create a new version of the registration and increase the VersionNumber\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_create_verified_destination_number]{create_verified_destination_number} \tab You can only send messages to verified destination numbers when your account is in the sandbox\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_account_default_protect_configuration]{delete_account_default_protect_configuration} \tab Removes the current account default protect configuration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_configuration_set]{delete_configuration_set} \tab Deletes an existing configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_default_message_type]{delete_default_message_type} \tab Deletes an existing default message type on a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_default_sender_id]{delete_default_sender_id} \tab Deletes an existing default sender ID on a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_event_destination]{delete_event_destination} \tab Deletes an existing event destination\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_keyword]{delete_keyword} \tab Deletes an existing keyword from an origination phone number or pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_media_message_spend_limit_override]{delete_media_message_spend_limit_override} \tab Deletes an account-level monthly spending limit override for sending multimedia messages (MMS)\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_opted_out_number]{delete_opted_out_number} \tab Deletes an existing opted out destination phone number from the specified opt-out list\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_opt_out_list]{delete_opt_out_list} \tab Deletes an existing opt-out list\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_pool]{delete_pool} \tab Deletes an existing pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_protect_configuration]{delete_protect_configuration} \tab Permanently delete the protect configuration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_protect_configuration_rule_set_number_override]{delete_protect_configuration_rule_set_number_override} \tab Permanently delete the protect configuration rule set number override\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_registration]{delete_registration} \tab Permanently delete an existing registration from your account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_registration_attachment]{delete_registration_attachment} \tab Permanently delete the specified registration attachment\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_registration_field_value]{delete_registration_field_value} \tab Delete the value in a registration form field\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource-based policy document attached to the AWS End User Messaging SMS and Voice resource\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_text_message_spend_limit_override]{delete_text_message_spend_limit_override} \tab Deletes an account-level monthly spending limit override for sending text messages\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_verified_destination_number]{delete_verified_destination_number} \tab Delete a verified destination phone number\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_delete_voice_message_spend_limit_override]{delete_voice_message_spend_limit_override} \tab Deletes an account level monthly spend limit override for sending voice messages\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_account_attributes]{describe_account_attributes} \tab Describes attributes of your Amazon Web Services account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_account_limits]{describe_account_limits} \tab Describes the current AWS End User Messaging SMS and Voice SMS Voice V2 resource quotas for your account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_configuration_sets]{describe_configuration_sets} \tab Describes the specified configuration sets or all in your account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_keywords]{describe_keywords} \tab Describes the specified keywords or all keywords on your origination phone number or pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_opted_out_numbers]{describe_opted_out_numbers} \tab Describes the specified opted out destination numbers or all opted out destination numbers in an opt-out list\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_opt_out_lists]{describe_opt_out_lists} \tab Describes the specified opt-out list or all opt-out lists in your account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_phone_numbers]{describe_phone_numbers} \tab Describes the specified origination phone number, or all the phone numbers in your account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_pools]{describe_pools} \tab Retrieves the specified pools or all pools associated with your Amazon Web Services account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_protect_configurations]{describe_protect_configurations} \tab Retrieves the protect configurations that match any of filters\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_registration_attachments]{describe_registration_attachments} \tab Retrieves the specified registration attachments or all registration attachments associated with your Amazon Web Services account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_registration_field_definitions]{describe_registration_field_definitions} \tab Retrieves the specified registration type field definitions\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_registration_field_values]{describe_registration_field_values} \tab Retrieves the specified registration field values\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_registrations]{describe_registrations} \tab Retrieves the specified registrations\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_registration_section_definitions]{describe_registration_section_definitions} \tab Retrieves the specified registration section definitions\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_registration_type_definitions]{describe_registration_type_definitions} \tab Retrieves the specified registration type definitions\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_registration_versions]{describe_registration_versions} \tab Retrieves the specified registration version\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_sender_ids]{describe_sender_ids} \tab Describes the specified SenderIds or all SenderIds associated with your Amazon Web Services account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_spend_limits]{describe_spend_limits} \tab Describes the current monthly spend limits for sending voice and text messages\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_describe_verified_destination_numbers]{describe_verified_destination_numbers} \tab Retrieves the specified verified destination numbers\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_disassociate_origination_identity]{disassociate_origination_identity} \tab Removes the specified origination identity from an existing pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_disassociate_protect_configuration]{disassociate_protect_configuration} \tab Disassociate a protect configuration from a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_discard_registration_version]{discard_registration_version} \tab Discard the current version of the registration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_get_protect_configuration_country_rule_set]{get_protect_configuration_country_rule_set} \tab Retrieve the CountryRuleSet for the specified NumberCapability from a protect configuration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_get_resource_policy]{get_resource_policy} \tab Retrieves the JSON text of the resource-based policy document attached to the AWS End User Messaging SMS and Voice resource\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_list_pool_origination_identities]{list_pool_origination_identities} \tab Lists all associated origination identities in your pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_list_protect_configuration_rule_set_number_overrides]{list_protect_configuration_rule_set_number_overrides} \tab Retrieve all of the protect configuration rule set number overrides that match the filters\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_list_registration_associations]{list_registration_associations} \tab Retrieve all of the origination identities that are associated with a registration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_list_tags_for_resource]{list_tags_for_resource} \tab List all tags associated with a resource\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_put_keyword]{put_keyword} \tab Creates or updates a keyword configuration on an origination phone number or pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_put_message_feedback]{put_message_feedback} \tab Set the MessageFeedbackStatus as RECEIVED or FAILED for the passed in MessageId\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_put_opted_out_number]{put_opted_out_number} \tab Creates an opted out destination phone number in the opt-out list\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_put_protect_configuration_rule_set_number_override]{put_protect_configuration_rule_set_number_override} \tab Create or update a RuleSetNumberOverride and associate it with a protect configuration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_put_registration_field_value]{put_registration_field_value} \tab Creates or updates a field value for a registration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_put_resource_policy]{put_resource_policy} \tab Attaches a resource-based policy to a AWS End User Messaging SMS and Voice resource(phone number, sender Id, phone poll, or opt-out list) that is used for sharing the resource\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_release_phone_number]{release_phone_number} \tab Releases an existing origination phone number in your account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_release_sender_id]{release_sender_id} \tab Releases an existing sender ID in your account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_request_phone_number]{request_phone_number} \tab Request an origination phone number for use in your account\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_request_sender_id]{request_sender_id} \tab Request a new sender ID that doesn't require registration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_send_destination_number_verification_code]{send_destination_number_verification_code} \tab Before you can send test messages to a verified destination phone number you need to opt-in the verified destination phone number\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_send_media_message]{send_media_message} \tab Creates a new multimedia message (MMS) and sends it to a recipient's phone number\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_send_text_message]{send_text_message} \tab Creates a new text message and sends it to a recipient's phone number\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_send_voice_message]{send_voice_message} \tab Allows you to send a request that sends a voice message\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_set_account_default_protect_configuration]{set_account_default_protect_configuration} \tab Set a protect configuration as your account default\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_set_default_message_feedback_enabled]{set_default_message_feedback_enabled} \tab Sets a configuration set's default for message feedback\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_set_default_message_type]{set_default_message_type} \tab Sets the default message type on a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_set_default_sender_id]{set_default_sender_id} \tab Sets default sender ID on a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_set_media_message_spend_limit_override]{set_media_message_spend_limit_override} \tab Sets an account level monthly spend limit override for sending MMS messages\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_set_text_message_spend_limit_override]{set_text_message_spend_limit_override} \tab Sets an account level monthly spend limit override for sending text messages\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_set_voice_message_spend_limit_override]{set_voice_message_spend_limit_override} \tab Sets an account level monthly spend limit override for sending voice messages\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_submit_registration_version]{submit_registration_version} \tab Submit the specified registration for review and approval\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_tag_resource]{tag_resource} \tab Adds or overwrites only the specified tags for the specified resource\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_untag_resource]{untag_resource} \tab Removes the association of the specified tags from a resource\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_update_event_destination]{update_event_destination} \tab Updates an existing event destination in a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_update_phone_number]{update_phone_number} \tab Updates the configuration of an existing origination phone number\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_update_pool]{update_pool} \tab Updates the configuration of an existing pool\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_update_protect_configuration]{update_protect_configuration} \tab Update the setting for an existing protect configuration\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_update_protect_configuration_country_rule_set]{update_protect_configuration_country_rule_set} \tab Update a country rule set to ALLOW or BLOCK messages to be sent to the specified destination counties\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_update_sender_id]{update_sender_id} \tab Updates the configuration of an existing sender ID\cr
#'  \link[paws.customer.engagement:pinpointsmsvoicev2_verify_destination_number]{verify_destination_number} \tab Use the verification code that was received by the verified destination phone number to opt-in the verified destination phone number to receive more messages
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname pinpointsmsvoicev2
#' @export
pinpointsmsvoicev2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::pinpointsmsvoicev2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Simple Email Service
#'
#' @description
#' This document contains reference information for the [Amazon Simple
#' Email Service](https://aws.amazon.com/ses/) (Amazon SES) API, version
#' 2010-12-01. This document is best used in conjunction with the [Amazon
#' SES Developer
#' Guide](https://docs.aws.amazon.com/ses/latest/dg/Welcome.html).
#' 
#' For a list of Amazon SES endpoints to use in service requests, see
#' [Regions and Amazon
#' SES](https://docs.aws.amazon.com/ses/latest/dg/regions.html) in the
#' [Amazon SES Developer
#' Guide](https://docs.aws.amazon.com/ses/latest/dg/Welcome.html).
#' 
#' This documentation contains reference information related to the
#' following:
#' 
#' -   [Amazon SES API
#'     Actions](https://docs.aws.amazon.com/ses/latest/APIReference/API_Operations.html)
#' 
#' -   [Amazon SES API Data
#'     Types](https://docs.aws.amazon.com/ses/latest/APIReference/API_Types.html)
#' 
#' -   [Common
#'     Parameters](https://docs.aws.amazon.com/ses/latest/APIReference/CommonParameters.html)
#' 
#' -   [Common
#'     Errors](https://docs.aws.amazon.com/ses/latest/APIReference/CommonErrors.html)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ses(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ses()
#' # The following example creates a receipt rule set by cloning an existing
#' # one:
#' svc$clone_receipt_rule_set(
#'   OriginalRuleSetName = "RuleSetToClone",
#'   RuleSetName = "RuleSetToCreate"
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:ses_clone_receipt_rule_set]{clone_receipt_rule_set} \tab Creates a receipt rule set by cloning an existing one\cr
#'  \link[paws.customer.engagement:ses_create_configuration_set]{create_configuration_set} \tab Creates a configuration set\cr
#'  \link[paws.customer.engagement:ses_create_configuration_set_event_destination]{create_configuration_set_event_destination} \tab Creates a configuration set event destination\cr
#'  \link[paws.customer.engagement:ses_create_configuration_set_tracking_options]{create_configuration_set_tracking_options} \tab Creates an association between a configuration set and a custom domain for open and click event tracking\cr
#'  \link[paws.customer.engagement:ses_create_custom_verification_email_template]{create_custom_verification_email_template} \tab Creates a new custom verification email template\cr
#'  \link[paws.customer.engagement:ses_create_receipt_filter]{create_receipt_filter} \tab Creates a new IP address filter\cr
#'  \link[paws.customer.engagement:ses_create_receipt_rule]{create_receipt_rule} \tab Creates a receipt rule\cr
#'  \link[paws.customer.engagement:ses_create_receipt_rule_set]{create_receipt_rule_set} \tab Creates an empty receipt rule set\cr
#'  \link[paws.customer.engagement:ses_create_template]{create_template} \tab Creates an email template\cr
#'  \link[paws.customer.engagement:ses_delete_configuration_set]{delete_configuration_set} \tab Deletes a configuration set\cr
#'  \link[paws.customer.engagement:ses_delete_configuration_set_event_destination]{delete_configuration_set_event_destination} \tab Deletes a configuration set event destination\cr
#'  \link[paws.customer.engagement:ses_delete_configuration_set_tracking_options]{delete_configuration_set_tracking_options} \tab Deletes an association between a configuration set and a custom domain for open and click event tracking\cr
#'  \link[paws.customer.engagement:ses_delete_custom_verification_email_template]{delete_custom_verification_email_template} \tab Deletes an existing custom verification email template\cr
#'  \link[paws.customer.engagement:ses_delete_identity]{delete_identity} \tab Deletes the specified identity (an email address or a domain) from the list of verified identities\cr
#'  \link[paws.customer.engagement:ses_delete_identity_policy]{delete_identity_policy} \tab Deletes the specified sending authorization policy for the given identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:ses_delete_receipt_filter]{delete_receipt_filter} \tab Deletes the specified IP address filter\cr
#'  \link[paws.customer.engagement:ses_delete_receipt_rule]{delete_receipt_rule} \tab Deletes the specified receipt rule\cr
#'  \link[paws.customer.engagement:ses_delete_receipt_rule_set]{delete_receipt_rule_set} \tab Deletes the specified receipt rule set and all of the receipt rules it contains\cr
#'  \link[paws.customer.engagement:ses_delete_template]{delete_template} \tab Deletes an email template\cr
#'  \link[paws.customer.engagement:ses_delete_verified_email_address]{delete_verified_email_address} \tab Deprecated\cr
#'  \link[paws.customer.engagement:ses_describe_active_receipt_rule_set]{describe_active_receipt_rule_set} \tab Returns the metadata and receipt rules for the receipt rule set that is currently active\cr
#'  \link[paws.customer.engagement:ses_describe_configuration_set]{describe_configuration_set} \tab Returns the details of the specified configuration set\cr
#'  \link[paws.customer.engagement:ses_describe_receipt_rule]{describe_receipt_rule} \tab Returns the details of the specified receipt rule\cr
#'  \link[paws.customer.engagement:ses_describe_receipt_rule_set]{describe_receipt_rule_set} \tab Returns the details of the specified receipt rule set\cr
#'  \link[paws.customer.engagement:ses_get_account_sending_enabled]{get_account_sending_enabled} \tab Returns the email sending status of the Amazon SES account for the current Region\cr
#'  \link[paws.customer.engagement:ses_get_custom_verification_email_template]{get_custom_verification_email_template} \tab Returns the custom email verification template for the template name you specify\cr
#'  \link[paws.customer.engagement:ses_get_identity_dkim_attributes]{get_identity_dkim_attributes} \tab Returns the current status of Easy DKIM signing for an entity\cr
#'  \link[paws.customer.engagement:ses_get_identity_mail_from_domain_attributes]{get_identity_mail_from_domain_attributes} \tab Returns the custom MAIL FROM attributes for a list of identities (email addresses : domains)\cr
#'  \link[paws.customer.engagement:ses_get_identity_notification_attributes]{get_identity_notification_attributes} \tab Given a list of verified identities (email addresses and/or domains), returns a structure describing identity notification attributes\cr
#'  \link[paws.customer.engagement:ses_get_identity_policies]{get_identity_policies} \tab Returns the requested sending authorization policies for the given identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:ses_get_identity_verification_attributes]{get_identity_verification_attributes} \tab Given a list of identities (email addresses and/or domains), returns the verification status and (for domain identities) the verification token for each identity\cr
#'  \link[paws.customer.engagement:ses_get_send_quota]{get_send_quota} \tab Provides the sending limits for the Amazon SES account\cr
#'  \link[paws.customer.engagement:ses_get_send_statistics]{get_send_statistics} \tab Provides sending statistics for the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_get_template]{get_template} \tab Displays the template object (which includes the Subject line, HTML part and text part) for the template you specify\cr
#'  \link[paws.customer.engagement:ses_list_configuration_sets]{list_configuration_sets} \tab Provides a list of the configuration sets associated with your Amazon SES account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_list_custom_verification_email_templates]{list_custom_verification_email_templates} \tab Lists the existing custom verification email templates for your account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_list_identities]{list_identities} \tab Returns a list containing all of the identities (email addresses and domains) for your Amazon Web Services account in the current Amazon Web Services Region, regardless of verification status\cr
#'  \link[paws.customer.engagement:ses_list_identity_policies]{list_identity_policies} \tab Returns a list of sending authorization policies that are attached to the given identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:ses_list_receipt_filters]{list_receipt_filters} \tab Lists the IP address filters associated with your Amazon Web Services account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_list_receipt_rule_sets]{list_receipt_rule_sets} \tab Lists the receipt rule sets that exist under your Amazon Web Services account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_list_templates]{list_templates} \tab Lists the email templates present in your Amazon SES account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_list_verified_email_addresses]{list_verified_email_addresses} \tab Deprecated\cr
#'  \link[paws.customer.engagement:ses_put_configuration_set_delivery_options]{put_configuration_set_delivery_options} \tab Adds or updates the delivery options for a configuration set\cr
#'  \link[paws.customer.engagement:ses_put_identity_policy]{put_identity_policy} \tab Adds or updates a sending authorization policy for the specified identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:ses_reorder_receipt_rule_set]{reorder_receipt_rule_set} \tab Reorders the receipt rules within a receipt rule set\cr
#'  \link[paws.customer.engagement:ses_send_bounce]{send_bounce} \tab Generates and sends a bounce message to the sender of an email you received through Amazon SES\cr
#'  \link[paws.customer.engagement:ses_send_bulk_templated_email]{send_bulk_templated_email} \tab Composes an email message to multiple destinations\cr
#'  \link[paws.customer.engagement:ses_send_custom_verification_email]{send_custom_verification_email} \tab Adds an email address to the list of identities for your Amazon SES account in the current Amazon Web Services Region and attempts to verify it\cr
#'  \link[paws.customer.engagement:ses_send_email]{send_email} \tab Composes an email message and immediately queues it for sending\cr
#'  \link[paws.customer.engagement:ses_send_raw_email]{send_raw_email} \tab Composes an email message and immediately queues it for sending\cr
#'  \link[paws.customer.engagement:ses_send_templated_email]{send_templated_email} \tab Composes an email message using an email template and immediately queues it for sending\cr
#'  \link[paws.customer.engagement:ses_set_active_receipt_rule_set]{set_active_receipt_rule_set} \tab Sets the specified receipt rule set as the active receipt rule set\cr
#'  \link[paws.customer.engagement:ses_set_identity_dkim_enabled]{set_identity_dkim_enabled} \tab Enables or disables Easy DKIM signing of email sent from an identity\cr
#'  \link[paws.customer.engagement:ses_set_identity_feedback_forwarding_enabled]{set_identity_feedback_forwarding_enabled} \tab Given an identity (an email address or a domain), enables or disables whether Amazon SES forwards bounce and complaint notifications as email\cr
#'  \link[paws.customer.engagement:ses_set_identity_headers_in_notifications_enabled]{set_identity_headers_in_notifications_enabled} \tab Given an identity (an email address or a domain), sets whether Amazon SES includes the original email headers in the Amazon Simple Notification Service (Amazon SNS) notifications of a specified type\cr
#'  \link[paws.customer.engagement:ses_set_identity_mail_from_domain]{set_identity_mail_from_domain} \tab Enables or disables the custom MAIL FROM domain setup for a verified identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:ses_set_identity_notification_topic]{set_identity_notification_topic} \tab Sets an Amazon Simple Notification Service (Amazon SNS) topic to use when delivering notifications\cr
#'  \link[paws.customer.engagement:ses_set_receipt_rule_position]{set_receipt_rule_position} \tab Sets the position of the specified receipt rule in the receipt rule set\cr
#'  \link[paws.customer.engagement:ses_test_render_template]{test_render_template} \tab Creates a preview of the MIME content of an email when provided with a template and a set of replacement data\cr
#'  \link[paws.customer.engagement:ses_update_account_sending_enabled]{update_account_sending_enabled} \tab Enables or disables email sending across your entire Amazon SES account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_update_configuration_set_event_destination]{update_configuration_set_event_destination} \tab Updates the event destination of a configuration set\cr
#'  \link[paws.customer.engagement:ses_update_configuration_set_reputation_metrics_enabled]{update_configuration_set_reputation_metrics_enabled} \tab Enables or disables the publishing of reputation metrics for emails sent using a specific configuration set in a given Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_update_configuration_set_sending_enabled]{update_configuration_set_sending_enabled} \tab Enables or disables email sending for messages sent using a specific configuration set in a given Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:ses_update_configuration_set_tracking_options]{update_configuration_set_tracking_options} \tab Modifies an association between a configuration set and a custom domain for open and click event tracking\cr
#'  \link[paws.customer.engagement:ses_update_custom_verification_email_template]{update_custom_verification_email_template} \tab Updates an existing custom verification email template\cr
#'  \link[paws.customer.engagement:ses_update_receipt_rule]{update_receipt_rule} \tab Updates a receipt rule\cr
#'  \link[paws.customer.engagement:ses_update_template]{update_template} \tab Updates an email template\cr
#'  \link[paws.customer.engagement:ses_verify_domain_dkim]{verify_domain_dkim} \tab Returns a set of DKIM tokens for a domain identity\cr
#'  \link[paws.customer.engagement:ses_verify_domain_identity]{verify_domain_identity} \tab Adds a domain to the list of identities for your Amazon SES account in the current Amazon Web Services Region and attempts to verify it\cr
#'  \link[paws.customer.engagement:ses_verify_email_address]{verify_email_address} \tab Deprecated\cr
#'  \link[paws.customer.engagement:ses_verify_email_identity]{verify_email_identity} \tab Adds an email address to the list of identities for your Amazon SES account in the current Amazon Web Services Region and attempts to verify it
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ses
#' @export
ses <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::ses(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Simple Email Service
#'
#' @description
#' Amazon SES API v2
#' 
#' [Amazon SES](https://aws.amazon.com/ses/) is an Amazon Web Services
#' service that you can use to send email messages to your customers.
#' 
#' If you're new to Amazon SES API v2, you might find it helpful to review
#' the [Amazon Simple Email Service Developer
#' Guide](https://docs.aws.amazon.com/ses/latest/dg/Welcome.html). The
#' *Amazon SES Developer Guide* provides information and code samples that
#' demonstrate how to use Amazon SES API v2 features programmatically.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- sesv2(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- sesv2()
#' svc$batch_get_metric_data(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:sesv2_batch_get_metric_data]{batch_get_metric_data} \tab Retrieves batches of metric data collected based on your sending activity\cr
#'  \link[paws.customer.engagement:sesv2_cancel_export_job]{cancel_export_job} \tab Cancels an export job\cr
#'  \link[paws.customer.engagement:sesv2_create_configuration_set]{create_configuration_set} \tab Create a configuration set\cr
#'  \link[paws.customer.engagement:sesv2_create_configuration_set_event_destination]{create_configuration_set_event_destination} \tab Create an event destination\cr
#'  \link[paws.customer.engagement:sesv2_create_contact]{create_contact} \tab Creates a contact, which is an end-user who is receiving the email, and adds them to a contact list\cr
#'  \link[paws.customer.engagement:sesv2_create_contact_list]{create_contact_list} \tab Creates a contact list\cr
#'  \link[paws.customer.engagement:sesv2_create_custom_verification_email_template]{create_custom_verification_email_template} \tab Creates a new custom verification email template\cr
#'  \link[paws.customer.engagement:sesv2_create_dedicated_ip_pool]{create_dedicated_ip_pool} \tab Create a new pool of dedicated IP addresses\cr
#'  \link[paws.customer.engagement:sesv2_create_deliverability_test_report]{create_deliverability_test_report} \tab Create a new predictive inbox placement test\cr
#'  \link[paws.customer.engagement:sesv2_create_email_identity]{create_email_identity} \tab Starts the process of verifying an email identity\cr
#'  \link[paws.customer.engagement:sesv2_create_email_identity_policy]{create_email_identity_policy} \tab Creates the specified sending authorization policy for the given identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:sesv2_create_email_template]{create_email_template} \tab Creates an email template\cr
#'  \link[paws.customer.engagement:sesv2_create_export_job]{create_export_job} \tab Creates an export job for a data source and destination\cr
#'  \link[paws.customer.engagement:sesv2_create_import_job]{create_import_job} \tab Creates an import job for a data destination\cr
#'  \link[paws.customer.engagement:sesv2_create_multi_region_endpoint]{create_multi_region_endpoint} \tab Creates a multi-region endpoint (global-endpoint)\cr
#'  \link[paws.customer.engagement:sesv2_delete_configuration_set]{delete_configuration_set} \tab Delete an existing configuration set\cr
#'  \link[paws.customer.engagement:sesv2_delete_configuration_set_event_destination]{delete_configuration_set_event_destination} \tab Delete an event destination\cr
#'  \link[paws.customer.engagement:sesv2_delete_contact]{delete_contact} \tab Removes a contact from a contact list\cr
#'  \link[paws.customer.engagement:sesv2_delete_contact_list]{delete_contact_list} \tab Deletes a contact list and all of the contacts on that list\cr
#'  \link[paws.customer.engagement:sesv2_delete_custom_verification_email_template]{delete_custom_verification_email_template} \tab Deletes an existing custom verification email template\cr
#'  \link[paws.customer.engagement:sesv2_delete_dedicated_ip_pool]{delete_dedicated_ip_pool} \tab Delete a dedicated IP pool\cr
#'  \link[paws.customer.engagement:sesv2_delete_email_identity]{delete_email_identity} \tab Deletes an email identity\cr
#'  \link[paws.customer.engagement:sesv2_delete_email_identity_policy]{delete_email_identity_policy} \tab Deletes the specified sending authorization policy for the given identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:sesv2_delete_email_template]{delete_email_template} \tab Deletes an email template\cr
#'  \link[paws.customer.engagement:sesv2_delete_multi_region_endpoint]{delete_multi_region_endpoint} \tab Deletes a multi-region endpoint (global-endpoint)\cr
#'  \link[paws.customer.engagement:sesv2_delete_suppressed_destination]{delete_suppressed_destination} \tab Removes an email address from the suppression list for your account\cr
#'  \link[paws.customer.engagement:sesv2_get_account]{get_account} \tab Obtain information about the email-sending status and capabilities of your Amazon SES account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:sesv2_get_blacklist_reports]{get_blacklist_reports} \tab Retrieve a list of the blacklists that your dedicated IP addresses appear on\cr
#'  \link[paws.customer.engagement:sesv2_get_configuration_set]{get_configuration_set} \tab Get information about an existing configuration set, including the dedicated IP pool that it's associated with, whether or not it's enabled for sending email, and more\cr
#'  \link[paws.customer.engagement:sesv2_get_configuration_set_event_destinations]{get_configuration_set_event_destinations} \tab Retrieve a list of event destinations that are associated with a configuration set\cr
#'  \link[paws.customer.engagement:sesv2_get_contact]{get_contact} \tab Returns a contact from a contact list\cr
#'  \link[paws.customer.engagement:sesv2_get_contact_list]{get_contact_list} \tab Returns contact list metadata\cr
#'  \link[paws.customer.engagement:sesv2_get_custom_verification_email_template]{get_custom_verification_email_template} \tab Returns the custom email verification template for the template name you specify\cr
#'  \link[paws.customer.engagement:sesv2_get_dedicated_ip]{get_dedicated_ip} \tab Get information about a dedicated IP address, including the name of the dedicated IP pool that it's associated with, as well information about the automatic warm-up process for the address\cr
#'  \link[paws.customer.engagement:sesv2_get_dedicated_ip_pool]{get_dedicated_ip_pool} \tab Retrieve information about the dedicated pool\cr
#'  \link[paws.customer.engagement:sesv2_get_dedicated_ips]{get_dedicated_ips} \tab List the dedicated IP addresses that are associated with your Amazon Web Services account\cr
#'  \link[paws.customer.engagement:sesv2_get_deliverability_dashboard_options]{get_deliverability_dashboard_options} \tab Retrieve information about the status of the Deliverability dashboard for your account\cr
#'  \link[paws.customer.engagement:sesv2_get_deliverability_test_report]{get_deliverability_test_report} \tab Retrieve the results of a predictive inbox placement test\cr
#'  \link[paws.customer.engagement:sesv2_get_domain_deliverability_campaign]{get_domain_deliverability_campaign} \tab Retrieve all the deliverability data for a specific campaign\cr
#'  \link[paws.customer.engagement:sesv2_get_domain_statistics_report]{get_domain_statistics_report} \tab Retrieve inbox placement and engagement rates for the domains that you use to send email\cr
#'  \link[paws.customer.engagement:sesv2_get_email_identity]{get_email_identity} \tab Provides information about a specific identity, including the identity's verification status, sending authorization policies, its DKIM authentication status, and its custom Mail-From settings\cr
#'  \link[paws.customer.engagement:sesv2_get_email_identity_policies]{get_email_identity_policies} \tab Returns the requested sending authorization policies for the given identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:sesv2_get_email_template]{get_email_template} \tab Displays the template object (which includes the subject line, HTML part and text part) for the template you specify\cr
#'  \link[paws.customer.engagement:sesv2_get_export_job]{get_export_job} \tab Provides information about an export job\cr
#'  \link[paws.customer.engagement:sesv2_get_import_job]{get_import_job} \tab Provides information about an import job\cr
#'  \link[paws.customer.engagement:sesv2_get_message_insights]{get_message_insights} \tab Provides information about a specific message, including the from address, the subject, the recipient address, email tags, as well as events associated with the message\cr
#'  \link[paws.customer.engagement:sesv2_get_multi_region_endpoint]{get_multi_region_endpoint} \tab Displays the multi-region endpoint (global-endpoint) configuration\cr
#'  \link[paws.customer.engagement:sesv2_get_suppressed_destination]{get_suppressed_destination} \tab Retrieves information about a specific email address that's on the suppression list for your account\cr
#'  \link[paws.customer.engagement:sesv2_list_configuration_sets]{list_configuration_sets} \tab List all of the configuration sets associated with your account in the current region\cr
#'  \link[paws.customer.engagement:sesv2_list_contact_lists]{list_contact_lists} \tab Lists all of the contact lists available\cr
#'  \link[paws.customer.engagement:sesv2_list_contacts]{list_contacts} \tab Lists the contacts present in a specific contact list\cr
#'  \link[paws.customer.engagement:sesv2_list_custom_verification_email_templates]{list_custom_verification_email_templates} \tab Lists the existing custom verification email templates for your account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:sesv2_list_dedicated_ip_pools]{list_dedicated_ip_pools} \tab List all of the dedicated IP pools that exist in your Amazon Web Services account in the current Region\cr
#'  \link[paws.customer.engagement:sesv2_list_deliverability_test_reports]{list_deliverability_test_reports} \tab Show a list of the predictive inbox placement tests that you've performed, regardless of their statuses\cr
#'  \link[paws.customer.engagement:sesv2_list_domain_deliverability_campaigns]{list_domain_deliverability_campaigns} \tab Retrieve deliverability data for all the campaigns that used a specific domain to send email during a specified time range\cr
#'  \link[paws.customer.engagement:sesv2_list_email_identities]{list_email_identities} \tab Returns a list of all of the email identities that are associated with your Amazon Web Services account\cr
#'  \link[paws.customer.engagement:sesv2_list_email_templates]{list_email_templates} \tab Lists the email templates present in your Amazon SES account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:sesv2_list_export_jobs]{list_export_jobs} \tab Lists all of the export jobs\cr
#'  \link[paws.customer.engagement:sesv2_list_import_jobs]{list_import_jobs} \tab Lists all of the import jobs\cr
#'  \link[paws.customer.engagement:sesv2_list_multi_region_endpoints]{list_multi_region_endpoints} \tab List the multi-region endpoints (global-endpoints)\cr
#'  \link[paws.customer.engagement:sesv2_list_recommendations]{list_recommendations} \tab Lists the recommendations present in your Amazon SES account in the current Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:sesv2_list_suppressed_destinations]{list_suppressed_destinations} \tab Retrieves a list of email addresses that are on the suppression list for your account\cr
#'  \link[paws.customer.engagement:sesv2_list_tags_for_resource]{list_tags_for_resource} \tab Retrieve a list of the tags (keys and values) that are associated with a specified resource\cr
#'  \link[paws.customer.engagement:sesv2_put_account_dedicated_ip_warmup_attributes]{put_account_dedicated_ip_warmup_attributes} \tab Enable or disable the automatic warm-up feature for dedicated IP addresses\cr
#'  \link[paws.customer.engagement:sesv2_put_account_details]{put_account_details} \tab Update your Amazon SES account details\cr
#'  \link[paws.customer.engagement:sesv2_put_account_sending_attributes]{put_account_sending_attributes} \tab Enable or disable the ability of your account to send email\cr
#'  \link[paws.customer.engagement:sesv2_put_account_suppression_attributes]{put_account_suppression_attributes} \tab Change the settings for the account-level suppression list\cr
#'  \link[paws.customer.engagement:sesv2_put_account_vdm_attributes]{put_account_vdm_attributes} \tab Update your Amazon SES account VDM attributes\cr
#'  \link[paws.customer.engagement:sesv2_put_configuration_set_archiving_options]{put_configuration_set_archiving_options} \tab Associate the configuration set with a MailManager archive\cr
#'  \link[paws.customer.engagement:sesv2_put_configuration_set_delivery_options]{put_configuration_set_delivery_options} \tab Associate a configuration set with a dedicated IP pool\cr
#'  \link[paws.customer.engagement:sesv2_put_configuration_set_reputation_options]{put_configuration_set_reputation_options} \tab Enable or disable collection of reputation metrics for emails that you send using a particular configuration set in a specific Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:sesv2_put_configuration_set_sending_options]{put_configuration_set_sending_options} \tab Enable or disable email sending for messages that use a particular configuration set in a specific Amazon Web Services Region\cr
#'  \link[paws.customer.engagement:sesv2_put_configuration_set_suppression_options]{put_configuration_set_suppression_options} \tab Specify the account suppression list preferences for a configuration set\cr
#'  \link[paws.customer.engagement:sesv2_put_configuration_set_tracking_options]{put_configuration_set_tracking_options} \tab Specify a custom domain to use for open and click tracking elements in email that you send\cr
#'  \link[paws.customer.engagement:sesv2_put_configuration_set_vdm_options]{put_configuration_set_vdm_options} \tab Specify VDM preferences for email that you send using the configuration set\cr
#'  \link[paws.customer.engagement:sesv2_put_dedicated_ip_in_pool]{put_dedicated_ip_in_pool} \tab Move a dedicated IP address to an existing dedicated IP pool\cr
#'  \link[paws.customer.engagement:sesv2_put_dedicated_ip_pool_scaling_attributes]{put_dedicated_ip_pool_scaling_attributes} \tab Used to convert a dedicated IP pool to a different scaling mode\cr
#'  \link[paws.customer.engagement:sesv2_put_dedicated_ip_warmup_attributes]{put_dedicated_ip_warmup_attributes} \tab Put dedicated ip warmup attributes\cr
#'  \link[paws.customer.engagement:sesv2_put_deliverability_dashboard_option]{put_deliverability_dashboard_option} \tab Enable or disable the Deliverability dashboard\cr
#'  \link[paws.customer.engagement:sesv2_put_email_identity_configuration_set_attributes]{put_email_identity_configuration_set_attributes} \tab Used to associate a configuration set with an email identity\cr
#'  \link[paws.customer.engagement:sesv2_put_email_identity_dkim_attributes]{put_email_identity_dkim_attributes} \tab Used to enable or disable DKIM authentication for an email identity\cr
#'  \link[paws.customer.engagement:sesv2_put_email_identity_dkim_signing_attributes]{put_email_identity_dkim_signing_attributes} \tab Used to configure or change the DKIM authentication settings for an email domain identity\cr
#'  \link[paws.customer.engagement:sesv2_put_email_identity_feedback_attributes]{put_email_identity_feedback_attributes} \tab Used to enable or disable feedback forwarding for an identity\cr
#'  \link[paws.customer.engagement:sesv2_put_email_identity_mail_from_attributes]{put_email_identity_mail_from_attributes} \tab Used to enable or disable the custom Mail-From domain configuration for an email identity\cr
#'  \link[paws.customer.engagement:sesv2_put_suppressed_destination]{put_suppressed_destination} \tab Adds an email address to the suppression list for your account\cr
#'  \link[paws.customer.engagement:sesv2_send_bulk_email]{send_bulk_email} \tab Composes an email message to multiple destinations\cr
#'  \link[paws.customer.engagement:sesv2_send_custom_verification_email]{send_custom_verification_email} \tab Adds an email address to the list of identities for your Amazon SES account in the current Amazon Web Services Region and attempts to verify it\cr
#'  \link[paws.customer.engagement:sesv2_send_email]{send_email} \tab Sends an email message\cr
#'  \link[paws.customer.engagement:sesv2_tag_resource]{tag_resource} \tab Add one or more tags (keys and values) to a specified resource\cr
#'  \link[paws.customer.engagement:sesv2_test_render_email_template]{test_render_email_template} \tab Creates a preview of the MIME content of an email when provided with a template and a set of replacement data\cr
#'  \link[paws.customer.engagement:sesv2_untag_resource]{untag_resource} \tab Remove one or more tags (keys and values) from a specified resource\cr
#'  \link[paws.customer.engagement:sesv2_update_configuration_set_event_destination]{update_configuration_set_event_destination} \tab Update the configuration of an event destination for a configuration set\cr
#'  \link[paws.customer.engagement:sesv2_update_contact]{update_contact} \tab Updates a contact's preferences for a list\cr
#'  \link[paws.customer.engagement:sesv2_update_contact_list]{update_contact_list} \tab Updates contact list metadata\cr
#'  \link[paws.customer.engagement:sesv2_update_custom_verification_email_template]{update_custom_verification_email_template} \tab Updates an existing custom verification email template\cr
#'  \link[paws.customer.engagement:sesv2_update_email_identity_policy]{update_email_identity_policy} \tab Updates the specified sending authorization policy for the given identity (an email address or a domain)\cr
#'  \link[paws.customer.engagement:sesv2_update_email_template]{update_email_template} \tab Updates an email template
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname sesv2
#' @export
sesv2 <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::sesv2(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Pinpoint SMS and Voice Service
#'
#' @description
#' Pinpoint SMS and Voice Messaging public facing APIs
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- pinpointsmsvoice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- pinpointsmsvoice()
#' svc$create_configuration_set(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.customer.engagement:pinpointsmsvoice_create_configuration_set]{create_configuration_set} \tab Create a new configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoice_create_configuration_set_event_destination]{create_configuration_set_event_destination} \tab Create a new event destination in a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoice_delete_configuration_set]{delete_configuration_set} \tab Deletes an existing configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoice_delete_configuration_set_event_destination]{delete_configuration_set_event_destination} \tab Deletes an event destination in a configuration set\cr
#'  \link[paws.customer.engagement:pinpointsmsvoice_get_configuration_set_event_destinations]{get_configuration_set_event_destinations} \tab Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination\cr
#'  \link[paws.customer.engagement:pinpointsmsvoice_list_configuration_sets]{list_configuration_sets} \tab List all of the configuration sets associated with your Amazon Pinpoint account in the current region\cr
#'  \link[paws.customer.engagement:pinpointsmsvoice_send_voice_message]{send_voice_message} \tab Create a new voice message and send it to a recipient's phone number\cr
#'  \link[paws.customer.engagement:pinpointsmsvoice_update_configuration_set_event_destination]{update_configuration_set_event_destination} \tab Update an event destination in a configuration set
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname pinpointsmsvoice
#' @export
pinpointsmsvoice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.customer.engagement::pinpointsmsvoice(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon AppStream
#'
#' @description
#' Amazon AppStream 2.0
#' 
#' This is the *Amazon AppStream 2.0 API Reference*. This documentation
#' provides descriptions and syntax for each of the actions and data types
#' in AppStream 2.0. AppStream 2.0 is a fully managed, secure application
#' streaming service that lets you stream desktop applications to users
#' without rewriting applications. AppStream 2.0 manages the AWS resources
#' that are required to host and run your applications, scales
#' automatically, and provides access to your users on demand.
#' 
#' You can call the AppStream 2.0 API operations by using an interface VPC
#' endpoint (interface endpoint). For more information, see [Access
#' AppStream 2.0 API Operations and CLI Commands Through an Interface VPC
#' Endpoint](https://docs.aws.amazon.com/appstream2/latest/developerguide/access-api-cli-through-interface-vpc-endpoint.html)
#' in the *Amazon AppStream 2.0 Administration Guide*.
#' 
#' To learn more about AppStream 2.0, see the following resources:
#' 
#' -   [Amazon AppStream 2.0 product
#'     page](https://aws.amazon.com/appstream2/)
#' 
#' -   [Amazon AppStream 2.0
#'     documentation](https://docs.aws.amazon.com/appstream2/)
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- appstream(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- appstream()
#' svc$associate_app_block_builder_app_block(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.end.user.computing:appstream_associate_app_block_builder_app_block]{associate_app_block_builder_app_block} \tab Associates the specified app block builder with the specified app block\cr
#'  \link[paws.end.user.computing:appstream_associate_application_fleet]{associate_application_fleet} \tab Associates the specified application with the specified fleet\cr
#'  \link[paws.end.user.computing:appstream_associate_application_to_entitlement]{associate_application_to_entitlement} \tab Associates an application to entitle\cr
#'  \link[paws.end.user.computing:appstream_associate_fleet]{associate_fleet} \tab Associates the specified fleet with the specified stack\cr
#'  \link[paws.end.user.computing:appstream_batch_associate_user_stack]{batch_associate_user_stack} \tab Associates the specified users with the specified stacks\cr
#'  \link[paws.end.user.computing:appstream_batch_disassociate_user_stack]{batch_disassociate_user_stack} \tab Disassociates the specified users from the specified stacks\cr
#'  \link[paws.end.user.computing:appstream_copy_image]{copy_image} \tab Copies the image within the same region or to a new region within the same AWS account\cr
#'  \link[paws.end.user.computing:appstream_create_app_block]{create_app_block} \tab Creates an app block\cr
#'  \link[paws.end.user.computing:appstream_create_app_block_builder]{create_app_block_builder} \tab Creates an app block builder\cr
#'  \link[paws.end.user.computing:appstream_create_app_block_builder_streaming_url]{create_app_block_builder_streaming_url} \tab Creates a URL to start a create app block builder streaming session\cr
#'  \link[paws.end.user.computing:appstream_create_application]{create_application} \tab Creates an application\cr
#'  \link[paws.end.user.computing:appstream_create_directory_config]{create_directory_config} \tab Creates a Directory Config object in AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_create_entitlement]{create_entitlement} \tab Creates a new entitlement\cr
#'  \link[paws.end.user.computing:appstream_create_fleet]{create_fleet} \tab Creates a fleet\cr
#'  \link[paws.end.user.computing:appstream_create_image_builder]{create_image_builder} \tab Creates an image builder\cr
#'  \link[paws.end.user.computing:appstream_create_image_builder_streaming_url]{create_image_builder_streaming_url} \tab Creates a URL to start an image builder streaming session\cr
#'  \link[paws.end.user.computing:appstream_create_stack]{create_stack} \tab Creates a stack to start streaming applications to users\cr
#'  \link[paws.end.user.computing:appstream_create_streaming_url]{create_streaming_url} \tab Creates a temporary URL to start an AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_create_theme_for_stack]{create_theme_for_stack} \tab Creates custom branding that customizes the appearance of the streaming application catalog page\cr
#'  \link[paws.end.user.computing:appstream_create_updated_image]{create_updated_image} \tab Creates a new image with the latest Windows operating system updates, driver updates, and AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_create_usage_report_subscription]{create_usage_report_subscription} \tab Creates a usage report subscription\cr
#'  \link[paws.end.user.computing:appstream_create_user]{create_user} \tab Creates a new user in the user pool\cr
#'  \link[paws.end.user.computing:appstream_delete_app_block]{delete_app_block} \tab Deletes an app block\cr
#'  \link[paws.end.user.computing:appstream_delete_app_block_builder]{delete_app_block_builder} \tab Deletes an app block builder\cr
#'  \link[paws.end.user.computing:appstream_delete_application]{delete_application} \tab Deletes an application\cr
#'  \link[paws.end.user.computing:appstream_delete_directory_config]{delete_directory_config} \tab Deletes the specified Directory Config object from AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_delete_entitlement]{delete_entitlement} \tab Deletes the specified entitlement\cr
#'  \link[paws.end.user.computing:appstream_delete_fleet]{delete_fleet} \tab Deletes the specified fleet\cr
#'  \link[paws.end.user.computing:appstream_delete_image]{delete_image} \tab Deletes the specified image\cr
#'  \link[paws.end.user.computing:appstream_delete_image_builder]{delete_image_builder} \tab Deletes the specified image builder and releases the capacity\cr
#'  \link[paws.end.user.computing:appstream_delete_image_permissions]{delete_image_permissions} \tab Deletes permissions for the specified private image\cr
#'  \link[paws.end.user.computing:appstream_delete_stack]{delete_stack} \tab Deletes the specified stack\cr
#'  \link[paws.end.user.computing:appstream_delete_theme_for_stack]{delete_theme_for_stack} \tab Deletes custom branding that customizes the appearance of the streaming application catalog page\cr
#'  \link[paws.end.user.computing:appstream_delete_usage_report_subscription]{delete_usage_report_subscription} \tab Disables usage report generation\cr
#'  \link[paws.end.user.computing:appstream_delete_user]{delete_user} \tab Deletes a user from the user pool\cr
#'  \link[paws.end.user.computing:appstream_describe_app_block_builder_app_block_associations]{describe_app_block_builder_app_block_associations} \tab Retrieves a list that describes one or more app block builder associations\cr
#'  \link[paws.end.user.computing:appstream_describe_app_block_builders]{describe_app_block_builders} \tab Retrieves a list that describes one or more app block builders\cr
#'  \link[paws.end.user.computing:appstream_describe_app_blocks]{describe_app_blocks} \tab Retrieves a list that describes one or more app blocks\cr
#'  \link[paws.end.user.computing:appstream_describe_application_fleet_associations]{describe_application_fleet_associations} \tab Retrieves a list that describes one or more application fleet associations\cr
#'  \link[paws.end.user.computing:appstream_describe_applications]{describe_applications} \tab Retrieves a list that describes one or more applications\cr
#'  \link[paws.end.user.computing:appstream_describe_directory_configs]{describe_directory_configs} \tab Retrieves a list that describes one or more specified Directory Config objects for AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_describe_entitlements]{describe_entitlements} \tab Retrieves a list that describes one of more entitlements\cr
#'  \link[paws.end.user.computing:appstream_describe_fleets]{describe_fleets} \tab Retrieves a list that describes one or more specified fleets, if the fleet names are provided\cr
#'  \link[paws.end.user.computing:appstream_describe_image_builders]{describe_image_builders} \tab Retrieves a list that describes one or more specified image builders, if the image builder names are provided\cr
#'  \link[paws.end.user.computing:appstream_describe_image_permissions]{describe_image_permissions} \tab Retrieves a list that describes the permissions for shared AWS account IDs on a private image that you own\cr
#'  \link[paws.end.user.computing:appstream_describe_images]{describe_images} \tab Retrieves a list that describes one or more specified images, if the image names or image ARNs are provided\cr
#'  \link[paws.end.user.computing:appstream_describe_sessions]{describe_sessions} \tab Retrieves a list that describes the streaming sessions for a specified stack and fleet\cr
#'  \link[paws.end.user.computing:appstream_describe_stacks]{describe_stacks} \tab Retrieves a list that describes one or more specified stacks, if the stack names are provided\cr
#'  \link[paws.end.user.computing:appstream_describe_theme_for_stack]{describe_theme_for_stack} \tab Retrieves a list that describes the theme for a specified stack\cr
#'  \link[paws.end.user.computing:appstream_describe_usage_report_subscriptions]{describe_usage_report_subscriptions} \tab Retrieves a list that describes one or more usage report subscriptions\cr
#'  \link[paws.end.user.computing:appstream_describe_users]{describe_users} \tab Retrieves a list that describes one or more specified users in the user pool\cr
#'  \link[paws.end.user.computing:appstream_describe_user_stack_associations]{describe_user_stack_associations} \tab Retrieves a list that describes the UserStackAssociation objects\cr
#'  \link[paws.end.user.computing:appstream_disable_user]{disable_user} \tab Disables the specified user in the user pool\cr
#'  \link[paws.end.user.computing:appstream_disassociate_app_block_builder_app_block]{disassociate_app_block_builder_app_block} \tab Disassociates a specified app block builder from a specified app block\cr
#'  \link[paws.end.user.computing:appstream_disassociate_application_fleet]{disassociate_application_fleet} \tab Disassociates the specified application from the fleet\cr
#'  \link[paws.end.user.computing:appstream_disassociate_application_from_entitlement]{disassociate_application_from_entitlement} \tab Deletes the specified application from the specified entitlement\cr
#'  \link[paws.end.user.computing:appstream_disassociate_fleet]{disassociate_fleet} \tab Disassociates the specified fleet from the specified stack\cr
#'  \link[paws.end.user.computing:appstream_enable_user]{enable_user} \tab Enables a user in the user pool\cr
#'  \link[paws.end.user.computing:appstream_expire_session]{expire_session} \tab Immediately stops the specified streaming session\cr
#'  \link[paws.end.user.computing:appstream_list_associated_fleets]{list_associated_fleets} \tab Retrieves the name of the fleet that is associated with the specified stack\cr
#'  \link[paws.end.user.computing:appstream_list_associated_stacks]{list_associated_stacks} \tab Retrieves the name of the stack with which the specified fleet is associated\cr
#'  \link[paws.end.user.computing:appstream_list_entitled_applications]{list_entitled_applications} \tab Retrieves a list of entitled applications\cr
#'  \link[paws.end.user.computing:appstream_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves a list of all tags for the specified AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_start_app_block_builder]{start_app_block_builder} \tab Starts an app block builder\cr
#'  \link[paws.end.user.computing:appstream_start_fleet]{start_fleet} \tab Starts the specified fleet\cr
#'  \link[paws.end.user.computing:appstream_start_image_builder]{start_image_builder} \tab Starts the specified image builder\cr
#'  \link[paws.end.user.computing:appstream_stop_app_block_builder]{stop_app_block_builder} \tab Stops an app block builder\cr
#'  \link[paws.end.user.computing:appstream_stop_fleet]{stop_fleet} \tab Stops the specified fleet\cr
#'  \link[paws.end.user.computing:appstream_stop_image_builder]{stop_image_builder} \tab Stops the specified image builder\cr
#'  \link[paws.end.user.computing:appstream_tag_resource]{tag_resource} \tab Adds or overwrites one or more tags for the specified AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_untag_resource]{untag_resource} \tab Disassociates one or more specified tags from the specified AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_update_app_block_builder]{update_app_block_builder} \tab Updates an app block builder\cr
#'  \link[paws.end.user.computing:appstream_update_application]{update_application} \tab Updates the specified application\cr
#'  \link[paws.end.user.computing:appstream_update_directory_config]{update_directory_config} \tab Updates the specified Directory Config object in AppStream 2\cr
#'  \link[paws.end.user.computing:appstream_update_entitlement]{update_entitlement} \tab Updates the specified entitlement\cr
#'  \link[paws.end.user.computing:appstream_update_fleet]{update_fleet} \tab Updates the specified fleet\cr
#'  \link[paws.end.user.computing:appstream_update_image_permissions]{update_image_permissions} \tab Adds or updates permissions for the specified private image\cr
#'  \link[paws.end.user.computing:appstream_update_stack]{update_stack} \tab Updates the specified fields for the specified stack\cr
#'  \link[paws.end.user.computing:appstream_update_theme_for_stack]{update_theme_for_stack} \tab Updates custom branding that customizes the appearance of the streaming application catalog page
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname appstream
#' @export
appstream <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.end.user.computing::appstream(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' AWS Chatbot
#'
#' @description
#' The *AWS Chatbot API Reference* provides descriptions, API request
#' parameters, and the XML response for each of the AWS Chatbot API
#' actions.
#' 
#' AWS Chatbot APIs are currently available in the following Regions:
#' 
#' -   US East (Ohio) - `us-east-2`
#' 
#' -   US West (Oregon) - `us-west-2`
#' 
#' -   Asia Pacific (Singapore) - `ap-southeast-1`
#' 
#' -   Europe (Ireland) - `eu-west-1`
#' 
#' The AWS Chatbot console can only be used in US East (Ohio). Your
#' configuration data however, is stored in each of the relevant available
#' Regions.
#' 
#' Your AWS CloudTrail events are logged in whatever Region you call from,
#' not US East (N. Virginia) by default.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- chatbot(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- chatbot()
#' svc$associate_to_configuration(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.end.user.computing:chatbot_associate_to_configuration]{associate_to_configuration} \tab Links a resource (for example, a custom action) to a channel configuration\cr
#'  \link[paws.end.user.computing:chatbot_create_chime_webhook_configuration]{create_chime_webhook_configuration} \tab Creates an AWS Chatbot configuration for Amazon Chime\cr
#'  \link[paws.end.user.computing:chatbot_create_custom_action]{create_custom_action} \tab Creates a custom action that can be invoked as an alias or as a button on a notification\cr
#'  \link[paws.end.user.computing:chatbot_create_microsoft_teams_channel_configuration]{create_microsoft_teams_channel_configuration} \tab Creates an AWS Chatbot configuration for Microsoft Teams\cr
#'  \link[paws.end.user.computing:chatbot_create_slack_channel_configuration]{create_slack_channel_configuration} \tab Creates an AWS Chatbot confugration for Slack\cr
#'  \link[paws.end.user.computing:chatbot_delete_chime_webhook_configuration]{delete_chime_webhook_configuration} \tab Deletes a Amazon Chime webhook configuration for AWS Chatbot\cr
#'  \link[paws.end.user.computing:chatbot_delete_custom_action]{delete_custom_action} \tab Deletes a custom action\cr
#'  \link[paws.end.user.computing:chatbot_delete_microsoft_teams_channel_configuration]{delete_microsoft_teams_channel_configuration} \tab Deletes a Microsoft Teams channel configuration for AWS Chatbot\cr
#'  \link[paws.end.user.computing:chatbot_delete_microsoft_teams_configured_team]{delete_microsoft_teams_configured_team} \tab Deletes the Microsoft Teams team authorization allowing for channels to be configured in that Microsoft Teams team\cr
#'  \link[paws.end.user.computing:chatbot_delete_microsoft_teams_user_identity]{delete_microsoft_teams_user_identity} \tab Identifes a user level permission for a channel configuration\cr
#'  \link[paws.end.user.computing:chatbot_delete_slack_channel_configuration]{delete_slack_channel_configuration} \tab Deletes a Slack channel configuration for AWS Chatbot\cr
#'  \link[paws.end.user.computing:chatbot_delete_slack_user_identity]{delete_slack_user_identity} \tab Deletes a user level permission for a Slack channel configuration\cr
#'  \link[paws.end.user.computing:chatbot_delete_slack_workspace_authorization]{delete_slack_workspace_authorization} \tab Deletes the Slack workspace authorization that allows channels to be configured in that workspace\cr
#'  \link[paws.end.user.computing:chatbot_describe_chime_webhook_configurations]{describe_chime_webhook_configurations} \tab Lists Amazon Chime webhook configurations optionally filtered by ChatConfigurationArn\cr
#'  \link[paws.end.user.computing:chatbot_describe_slack_channel_configurations]{describe_slack_channel_configurations} \tab Lists Slack channel configurations optionally filtered by ChatConfigurationArn\cr
#'  \link[paws.end.user.computing:chatbot_describe_slack_user_identities]{describe_slack_user_identities} \tab Lists all Slack user identities with a mapped role\cr
#'  \link[paws.end.user.computing:chatbot_describe_slack_workspaces]{describe_slack_workspaces} \tab List all authorized Slack workspaces connected to the AWS Account onboarded with AWS Chatbot\cr
#'  \link[paws.end.user.computing:chatbot_disassociate_from_configuration]{disassociate_from_configuration} \tab Unlink a resource, for example a custom action, from a channel configuration\cr
#'  \link[paws.end.user.computing:chatbot_get_account_preferences]{get_account_preferences} \tab Returns AWS Chatbot account preferences\cr
#'  \link[paws.end.user.computing:chatbot_get_custom_action]{get_custom_action} \tab Returns a custom action\cr
#'  \link[paws.end.user.computing:chatbot_get_microsoft_teams_channel_configuration]{get_microsoft_teams_channel_configuration} \tab Returns a Microsoft Teams channel configuration in an AWS account\cr
#'  \link[paws.end.user.computing:chatbot_list_associations]{list_associations} \tab Lists resources associated with a channel configuration\cr
#'  \link[paws.end.user.computing:chatbot_list_custom_actions]{list_custom_actions} \tab Lists custom actions defined in this account\cr
#'  \link[paws.end.user.computing:chatbot_list_microsoft_teams_channel_configurations]{list_microsoft_teams_channel_configurations} \tab Lists all AWS Chatbot Microsoft Teams channel configurations in an AWS account\cr
#'  \link[paws.end.user.computing:chatbot_list_microsoft_teams_configured_teams]{list_microsoft_teams_configured_teams} \tab Lists all authorized Microsoft Teams for an AWS Account\cr
#'  \link[paws.end.user.computing:chatbot_list_microsoft_teams_user_identities]{list_microsoft_teams_user_identities} \tab A list all Microsoft Teams user identities with a mapped role\cr
#'  \link[paws.end.user.computing:chatbot_list_tags_for_resource]{list_tags_for_resource} \tab Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify\cr
#'  \link[paws.end.user.computing:chatbot_tag_resource]{tag_resource} \tab Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN)\cr
#'  \link[paws.end.user.computing:chatbot_untag_resource]{untag_resource} \tab Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN)\cr
#'  \link[paws.end.user.computing:chatbot_update_account_preferences]{update_account_preferences} \tab Updates AWS Chatbot account preferences\cr
#'  \link[paws.end.user.computing:chatbot_update_chime_webhook_configuration]{update_chime_webhook_configuration} \tab Updates a Amazon Chime webhook configuration\cr
#'  \link[paws.end.user.computing:chatbot_update_custom_action]{update_custom_action} \tab Updates a custom action\cr
#'  \link[paws.end.user.computing:chatbot_update_microsoft_teams_channel_configuration]{update_microsoft_teams_channel_configuration} \tab Updates an Microsoft Teams channel configuration\cr
#'  \link[paws.end.user.computing:chatbot_update_slack_channel_configuration]{update_slack_channel_configuration} \tab Updates a Slack channel configuration
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname chatbot
#' @export
chatbot <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.end.user.computing::chatbot(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon Interactive Video Service Chat
#'
#' @description
#' **Introduction**
#' 
#' The Amazon IVS Chat control-plane API enables you to create and manage
#' Amazon IVS Chat resources. You also need to integrate with the [Amazon
#' IVS Chat Messaging
#' API](https://docs.aws.amazon.com/ivs/latest/chatmsgapireference/), to
#' enable users to interact with chat rooms in real time.
#' 
#' The API is an AWS regional service. For a list of supported regions and
#' Amazon IVS Chat HTTPS service endpoints, see the Amazon IVS Chat
#' information on the [Amazon IVS
#' page](https://docs.aws.amazon.com/general/latest/gr/ivs.html) in the
#' *AWS General Reference*.
#' 
#' This document describes HTTP operations. There is a separate *messaging*
#' API for managing Chat resources; see the [Amazon IVS Chat Messaging API
#' Reference](https://docs.aws.amazon.com/ivs/latest/chatmsgapireference/).
#' 
#' **Notes on terminology:**
#' 
#' -   You create service applications using the Amazon IVS Chat API. We
#'     refer to these as *applications*.
#' 
#' -   You create front-end client applications (browser and Android/iOS
#'     apps) using the Amazon IVS Chat Messaging API. We refer to these as
#'     *clients*.
#' 
#' **Resources**
#' 
#' The following resources are part of Amazon IVS Chat:
#' 
#' -   **LoggingConfiguration** — A configuration that allows customers to
#'     store and record sent messages in a chat room. See the Logging
#'     Configuration endpoints for more information.
#' 
#' -   **Room** — The central Amazon IVS Chat resource through which
#'     clients connect to and exchange chat messages. See the Room
#'     endpoints for more information.
#' 
#' **Tagging**
#' 
#' A *tag* is a metadata label that you assign to an AWS resource. A tag
#' comprises a *key* and a *value*, both set by you. For example, you might
#' set a tag as `topic:nature` to label a particular video category. See
#' [Best practices and
#' strategies](https://docs.aws.amazon.com/tag-editor/latest/userguide/best-practices-and-strats.html)
#' in *Tagging Amazon Web Services Resources and Tag Editor* for details,
#' including restrictions that apply to tags and "Tag naming limits and
#' requirements"; Amazon IVS Chat has no service-specific constraints
#' beyond what is documented there.
#' 
#' Tags can help you identify and organize your AWS resources. For example,
#' you can use the same tag for different resources to indicate that they
#' are related. You can also use tags to manage access (see [Access
#' Tags](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html)).
#' 
#' The Amazon IVS Chat API has these tag-related operations:
#' `tag_resource`,
#' `untag_resource`, and
#' `list_tags_for_resource`. The
#' following resource supports tagging: Room.
#' 
#' At most 50 tags can be applied to a resource.
#' 
#' **API Access Security**
#' 
#' Your Amazon IVS Chat applications (service applications and clients)
#' must be authenticated and authorized to access Amazon IVS Chat
#' resources. Note the differences between these concepts:
#' 
#' -   *Authentication* is about verifying identity. Requests to the Amazon
#'     IVS Chat API must be signed to verify your identity.
#' 
#' -   *Authorization* is about granting permissions. Your IAM roles need
#'     to have permissions for Amazon IVS Chat API requests.
#' 
#' Users (viewers) connect to a room using secure access tokens that you
#' create using the `create_chat_token`
#' operation through the AWS SDK. You call CreateChatToken for every user’s
#' chat session, passing identity and authorization information about the
#' user.
#' 
#' **Signing API Requests**
#' 
#' HTTP API requests must be signed with an AWS SigV4 signature using your
#' AWS security credentials. The AWS Command Line Interface (CLI) and the
#' AWS SDKs take care of signing the underlying API calls for you. However,
#' if your application calls the Amazon IVS Chat HTTP API directly, it’s
#' your responsibility to sign the requests.
#' 
#' You generate a signature using valid AWS credentials for an IAM role
#' that has permission to perform the requested action. For example,
#' DeleteMessage requests must be made using an IAM role that has the
#' `ivschat:DeleteMessage` permission.
#' 
#' For more information:
#' 
#' -   Authentication and generating signatures — See [Authenticating
#'     Requests (Amazon Web Services Signature Version
#'     4)](https://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-authenticating-requests.html)
#'     in the *Amazon Web Services General Reference*.
#' 
#' -   Managing Amazon IVS permissions — See [Identity and Access
#'     Management](https://docs.aws.amazon.com/ivs/latest/LowLatencyUserGuide/security-iam.html)
#'     on the Security page of the *Amazon IVS User Guide*.
#' 
#' **Amazon Resource Names (ARNs)**
#' 
#' ARNs uniquely identify AWS resources. An ARN is required when you need
#' to specify a resource unambiguously across all of AWS, such as in IAM
#' policies and API calls. For more information, see [Amazon Resource
#' Names](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html)
#' in the *AWS General Reference*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ivschat(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ivschat()
#' svc$create_chat_token(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.end.user.computing:ivschat_create_chat_token]{create_chat_token} \tab Creates an encrypted token that is used by a chat participant to establish an individual WebSocket chat connection to a room\cr
#'  \link[paws.end.user.computing:ivschat_create_logging_configuration]{create_logging_configuration} \tab Creates a logging configuration that allows clients to store and record sent messages\cr
#'  \link[paws.end.user.computing:ivschat_create_room]{create_room} \tab Creates a room that allows clients to connect and pass messages\cr
#'  \link[paws.end.user.computing:ivschat_delete_logging_configuration]{delete_logging_configuration} \tab Deletes the specified logging configuration\cr
#'  \link[paws.end.user.computing:ivschat_delete_message]{delete_message} \tab Sends an event to a specific room which directs clients to delete a specific message; that is, unrender it from view and delete it from the client’s chat history\cr
#'  \link[paws.end.user.computing:ivschat_delete_room]{delete_room} \tab Deletes the specified room\cr
#'  \link[paws.end.user.computing:ivschat_disconnect_user]{disconnect_user} \tab Disconnects all connections using a specified user ID from a room\cr
#'  \link[paws.end.user.computing:ivschat_get_logging_configuration]{get_logging_configuration} \tab Gets the specified logging configuration\cr
#'  \link[paws.end.user.computing:ivschat_get_room]{get_room} \tab Gets the specified room\cr
#'  \link[paws.end.user.computing:ivschat_list_logging_configurations]{list_logging_configurations} \tab Gets summary information about all your logging configurations in the AWS region where the API request is processed\cr
#'  \link[paws.end.user.computing:ivschat_list_rooms]{list_rooms} \tab Gets summary information about all your rooms in the AWS region where the API request is processed\cr
#'  \link[paws.end.user.computing:ivschat_list_tags_for_resource]{list_tags_for_resource} \tab Gets information about AWS tags for the specified ARN\cr
#'  \link[paws.end.user.computing:ivschat_send_event]{send_event} \tab Sends an event to a room\cr
#'  \link[paws.end.user.computing:ivschat_tag_resource]{tag_resource} \tab Adds or updates tags for the AWS resource with the specified ARN\cr
#'  \link[paws.end.user.computing:ivschat_untag_resource]{untag_resource} \tab Removes tags from the resource with the specified ARN\cr
#'  \link[paws.end.user.computing:ivschat_update_logging_configuration]{update_logging_configuration} \tab Updates a specified logging configuration\cr
#'  \link[paws.end.user.computing:ivschat_update_room]{update_room} \tab Updates a room’s configuration
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ivschat
#' @export
ivschat <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.end.user.computing::ivschat(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon WorkDocs
#'
#' @description
#' The Amazon WorkDocs API is designed for the following use cases:
#' 
#' -   File Migration: File migration applications are supported for users
#'     who want to migrate their files from an on-premises or off-premises
#'     file system or service. Users can insert files into a user directory
#'     structure, as well as allow for basic metadata changes, such as
#'     modifications to the permissions of files.
#' 
#' -   Security: Support security applications are supported for users who
#'     have additional security needs, such as antivirus or data loss
#'     prevention. The API actions, along with CloudTrail, allow these
#'     applications to detect when changes occur in Amazon WorkDocs. Then,
#'     the application can take the necessary actions and replace the
#'     target file. If the target file violates the policy, the application
#'     can also choose to email the user.
#' 
#' -   eDiscovery/Analytics: General administrative applications are
#'     supported, such as eDiscovery and analytics. These applications can
#'     choose to mimic or record the actions in an Amazon WorkDocs site,
#'     along with CloudTrail, to replicate data for eDiscovery, backup, or
#'     analytical applications.
#' 
#' All Amazon WorkDocs API actions are Amazon authenticated and
#' certificate-signed. They not only require the use of the Amazon Web
#' Services SDK, but also allow for the exclusive use of IAM users and
#' roles to help facilitate access, trust, and permission policies. By
#' creating a role and allowing an IAM user to access the Amazon WorkDocs
#' site, the IAM user gains full administrative visibility into the entire
#' Amazon WorkDocs site (or as set in the IAM policy). This includes, but
#' is not limited to, the ability to modify file permissions and upload any
#' file to any user. This allows developers to perform the three use cases
#' above, as well as give users the ability to grant access on a selective
#' basis using the IAM model.
#' 
#' The pricing for Amazon WorkDocs APIs varies depending on the API call
#' type for these actions:
#' 
#' -   `READ (Get*)`
#' 
#' -   `WRITE (Activate*, Add*, Create*, Deactivate*, Initiate*, Update*)`
#' 
#' -   `LIST (Describe*)`
#' 
#' -   `DELETE*, CANCEL`
#' 
#' For information about Amazon WorkDocs API pricing, see [Amazon WorkDocs
#' Pricing](https://aws.amazon.com/workdocs/pricing/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- workdocs(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- workdocs()
#' svc$abort_document_version_upload(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.end.user.computing:workdocs_abort_document_version_upload]{abort_document_version_upload} \tab Aborts the upload of the specified document version that was previously initiated by InitiateDocumentVersionUpload\cr
#'  \link[paws.end.user.computing:workdocs_activate_user]{activate_user} \tab Activates the specified user\cr
#'  \link[paws.end.user.computing:workdocs_add_resource_permissions]{add_resource_permissions} \tab Creates a set of permissions for the specified folder or document\cr
#'  \link[paws.end.user.computing:workdocs_create_comment]{create_comment} \tab Adds a new comment to the specified document version\cr
#'  \link[paws.end.user.computing:workdocs_create_custom_metadata]{create_custom_metadata} \tab Adds one or more custom properties to the specified resource (a folder, document, or version)\cr
#'  \link[paws.end.user.computing:workdocs_create_folder]{create_folder} \tab Creates a folder with the specified name and parent folder\cr
#'  \link[paws.end.user.computing:workdocs_create_labels]{create_labels} \tab Adds the specified list of labels to the given resource (a document or folder)\cr
#'  \link[paws.end.user.computing:workdocs_create_notification_subscription]{create_notification_subscription} \tab Configure Amazon WorkDocs to use Amazon SNS notifications\cr
#'  \link[paws.end.user.computing:workdocs_create_user]{create_user} \tab Creates a user in a Simple AD or Microsoft AD directory\cr
#'  \link[paws.end.user.computing:workdocs_deactivate_user]{deactivate_user} \tab Deactivates the specified user, which revokes the user's access to Amazon WorkDocs\cr
#'  \link[paws.end.user.computing:workdocs_delete_comment]{delete_comment} \tab Deletes the specified comment from the document version\cr
#'  \link[paws.end.user.computing:workdocs_delete_custom_metadata]{delete_custom_metadata} \tab Deletes custom metadata from the specified resource\cr
#'  \link[paws.end.user.computing:workdocs_delete_document]{delete_document} \tab Permanently deletes the specified document and its associated metadata\cr
#'  \link[paws.end.user.computing:workdocs_delete_document_version]{delete_document_version} \tab Deletes a specific version of a document\cr
#'  \link[paws.end.user.computing:workdocs_delete_folder]{delete_folder} \tab Permanently deletes the specified folder and its contents\cr
#'  \link[paws.end.user.computing:workdocs_delete_folder_contents]{delete_folder_contents} \tab Deletes the contents of the specified folder\cr
#'  \link[paws.end.user.computing:workdocs_delete_labels]{delete_labels} \tab Deletes the specified list of labels from a resource\cr
#'  \link[paws.end.user.computing:workdocs_delete_notification_subscription]{delete_notification_subscription} \tab Deletes the specified subscription from the specified organization\cr
#'  \link[paws.end.user.computing:workdocs_delete_user]{delete_user} \tab Deletes the specified user from a Simple AD or Microsoft AD directory\cr
#'  \link[paws.end.user.computing:workdocs_describe_activities]{describe_activities} \tab Describes the user activities in a specified time period\cr
#'  \link[paws.end.user.computing:workdocs_describe_comments]{describe_comments} \tab List all the comments for the specified document version\cr
#'  \link[paws.end.user.computing:workdocs_describe_document_versions]{describe_document_versions} \tab Retrieves the document versions for the specified document\cr
#'  \link[paws.end.user.computing:workdocs_describe_folder_contents]{describe_folder_contents} \tab Describes the contents of the specified folder, including its documents and subfolders\cr
#'  \link[paws.end.user.computing:workdocs_describe_groups]{describe_groups} \tab Describes the groups specified by the query\cr
#'  \link[paws.end.user.computing:workdocs_describe_notification_subscriptions]{describe_notification_subscriptions} \tab Lists the specified notification subscriptions\cr
#'  \link[paws.end.user.computing:workdocs_describe_resource_permissions]{describe_resource_permissions} \tab Describes the permissions of a specified resource\cr
#'  \link[paws.end.user.computing:workdocs_describe_root_folders]{describe_root_folders} \tab Describes the current user's special folders; the RootFolder and the RecycleBin\cr
#'  \link[paws.end.user.computing:workdocs_describe_users]{describe_users} \tab Describes the specified users\cr
#'  \link[paws.end.user.computing:workdocs_get_current_user]{get_current_user} \tab Retrieves details of the current user for whom the authentication token was generated\cr
#'  \link[paws.end.user.computing:workdocs_get_document]{get_document} \tab Retrieves details of a document\cr
#'  \link[paws.end.user.computing:workdocs_get_document_path]{get_document_path} \tab Retrieves the path information (the hierarchy from the root folder) for the requested document\cr
#'  \link[paws.end.user.computing:workdocs_get_document_version]{get_document_version} \tab Retrieves version metadata for the specified document\cr
#'  \link[paws.end.user.computing:workdocs_get_folder]{get_folder} \tab Retrieves the metadata of the specified folder\cr
#'  \link[paws.end.user.computing:workdocs_get_folder_path]{get_folder_path} \tab Retrieves the path information (the hierarchy from the root folder) for the specified folder\cr
#'  \link[paws.end.user.computing:workdocs_get_resources]{get_resources} \tab Retrieves a collection of resources, including folders and documents\cr
#'  \link[paws.end.user.computing:workdocs_initiate_document_version_upload]{initiate_document_version_upload} \tab Creates a new document object and version object\cr
#'  \link[paws.end.user.computing:workdocs_remove_all_resource_permissions]{remove_all_resource_permissions} \tab Removes all the permissions from the specified resource\cr
#'  \link[paws.end.user.computing:workdocs_remove_resource_permission]{remove_resource_permission} \tab Removes the permission for the specified principal from the specified resource\cr
#'  \link[paws.end.user.computing:workdocs_restore_document_versions]{restore_document_versions} \tab Recovers a deleted version of an Amazon WorkDocs document\cr
#'  \link[paws.end.user.computing:workdocs_search_resources]{search_resources} \tab Searches metadata and the content of folders, documents, document versions, and comments\cr
#'  \link[paws.end.user.computing:workdocs_update_document]{update_document} \tab Updates the specified attributes of a document\cr
#'  \link[paws.end.user.computing:workdocs_update_document_version]{update_document_version} \tab Changes the status of the document version to ACTIVE\cr
#'  \link[paws.end.user.computing:workdocs_update_folder]{update_folder} \tab Updates the specified attributes of the specified folder\cr
#'  \link[paws.end.user.computing:workdocs_update_user]{update_user} \tab Updates the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname workdocs
#' @export
workdocs <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.end.user.computing::workdocs(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon WorkMail
#'
#' @description
#' WorkMail is a secure, managed business email and calendaring service
#' with support for existing desktop and mobile email clients. You can
#' access your email, contacts, and calendars using Microsoft Outlook, your
#' browser, or other native iOS and Android email applications. You can
#' integrate WorkMail with your existing corporate directory and control
#' both the keys that encrypt your data and the location in which your data
#' is stored.
#' 
#' The WorkMail API is designed for the following scenarios:
#' 
#' -   Listing and describing organizations
#' 
#' 
#' -   Managing users
#' 
#' 
#' -   Managing groups
#' 
#' 
#' -   Managing resources
#' 
#' All WorkMail API operations are Amazon-authenticated and
#' certificate-signed. They not only require the use of the AWS SDK, but
#' also allow for the exclusive use of AWS Identity and Access Management
#' users and roles to help facilitate access, trust, and permission
#' policies. By creating a role and allowing an IAM user to access the
#' WorkMail site, the IAM user gains full administrative visibility into
#' the entire WorkMail organization (or as set in the IAM policy). This
#' includes, but is not limited to, the ability to create, update, and
#' delete users, groups, and resources. This allows developers to perform
#' the scenarios listed above, as well as give users the ability to grant
#' access on a selective basis using the IAM model.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- workmail(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- workmail()
#' svc$associate_delegate_to_resource(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.end.user.computing:workmail_associate_delegate_to_resource]{associate_delegate_to_resource} \tab Adds a member (user or group) to the resource's set of delegates\cr
#'  \link[paws.end.user.computing:workmail_associate_member_to_group]{associate_member_to_group} \tab Adds a member (user or group) to the group's set\cr
#'  \link[paws.end.user.computing:workmail_assume_impersonation_role]{assume_impersonation_role} \tab Assumes an impersonation role for the given WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_cancel_mailbox_export_job]{cancel_mailbox_export_job} \tab Cancels a mailbox export job\cr
#'  \link[paws.end.user.computing:workmail_create_alias]{create_alias} \tab Adds an alias to the set of a given member (user or group) of WorkMail\cr
#'  \link[paws.end.user.computing:workmail_create_availability_configuration]{create_availability_configuration} \tab Creates an AvailabilityConfiguration for the given WorkMail organization and domain\cr
#'  \link[paws.end.user.computing:workmail_create_group]{create_group} \tab Creates a group that can be used in WorkMail by calling the RegisterToWorkMail operation\cr
#'  \link[paws.end.user.computing:workmail_create_identity_center_application]{create_identity_center_application} \tab Creates the WorkMail application in IAM Identity Center that can be used later in the WorkMail - IdC integration\cr
#'  \link[paws.end.user.computing:workmail_create_impersonation_role]{create_impersonation_role} \tab Creates an impersonation role for the given WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_create_mobile_device_access_rule]{create_mobile_device_access_rule} \tab Creates a new mobile device access rule for the specified WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_create_organization]{create_organization} \tab Creates a new WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_create_resource]{create_resource} \tab Creates a new WorkMail resource\cr
#'  \link[paws.end.user.computing:workmail_create_user]{create_user} \tab Creates a user who can be used in WorkMail by calling the RegisterToWorkMail operation\cr
#'  \link[paws.end.user.computing:workmail_delete_access_control_rule]{delete_access_control_rule} \tab Deletes an access control rule for the specified WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_delete_alias]{delete_alias} \tab Remove one or more specified aliases from a set of aliases for a given user\cr
#'  \link[paws.end.user.computing:workmail_delete_availability_configuration]{delete_availability_configuration} \tab Deletes the AvailabilityConfiguration for the given WorkMail organization and domain\cr
#'  \link[paws.end.user.computing:workmail_delete_email_monitoring_configuration]{delete_email_monitoring_configuration} \tab Deletes the email monitoring configuration for a specified organization\cr
#'  \link[paws.end.user.computing:workmail_delete_group]{delete_group} \tab Deletes a group from WorkMail\cr
#'  \link[paws.end.user.computing:workmail_delete_identity_center_application]{delete_identity_center_application} \tab Deletes the IAM Identity Center application from WorkMail\cr
#'  \link[paws.end.user.computing:workmail_delete_identity_provider_configuration]{delete_identity_provider_configuration} \tab Disables the integration between IdC and WorkMail\cr
#'  \link[paws.end.user.computing:workmail_delete_impersonation_role]{delete_impersonation_role} \tab Deletes an impersonation role for the given WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_delete_mailbox_permissions]{delete_mailbox_permissions} \tab Deletes permissions granted to a member (user or group)\cr
#'  \link[paws.end.user.computing:workmail_delete_mobile_device_access_override]{delete_mobile_device_access_override} \tab Deletes the mobile device access override for the given WorkMail organization, user, and device\cr
#'  \link[paws.end.user.computing:workmail_delete_mobile_device_access_rule]{delete_mobile_device_access_rule} \tab Deletes a mobile device access rule for the specified WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_delete_organization]{delete_organization} \tab Deletes an WorkMail organization and all underlying AWS resources managed by WorkMail as part of the organization\cr
#'  \link[paws.end.user.computing:workmail_delete_personal_access_token]{delete_personal_access_token} \tab Deletes the Personal Access Token from the provided WorkMail Organization\cr
#'  \link[paws.end.user.computing:workmail_delete_resource]{delete_resource} \tab Deletes the specified resource\cr
#'  \link[paws.end.user.computing:workmail_delete_retention_policy]{delete_retention_policy} \tab Deletes the specified retention policy from the specified organization\cr
#'  \link[paws.end.user.computing:workmail_delete_user]{delete_user} \tab Deletes a user from WorkMail and all subsequent systems\cr
#'  \link[paws.end.user.computing:workmail_deregister_from_work_mail]{deregister_from_work_mail} \tab Mark a user, group, or resource as no longer used in WorkMail\cr
#'  \link[paws.end.user.computing:workmail_deregister_mail_domain]{deregister_mail_domain} \tab Removes a domain from WorkMail, stops email routing to WorkMail, and removes the authorization allowing WorkMail use\cr
#'  \link[paws.end.user.computing:workmail_describe_email_monitoring_configuration]{describe_email_monitoring_configuration} \tab Describes the current email monitoring configuration for a specified organization\cr
#'  \link[paws.end.user.computing:workmail_describe_entity]{describe_entity} \tab Returns basic details about an entity in WorkMail\cr
#'  \link[paws.end.user.computing:workmail_describe_group]{describe_group} \tab Returns the data available for the group\cr
#'  \link[paws.end.user.computing:workmail_describe_identity_provider_configuration]{describe_identity_provider_configuration} \tab Returns detailed information on the current IdC setup for the WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_describe_inbound_dmarc_settings]{describe_inbound_dmarc_settings} \tab Lists the settings in a DMARC policy for a specified organization\cr
#'  \link[paws.end.user.computing:workmail_describe_mailbox_export_job]{describe_mailbox_export_job} \tab Describes the current status of a mailbox export job\cr
#'  \link[paws.end.user.computing:workmail_describe_organization]{describe_organization} \tab Provides more information regarding a given organization based on its identifier\cr
#'  \link[paws.end.user.computing:workmail_describe_resource]{describe_resource} \tab Returns the data available for the resource\cr
#'  \link[paws.end.user.computing:workmail_describe_user]{describe_user} \tab Provides information regarding the user\cr
#'  \link[paws.end.user.computing:workmail_disassociate_delegate_from_resource]{disassociate_delegate_from_resource} \tab Removes a member from the resource's set of delegates\cr
#'  \link[paws.end.user.computing:workmail_disassociate_member_from_group]{disassociate_member_from_group} \tab Removes a member from a group\cr
#'  \link[paws.end.user.computing:workmail_get_access_control_effect]{get_access_control_effect} \tab Gets the effects of an organization's access control rules as they apply to a specified IPv4 address, access protocol action, and user ID or impersonation role ID\cr
#'  \link[paws.end.user.computing:workmail_get_default_retention_policy]{get_default_retention_policy} \tab Gets the default retention policy details for the specified organization\cr
#'  \link[paws.end.user.computing:workmail_get_impersonation_role]{get_impersonation_role} \tab Gets the impersonation role details for the given WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_get_impersonation_role_effect]{get_impersonation_role_effect} \tab Tests whether the given impersonation role can impersonate a target user\cr
#'  \link[paws.end.user.computing:workmail_get_mailbox_details]{get_mailbox_details} \tab Requests a user's mailbox details for a specified organization and user\cr
#'  \link[paws.end.user.computing:workmail_get_mail_domain]{get_mail_domain} \tab Gets details for a mail domain, including domain records required to configure your domain with recommended security\cr
#'  \link[paws.end.user.computing:workmail_get_mobile_device_access_effect]{get_mobile_device_access_effect} \tab Simulates the effect of the mobile device access rules for the given attributes of a sample access event\cr
#'  \link[paws.end.user.computing:workmail_get_mobile_device_access_override]{get_mobile_device_access_override} \tab Gets the mobile device access override for the given WorkMail organization, user, and device\cr
#'  \link[paws.end.user.computing:workmail_get_personal_access_token_metadata]{get_personal_access_token_metadata} \tab Requests details of a specific Personal Access Token within the WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_list_access_control_rules]{list_access_control_rules} \tab Lists the access control rules for the specified organization\cr
#'  \link[paws.end.user.computing:workmail_list_aliases]{list_aliases} \tab Creates a paginated call to list the aliases associated with a given entity\cr
#'  \link[paws.end.user.computing:workmail_list_availability_configurations]{list_availability_configurations} \tab List all the AvailabilityConfiguration's for the given WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_list_group_members]{list_group_members} \tab Returns an overview of the members of a group\cr
#'  \link[paws.end.user.computing:workmail_list_groups]{list_groups} \tab Returns summaries of the organization's groups\cr
#'  \link[paws.end.user.computing:workmail_list_groups_for_entity]{list_groups_for_entity} \tab Returns all the groups to which an entity belongs\cr
#'  \link[paws.end.user.computing:workmail_list_impersonation_roles]{list_impersonation_roles} \tab Lists all the impersonation roles for the given WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_list_mailbox_export_jobs]{list_mailbox_export_jobs} \tab Lists the mailbox export jobs started for the specified organization within the last seven days\cr
#'  \link[paws.end.user.computing:workmail_list_mailbox_permissions]{list_mailbox_permissions} \tab Lists the mailbox permissions associated with a user, group, or resource mailbox\cr
#'  \link[paws.end.user.computing:workmail_list_mail_domains]{list_mail_domains} \tab Lists the mail domains in a given WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_list_mobile_device_access_overrides]{list_mobile_device_access_overrides} \tab Lists all the mobile device access overrides for any given combination of WorkMail organization, user, or device\cr
#'  \link[paws.end.user.computing:workmail_list_mobile_device_access_rules]{list_mobile_device_access_rules} \tab Lists the mobile device access rules for the specified WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_list_organizations]{list_organizations} \tab Returns summaries of the customer's organizations\cr
#'  \link[paws.end.user.computing:workmail_list_personal_access_tokens]{list_personal_access_tokens} \tab Returns a summary of your Personal Access Tokens\cr
#'  \link[paws.end.user.computing:workmail_list_resource_delegates]{list_resource_delegates} \tab Lists the delegates associated with a resource\cr
#'  \link[paws.end.user.computing:workmail_list_resources]{list_resources} \tab Returns summaries of the organization's resources\cr
#'  \link[paws.end.user.computing:workmail_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags applied to an WorkMail organization resource\cr
#'  \link[paws.end.user.computing:workmail_list_users]{list_users} \tab Returns summaries of the organization's users\cr
#'  \link[paws.end.user.computing:workmail_put_access_control_rule]{put_access_control_rule} \tab Adds a new access control rule for the specified organization\cr
#'  \link[paws.end.user.computing:workmail_put_email_monitoring_configuration]{put_email_monitoring_configuration} \tab Creates or updates the email monitoring configuration for a specified organization\cr
#'  \link[paws.end.user.computing:workmail_put_identity_provider_configuration]{put_identity_provider_configuration} \tab Enables integration between IAM Identity Center (IdC) and WorkMail to proxy authentication requests for mailbox users\cr
#'  \link[paws.end.user.computing:workmail_put_inbound_dmarc_settings]{put_inbound_dmarc_settings} \tab Enables or disables a DMARC policy for a given organization\cr
#'  \link[paws.end.user.computing:workmail_put_mailbox_permissions]{put_mailbox_permissions} \tab Sets permissions for a user, group, or resource\cr
#'  \link[paws.end.user.computing:workmail_put_mobile_device_access_override]{put_mobile_device_access_override} \tab Creates or updates a mobile device access override for the given WorkMail organization, user, and device\cr
#'  \link[paws.end.user.computing:workmail_put_retention_policy]{put_retention_policy} \tab Puts a retention policy to the specified organization\cr
#'  \link[paws.end.user.computing:workmail_register_mail_domain]{register_mail_domain} \tab Registers a new domain in WorkMail and SES, and configures it for use by WorkMail\cr
#'  \link[paws.end.user.computing:workmail_register_to_work_mail]{register_to_work_mail} \tab Registers an existing and disabled user, group, or resource for WorkMail use by associating a mailbox and calendaring capabilities\cr
#'  \link[paws.end.user.computing:workmail_reset_password]{reset_password} \tab Allows the administrator to reset the password for a user\cr
#'  \link[paws.end.user.computing:workmail_start_mailbox_export_job]{start_mailbox_export_job} \tab Starts a mailbox export job to export MIME-format email messages and calendar items from the specified mailbox to the specified Amazon Simple Storage Service (Amazon S3) bucket\cr
#'  \link[paws.end.user.computing:workmail_tag_resource]{tag_resource} \tab Applies the specified tags to the specified WorkMailorganization resource\cr
#'  \link[paws.end.user.computing:workmail_test_availability_configuration]{test_availability_configuration} \tab Performs a test on an availability provider to ensure that access is allowed\cr
#'  \link[paws.end.user.computing:workmail_untag_resource]{untag_resource} \tab Untags the specified tags from the specified WorkMail organization resource\cr
#'  \link[paws.end.user.computing:workmail_update_availability_configuration]{update_availability_configuration} \tab Updates an existing AvailabilityConfiguration for the given WorkMail organization and domain\cr
#'  \link[paws.end.user.computing:workmail_update_default_mail_domain]{update_default_mail_domain} \tab Updates the default mail domain for an organization\cr
#'  \link[paws.end.user.computing:workmail_update_group]{update_group} \tab Updates attributes in a group\cr
#'  \link[paws.end.user.computing:workmail_update_impersonation_role]{update_impersonation_role} \tab Updates an impersonation role for the given WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_update_mailbox_quota]{update_mailbox_quota} \tab Updates a user's current mailbox quota for a specified organization and user\cr
#'  \link[paws.end.user.computing:workmail_update_mobile_device_access_rule]{update_mobile_device_access_rule} \tab Updates a mobile device access rule for the specified WorkMail organization\cr
#'  \link[paws.end.user.computing:workmail_update_primary_email_address]{update_primary_email_address} \tab Updates the primary email for a user, group, or resource\cr
#'  \link[paws.end.user.computing:workmail_update_resource]{update_resource} \tab Updates data for the resource\cr
#'  \link[paws.end.user.computing:workmail_update_user]{update_user} \tab Updates data for the user
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname workmail
#' @export
workmail <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.end.user.computing::workmail(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon WorkMail Message Flow
#'
#' @description
#' The WorkMail Message Flow API provides access to email messages as they
#' are being sent and received by a WorkMail organization.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- workmailmessageflow(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- workmailmessageflow()
#' svc$get_raw_message_content(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.end.user.computing:workmailmessageflow_get_raw_message_content]{get_raw_message_content} \tab Retrieves the raw content of an in-transit email message, in MIME format\cr
#'  \link[paws.end.user.computing:workmailmessageflow_put_raw_message_content]{put_raw_message_content} \tab Updates the raw content of an in-transit email message, in MIME format
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname workmailmessageflow
#' @export
workmailmessageflow <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.end.user.computing::workmailmessageflow(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon WorkSpaces
#'
#' @description
#' Amazon WorkSpaces Service
#' 
#' Amazon WorkSpaces enables you to provision virtual, cloud-based
#' Microsoft Windows or Amazon Linux desktops for your users, known as
#' *WorkSpaces*. WorkSpaces eliminates the need to procure and deploy
#' hardware or install complex software. You can quickly add or remove
#' users as your needs change. Users can access their virtual desktops from
#' multiple devices or web browsers.
#' 
#' This API Reference provides detailed information about the actions, data
#' types, parameters, and errors of the WorkSpaces service. For more
#' information about the supported Amazon Web Services Regions, endpoints,
#' and service quotas of the Amazon WorkSpaces service, see [WorkSpaces
#' endpoints and
#' quotas](https://docs.aws.amazon.com/general/latest/gr/wsp.html) in the
#' *Amazon Web Services General Reference*.
#' 
#' You can also manage your WorkSpaces resources using the WorkSpaces
#' console, Command Line Interface (CLI), and SDKs. For more information
#' about administering WorkSpaces, see the [Amazon WorkSpaces
#' Administration
#' Guide](https://docs.aws.amazon.com/workspaces/latest/adminguide/). For
#' more information about using the Amazon WorkSpaces client application or
#' web browser to access provisioned WorkSpaces, see the [Amazon WorkSpaces
#' User Guide](https://docs.aws.amazon.com/workspaces/latest/userguide/).
#' For more information about using the CLI to manage your WorkSpaces
#' resources, see the [WorkSpaces section of the CLI
#' Reference](https://docs.aws.amazon.com/cli/latest/reference/workspaces/).
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- workspaces(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- workspaces()
#' svc$accept_account_link_invitation(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.end.user.computing:workspaces_accept_account_link_invitation]{accept_account_link_invitation} \tab Accepts the account link invitation\cr
#'  \link[paws.end.user.computing:workspaces_associate_connection_alias]{associate_connection_alias} \tab Associates the specified connection alias with the specified directory to enable cross-Region redirection\cr
#'  \link[paws.end.user.computing:workspaces_associate_ip_groups]{associate_ip_groups} \tab Associates the specified IP access control group with the specified directory\cr
#'  \link[paws.end.user.computing:workspaces_associate_workspace_application]{associate_workspace_application} \tab Associates the specified application to the specified WorkSpace\cr
#'  \link[paws.end.user.computing:workspaces_authorize_ip_rules]{authorize_ip_rules} \tab Adds one or more rules to the specified IP access control group\cr
#'  \link[paws.end.user.computing:workspaces_copy_workspace_image]{copy_workspace_image} \tab Copies the specified image from the specified Region to the current Region\cr
#'  \link[paws.end.user.computing:workspaces_create_account_link_invitation]{create_account_link_invitation} \tab Creates the account link invitation\cr
#'  \link[paws.end.user.computing:workspaces_create_connect_client_add_in]{create_connect_client_add_in} \tab Creates a client-add-in for Amazon Connect within a directory\cr
#'  \link[paws.end.user.computing:workspaces_create_connection_alias]{create_connection_alias} \tab Creates the specified connection alias for use with cross-Region redirection\cr
#'  \link[paws.end.user.computing:workspaces_create_ip_group]{create_ip_group} \tab Creates an IP access control group\cr
#'  \link[paws.end.user.computing:workspaces_create_standby_workspaces]{create_standby_workspaces} \tab Creates a standby WorkSpace in a secondary Region\cr
#'  \link[paws.end.user.computing:workspaces_create_tags]{create_tags} \tab Creates the specified tags for the specified WorkSpaces resource\cr
#'  \link[paws.end.user.computing:workspaces_create_updated_workspace_image]{create_updated_workspace_image} \tab Creates a new updated WorkSpace image based on the specified source image\cr
#'  \link[paws.end.user.computing:workspaces_create_workspace_bundle]{create_workspace_bundle} \tab Creates the specified WorkSpace bundle\cr
#'  \link[paws.end.user.computing:workspaces_create_workspace_image]{create_workspace_image} \tab Creates a new WorkSpace image from an existing WorkSpace\cr
#'  \link[paws.end.user.computing:workspaces_create_workspaces]{create_workspaces} \tab Creates one or more WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_create_workspaces_pool]{create_workspaces_pool} \tab Creates a pool of WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_delete_account_link_invitation]{delete_account_link_invitation} \tab Deletes the account link invitation\cr
#'  \link[paws.end.user.computing:workspaces_delete_client_branding]{delete_client_branding} \tab Deletes customized client branding\cr
#'  \link[paws.end.user.computing:workspaces_delete_connect_client_add_in]{delete_connect_client_add_in} \tab Deletes a client-add-in for Amazon Connect that is configured within a directory\cr
#'  \link[paws.end.user.computing:workspaces_delete_connection_alias]{delete_connection_alias} \tab Deletes the specified connection alias\cr
#'  \link[paws.end.user.computing:workspaces_delete_ip_group]{delete_ip_group} \tab Deletes the specified IP access control group\cr
#'  \link[paws.end.user.computing:workspaces_delete_tags]{delete_tags} \tab Deletes the specified tags from the specified WorkSpaces resource\cr
#'  \link[paws.end.user.computing:workspaces_delete_workspace_bundle]{delete_workspace_bundle} \tab Deletes the specified WorkSpace bundle\cr
#'  \link[paws.end.user.computing:workspaces_delete_workspace_image]{delete_workspace_image} \tab Deletes the specified image from your account\cr
#'  \link[paws.end.user.computing:workspaces_deploy_workspace_applications]{deploy_workspace_applications} \tab Deploys associated applications to the specified WorkSpace\cr
#'  \link[paws.end.user.computing:workspaces_deregister_workspace_directory]{deregister_workspace_directory} \tab Deregisters the specified directory\cr
#'  \link[paws.end.user.computing:workspaces_describe_account]{describe_account} \tab Retrieves a list that describes the configuration of Bring Your Own License (BYOL) for the specified account\cr
#'  \link[paws.end.user.computing:workspaces_describe_account_modifications]{describe_account_modifications} \tab Retrieves a list that describes modifications to the configuration of Bring Your Own License (BYOL) for the specified account\cr
#'  \link[paws.end.user.computing:workspaces_describe_application_associations]{describe_application_associations} \tab Describes the associations between the application and the specified associated resources\cr
#'  \link[paws.end.user.computing:workspaces_describe_applications]{describe_applications} \tab Describes the specified applications by filtering based on their compute types, license availability, operating systems, and owners\cr
#'  \link[paws.end.user.computing:workspaces_describe_bundle_associations]{describe_bundle_associations} \tab Describes the associations between the applications and the specified bundle\cr
#'  \link[paws.end.user.computing:workspaces_describe_client_branding]{describe_client_branding} \tab Describes the specified client branding\cr
#'  \link[paws.end.user.computing:workspaces_describe_client_properties]{describe_client_properties} \tab Retrieves a list that describes one or more specified Amazon WorkSpaces clients\cr
#'  \link[paws.end.user.computing:workspaces_describe_connect_client_add_ins]{describe_connect_client_add_ins} \tab Retrieves a list of Amazon Connect client add-ins that have been created\cr
#'  \link[paws.end.user.computing:workspaces_describe_connection_aliases]{describe_connection_aliases} \tab Retrieves a list that describes the connection aliases used for cross-Region redirection\cr
#'  \link[paws.end.user.computing:workspaces_describe_connection_alias_permissions]{describe_connection_alias_permissions} \tab Describes the permissions that the owner of a connection alias has granted to another Amazon Web Services account for the specified connection alias\cr
#'  \link[paws.end.user.computing:workspaces_describe_image_associations]{describe_image_associations} \tab Describes the associations between the applications and the specified image\cr
#'  \link[paws.end.user.computing:workspaces_describe_ip_groups]{describe_ip_groups} \tab Describes one or more of your IP access control groups\cr
#'  \link[paws.end.user.computing:workspaces_describe_tags]{describe_tags} \tab Describes the specified tags for the specified WorkSpaces resource\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspace_associations]{describe_workspace_associations} \tab Describes the associations betweens applications and the specified WorkSpace\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspace_bundles]{describe_workspace_bundles} \tab Retrieves a list that describes the available WorkSpace bundles\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspace_directories]{describe_workspace_directories} \tab Describes the available directories that are registered with Amazon WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspace_image_permissions]{describe_workspace_image_permissions} \tab Describes the permissions that the owner of an image has granted to other Amazon Web Services accounts for an image\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspace_images]{describe_workspace_images} \tab Retrieves a list that describes one or more specified images, if the image identifiers are provided\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspaces]{describe_workspaces} \tab Describes the specified WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspaces_connection_status]{describe_workspaces_connection_status} \tab Describes the connection status of the specified WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspace_snapshots]{describe_workspace_snapshots} \tab Describes the snapshots for the specified WorkSpace\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspaces_pools]{describe_workspaces_pools} \tab Describes the specified WorkSpaces Pools\cr
#'  \link[paws.end.user.computing:workspaces_describe_workspaces_pool_sessions]{describe_workspaces_pool_sessions} \tab Retrieves a list that describes the streaming sessions for a specified pool\cr
#'  \link[paws.end.user.computing:workspaces_disassociate_connection_alias]{disassociate_connection_alias} \tab Disassociates a connection alias from a directory\cr
#'  \link[paws.end.user.computing:workspaces_disassociate_ip_groups]{disassociate_ip_groups} \tab Disassociates the specified IP access control group from the specified directory\cr
#'  \link[paws.end.user.computing:workspaces_disassociate_workspace_application]{disassociate_workspace_application} \tab Disassociates the specified application from a WorkSpace\cr
#'  \link[paws.end.user.computing:workspaces_get_account_link]{get_account_link} \tab Retrieves account link information\cr
#'  \link[paws.end.user.computing:workspaces_import_client_branding]{import_client_branding} \tab Imports client branding\cr
#'  \link[paws.end.user.computing:workspaces_import_workspace_image]{import_workspace_image} \tab Imports the specified Windows 10 or 11 Bring Your Own License (BYOL) image into Amazon WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_list_account_links]{list_account_links} \tab Lists all account links\cr
#'  \link[paws.end.user.computing:workspaces_list_available_management_cidr_ranges]{list_available_management_cidr_ranges} \tab Retrieves a list of IP address ranges, specified as IPv4 CIDR blocks, that you can use for the network management interface when you enable Bring Your Own License (BYOL)\cr
#'  \link[paws.end.user.computing:workspaces_migrate_workspace]{migrate_workspace} \tab Migrates a WorkSpace from one operating system or bundle type to another, while retaining the data on the user volume\cr
#'  \link[paws.end.user.computing:workspaces_modify_account]{modify_account} \tab Modifies the configuration of Bring Your Own License (BYOL) for the specified account\cr
#'  \link[paws.end.user.computing:workspaces_modify_certificate_based_auth_properties]{modify_certificate_based_auth_properties} \tab Modifies the properties of the certificate-based authentication you want to use with your WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_modify_client_properties]{modify_client_properties} \tab Modifies the properties of the specified Amazon WorkSpaces clients\cr
#'  \link[paws.end.user.computing:workspaces_modify_saml_properties]{modify_saml_properties} \tab Modifies multiple properties related to SAML 2\cr
#'  \link[paws.end.user.computing:workspaces_modify_selfservice_permissions]{modify_selfservice_permissions} \tab Modifies the self-service WorkSpace management capabilities for your users\cr
#'  \link[paws.end.user.computing:workspaces_modify_streaming_properties]{modify_streaming_properties} \tab Modifies the specified streaming properties\cr
#'  \link[paws.end.user.computing:workspaces_modify_workspace_access_properties]{modify_workspace_access_properties} \tab Specifies which devices and operating systems users can use to access their WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_modify_workspace_creation_properties]{modify_workspace_creation_properties} \tab Modify the default properties used to create WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_modify_workspace_properties]{modify_workspace_properties} \tab Modifies the specified WorkSpace properties\cr
#'  \link[paws.end.user.computing:workspaces_modify_workspace_state]{modify_workspace_state} \tab Sets the state of the specified WorkSpace\cr
#'  \link[paws.end.user.computing:workspaces_reboot_workspaces]{reboot_workspaces} \tab Reboots the specified WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_rebuild_workspaces]{rebuild_workspaces} \tab Rebuilds the specified WorkSpace\cr
#'  \link[paws.end.user.computing:workspaces_register_workspace_directory]{register_workspace_directory} \tab Registers the specified directory\cr
#'  \link[paws.end.user.computing:workspaces_reject_account_link_invitation]{reject_account_link_invitation} \tab Rejects the account link invitation\cr
#'  \link[paws.end.user.computing:workspaces_restore_workspace]{restore_workspace} \tab Restores the specified WorkSpace to its last known healthy state\cr
#'  \link[paws.end.user.computing:workspaces_revoke_ip_rules]{revoke_ip_rules} \tab Removes one or more rules from the specified IP access control group\cr
#'  \link[paws.end.user.computing:workspaces_start_workspaces]{start_workspaces} \tab Starts the specified WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_start_workspaces_pool]{start_workspaces_pool} \tab Starts the specified pool\cr
#'  \link[paws.end.user.computing:workspaces_stop_workspaces]{stop_workspaces} \tab Stops the specified WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_stop_workspaces_pool]{stop_workspaces_pool} \tab Stops the specified pool\cr
#'  \link[paws.end.user.computing:workspaces_terminate_workspaces]{terminate_workspaces} \tab Terminates the specified WorkSpaces\cr
#'  \link[paws.end.user.computing:workspaces_terminate_workspaces_pool]{terminate_workspaces_pool} \tab Terminates the specified pool\cr
#'  \link[paws.end.user.computing:workspaces_terminate_workspaces_pool_session]{terminate_workspaces_pool_session} \tab Terminates the pool session\cr
#'  \link[paws.end.user.computing:workspaces_update_connect_client_add_in]{update_connect_client_add_in} \tab Updates a Amazon Connect client add-in\cr
#'  \link[paws.end.user.computing:workspaces_update_connection_alias_permission]{update_connection_alias_permission} \tab Shares or unshares a connection alias with one account by specifying whether that account has permission to associate the connection alias with a directory\cr
#'  \link[paws.end.user.computing:workspaces_update_rules_of_ip_group]{update_rules_of_ip_group} \tab Replaces the current rules of the specified IP access control group with the specified rules\cr
#'  \link[paws.end.user.computing:workspaces_update_workspace_bundle]{update_workspace_bundle} \tab Updates a WorkSpace bundle with a new image\cr
#'  \link[paws.end.user.computing:workspaces_update_workspace_image_permission]{update_workspace_image_permission} \tab Shares or unshares an image with one account in the same Amazon Web Services Region by specifying whether that account has permission to copy the image\cr
#'  \link[paws.end.user.computing:workspaces_update_workspaces_pool]{update_workspaces_pool} \tab Updates the specified pool
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname workspaces
#' @export
workspaces <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.end.user.computing::workspaces(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}

#' Amazon WorkSpaces Web
#'
#' @description
#' Amazon WorkSpaces Secure Browser is a low cost, fully managed WorkSpace
#' built specifically to facilitate secure, web-based workloads. WorkSpaces
#' Secure Browser makes it easy for customers to safely provide their
#' employees with access to internal websites and SaaS web applications
#' without the administrative burden of appliances or specialized client
#' software. WorkSpaces Secure Browser provides simple policy tools
#' tailored for user interactions, while offloading common tasks like
#' capacity management, scaling, and maintaining browser images.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- workspacesweb(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- workspacesweb()
#' svc$associate_browser_settings(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[paws.end.user.computing:workspacesweb_associate_browser_settings]{associate_browser_settings} \tab Associates a browser settings resource with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_associate_data_protection_settings]{associate_data_protection_settings} \tab Associates a data protection settings resource with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_associate_ip_access_settings]{associate_ip_access_settings} \tab Associates an IP access settings resource with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_associate_network_settings]{associate_network_settings} \tab Associates a network settings resource with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_associate_trust_store]{associate_trust_store} \tab Associates a trust store with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_associate_user_access_logging_settings]{associate_user_access_logging_settings} \tab Associates a user access logging settings resource with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_associate_user_settings]{associate_user_settings} \tab Associates a user settings resource with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_browser_settings]{create_browser_settings} \tab Creates a browser settings resource that can be associated with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_data_protection_settings]{create_data_protection_settings} \tab Creates a data protection settings resource that can be associated with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_identity_provider]{create_identity_provider} \tab Creates an identity provider resource that is then associated with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_ip_access_settings]{create_ip_access_settings} \tab Creates an IP access settings resource that can be associated with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_network_settings]{create_network_settings} \tab Creates a network settings resource that can be associated with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_portal]{create_portal} \tab Creates a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_trust_store]{create_trust_store} \tab Creates a trust store that can be associated with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_user_access_logging_settings]{create_user_access_logging_settings} \tab Creates a user access logging settings resource that can be associated with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_create_user_settings]{create_user_settings} \tab Creates a user settings resource that can be associated with a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_browser_settings]{delete_browser_settings} \tab Deletes browser settings\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_data_protection_settings]{delete_data_protection_settings} \tab Deletes data protection settings\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_identity_provider]{delete_identity_provider} \tab Deletes the identity provider\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_ip_access_settings]{delete_ip_access_settings} \tab Deletes IP access settings\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_network_settings]{delete_network_settings} \tab Deletes network settings\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_portal]{delete_portal} \tab Deletes a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_trust_store]{delete_trust_store} \tab Deletes the trust store\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_user_access_logging_settings]{delete_user_access_logging_settings} \tab Deletes user access logging settings\cr
#'  \link[paws.end.user.computing:workspacesweb_delete_user_settings]{delete_user_settings} \tab Deletes user settings\cr
#'  \link[paws.end.user.computing:workspacesweb_disassociate_browser_settings]{disassociate_browser_settings} \tab Disassociates browser settings from a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_disassociate_data_protection_settings]{disassociate_data_protection_settings} \tab Disassociates data protection settings from a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_disassociate_ip_access_settings]{disassociate_ip_access_settings} \tab Disassociates IP access settings from a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_disassociate_network_settings]{disassociate_network_settings} \tab Disassociates network settings from a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_disassociate_trust_store]{disassociate_trust_store} \tab Disassociates a trust store from a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_disassociate_user_access_logging_settings]{disassociate_user_access_logging_settings} \tab Disassociates user access logging settings from a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_disassociate_user_settings]{disassociate_user_settings} \tab Disassociates user settings from a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_expire_session]{expire_session} \tab Expires an active secure browser session\cr
#'  \link[paws.end.user.computing:workspacesweb_get_browser_settings]{get_browser_settings} \tab Gets browser settings\cr
#'  \link[paws.end.user.computing:workspacesweb_get_data_protection_settings]{get_data_protection_settings} \tab Gets the data protection settings\cr
#'  \link[paws.end.user.computing:workspacesweb_get_identity_provider]{get_identity_provider} \tab Gets the identity provider\cr
#'  \link[paws.end.user.computing:workspacesweb_get_ip_access_settings]{get_ip_access_settings} \tab Gets the IP access settings\cr
#'  \link[paws.end.user.computing:workspacesweb_get_network_settings]{get_network_settings} \tab Gets the network settings\cr
#'  \link[paws.end.user.computing:workspacesweb_get_portal]{get_portal} \tab Gets the web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_get_portal_service_provider_metadata]{get_portal_service_provider_metadata} \tab Gets the service provider metadata\cr
#'  \link[paws.end.user.computing:workspacesweb_get_session]{get_session} \tab Gets information for a secure browser session\cr
#'  \link[paws.end.user.computing:workspacesweb_get_trust_store]{get_trust_store} \tab Gets the trust store\cr
#'  \link[paws.end.user.computing:workspacesweb_get_trust_store_certificate]{get_trust_store_certificate} \tab Gets the trust store certificate\cr
#'  \link[paws.end.user.computing:workspacesweb_get_user_access_logging_settings]{get_user_access_logging_settings} \tab Gets user access logging settings\cr
#'  \link[paws.end.user.computing:workspacesweb_get_user_settings]{get_user_settings} \tab Gets user settings\cr
#'  \link[paws.end.user.computing:workspacesweb_list_browser_settings]{list_browser_settings} \tab Retrieves a list of browser settings\cr
#'  \link[paws.end.user.computing:workspacesweb_list_data_protection_settings]{list_data_protection_settings} \tab Retrieves a list of data protection settings\cr
#'  \link[paws.end.user.computing:workspacesweb_list_identity_providers]{list_identity_providers} \tab Retrieves a list of identity providers for a specific web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_list_ip_access_settings]{list_ip_access_settings} \tab Retrieves a list of IP access settings\cr
#'  \link[paws.end.user.computing:workspacesweb_list_network_settings]{list_network_settings} \tab Retrieves a list of network settings\cr
#'  \link[paws.end.user.computing:workspacesweb_list_portals]{list_portals} \tab Retrieves a list or web portals\cr
#'  \link[paws.end.user.computing:workspacesweb_list_sessions]{list_sessions} \tab Lists information for multiple secure browser sessions from a specific portal\cr
#'  \link[paws.end.user.computing:workspacesweb_list_tags_for_resource]{list_tags_for_resource} \tab Retrieves a list of tags for a resource\cr
#'  \link[paws.end.user.computing:workspacesweb_list_trust_store_certificates]{list_trust_store_certificates} \tab Retrieves a list of trust store certificates\cr
#'  \link[paws.end.user.computing:workspacesweb_list_trust_stores]{list_trust_stores} \tab Retrieves a list of trust stores\cr
#'  \link[paws.end.user.computing:workspacesweb_list_user_access_logging_settings]{list_user_access_logging_settings} \tab Retrieves a list of user access logging settings\cr
#'  \link[paws.end.user.computing:workspacesweb_list_user_settings]{list_user_settings} \tab Retrieves a list of user settings\cr
#'  \link[paws.end.user.computing:workspacesweb_tag_resource]{tag_resource} \tab Adds or overwrites one or more tags for the specified resource\cr
#'  \link[paws.end.user.computing:workspacesweb_untag_resource]{untag_resource} \tab Removes one or more tags from the specified resource\cr
#'  \link[paws.end.user.computing:workspacesweb_update_browser_settings]{update_browser_settings} \tab Updates browser settings\cr
#'  \link[paws.end.user.computing:workspacesweb_update_data_protection_settings]{update_data_protection_settings} \tab Updates data protection settings\cr
#'  \link[paws.end.user.computing:workspacesweb_update_identity_provider]{update_identity_provider} \tab Updates the identity provider\cr
#'  \link[paws.end.user.computing:workspacesweb_update_ip_access_settings]{update_ip_access_settings} \tab Updates IP access settings\cr
#'  \link[paws.end.user.computing:workspacesweb_update_network_settings]{update_network_settings} \tab Updates network settings\cr
#'  \link[paws.end.user.computing:workspacesweb_update_portal]{update_portal} \tab Updates a web portal\cr
#'  \link[paws.end.user.computing:workspacesweb_update_trust_store]{update_trust_store} \tab Updates the trust store\cr
#'  \link[paws.end.user.computing:workspacesweb_update_user_access_logging_settings]{update_user_access_logging_settings} \tab Updates the user access logging settings\cr
#'  \link[paws.end.user.computing:workspacesweb_update_user_settings]{update_user_settings} \tab Updates the user settings
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname workspacesweb
#' @export
workspacesweb <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  paws.end.user.computing::workspacesweb(
    config = config,
    credentials = credentials,
    endpoint = endpoint,
    region = region
  )
}
